""" Cisco_IOS_XR_bundlemgr_oper 

This module contains a collection of YANG definitions
for Cisco IOS\-XR bundlemgr package operational data.

This module contains definitions
for the following management objects\:
  lacp\-bundles\: LACP bundle data
  bundle\-information\: bundle information
  lacp\-data\: lacp data
  bundles\: bundles
  lacp\-bundle\-members\: lacp bundle members
  bundles\-adjacency\: bundles adjacency

Copyright (c) 2013\-2016 by Cisco Systems, Inc.
All rights reserved.

"""
from ydk.entity_utils import get_relative_entity_path as _get_relative_entity_path
from ydk.types import Entity, EntityPath, Identity, Enum, YType, YLeaf, YLeafList, YList, LeafDataList, Bits, Empty, Decimal64
from ydk.filters import YFilter
from ydk.errors import YPYError, YPYModelError
from ydk.errors.error_handler import handle_type_error as _handle_type_error


class BmAfId(Enum):
    """
    BmAfId

    Bm af id

    .. data:: bm_af_id_ipv4 = 1136568623

    	IPv4 AFI

    .. data:: bm_af_id_ipv6 = 1136568624

    	IPv6 AFI

    """

    bm_af_id_ipv4 = Enum.YLeaf(1136568623, "bm-af-id-ipv4")

    bm_af_id_ipv6 = Enum.YLeaf(1136568624, "bm-af-id-ipv6")


class BmBdlMacSource(Enum):
    """
    BmBdlMacSource

    Bm bdl mac source

    .. data:: bm_bdl_mac_source_unknown = 0

    	The MAC is currently unknown

    .. data:: bm_bdl_mac_source_chassis = 1

    	The MAC was allocated from the chassis pool

    .. data:: bm_bdl_mac_source_configured = 2

    	The MAC was configured by the user

    .. data:: bm_bdl_mac_source_member = 3

    	The MAC belongs to a member

    .. data:: bm_bdl_mac_source_peer = 4

    	The MAC has come from the peer device

    """

    bm_bdl_mac_source_unknown = Enum.YLeaf(0, "bm-bdl-mac-source-unknown")

    bm_bdl_mac_source_chassis = Enum.YLeaf(1, "bm-bdl-mac-source-chassis")

    bm_bdl_mac_source_configured = Enum.YLeaf(2, "bm-bdl-mac-source-configured")

    bm_bdl_mac_source_member = Enum.YLeaf(3, "bm-bdl-mac-source-member")

    bm_bdl_mac_source_peer = Enum.YLeaf(4, "bm-bdl-mac-source-peer")


class BmBdlState(Enum):
    """
    BmBdlState

    Bm bdl state

    .. data:: bm_bdl_state_admin_down = 0

    	The bundle has been configured Down

    .. data:: bm_bdl_state_down = 1

    	The bundle is Down

    .. data:: bm_bdl_state_client_down = 2

    	The bundle is controlled by CLIENT Down

    .. data:: bm_bdl_state_ptnr_down = 3

    	The bundle is Down on the partner device

    .. data:: bm_bdl_state_bundle_shutdown = 4

    	Bundle shutdown has been configured

    .. data:: bm_bdl_state_pe_isolated = 5

    	The bundle cannot contact the core

    .. data:: bm_bdl_state_nak = 6

    	The state is disputed by a peer device

    .. data:: bm_bdl_state_up_active = 7

    	The bundle is Up

    .. data:: bm_bdl_state_mlacp_hot_standby = 8

    	The bundle is Up, but is mLACP standby

    .. data:: bm_bdl_state_mlacp_cold_standby = 9

    	The bundle is mLACP standby, but will not

    	eliminate traffic loss

    .. data:: bm_bdl_state_unknown = 10

    	The bundle state has not been determined

    .. data:: bm_bdl_state_cold_standby = 11

    	The bundle is standby, but will not eliminate

    	traffic loss

    .. data:: bm_bdl_state_error_disabled = 12

    	The bundle has been error-disabled

    .. data:: bm_bdl_state_efd_disabled = 13

    	The bundle has been disabled by EFD

    """

    bm_bdl_state_admin_down = Enum.YLeaf(0, "bm-bdl-state-admin-down")

    bm_bdl_state_down = Enum.YLeaf(1, "bm-bdl-state-down")

    bm_bdl_state_client_down = Enum.YLeaf(2, "bm-bdl-state-client-down")

    bm_bdl_state_ptnr_down = Enum.YLeaf(3, "bm-bdl-state-ptnr-down")

    bm_bdl_state_bundle_shutdown = Enum.YLeaf(4, "bm-bdl-state-bundle-shutdown")

    bm_bdl_state_pe_isolated = Enum.YLeaf(5, "bm-bdl-state-pe-isolated")

    bm_bdl_state_nak = Enum.YLeaf(6, "bm-bdl-state-nak")

    bm_bdl_state_up_active = Enum.YLeaf(7, "bm-bdl-state-up-active")

    bm_bdl_state_mlacp_hot_standby = Enum.YLeaf(8, "bm-bdl-state-mlacp-hot-standby")

    bm_bdl_state_mlacp_cold_standby = Enum.YLeaf(9, "bm-bdl-state-mlacp-cold-standby")

    bm_bdl_state_unknown = Enum.YLeaf(10, "bm-bdl-state-unknown")

    bm_bdl_state_cold_standby = Enum.YLeaf(11, "bm-bdl-state-cold-standby")

    bm_bdl_state_error_disabled = Enum.YLeaf(12, "bm-bdl-state-error-disabled")

    bm_bdl_state_efd_disabled = Enum.YLeaf(13, "bm-bdl-state-efd-disabled")


class BmFeatureStatus(Enum):
    """
    BmFeatureStatus

    Bm feature status

    .. data:: bm_feature_not_configured = 0

    	No configuration is applied for a feature

    .. data:: bm_feature_not_operational = 1

    	The feature is currently not operational

    .. data:: bm_feature_operational = 2

    	The feature is currently operational

    """

    bm_feature_not_configured = Enum.YLeaf(0, "bm-feature-not-configured")

    bm_feature_not_operational = Enum.YLeaf(1, "bm-feature-not-operational")

    bm_feature_operational = Enum.YLeaf(2, "bm-feature-operational")


class BmMbrStateReason(Enum):
    """
    BmMbrStateReason

    Bm mbr state reason

    .. data:: bm_mbr_state_reason_unknown = 0

    	Reason unavailable (diagnostics error)

    .. data:: bm_mbr_state_reason_unselectable_unknown = 1

    	Link cannot be used (unknown reason)

    .. data:: bm_mbr_state_reason_link_down = 2

    	Link is down

    .. data:: bm_mbr_state_reason_link_deleting = 3

    	Link is being removed from the bundle

    .. data:: bm_mbr_state_reason_creating = 4

    	Link is in the process of being created

    .. data:: bm_mbr_state_reason_bundle_creating = 5

    	Bundle is in the process of being created

    .. data:: bm_mbr_state_reason_bundle_deleting = 6

    	Bundle is in the process of being deleted

    .. data:: bm_mbr_state_reason_bundle_admin_down = 7

    	Bundle has been shut down

    .. data:: bm_mbr_state_reason_replicating = 8

    	Bundle is in the process of being replicated to

    	this location

    .. data:: bm_mbr_state_reason_bandwidth = 9

    	Incompatible with other links in the bundle

    	(bandwidth out of range)

    .. data:: bm_mbr_state_reason_loop_back = 10

    	Loopback: Actor and Partner have the same

    	System ID and Key

    .. data:: bm_mbr_state_reason_activity_type = 11

    	Incompatible with other links in the bundle

    	(LACP vs non-LACP)

    .. data:: bm_mbr_state_reason_bundle_shutdown = 12

    	Bundle shutdown is configured for the bundle

    .. data:: bm_mbr_state_reason_min_selected = 13

    	Not enough links available to meet

    	minimum-active threshold

    .. data:: bm_mbr_state_reason_max_selected = 14

    	Link is Standby due to maximum-active links

    	configuration

    .. data:: bm_mbr_state_reason_link_limit = 15

    	Bundle has too many member links configured

    .. data:: bm_mbr_state_reason_active_limit = 16

    	Bundle has reached maximum supported number of

    	active links

    .. data:: bm_mbr_state_reason_standby_unknown = 17

    	Link is Standby (unknown reason)

    .. data:: bm_mbr_state_reason_expired = 18

    	Link is Expired; LACPDUs are not being received

    	from the partner

    .. data:: bm_mbr_state_reason_defaulted = 19

    	Link is Defaulted; LACPDUs are not being

    	received from the partner

    .. data:: bm_mbr_state_reason_act_or_not_agg = 20

    	Link is Not Aggregatable (unknown reason)

    .. data:: bm_mbr_state_reason_partner_not_agg = 21

    	Partner has marked the link as Not Aggregatable

    .. data:: bm_mbr_state_reason_lagid = 22

    	Partner System ID/Key do not match that of the

    	Selected links

    .. data:: bm_mbr_state_reason_bundle_not_cfgd = 23

    	Bundle interface is not present in

    	configuration

    .. data:: bm_mbr_state_reason_bundle_not_ready = 24

    	Wait-while timer is running

    .. data:: bm_mbr_state_reason_partner_ood = 25

    	Partner has not echoed the correct parameters

    	for this link

    .. data:: bm_mbr_state_reason_partner_not_in_sync = 26

    	Partner is not Synchronized (Waiting, Standby,

    	or LAG ID mismatch)

    .. data:: bm_mbr_state_reason_foreign_partner_oos = 27

    	Partner is not Synchronized (Waiting, not

    	Selected, or out-of-date)

    .. data:: bm_mbr_state_reason_attach_unknown = 28

    	Link is Attached and has not gone Collecting

    	(unknown reason)

    .. data:: bm_mbr_state_reason_partner_not_collecting = 29

    	Partner has not advertized that it is

    	Collecting

    .. data:: bm_mbr_state_reason_collect_unknown = 30

    	Link is Collecting and has not gone

    	Distributing (unknown reason)

    .. data:: bm_mbr_state_reason_standby_foreign = 31

    	Link is marked as Standby by mLACP peer

    .. data:: bm_mbr_state_reason_bfd_starting = 32

    	Link is waiting for BFD session to start

    .. data:: bm_mbr_state_reason_bfd_down = 33

    	BFD state of this link is Down

    .. data:: bm_mbr_state_reason_bfd_nbr_unconfig = 34

    	BFD session is unconfigured on the remote end

    .. data:: bm_mbr_state_reason_mlacp = 35

    	Link is not operational as a result of mLACP

    	negotiations

    .. data:: bm_mbr_state_reason_pe_isolated = 36

    	ICCP group is isolated from the core network

    .. data:: bm_mbr_state_reason_forced_switchover = 37

    	Forced switchover to the mLACP peer

    .. data:: bm_mbr_state_reason_errdis_unknown = 38

    	Link is error disabled (unknown reason)

    .. data:: bm_mbr_state_reason_mlacp_no_mbr_state_info = 39

    	Waiting for member state information from mLACP

    	peer

    .. data:: bm_mbr_state_reason_active = 40

    	Link is Active

    .. data:: bm_mbr_state_reason_mlacp_no_bdl_state_info = 41

    	Waiting for bundle state information from mLACP

    	peer

    .. data:: bm_mbr_state_reason_mlacp_no_bdl_config_info = 42

    	Waiting for bundle configuration information

    	from mLACP peer

    .. data:: bm_mbr_state_reason_mlacp_no_bdl_sync = 43

    	Waiting for bundle to complete initial

    	synchronization with mLACP peer

    .. data:: bm_mbr_state_reason_mlacp_bdl_has_no_peer = 44

    	mLACP bundle does not have a peer device

    .. data:: bm_mbr_state_reason_mlacp_nak = 45

    	Link is being ignored due to an inconsistency

    	with mLACP peer

    .. data:: bm_mbr_state_reason_mlacp_transport_unavailable = 46

    	ICCP transport is unavailable

    .. data:: bm_mbr_state_reason_mlacp_not_configured = 47

    	ICCP Group is not fully configured

    .. data:: bm_mbr_state_reason_recovery_timer = 48

    	mLACP recovery delay timer is running

    .. data:: bm_mbr_state_reason_mlacp_standby = 49

    	mLACP peer is active

    .. data:: bm_mbr_state_reason_maximized_out = 50

    	mLACP peer has more links/bandwidth available

    .. data:: bm_mbr_state_reason_mlacp_peer_selected = 51

    	mLACP peer has one or more links Selected

    .. data:: bm_mbr_state_reason_mlacp_connect_timer_running = 52

    	mLACP bundle does not have a peer device

    	(connect timer running)

    .. data:: bm_mbr_state_reason_bundle_not_mlacp = 53

    	Bundle is not configured to run mLACP

    .. data:: bm_mbr_state_reason_no_lon = 54

    	Bundle has too many working links configured

    	(more than the maximum-active limit)

    .. data:: bm_mbr_state_reason_cumul_rel_bw_limit = 55

    	Additional bandwidth from link would exceed

    	load balancing capabilities

    .. data:: bm_mbr_state_reason_no_mac = 56

    	No MAC address available for the bundle

    .. data:: bm_mbr_state_reason_no_system_id = 57

    	No system ID available for use by this bundle

    .. data:: bm_mbr_state_reason_link_shutdown = 58

    	Link is shutdown

    .. data:: bm_mbr_state_reason_activity_mlacp = 59

    	Non-LACP link in mLACP bundle

    .. data:: bm_mbr_state_reason_activity_iccp = 60

    	LACP link in inter-chassis bundle

    .. data:: bm_mbr_state_reason_bundle_icpe_mlacp = 61

    	Parent bundle is both inter-chassis and

    	configured for mLACP

    .. data:: bm_mbr_state_reason_no_link_num = 62

    	Too many bundle members in system; no link

    	number available

    .. data:: bm_mbr_state_reason_standby_peer_higher_prio = 63

    	mLACP peer has a higher priority link

    .. data:: bm_mbr_state_reason_red_state_standby = 64

    	Link is in standby redundancy state

    .. data:: bm_mbr_state_reason_other_red_state_standby = 65

    	One or more links in the bundle are in standby

    	redundancy state

    .. data:: bm_mbr_state_reason_hold_ing = 66

    	Holding down temporary to avoid churn after

    	restart

    .. data:: bm_mbr_state_reason_bundle_error_disabled = 67

    	Bundle has been error-disabled

    .. data:: bm_mbr_state_reason_bundle_efd_disabled = 68

    	Bundle has been disabled by EFD

    .. data:: bm_mbr_state_reason_singleton_pe_isolated = 69

    	Singleton ICCP group is isolated from the core

    	network

    .. data:: bm_mbr_state_reason_bfd_ipv6_starting = 70

    	Link is waiting for BFDv6 session to start

    .. data:: bm_mbr_state_reason_bfd_ipv6_down = 71

    	BFDv6 state of this link is Down

    .. data:: bm_mbr_state_reason_bfd_ipv6_nbr_unconfig = 72

    	BFDv6 session is unconfigured on the remote end

    .. data:: bm_mbr_state_reason_timer_running = 73

    	LACP delay timer is running

    .. data:: bm_mbr_state_reason_client_bundle_ctrl = 74

    	Client has configured the bundle state Down

    .. data:: bm_mbr_state_reason_count = 75

    	Enumeration maximum value

    """

    bm_mbr_state_reason_unknown = Enum.YLeaf(0, "bm-mbr-state-reason-unknown")

    bm_mbr_state_reason_unselectable_unknown = Enum.YLeaf(1, "bm-mbr-state-reason-unselectable-unknown")

    bm_mbr_state_reason_link_down = Enum.YLeaf(2, "bm-mbr-state-reason-link-down")

    bm_mbr_state_reason_link_deleting = Enum.YLeaf(3, "bm-mbr-state-reason-link-deleting")

    bm_mbr_state_reason_creating = Enum.YLeaf(4, "bm-mbr-state-reason-creating")

    bm_mbr_state_reason_bundle_creating = Enum.YLeaf(5, "bm-mbr-state-reason-bundle-creating")

    bm_mbr_state_reason_bundle_deleting = Enum.YLeaf(6, "bm-mbr-state-reason-bundle-deleting")

    bm_mbr_state_reason_bundle_admin_down = Enum.YLeaf(7, "bm-mbr-state-reason-bundle-admin-down")

    bm_mbr_state_reason_replicating = Enum.YLeaf(8, "bm-mbr-state-reason-replicating")

    bm_mbr_state_reason_bandwidth = Enum.YLeaf(9, "bm-mbr-state-reason-bandwidth")

    bm_mbr_state_reason_loop_back = Enum.YLeaf(10, "bm-mbr-state-reason-loop-back")

    bm_mbr_state_reason_activity_type = Enum.YLeaf(11, "bm-mbr-state-reason-activity-type")

    bm_mbr_state_reason_bundle_shutdown = Enum.YLeaf(12, "bm-mbr-state-reason-bundle-shutdown")

    bm_mbr_state_reason_min_selected = Enum.YLeaf(13, "bm-mbr-state-reason-min-selected")

    bm_mbr_state_reason_max_selected = Enum.YLeaf(14, "bm-mbr-state-reason-max-selected")

    bm_mbr_state_reason_link_limit = Enum.YLeaf(15, "bm-mbr-state-reason-link-limit")

    bm_mbr_state_reason_active_limit = Enum.YLeaf(16, "bm-mbr-state-reason-active-limit")

    bm_mbr_state_reason_standby_unknown = Enum.YLeaf(17, "bm-mbr-state-reason-standby-unknown")

    bm_mbr_state_reason_expired = Enum.YLeaf(18, "bm-mbr-state-reason-expired")

    bm_mbr_state_reason_defaulted = Enum.YLeaf(19, "bm-mbr-state-reason-defaulted")

    bm_mbr_state_reason_act_or_not_agg = Enum.YLeaf(20, "bm-mbr-state-reason-act-or-not-agg")

    bm_mbr_state_reason_partner_not_agg = Enum.YLeaf(21, "bm-mbr-state-reason-partner-not-agg")

    bm_mbr_state_reason_lagid = Enum.YLeaf(22, "bm-mbr-state-reason-lagid")

    bm_mbr_state_reason_bundle_not_cfgd = Enum.YLeaf(23, "bm-mbr-state-reason-bundle-not-cfgd")

    bm_mbr_state_reason_bundle_not_ready = Enum.YLeaf(24, "bm-mbr-state-reason-bundle-not-ready")

    bm_mbr_state_reason_partner_ood = Enum.YLeaf(25, "bm-mbr-state-reason-partner-ood")

    bm_mbr_state_reason_partner_not_in_sync = Enum.YLeaf(26, "bm-mbr-state-reason-partner-not-in-sync")

    bm_mbr_state_reason_foreign_partner_oos = Enum.YLeaf(27, "bm-mbr-state-reason-foreign-partner-oos")

    bm_mbr_state_reason_attach_unknown = Enum.YLeaf(28, "bm-mbr-state-reason-attach-unknown")

    bm_mbr_state_reason_partner_not_collecting = Enum.YLeaf(29, "bm-mbr-state-reason-partner-not-collecting")

    bm_mbr_state_reason_collect_unknown = Enum.YLeaf(30, "bm-mbr-state-reason-collect-unknown")

    bm_mbr_state_reason_standby_foreign = Enum.YLeaf(31, "bm-mbr-state-reason-standby-foreign")

    bm_mbr_state_reason_bfd_starting = Enum.YLeaf(32, "bm-mbr-state-reason-bfd-starting")

    bm_mbr_state_reason_bfd_down = Enum.YLeaf(33, "bm-mbr-state-reason-bfd-down")

    bm_mbr_state_reason_bfd_nbr_unconfig = Enum.YLeaf(34, "bm-mbr-state-reason-bfd-nbr-unconfig")

    bm_mbr_state_reason_mlacp = Enum.YLeaf(35, "bm-mbr-state-reason-mlacp")

    bm_mbr_state_reason_pe_isolated = Enum.YLeaf(36, "bm-mbr-state-reason-pe-isolated")

    bm_mbr_state_reason_forced_switchover = Enum.YLeaf(37, "bm-mbr-state-reason-forced-switchover")

    bm_mbr_state_reason_errdis_unknown = Enum.YLeaf(38, "bm-mbr-state-reason-errdis-unknown")

    bm_mbr_state_reason_mlacp_no_mbr_state_info = Enum.YLeaf(39, "bm-mbr-state-reason-mlacp-no-mbr-state-info")

    bm_mbr_state_reason_active = Enum.YLeaf(40, "bm-mbr-state-reason-active")

    bm_mbr_state_reason_mlacp_no_bdl_state_info = Enum.YLeaf(41, "bm-mbr-state-reason-mlacp-no-bdl-state-info")

    bm_mbr_state_reason_mlacp_no_bdl_config_info = Enum.YLeaf(42, "bm-mbr-state-reason-mlacp-no-bdl-config-info")

    bm_mbr_state_reason_mlacp_no_bdl_sync = Enum.YLeaf(43, "bm-mbr-state-reason-mlacp-no-bdl-sync")

    bm_mbr_state_reason_mlacp_bdl_has_no_peer = Enum.YLeaf(44, "bm-mbr-state-reason-mlacp-bdl-has-no-peer")

    bm_mbr_state_reason_mlacp_nak = Enum.YLeaf(45, "bm-mbr-state-reason-mlacp-nak")

    bm_mbr_state_reason_mlacp_transport_unavailable = Enum.YLeaf(46, "bm-mbr-state-reason-mlacp-transport-unavailable")

    bm_mbr_state_reason_mlacp_not_configured = Enum.YLeaf(47, "bm-mbr-state-reason-mlacp-not-configured")

    bm_mbr_state_reason_recovery_timer = Enum.YLeaf(48, "bm-mbr-state-reason-recovery-timer")

    bm_mbr_state_reason_mlacp_standby = Enum.YLeaf(49, "bm-mbr-state-reason-mlacp-standby")

    bm_mbr_state_reason_maximized_out = Enum.YLeaf(50, "bm-mbr-state-reason-maximized-out")

    bm_mbr_state_reason_mlacp_peer_selected = Enum.YLeaf(51, "bm-mbr-state-reason-mlacp-peer-selected")

    bm_mbr_state_reason_mlacp_connect_timer_running = Enum.YLeaf(52, "bm-mbr-state-reason-mlacp-connect-timer-running")

    bm_mbr_state_reason_bundle_not_mlacp = Enum.YLeaf(53, "bm-mbr-state-reason-bundle-not-mlacp")

    bm_mbr_state_reason_no_lon = Enum.YLeaf(54, "bm-mbr-state-reason-no-lon")

    bm_mbr_state_reason_cumul_rel_bw_limit = Enum.YLeaf(55, "bm-mbr-state-reason-cumul-rel-bw-limit")

    bm_mbr_state_reason_no_mac = Enum.YLeaf(56, "bm-mbr-state-reason-no-mac")

    bm_mbr_state_reason_no_system_id = Enum.YLeaf(57, "bm-mbr-state-reason-no-system-id")

    bm_mbr_state_reason_link_shutdown = Enum.YLeaf(58, "bm-mbr-state-reason-link-shutdown")

    bm_mbr_state_reason_activity_mlacp = Enum.YLeaf(59, "bm-mbr-state-reason-activity-mlacp")

    bm_mbr_state_reason_activity_iccp = Enum.YLeaf(60, "bm-mbr-state-reason-activity-iccp")

    bm_mbr_state_reason_bundle_icpe_mlacp = Enum.YLeaf(61, "bm-mbr-state-reason-bundle-icpe-mlacp")

    bm_mbr_state_reason_no_link_num = Enum.YLeaf(62, "bm-mbr-state-reason-no-link-num")

    bm_mbr_state_reason_standby_peer_higher_prio = Enum.YLeaf(63, "bm-mbr-state-reason-standby-peer-higher-prio")

    bm_mbr_state_reason_red_state_standby = Enum.YLeaf(64, "bm-mbr-state-reason-red-state-standby")

    bm_mbr_state_reason_other_red_state_standby = Enum.YLeaf(65, "bm-mbr-state-reason-other-red-state-standby")

    bm_mbr_state_reason_hold_ing = Enum.YLeaf(66, "bm-mbr-state-reason-hold-ing")

    bm_mbr_state_reason_bundle_error_disabled = Enum.YLeaf(67, "bm-mbr-state-reason-bundle-error-disabled")

    bm_mbr_state_reason_bundle_efd_disabled = Enum.YLeaf(68, "bm-mbr-state-reason-bundle-efd-disabled")

    bm_mbr_state_reason_singleton_pe_isolated = Enum.YLeaf(69, "bm-mbr-state-reason-singleton-pe-isolated")

    bm_mbr_state_reason_bfd_ipv6_starting = Enum.YLeaf(70, "bm-mbr-state-reason-bfd-ipv6-starting")

    bm_mbr_state_reason_bfd_ipv6_down = Enum.YLeaf(71, "bm-mbr-state-reason-bfd-ipv6-down")

    bm_mbr_state_reason_bfd_ipv6_nbr_unconfig = Enum.YLeaf(72, "bm-mbr-state-reason-bfd-ipv6-nbr-unconfig")

    bm_mbr_state_reason_timer_running = Enum.YLeaf(73, "bm-mbr-state-reason-timer-running")

    bm_mbr_state_reason_client_bundle_ctrl = Enum.YLeaf(74, "bm-mbr-state-reason-client-bundle-ctrl")

    bm_mbr_state_reason_count = Enum.YLeaf(75, "bm-mbr-state-reason-count")


class BmMuxreason(Enum):
    """
    BmMuxreason

    Bm muxreason

    .. data:: bm_mux_reason_no_reason = 0

    	Selection logic has not yet been run for the

    	bundle this link is a member of

    .. data:: bm_mux_reason_link_down = 1

    	Link is down

    .. data:: bm_mux_reason_link_deleted = 2

    	Link is being removed from the bundle

    .. data:: bm_mux_reason_duplex = 3

    	Link has wrong duplexity

    .. data:: bm_mux_reason_bandwidth = 4

    	Link has wrong bandwidth

    .. data:: bm_mux_reason_loop_back = 5

    	Link is a loopback interface

    .. data:: bm_mux_reason_activity_type = 6

    	Link has wrong activity type

    .. data:: bm_mux_reason_link_limit = 7

    	Link's bundle already has maximum number of

    	members allowed

    .. data:: bm_mux_reason_shared = 8

    	Link is attached to a shared medium

    .. data:: bm_mux_reason_lagid = 9

    	Link has wrong LAG ID

    .. data:: bm_mux_reason_no_bundle = 10

    	Link's bundle does not exist

    .. data:: bm_mux_reason_no_primary = 11

    	Link's bundle has no primary link

    .. data:: bm_mux_reason_bundle_down = 12

    	Link's bundle is shut down

    .. data:: bm_mux_reason_individual = 13

    	Link is marked individual by partner

    .. data:: bm_mux_reason_defaulted = 14

    	Link is Defaulted, suggesting it is not

    	receiving LACPDUs from the peer

    .. data:: bm_mux_reason_in_sync = 15

    	Link is in InSync state

    .. data:: bm_mux_reason_collecting = 16

    	Link is in Collecting state

    .. data:: bm_mux_reason_active_link_limit = 17

    	Link exceeds maximum active limit

    .. data:: bm_mux_reason_distributing = 18

    	Link is in Distributing state

    .. data:: bm_mux_reason_count = 19

    	Enumeration maximum value

    """

    bm_mux_reason_no_reason = Enum.YLeaf(0, "bm-mux-reason-no-reason")

    bm_mux_reason_link_down = Enum.YLeaf(1, "bm-mux-reason-link-down")

    bm_mux_reason_link_deleted = Enum.YLeaf(2, "bm-mux-reason-link-deleted")

    bm_mux_reason_duplex = Enum.YLeaf(3, "bm-mux-reason-duplex")

    bm_mux_reason_bandwidth = Enum.YLeaf(4, "bm-mux-reason-bandwidth")

    bm_mux_reason_loop_back = Enum.YLeaf(5, "bm-mux-reason-loop-back")

    bm_mux_reason_activity_type = Enum.YLeaf(6, "bm-mux-reason-activity-type")

    bm_mux_reason_link_limit = Enum.YLeaf(7, "bm-mux-reason-link-limit")

    bm_mux_reason_shared = Enum.YLeaf(8, "bm-mux-reason-shared")

    bm_mux_reason_lagid = Enum.YLeaf(9, "bm-mux-reason-lagid")

    bm_mux_reason_no_bundle = Enum.YLeaf(10, "bm-mux-reason-no-bundle")

    bm_mux_reason_no_primary = Enum.YLeaf(11, "bm-mux-reason-no-primary")

    bm_mux_reason_bundle_down = Enum.YLeaf(12, "bm-mux-reason-bundle-down")

    bm_mux_reason_individual = Enum.YLeaf(13, "bm-mux-reason-individual")

    bm_mux_reason_defaulted = Enum.YLeaf(14, "bm-mux-reason-defaulted")

    bm_mux_reason_in_sync = Enum.YLeaf(15, "bm-mux-reason-in-sync")

    bm_mux_reason_collecting = Enum.YLeaf(16, "bm-mux-reason-collecting")

    bm_mux_reason_active_link_limit = Enum.YLeaf(17, "bm-mux-reason-active-link-limit")

    bm_mux_reason_distributing = Enum.YLeaf(18, "bm-mux-reason-distributing")

    bm_mux_reason_count = Enum.YLeaf(19, "bm-mux-reason-count")


class BmMuxstate(Enum):
    """
    BmMuxstate

    Bm muxstate

    .. data:: detached = 1

    	Port is not attached to a bundle

    .. data:: waiting = 2

    	Port has chosen bundle and is waiting to join

    .. data:: attached = 3

    	Port is attached to the bundle but not active

    .. data:: collecting = 4

    	Port is ready to receive data

    .. data:: distributing = 5

    	Port is distributing data

    .. data:: collecting_distributing = 6

    	Port is active and can send and receive data

    """

    detached = Enum.YLeaf(1, "detached")

    waiting = Enum.YLeaf(2, "waiting")

    attached = Enum.YLeaf(3, "attached")

    collecting = Enum.YLeaf(4, "collecting")

    distributing = Enum.YLeaf(5, "distributing")

    collecting_distributing = Enum.YLeaf(6, "collecting-distributing")


class BmSeverity(Enum):
    """
    BmSeverity

    Severity of the member state reason

    .. data:: ok = 0

    	OK

    .. data:: information = 1

    	Information

    .. data:: misconfiguration = 2

    	Misconfiguration

    .. data:: warning = 3

    	Warning

    .. data:: error = 5

    	Error

    """

    ok = Enum.YLeaf(0, "ok")

    information = Enum.YLeaf(1, "information")

    misconfiguration = Enum.YLeaf(2, "misconfiguration")

    warning = Enum.YLeaf(3, "warning")

    error = Enum.YLeaf(5, "error")


class BmStateReasonTarget(Enum):
    """
    BmStateReasonTarget

    Scope of the state reason

    .. data:: member_reason = 0

    	Member applicable reason

    .. data:: bundle_reason = 1

    	Bundle applicable reason

    """

    member_reason = Enum.YLeaf(0, "member-reason")

    bundle_reason = Enum.YLeaf(1, "bundle-reason")


class BmWhichSystem(Enum):
    """
    BmWhichSystem

    Bm which system

    .. data:: bm_which_system_actr = 0

    	Actor

    .. data:: bm_which_system_ptnr = 1

    	Partner

    """

    bm_which_system_actr = Enum.YLeaf(0, "bm-which-system-actr")

    bm_which_system_ptnr = Enum.YLeaf(1, "bm-which-system-ptnr")


class BmdBagEventBdlItem(Enum):
    """
    BmdBagEventBdlItem

    Description of an event for a bundle

    .. data:: bmd_event_bdl_idb_create = 0

    	Bundle structure created

    .. data:: bmd_event_bdl_configured = 1

    	Bundle configured by user

    .. data:: bmd_event_bdl_im_state = 2

    	Bundle's IM state changed

    .. data:: bmd_event_bdl_mbr_added = 3

    	Member added to the bundle

    .. data:: bmd_event_bdl_mbr_deleted = 4

    	Member removed from the bundle

    .. data:: bmd_event_bdl_mac_addr = 5

    	Bundle's MAC address changed

    .. data:: bmd_event_bdl_first_retry = 6

    	First retry

    .. data:: bmd_event_bdl_user_config = 7

    	User changed the configuration

    .. data:: bmd_event_bdl_error = 8

    	Last error

    .. data:: bmd_event_bdl_mlacp_tlv = 9

    	mLACP TLV received

    .. data:: bmd_event_bdl_redundancy_role = 10

    	redundancy role change

    .. data:: bdl_bfd_state_change = 11

    	BFD state change

    .. data:: bmd_event_bdl_icl = 12

    	Inter-chassis link mode changed

    .. data:: bmd_event_bdl_count = 13

    	Number of bundle events

    """

    bmd_event_bdl_idb_create = Enum.YLeaf(0, "bmd-event-bdl-idb-create")

    bmd_event_bdl_configured = Enum.YLeaf(1, "bmd-event-bdl-configured")

    bmd_event_bdl_im_state = Enum.YLeaf(2, "bmd-event-bdl-im-state")

    bmd_event_bdl_mbr_added = Enum.YLeaf(3, "bmd-event-bdl-mbr-added")

    bmd_event_bdl_mbr_deleted = Enum.YLeaf(4, "bmd-event-bdl-mbr-deleted")

    bmd_event_bdl_mac_addr = Enum.YLeaf(5, "bmd-event-bdl-mac-addr")

    bmd_event_bdl_first_retry = Enum.YLeaf(6, "bmd-event-bdl-first-retry")

    bmd_event_bdl_user_config = Enum.YLeaf(7, "bmd-event-bdl-user-config")

    bmd_event_bdl_error = Enum.YLeaf(8, "bmd-event-bdl-error")

    bmd_event_bdl_mlacp_tlv = Enum.YLeaf(9, "bmd-event-bdl-mlacp-tlv")

    bmd_event_bdl_redundancy_role = Enum.YLeaf(10, "bmd-event-bdl-redundancy-role")

    bdl_bfd_state_change = Enum.YLeaf(11, "bdl-bfd-state-change")

    bmd_event_bdl_icl = Enum.YLeaf(12, "bmd-event-bdl-icl")

    bmd_event_bdl_count = Enum.YLeaf(13, "bmd-event-bdl-count")


class BmdBagEventData(Enum):
    """
    BmdBagEventData

    Type of additional info for an event

    .. data:: bmd_bag_evt_data_none = 0

    	No additional data

    .. data:: bmd_bag_evt_data_error = 1

    	Additional data is an error code

    .. data:: bmd_bag_evt_data_string = 2

    	Additional data is a string

    """

    bmd_bag_evt_data_none = Enum.YLeaf(0, "bmd-bag-evt-data-none")

    bmd_bag_evt_data_error = Enum.YLeaf(1, "bmd-bag-evt-data-error")

    bmd_bag_evt_data_string = Enum.YLeaf(2, "bmd-bag-evt-data-string")


class BmdBagEventMbrItem(Enum):
    """
    BmdBagEventMbrItem

    Description of an event for a member

    .. data:: bmd_event_mbr_idb_create = 0

    	Member structure created

    .. data:: bmd_event_mbr_bdl_add = 1

    	Added to bundle

    .. data:: bmd_event_mbr_im_state = 2

    	Member's IM state changed

    .. data:: bmd_event_mbr_sel_logic = 3

    	Sel logic state changed

    .. data:: bmd_event_mbr_mux = 4

    	Mux state changed

    .. data:: bmd_event_mbr_bfd = 5

    	BFD state changed

    .. data:: bmd_event_mbr_expired = 6

    	Expired

    .. data:: bmd_event_mbr_defaulted = 7

    	Defaulted

    .. data:: bmd_event_mbr_first_retry = 8

    	First retry

    .. data:: bmd_event_mbr_msg = 9

    	Message from BML

    .. data:: bmd_event_mbr_error = 10

    	Last error

    .. data:: bmd_event_mbr_mlacp_tlv = 11

    	mLACP TLV received

    .. data:: bmd_event_mbr_redundancy_role = 12

    	redundancy role change

    .. data:: bmd_event_mbr_count = 13

    	Number of member events

    """

    bmd_event_mbr_idb_create = Enum.YLeaf(0, "bmd-event-mbr-idb-create")

    bmd_event_mbr_bdl_add = Enum.YLeaf(1, "bmd-event-mbr-bdl-add")

    bmd_event_mbr_im_state = Enum.YLeaf(2, "bmd-event-mbr-im-state")

    bmd_event_mbr_sel_logic = Enum.YLeaf(3, "bmd-event-mbr-sel-logic")

    bmd_event_mbr_mux = Enum.YLeaf(4, "bmd-event-mbr-mux")

    bmd_event_mbr_bfd = Enum.YLeaf(5, "bmd-event-mbr-bfd")

    bmd_event_mbr_expired = Enum.YLeaf(6, "bmd-event-mbr-expired")

    bmd_event_mbr_defaulted = Enum.YLeaf(7, "bmd-event-mbr-defaulted")

    bmd_event_mbr_first_retry = Enum.YLeaf(8, "bmd-event-mbr-first-retry")

    bmd_event_mbr_msg = Enum.YLeaf(9, "bmd-event-mbr-msg")

    bmd_event_mbr_error = Enum.YLeaf(10, "bmd-event-mbr-error")

    bmd_event_mbr_mlacp_tlv = Enum.YLeaf(11, "bmd-event-mbr-mlacp-tlv")

    bmd_event_mbr_redundancy_role = Enum.YLeaf(12, "bmd-event-mbr-redundancy-role")

    bmd_event_mbr_count = Enum.YLeaf(13, "bmd-event-mbr-count")


class BmdBagEventRgItem(Enum):
    """
    BmdBagEventRgItem

    Description of an event for a RG

    .. data:: bmd_event_rg_idb_create = 0

    	RG structure created

    .. data:: bmd_event_rg_configured = 1

    	RG configured by user

    .. data:: bmd_event_rg_user_config = 2

    	User changed the configuration

    .. data:: bmd_event_rg_connect_ion = 3

    	Connection to peer

    .. data:: bmd_event_rg_data = 4

    	Data received

    .. data:: bmd_event_rg_sync = 5

    	Sync performed

    .. data:: bmd_event_rg_first_retry = 6

    	First retry

    .. data:: bmd_event_rg_error = 7

    	Last error

    .. data:: bmd_event_rg_mlacp_tlv = 8

    	mLACP TLV received

    .. data:: bmd_event_rg_iccp_event = 9

    	ICCP event received

    .. data:: bmd_event_rg_count = 10

    	Number of RG events

    """

    bmd_event_rg_idb_create = Enum.YLeaf(0, "bmd-event-rg-idb-create")

    bmd_event_rg_configured = Enum.YLeaf(1, "bmd-event-rg-configured")

    bmd_event_rg_user_config = Enum.YLeaf(2, "bmd-event-rg-user-config")

    bmd_event_rg_connect_ion = Enum.YLeaf(3, "bmd-event-rg-connect-ion")

    bmd_event_rg_data = Enum.YLeaf(4, "bmd-event-rg-data")

    bmd_event_rg_sync = Enum.YLeaf(5, "bmd-event-rg-sync")

    bmd_event_rg_first_retry = Enum.YLeaf(6, "bmd-event-rg-first-retry")

    bmd_event_rg_error = Enum.YLeaf(7, "bmd-event-rg-error")

    bmd_event_rg_mlacp_tlv = Enum.YLeaf(8, "bmd-event-rg-mlacp-tlv")

    bmd_event_rg_iccp_event = Enum.YLeaf(9, "bmd-event-rg-iccp-event")

    bmd_event_rg_count = Enum.YLeaf(10, "bmd-event-rg-count")


class BmdBagMlacpSchActionItem(Enum):
    """
    BmdBagMlacpSchActionItem

    Description of scheduled actions for a bundle

    .. data:: switchover = 0

    	mLACP Switchover scheduled

    .. data:: switchback = 1

    	mLACP Switchback scheduled

    """

    switchover = Enum.YLeaf(0, "switchover")

    switchback = Enum.YLeaf(1, "switchback")


class BmdBagTarget(Enum):
    """
    BmdBagTarget

    Scope of information

    .. data:: bm_bag_target_mbr = 0

    	Information for a member

    .. data:: bm_bag_target_bdl = 1

    	Information for a bundle

    .. data:: bm_bag_target_node = 2

    	Information for a node

    .. data:: bm_bag_target_rg = 3

    	Information for an RG

    """

    bm_bag_target_mbr = Enum.YLeaf(0, "bm-bag-target-mbr")

    bm_bag_target_bdl = Enum.YLeaf(1, "bm-bag-target-bdl")

    bm_bag_target_node = Enum.YLeaf(2, "bm-bag-target-node")

    bm_bag_target_rg = Enum.YLeaf(3, "bm-bag-target-rg")


class BmdBfdBdlState(Enum):
    """
    BmdBfdBdlState

    Bmd bfd bdl state

    .. data:: bmd_bfd_bdl_down = 0

    	BFD is down on the bundle

    .. data:: bmd_bfd_bdl_unknown = 1

    	BFD has just started on a bundle, and the state

    	has not been determined

    .. data:: bmd_bfd_bdl_up = 2

    	BFD is up on the bundle

    .. data:: bmd_bfd_bdl_count = 3

    	Number of BFD states on a bundle

    """

    bmd_bfd_bdl_down = Enum.YLeaf(0, "bmd-bfd-bdl-down")

    bmd_bfd_bdl_unknown = Enum.YLeaf(1, "bmd-bfd-bdl-unknown")

    bmd_bfd_bdl_up = Enum.YLeaf(2, "bmd-bfd-bdl-up")

    bmd_bfd_bdl_count = Enum.YLeaf(3, "bmd-bfd-bdl-count")


class BmdMemberState(Enum):
    """
    BmdMemberState

    Bmd member state

    .. data:: bmd_mbr_state_configured = 1

    	Member is configured

    .. data:: bmd_mbr_state_standby = 2

    	Member is standby

    .. data:: bmd_mbr_state_hot_standby = 3

    	Member is hot standby

    .. data:: bmd_mbr_state_negotiating = 4

    	Member is negotiating

    .. data:: bmd_mbr_state_bfd_running = 5

    	Member has a BFD session running

    .. data:: bmd_mbr_state_active = 6

    	Member is active

    """

    bmd_mbr_state_configured = Enum.YLeaf(1, "bmd-mbr-state-configured")

    bmd_mbr_state_standby = Enum.YLeaf(2, "bmd-mbr-state-standby")

    bmd_mbr_state_hot_standby = Enum.YLeaf(3, "bmd-mbr-state-hot-standby")

    bmd_mbr_state_negotiating = Enum.YLeaf(4, "bmd-mbr-state-negotiating")

    bmd_mbr_state_bfd_running = Enum.YLeaf(5, "bmd-mbr-state-bfd-running")

    bmd_mbr_state_active = Enum.YLeaf(6, "bmd-mbr-state-active")


class BmdMemberTypeEnum(Enum):
    """
    BmdMemberTypeEnum

    Bmd member type enum

    .. data:: bmd_mbr_local = 0

    	Member has been configured on the local device

    .. data:: bmd_mbr_foreign = 1

    	Member has been configured on an mLACP peer

    	device

    .. data:: bmd_mbr_unknown = 2

    	Member's type is unknown

    """

    bmd_mbr_local = Enum.YLeaf(0, "bmd-mbr-local")

    bmd_mbr_foreign = Enum.YLeaf(1, "bmd-mbr-foreign")

    bmd_mbr_unknown = Enum.YLeaf(2, "bmd-mbr-unknown")


class BmdMlacpBdlStateEnum(Enum):
    """
    BmdMlacpBdlStateEnum

    State of an mLACP device

    .. data:: bdl_state_nak = 0

    	Bundle info NAK'd

    .. data:: bdl_state_unknown = 1

    	No bundle state TLV received

    .. data:: bdl_state_no_sync = 2

    	No bundle config TLV with sync bit set received

    .. data:: bdl_state_rec_delay = 3

    	Revertive delay timer running

    .. data:: bdl_state_up = 4

    	Bundle is up

    .. data:: bdl_state_down = 5

    	Bundle is down

    .. data:: bdl_state_admin_down = 6

    	Bundle is admin down

    .. data:: bdl_state_test = 7

    	Bundle state TLV reported test

    .. data:: bdl_state_error = 8

    	Bundle state TLV reported error

    """

    bdl_state_nak = Enum.YLeaf(0, "bdl-state-nak")

    bdl_state_unknown = Enum.YLeaf(1, "bdl-state-unknown")

    bdl_state_no_sync = Enum.YLeaf(2, "bdl-state-no-sync")

    bdl_state_rec_delay = Enum.YLeaf(3, "bdl-state-rec-delay")

    bdl_state_up = Enum.YLeaf(4, "bdl-state-up")

    bdl_state_down = Enum.YLeaf(5, "bdl-state-down")

    bdl_state_admin_down = Enum.YLeaf(6, "bdl-state-admin-down")

    bdl_state_test = Enum.YLeaf(7, "bdl-state-test")

    bdl_state_error = Enum.YLeaf(8, "bdl-state-error")


class BmdMlacpMbrStateEnum(Enum):
    """
    BmdMlacpMbrStateEnum

    State of an mLACP device

    .. data:: mbr_state_nak = 0

    	Member info NAK'd

    .. data:: mbr_state_unknown = 1

    	No member state TLV received

    .. data:: mbr_state_up = 2

    	Member is up

    .. data:: mbr_state_down = 3

    	Member is down

    .. data:: mbr_state_admin_down = 4

    	Member is admin down

    .. data:: mbr_state_test = 5

    	Member state TLV reported test

    .. data:: mbr_state_error = 6

    	Member state TLV reported error

    """

    mbr_state_nak = Enum.YLeaf(0, "mbr-state-nak")

    mbr_state_unknown = Enum.YLeaf(1, "mbr-state-unknown")

    mbr_state_up = Enum.YLeaf(2, "mbr-state-up")

    mbr_state_down = Enum.YLeaf(3, "mbr-state-down")

    mbr_state_admin_down = Enum.YLeaf(4, "mbr-state-admin-down")

    mbr_state_test = Enum.YLeaf(5, "mbr-state-test")

    mbr_state_error = Enum.YLeaf(6, "mbr-state-error")


class BmdMlacpNodeStateEnum(Enum):
    """
    BmdMlacpNodeStateEnum

    State of an mLACP device

    .. data:: node_state_incomplete = 0

    	Missing some mLACP IG config

    .. data:: node_state_conn_rejected = 1

    	Connection rejected by peer

    .. data:: node_state_connect_sent = 2

    	Connect timer running

    .. data:: node_state_unconfigured = 3

    	Missing some ICCP IG config

    .. data:: node_state_unreachable = 4

    	ICCP declared peer node unreachable

    .. data:: node_state_iccp_down = 5

    	ICCP declared peer node down

    .. data:: node_state_nak = 6

    	System info NAK'd

    .. data:: node_state_unknown = 7

    	No system state TLV received

    .. data:: node_state_mlacp_down = 8

    	System state TLV reported down

    .. data:: node_state_admin_down = 9

    	System state TLV reported admin down

    .. data:: node_state_pe_isolated = 10

    	System is isolated from core network

    .. data:: node_state_error = 11

    	System state TLV reported error

    .. data:: node_state_test = 12

    	System state TLV reported test

    .. data:: node_state_up = 13

    	System is up

    """

    node_state_incomplete = Enum.YLeaf(0, "node-state-incomplete")

    node_state_conn_rejected = Enum.YLeaf(1, "node-state-conn-rejected")

    node_state_connect_sent = Enum.YLeaf(2, "node-state-connect-sent")

    node_state_unconfigured = Enum.YLeaf(3, "node-state-unconfigured")

    node_state_unreachable = Enum.YLeaf(4, "node-state-unreachable")

    node_state_iccp_down = Enum.YLeaf(5, "node-state-iccp-down")

    node_state_nak = Enum.YLeaf(6, "node-state-nak")

    node_state_unknown = Enum.YLeaf(7, "node-state-unknown")

    node_state_mlacp_down = Enum.YLeaf(8, "node-state-mlacp-down")

    node_state_admin_down = Enum.YLeaf(9, "node-state-admin-down")

    node_state_pe_isolated = Enum.YLeaf(10, "node-state-pe-isolated")

    node_state_error = Enum.YLeaf(11, "node-state-error")

    node_state_test = Enum.YLeaf(12, "node-state-test")

    node_state_up = Enum.YLeaf(13, "node-state-up")


class BmdMlacpNodeSyncEnum(Enum):
    """
    BmdMlacpNodeSyncEnum

    Synchronization states of an mLACP device

    .. data:: node_sync_req = 0

    	Sync requested of device

    .. data:: node_sync_done = 1

    	Sync performed by device

    .. data:: node_sync_start = 2

    	Sync in progress from device

    .. data:: node_sync_init = 3

    	Initial sync pending from device

    .. data:: node_sync_singleton = 4

    	Sync not required for singleton groups

    """

    node_sync_req = Enum.YLeaf(0, "node-sync-req")

    node_sync_done = Enum.YLeaf(1, "node-sync-done")

    node_sync_start = Enum.YLeaf(2, "node-sync-start")

    node_sync_init = Enum.YLeaf(3, "node-sync-init")

    node_sync_singleton = Enum.YLeaf(4, "node-sync-singleton")


class BmdMlacpSwitchover(Enum):
    """
    BmdMlacpSwitchover

    Bmd mlacp switchover

    .. data:: bmd_mlacp_switchover_nonrevertive = 0

    	Non-revertive switchover type

    .. data:: bmd_mlacp_switchover_brute_force = 1

    	Brute force switchover type

    .. data:: bmd_mlacp_switchover_revertive = 2

    	Revertive switchover type

    .. data:: bmd_mlacp_switchover_count = 3

    	Number of switchover types

    """

    bmd_mlacp_switchover_nonrevertive = Enum.YLeaf(0, "bmd-mlacp-switchover-nonrevertive")

    bmd_mlacp_switchover_brute_force = Enum.YLeaf(1, "bmd-mlacp-switchover-brute-force")

    bmd_mlacp_switchover_revertive = Enum.YLeaf(2, "bmd-mlacp-switchover-revertive")

    bmd_mlacp_switchover_count = Enum.YLeaf(3, "bmd-mlacp-switchover-count")


class BmdSwitchReason(Enum):
    """
    BmdSwitchReason

    Bmd switch reason

    .. data:: bm_switch_reason_none = 0

    	Switch is permitted

    .. data:: bm_switch_reason_noop = 1

    	Switch has no effect

    .. data:: bm_switch_reason_not_mlacp = 2

    	mLACP not configured

    .. data:: bm_switch_reason_revertive = 3

    	Brute-force or revertive switchover is in

    	effect

    .. data:: bm_switch_reason_bdl_down = 4

    	Would-be active bundle is not ready

    .. data:: bm_switch_reason_recovery = 5

    	Recovery delay in effect, applications may not

    	be fully synced

    .. data:: bm_switch_reason_preceding_error = 6

    	Preceding switch action not viable

    .. data:: bm_switch_reason_wrong_order = 7

    	Switch actions are scheduled incorrectly

    .. data:: bm_switch_reason_singleton = 8

    	The ICCP group is operating in singleton mode

    """

    bm_switch_reason_none = Enum.YLeaf(0, "bm-switch-reason-none")

    bm_switch_reason_noop = Enum.YLeaf(1, "bm-switch-reason-noop")

    bm_switch_reason_not_mlacp = Enum.YLeaf(2, "bm-switch-reason-not-mlacp")

    bm_switch_reason_revertive = Enum.YLeaf(3, "bm-switch-reason-revertive")

    bm_switch_reason_bdl_down = Enum.YLeaf(4, "bm-switch-reason-bdl-down")

    bm_switch_reason_recovery = Enum.YLeaf(5, "bm-switch-reason-recovery")

    bm_switch_reason_preceding_error = Enum.YLeaf(6, "bm-switch-reason-preceding-error")

    bm_switch_reason_wrong_order = Enum.YLeaf(7, "bm-switch-reason-wrong-order")

    bm_switch_reason_singleton = Enum.YLeaf(8, "bm-switch-reason-singleton")


class BundleMedia(Enum):
    """
    BundleMedia

    Bundle media

    .. data:: bundle_media_ethernet = 0

    	bundle media ethernet

    .. data:: bundle_media_pos = 1

    	bundle media pos

    .. data:: bundle_media_count = 2

    	bundle media count

    """

    bundle_media_ethernet = Enum.YLeaf(0, "bundle-media-ethernet")

    bundle_media_pos = Enum.YLeaf(1, "bundle-media-pos")

    bundle_media_count = Enum.YLeaf(2, "bundle-media-count")


class BundleMedia1(Enum):
    """
    BundleMedia1

    Bundle media1

    .. data:: ethernet = 0

    	Ethernet

    .. data:: pos = 1

    	POS

    """

    ethernet = Enum.YLeaf(0, "ethernet")

    pos = Enum.YLeaf(1, "pos")


class BundleMlacpMode(Enum):
    """
    BundleMlacpMode

    Bundle mlacp mode

    .. data:: bundle_mlacp_mode_standby = 0

    	bundle mlacp mode standby

    .. data:: bundle_mlacp_mode_active = 1

    	bundle mlacp mode active

    .. data:: bundle_mlacp_mode_count = 2

    	bundle mlacp mode count

    """

    bundle_mlacp_mode_standby = Enum.YLeaf(0, "bundle-mlacp-mode-standby")

    bundle_mlacp_mode_active = Enum.YLeaf(1, "bundle-mlacp-mode-active")

    bundle_mlacp_mode_count = Enum.YLeaf(2, "bundle-mlacp-mode-count")


class LacpChurnstates(Enum):
    """
    LacpChurnstates

    Lacp churnstates

    .. data:: no_churn = 1

    	The port is synchronized correctly

    .. data:: churn = 2

    	The port is OutOfSync and the churn timer has

    	expired

    .. data:: churn_monitor = 3

    	The port is OutOfSync but the churn timer has

    	not expired

    """

    no_churn = Enum.YLeaf(1, "no-churn")

    churn = Enum.YLeaf(2, "churn")

    churn_monitor = Enum.YLeaf(3, "churn-monitor")


class LacpPeriodState(Enum):
    """
    LacpPeriodState

    Lacp period state

    .. data:: period_s_low = 0

    	Packets are being sent using a long period

    .. data:: period_fast = 1

    	Packets are being sent using a short period

    .. data:: period_none = 2

    	Packets are not being sent

    """

    period_s_low = Enum.YLeaf(0, "period-s-low")

    period_fast = Enum.YLeaf(1, "period-fast")

    period_none = Enum.YLeaf(2, "period-none")


class LacpSelState(Enum):
    """
    LacpSelState

    Lacp sel state

    .. data:: unselected = 0

    	The link is Unselected

    .. data:: standby = 1

    	The link is Standby

    .. data:: selected = 2

    	The link is Selected

    """

    unselected = Enum.YLeaf(0, "unselected")

    standby = Enum.YLeaf(1, "standby")

    selected = Enum.YLeaf(2, "selected")


class LoadBalance(Enum):
    """
    LoadBalance

    Load balance

    .. data:: default = 0

    	Default

    .. data:: auto = 1

    	Auto

    .. data:: value = 2

    	Value

    .. data:: source_ip = 3

    	Source IP

    .. data:: destination_ip = 4

    	Destination IP

    .. data:: unknown = 5

    	Unknown

    """

    default = Enum.YLeaf(0, "default")

    auto = Enum.YLeaf(1, "auto")

    value = Enum.YLeaf(2, "value")

    source_ip = Enum.YLeaf(3, "source-ip")

    destination_ip = Enum.YLeaf(4, "destination-ip")

    unknown = Enum.YLeaf(5, "unknown")


class Rxstates(Enum):
    """
    Rxstates

    Rxstates

    .. data:: current_rx = 1

    	current rx

    .. data:: expired = 2

    	expired

    .. data:: defaulted = 3

    	defaulted

    .. data:: initialize = 4

    	initialize

    .. data:: lacp_disabled = 5

    	lacp disabled

    .. data:: port_disabled = 6

    	port disabled

    """

    current_rx = Enum.YLeaf(1, "current-rx")

    expired = Enum.YLeaf(2, "expired")

    defaulted = Enum.YLeaf(3, "defaulted")

    initialize = Enum.YLeaf(4, "initialize")

    lacp_disabled = Enum.YLeaf(5, "lacp-disabled")

    port_disabled = Enum.YLeaf(6, "port-disabled")



class LacpBundles(Entity):
    """
    LACP bundle data
    
    .. attribute:: bundles
    
    	LACP bundle data
    	**type**\:   :py:class:`Bundles <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.LacpBundles.Bundles>`
    
    

    """

    _prefix = 'bundlemgr-oper'
    _revision = '2015-11-09'

    def __init__(self):
        super(LacpBundles, self).__init__()
        self._top_entity = None

        self.yang_name = "lacp-bundles"
        self.yang_parent_name = "Cisco-IOS-XR-bundlemgr-oper"

        self.bundles = LacpBundles.Bundles()
        self.bundles.parent = self
        self._children_name_map["bundles"] = "bundles"
        self._children_yang_names.add("bundles")


    class Bundles(Entity):
        """
        LACP bundle data
        
        .. attribute:: bundle
        
        	LACP Bundle interface
        	**type**\: list of    :py:class:`Bundle <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.LacpBundles.Bundles.Bundle>`
        
        

        """

        _prefix = 'bundlemgr-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(LacpBundles.Bundles, self).__init__()

            self.yang_name = "bundles"
            self.yang_parent_name = "lacp-bundles"

            self.bundle = YList(self)

        def __setattr__(self, name, value):
            self._check_monkey_patching_error(name, value)
            with _handle_type_error():
                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                        "Please use list append or extend method."
                                        .format(value))
                if isinstance(value, Enum.YLeaf):
                    value = value.name
                if name in () and name in self.__dict__:
                    if isinstance(value, YLeaf):
                        self.__dict__[name].set(value.get())
                    elif isinstance(value, YLeafList):
                        super(LacpBundles.Bundles, self).__setattr__(name, value)
                    else:
                        self.__dict__[name].set(value)
                else:
                    if hasattr(value, "parent") and name != "parent":
                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                            value.parent = self
                        elif value.parent is None and value.yang_name in self._children_yang_names:
                            value.parent = self
                    super(LacpBundles.Bundles, self).__setattr__(name, value)


        class Bundle(Entity):
            """
            LACP Bundle interface
            
            .. attribute:: bundle_interface  <key>
            
            	LACP Bundle interface
            	**type**\:  str
            
            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
            
            .. attribute:: data
            
            	Data for each Bundle
            	**type**\:   :py:class:`Data <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.LacpBundles.Bundles.Bundle.Data>`
            
            .. attribute:: members
            
            	LACP Member interface
            	**type**\:   :py:class:`Members <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.LacpBundles.Bundles.Bundle.Members>`
            
            

            """

            _prefix = 'bundlemgr-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(LacpBundles.Bundles.Bundle, self).__init__()

                self.yang_name = "bundle"
                self.yang_parent_name = "bundles"

                self.bundle_interface = YLeaf(YType.str, "bundle-interface")

                self.data = LacpBundles.Bundles.Bundle.Data()
                self.data.parent = self
                self._children_name_map["data"] = "data"
                self._children_yang_names.add("data")

                self.members = LacpBundles.Bundles.Bundle.Members()
                self.members.parent = self
                self._children_name_map["members"] = "members"
                self._children_yang_names.add("members")

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in ("bundle_interface") and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(LacpBundles.Bundles.Bundle, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(LacpBundles.Bundles.Bundle, self).__setattr__(name, value)


            class Data(Entity):
                """
                Data for each Bundle
                
                .. attribute:: actor_bundle_data
                
                	Basic bundle information
                	**type**\:   :py:class:`ActorBundleData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.LacpBundles.Bundles.Bundle.Data.ActorBundleData>`
                
                .. attribute:: actor_operational_key
                
                	Operational key of the interface
                	**type**\:  int
                
                	**range:** 0..65535
                
                .. attribute:: bundle_system_id
                
                	System ID for the bundle
                	**type**\:   :py:class:`BundleSystemId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.LacpBundles.Bundles.Bundle.Data.BundleSystemId>`
                
                .. attribute:: partner_operational_key
                
                	Operational key of the partner
                	**type**\:  int
                
                	**range:** 0..65535
                
                .. attribute:: partner_system_mac_address
                
                	MAC Address used to identify the partner system
                	**type**\:  str
                
                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                
                .. attribute:: partner_system_priority
                
                	Priority of the partner system
                	**type**\:  int
                
                	**range:** 0..65535
                
                

                """

                _prefix = 'bundlemgr-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(LacpBundles.Bundles.Bundle.Data, self).__init__()

                    self.yang_name = "data"
                    self.yang_parent_name = "bundle"

                    self.actor_operational_key = YLeaf(YType.uint16, "actor-operational-key")

                    self.partner_operational_key = YLeaf(YType.uint16, "partner-operational-key")

                    self.partner_system_mac_address = YLeaf(YType.str, "partner-system-mac-address")

                    self.partner_system_priority = YLeaf(YType.uint16, "partner-system-priority")

                    self.actor_bundle_data = LacpBundles.Bundles.Bundle.Data.ActorBundleData()
                    self.actor_bundle_data.parent = self
                    self._children_name_map["actor_bundle_data"] = "actor-bundle-data"
                    self._children_yang_names.add("actor-bundle-data")

                    self.bundle_system_id = LacpBundles.Bundles.Bundle.Data.BundleSystemId()
                    self.bundle_system_id.parent = self
                    self._children_name_map["bundle_system_id"] = "bundle-system-id"
                    self._children_yang_names.add("bundle-system-id")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("actor_operational_key",
                                    "partner_operational_key",
                                    "partner_system_mac_address",
                                    "partner_system_priority") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(LacpBundles.Bundles.Bundle.Data, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(LacpBundles.Bundles.Bundle.Data, self).__setattr__(name, value)


                class ActorBundleData(Entity):
                    """
                    Basic bundle information
                    
                    .. attribute:: active_foreign_member_count
                    
                    	The number of active foreign members on the bundle
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: active_member_count
                    
                    	The number of active local members on the bundle
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: available_bandwidth
                    
                    	Bandwidth available to the bundle interface (kbps)
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: kbit/s
                    
                    .. attribute:: bfd_config
                    
                    	Configuration values for BFD on bundle members
                    	**type**\: list of    :py:class:`BfdConfig <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.LacpBundles.Bundles.Bundle.Data.ActorBundleData.BfdConfig>`
                    
                    .. attribute:: bundle_interface_name
                    
                    	Bundle interface name
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: bundle_status
                    
                    	The state of the bundle
                    	**type**\:   :py:class:`BmBdlState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmBdlState>`
                    
                    .. attribute:: cisco_extensions
                    
                    	The status of the Cisco Extensions feature (1 = enabled, 0 = not enabled)
                    	**type**\:  bool
                    
                    .. attribute:: collector_max_delay
                    
                    	Collector Max Delay
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: configured_bandwidth
                    
                    	Bandwidth configured on the bundle interface (kbps)
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: kbit/s
                    
                    .. attribute:: configured_foreign_member_count
                    
                    	The number of configured local members on the bundle
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: configured_member_count
                    
                    	The number of configured local members on the bundle
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: effective_bandwidth
                    
                    	Effective bandwidth on the bundle interface (kbps)
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: kbit/s
                    
                    .. attribute:: iccp_group_id
                    
                    	ICCP Group that the bundle is configured to
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: inter_chassis
                    
                    	Indicates if this bundle is operating as an inter\-chassis link (1 = I\-C link, 0 = normal)
                    	**type**\:  bool
                    
                    .. attribute:: ipv4bfd_status
                    
                    	The status of the BFD (IPv4) feature on the bundle
                    	**type**\:   :py:class:`BmFeatureStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmFeatureStatus>`
                    
                    .. attribute:: ipv6bfd_status
                    
                    	The status of the BFD (IPv6) feature on the bundle
                    	**type**\:   :py:class:`BmFeatureStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmFeatureStatus>`
                    
                    .. attribute:: is_active
                    
                    	Indicates the active/standby redundancy state of the device for the bundle
                    	**type**\:  bool
                    
                    .. attribute:: lacp_nonrevertive
                    
                    	The status of the LACP nonrevertive feature (1 = enable, 0 = not enabled)
                    	**type**\:  bool
                    
                    .. attribute:: lacp_status
                    
                    	The status of the LACP feature on the bundle
                    	**type**\:   :py:class:`BmFeatureStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmFeatureStatus>`
                    
                    .. attribute:: link_order_status
                    
                    	The status of the link order signaling feature on the bundle
                    	**type**\:   :py:class:`BmFeatureStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmFeatureStatus>`
                    
                    .. attribute:: load_balance_hash_type
                    
                    	The type of hash to use for load balancing
                    	**type**\:  str
                    
                    .. attribute:: load_balance_locality_threshold
                    
                    	The number of links required per rack for localized load balancing
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: mac_address
                    
                    	MAC address of this member
                    	**type**\:   :py:class:`MacAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.LacpBundles.Bundles.Bundle.Data.ActorBundleData.MacAddress>`
                    
                    .. attribute:: mac_source
                    
                    	The source of the MAC Address
                    	**type**\:   :py:class:`BmBdlMacSource <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmBdlMacSource>`
                    
                    .. attribute:: mac_source_member
                    
                    	The name of the member that supplied the MAC address
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: maximize_threshold_value_band_width
                    
                    	Attempt to maximize the bundle if bandwidth is below this value
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: maximize_threshold_value_links
                    
                    	Attempt to maximize the bundle if links are below this value
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: maximum_active_links
                    
                    	Maximum number of active links in the bundle
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: maximum_active_links_source
                    
                    	Source of maximum active links value
                    	**type**\:   :py:class:`BmWhichSystem <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmWhichSystem>`
                    
                    .. attribute:: minimum_active_links
                    
                    	Minimum number of active links for bundle to go up
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: minimum_bandwidth
                    
                    	Minimum bundle bandwidth for bundle to go up (kbps)
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: kbit/s
                    
                    .. attribute:: mlacp_mode
                    
                    	Indicates the mode of the device for the bundle
                    	**type**\:   :py:class:`BundleMlacpMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleMlacpMode>`
                    
                    .. attribute:: mlacp_status
                    
                    	The status of the mLACP feature on the bundle
                    	**type**\:   :py:class:`BmFeatureStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmFeatureStatus>`
                    
                    .. attribute:: primary_member
                    
                    	Primary bundle member (no longer applicable)
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: recovery_delay
                    
                    	Number of seconds to wait before becoming active after recovering from a failure
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    	**units**\: second
                    
                    .. attribute:: singleton
                    
                    	Is the ICCP group of the bundle in singleton mode (1 = singleton; 0 = not singleton)
                    	**type**\:  bool
                    
                    .. attribute:: standby_member_count
                    
                    	The number of standby local members on the bundle
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: suppression_timer
                    
                    	Timer for suppressing bundle state flaps
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: switchover_type
                    
                    	How a switchover of the bundle from this device will occur
                    	**type**\:   :py:class:`BmdMlacpSwitchover <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmdMlacpSwitchover>`
                    
                    .. attribute:: wait_while_timer
                    
                    	The wait while time used for member ports
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'bundlemgr-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(LacpBundles.Bundles.Bundle.Data.ActorBundleData, self).__init__()

                        self.yang_name = "actor-bundle-data"
                        self.yang_parent_name = "data"

                        self.active_foreign_member_count = YLeaf(YType.uint16, "active-foreign-member-count")

                        self.active_member_count = YLeaf(YType.uint16, "active-member-count")

                        self.available_bandwidth = YLeaf(YType.uint32, "available-bandwidth")

                        self.bundle_interface_name = YLeaf(YType.str, "bundle-interface-name")

                        self.bundle_status = YLeaf(YType.enumeration, "bundle-status")

                        self.cisco_extensions = YLeaf(YType.boolean, "cisco-extensions")

                        self.collector_max_delay = YLeaf(YType.uint16, "collector-max-delay")

                        self.configured_bandwidth = YLeaf(YType.uint32, "configured-bandwidth")

                        self.configured_foreign_member_count = YLeaf(YType.uint16, "configured-foreign-member-count")

                        self.configured_member_count = YLeaf(YType.uint16, "configured-member-count")

                        self.effective_bandwidth = YLeaf(YType.uint32, "effective-bandwidth")

                        self.iccp_group_id = YLeaf(YType.uint32, "iccp-group-id")

                        self.inter_chassis = YLeaf(YType.boolean, "inter-chassis")

                        self.ipv4bfd_status = YLeaf(YType.enumeration, "ipv4bfd-status")

                        self.ipv6bfd_status = YLeaf(YType.enumeration, "ipv6bfd-status")

                        self.is_active = YLeaf(YType.boolean, "is-active")

                        self.lacp_nonrevertive = YLeaf(YType.boolean, "lacp-nonrevertive")

                        self.lacp_status = YLeaf(YType.enumeration, "lacp-status")

                        self.link_order_status = YLeaf(YType.enumeration, "link-order-status")

                        self.load_balance_hash_type = YLeaf(YType.str, "load-balance-hash-type")

                        self.load_balance_locality_threshold = YLeaf(YType.uint16, "load-balance-locality-threshold")

                        self.mac_source = YLeaf(YType.enumeration, "mac-source")

                        self.mac_source_member = YLeaf(YType.str, "mac-source-member")

                        self.maximize_threshold_value_band_width = YLeaf(YType.uint32, "maximize-threshold-value-band-width")

                        self.maximize_threshold_value_links = YLeaf(YType.uint32, "maximize-threshold-value-links")

                        self.maximum_active_links = YLeaf(YType.uint8, "maximum-active-links")

                        self.maximum_active_links_source = YLeaf(YType.enumeration, "maximum-active-links-source")

                        self.minimum_active_links = YLeaf(YType.uint8, "minimum-active-links")

                        self.minimum_bandwidth = YLeaf(YType.uint32, "minimum-bandwidth")

                        self.mlacp_mode = YLeaf(YType.enumeration, "mlacp-mode")

                        self.mlacp_status = YLeaf(YType.enumeration, "mlacp-status")

                        self.primary_member = YLeaf(YType.str, "primary-member")

                        self.recovery_delay = YLeaf(YType.uint16, "recovery-delay")

                        self.singleton = YLeaf(YType.boolean, "singleton")

                        self.standby_member_count = YLeaf(YType.uint16, "standby-member-count")

                        self.suppression_timer = YLeaf(YType.uint16, "suppression-timer")

                        self.switchover_type = YLeaf(YType.enumeration, "switchover-type")

                        self.wait_while_timer = YLeaf(YType.uint16, "wait-while-timer")

                        self.mac_address = LacpBundles.Bundles.Bundle.Data.ActorBundleData.MacAddress()
                        self.mac_address.parent = self
                        self._children_name_map["mac_address"] = "mac-address"
                        self._children_yang_names.add("mac-address")

                        self.bfd_config = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("active_foreign_member_count",
                                        "active_member_count",
                                        "available_bandwidth",
                                        "bundle_interface_name",
                                        "bundle_status",
                                        "cisco_extensions",
                                        "collector_max_delay",
                                        "configured_bandwidth",
                                        "configured_foreign_member_count",
                                        "configured_member_count",
                                        "effective_bandwidth",
                                        "iccp_group_id",
                                        "inter_chassis",
                                        "ipv4bfd_status",
                                        "ipv6bfd_status",
                                        "is_active",
                                        "lacp_nonrevertive",
                                        "lacp_status",
                                        "link_order_status",
                                        "load_balance_hash_type",
                                        "load_balance_locality_threshold",
                                        "mac_source",
                                        "mac_source_member",
                                        "maximize_threshold_value_band_width",
                                        "maximize_threshold_value_links",
                                        "maximum_active_links",
                                        "maximum_active_links_source",
                                        "minimum_active_links",
                                        "minimum_bandwidth",
                                        "mlacp_mode",
                                        "mlacp_status",
                                        "primary_member",
                                        "recovery_delay",
                                        "singleton",
                                        "standby_member_count",
                                        "suppression_timer",
                                        "switchover_type",
                                        "wait_while_timer") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(LacpBundles.Bundles.Bundle.Data.ActorBundleData, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(LacpBundles.Bundles.Bundle.Data.ActorBundleData, self).__setattr__(name, value)


                    class MacAddress(Entity):
                        """
                        MAC address of this member
                        
                        .. attribute:: address
                        
                        	MAC address
                        	**type**\:  str
                        
                        	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                        
                        

                        """

                        _prefix = 'bundlemgr-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(LacpBundles.Bundles.Bundle.Data.ActorBundleData.MacAddress, self).__init__()

                            self.yang_name = "mac-address"
                            self.yang_parent_name = "actor-bundle-data"

                            self.address = YLeaf(YType.str, "address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(LacpBundles.Bundles.Bundle.Data.ActorBundleData.MacAddress, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(LacpBundles.Bundles.Bundle.Data.ActorBundleData.MacAddress, self).__setattr__(name, value)

                        def has_data(self):
                            return self.address.is_set

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "mac-address" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.address.is_set or self.address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "address"):
                                self.address = value
                                self.address.value_namespace = name_space
                                self.address.value_namespace_prefix = name_space_prefix


                    class BfdConfig(Entity):
                        """
                        Configuration values for BFD on bundle members
                        
                        .. attribute:: bundle_status
                        
                        	Status of BFD on the bundle
                        	**type**\:   :py:class:`BmdBfdBdlState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmdBfdBdlState>`
                        
                        .. attribute:: destination_address
                        
                        	Configured destination address for BFD session
                        	**type**\:   :py:class:`DestinationAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.LacpBundles.Bundles.Bundle.Data.ActorBundleData.BfdConfig.DestinationAddress>`
                        
                        .. attribute:: fast_detect
                        
                        	Flag indicating if BFD is enabled (1 = enabled; 0 = not enabled)
                        	**type**\:  bool
                        
                        .. attribute:: mode_info
                        
                        	Standard used for per\-member BFD
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: nbr_unconfig_timer
                        
                        	Time to wait on session NBR\_UNCONFIG before declaring DOWN
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: pref_echo_min_interval
                        
                        	Preferred echo minimum interval for the BFD session (ms)
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: pref_min_interval
                        
                        	Preferred minimum interval for the BFD session (ms)
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: pref_multiplier
                        
                        	Preferred multiplier for the BFD session
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: start_timer
                        
                        	Time to wait on session start before declaring DOWN
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'bundlemgr-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(LacpBundles.Bundles.Bundle.Data.ActorBundleData.BfdConfig, self).__init__()

                            self.yang_name = "bfd-config"
                            self.yang_parent_name = "actor-bundle-data"

                            self.bundle_status = YLeaf(YType.enumeration, "bundle-status")

                            self.fast_detect = YLeaf(YType.boolean, "fast-detect")

                            self.mode_info = YLeaf(YType.uint32, "mode-info")

                            self.nbr_unconfig_timer = YLeaf(YType.uint32, "nbr-unconfig-timer")

                            self.pref_echo_min_interval = YLeaf(YType.uint32, "pref-echo-min-interval")

                            self.pref_min_interval = YLeaf(YType.uint32, "pref-min-interval")

                            self.pref_multiplier = YLeaf(YType.uint16, "pref-multiplier")

                            self.start_timer = YLeaf(YType.uint32, "start-timer")

                            self.destination_address = LacpBundles.Bundles.Bundle.Data.ActorBundleData.BfdConfig.DestinationAddress()
                            self.destination_address.parent = self
                            self._children_name_map["destination_address"] = "destination-address"
                            self._children_yang_names.add("destination-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("bundle_status",
                                            "fast_detect",
                                            "mode_info",
                                            "nbr_unconfig_timer",
                                            "pref_echo_min_interval",
                                            "pref_min_interval",
                                            "pref_multiplier",
                                            "start_timer") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(LacpBundles.Bundles.Bundle.Data.ActorBundleData.BfdConfig, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(LacpBundles.Bundles.Bundle.Data.ActorBundleData.BfdConfig, self).__setattr__(name, value)


                        class DestinationAddress(Entity):
                            """
                            Configured destination address for BFD session
                            
                            .. attribute:: af
                            
                            	AF
                            	**type**\:   :py:class:`BmAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmAfId>`
                            
                            .. attribute:: ipv4
                            
                            	IPv4 address type
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6
                            
                            	IPv6 address type
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'bundlemgr-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(LacpBundles.Bundles.Bundle.Data.ActorBundleData.BfdConfig.DestinationAddress, self).__init__()

                                self.yang_name = "destination-address"
                                self.yang_parent_name = "bfd-config"

                                self.af = YLeaf(YType.enumeration, "af")

                                self.ipv4 = YLeaf(YType.str, "ipv4")

                                self.ipv6 = YLeaf(YType.str, "ipv6")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af",
                                                "ipv4",
                                                "ipv6") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(LacpBundles.Bundles.Bundle.Data.ActorBundleData.BfdConfig.DestinationAddress, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(LacpBundles.Bundles.Bundle.Data.ActorBundleData.BfdConfig.DestinationAddress, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af.is_set or
                                    self.ipv4.is_set or
                                    self.ipv6.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af.yfilter != YFilter.not_set or
                                    self.ipv4.yfilter != YFilter.not_set or
                                    self.ipv6.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "destination-address" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af.is_set or self.af.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af.get_name_leafdata())
                                if (self.ipv4.is_set or self.ipv4.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4.get_name_leafdata())
                                if (self.ipv6.is_set or self.ipv6.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af" or name == "ipv4" or name == "ipv6"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af"):
                                    self.af = value
                                    self.af.value_namespace = name_space
                                    self.af.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4"):
                                    self.ipv4 = value
                                    self.ipv4.value_namespace = name_space
                                    self.ipv4.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6"):
                                    self.ipv6 = value
                                    self.ipv6.value_namespace = name_space
                                    self.ipv6.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.bundle_status.is_set or
                                self.fast_detect.is_set or
                                self.mode_info.is_set or
                                self.nbr_unconfig_timer.is_set or
                                self.pref_echo_min_interval.is_set or
                                self.pref_min_interval.is_set or
                                self.pref_multiplier.is_set or
                                self.start_timer.is_set or
                                (self.destination_address is not None and self.destination_address.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.bundle_status.yfilter != YFilter.not_set or
                                self.fast_detect.yfilter != YFilter.not_set or
                                self.mode_info.yfilter != YFilter.not_set or
                                self.nbr_unconfig_timer.yfilter != YFilter.not_set or
                                self.pref_echo_min_interval.yfilter != YFilter.not_set or
                                self.pref_min_interval.yfilter != YFilter.not_set or
                                self.pref_multiplier.yfilter != YFilter.not_set or
                                self.start_timer.yfilter != YFilter.not_set or
                                (self.destination_address is not None and self.destination_address.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "bfd-config" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.bundle_status.is_set or self.bundle_status.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.bundle_status.get_name_leafdata())
                            if (self.fast_detect.is_set or self.fast_detect.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.fast_detect.get_name_leafdata())
                            if (self.mode_info.is_set or self.mode_info.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mode_info.get_name_leafdata())
                            if (self.nbr_unconfig_timer.is_set or self.nbr_unconfig_timer.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.nbr_unconfig_timer.get_name_leafdata())
                            if (self.pref_echo_min_interval.is_set or self.pref_echo_min_interval.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.pref_echo_min_interval.get_name_leafdata())
                            if (self.pref_min_interval.is_set or self.pref_min_interval.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.pref_min_interval.get_name_leafdata())
                            if (self.pref_multiplier.is_set or self.pref_multiplier.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.pref_multiplier.get_name_leafdata())
                            if (self.start_timer.is_set or self.start_timer.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.start_timer.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "destination-address"):
                                if (self.destination_address is None):
                                    self.destination_address = LacpBundles.Bundles.Bundle.Data.ActorBundleData.BfdConfig.DestinationAddress()
                                    self.destination_address.parent = self
                                    self._children_name_map["destination_address"] = "destination-address"
                                return self.destination_address

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "destination-address" or name == "bundle-status" or name == "fast-detect" or name == "mode-info" or name == "nbr-unconfig-timer" or name == "pref-echo-min-interval" or name == "pref-min-interval" or name == "pref-multiplier" or name == "start-timer"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "bundle-status"):
                                self.bundle_status = value
                                self.bundle_status.value_namespace = name_space
                                self.bundle_status.value_namespace_prefix = name_space_prefix
                            if(value_path == "fast-detect"):
                                self.fast_detect = value
                                self.fast_detect.value_namespace = name_space
                                self.fast_detect.value_namespace_prefix = name_space_prefix
                            if(value_path == "mode-info"):
                                self.mode_info = value
                                self.mode_info.value_namespace = name_space
                                self.mode_info.value_namespace_prefix = name_space_prefix
                            if(value_path == "nbr-unconfig-timer"):
                                self.nbr_unconfig_timer = value
                                self.nbr_unconfig_timer.value_namespace = name_space
                                self.nbr_unconfig_timer.value_namespace_prefix = name_space_prefix
                            if(value_path == "pref-echo-min-interval"):
                                self.pref_echo_min_interval = value
                                self.pref_echo_min_interval.value_namespace = name_space
                                self.pref_echo_min_interval.value_namespace_prefix = name_space_prefix
                            if(value_path == "pref-min-interval"):
                                self.pref_min_interval = value
                                self.pref_min_interval.value_namespace = name_space
                                self.pref_min_interval.value_namespace_prefix = name_space_prefix
                            if(value_path == "pref-multiplier"):
                                self.pref_multiplier = value
                                self.pref_multiplier.value_namespace = name_space
                                self.pref_multiplier.value_namespace_prefix = name_space_prefix
                            if(value_path == "start-timer"):
                                self.start_timer = value
                                self.start_timer.value_namespace = name_space
                                self.start_timer.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.bfd_config:
                            if (c.has_data()):
                                return True
                        return (
                            self.active_foreign_member_count.is_set or
                            self.active_member_count.is_set or
                            self.available_bandwidth.is_set or
                            self.bundle_interface_name.is_set or
                            self.bundle_status.is_set or
                            self.cisco_extensions.is_set or
                            self.collector_max_delay.is_set or
                            self.configured_bandwidth.is_set or
                            self.configured_foreign_member_count.is_set or
                            self.configured_member_count.is_set or
                            self.effective_bandwidth.is_set or
                            self.iccp_group_id.is_set or
                            self.inter_chassis.is_set or
                            self.ipv4bfd_status.is_set or
                            self.ipv6bfd_status.is_set or
                            self.is_active.is_set or
                            self.lacp_nonrevertive.is_set or
                            self.lacp_status.is_set or
                            self.link_order_status.is_set or
                            self.load_balance_hash_type.is_set or
                            self.load_balance_locality_threshold.is_set or
                            self.mac_source.is_set or
                            self.mac_source_member.is_set or
                            self.maximize_threshold_value_band_width.is_set or
                            self.maximize_threshold_value_links.is_set or
                            self.maximum_active_links.is_set or
                            self.maximum_active_links_source.is_set or
                            self.minimum_active_links.is_set or
                            self.minimum_bandwidth.is_set or
                            self.mlacp_mode.is_set or
                            self.mlacp_status.is_set or
                            self.primary_member.is_set or
                            self.recovery_delay.is_set or
                            self.singleton.is_set or
                            self.standby_member_count.is_set or
                            self.suppression_timer.is_set or
                            self.switchover_type.is_set or
                            self.wait_while_timer.is_set or
                            (self.mac_address is not None and self.mac_address.has_data()))

                    def has_operation(self):
                        for c in self.bfd_config:
                            if (c.has_operation()):
                                return True
                        return (
                            self.yfilter != YFilter.not_set or
                            self.active_foreign_member_count.yfilter != YFilter.not_set or
                            self.active_member_count.yfilter != YFilter.not_set or
                            self.available_bandwidth.yfilter != YFilter.not_set or
                            self.bundle_interface_name.yfilter != YFilter.not_set or
                            self.bundle_status.yfilter != YFilter.not_set or
                            self.cisco_extensions.yfilter != YFilter.not_set or
                            self.collector_max_delay.yfilter != YFilter.not_set or
                            self.configured_bandwidth.yfilter != YFilter.not_set or
                            self.configured_foreign_member_count.yfilter != YFilter.not_set or
                            self.configured_member_count.yfilter != YFilter.not_set or
                            self.effective_bandwidth.yfilter != YFilter.not_set or
                            self.iccp_group_id.yfilter != YFilter.not_set or
                            self.inter_chassis.yfilter != YFilter.not_set or
                            self.ipv4bfd_status.yfilter != YFilter.not_set or
                            self.ipv6bfd_status.yfilter != YFilter.not_set or
                            self.is_active.yfilter != YFilter.not_set or
                            self.lacp_nonrevertive.yfilter != YFilter.not_set or
                            self.lacp_status.yfilter != YFilter.not_set or
                            self.link_order_status.yfilter != YFilter.not_set or
                            self.load_balance_hash_type.yfilter != YFilter.not_set or
                            self.load_balance_locality_threshold.yfilter != YFilter.not_set or
                            self.mac_source.yfilter != YFilter.not_set or
                            self.mac_source_member.yfilter != YFilter.not_set or
                            self.maximize_threshold_value_band_width.yfilter != YFilter.not_set or
                            self.maximize_threshold_value_links.yfilter != YFilter.not_set or
                            self.maximum_active_links.yfilter != YFilter.not_set or
                            self.maximum_active_links_source.yfilter != YFilter.not_set or
                            self.minimum_active_links.yfilter != YFilter.not_set or
                            self.minimum_bandwidth.yfilter != YFilter.not_set or
                            self.mlacp_mode.yfilter != YFilter.not_set or
                            self.mlacp_status.yfilter != YFilter.not_set or
                            self.primary_member.yfilter != YFilter.not_set or
                            self.recovery_delay.yfilter != YFilter.not_set or
                            self.singleton.yfilter != YFilter.not_set or
                            self.standby_member_count.yfilter != YFilter.not_set or
                            self.suppression_timer.yfilter != YFilter.not_set or
                            self.switchover_type.yfilter != YFilter.not_set or
                            self.wait_while_timer.yfilter != YFilter.not_set or
                            (self.mac_address is not None and self.mac_address.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "actor-bundle-data" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.active_foreign_member_count.is_set or self.active_foreign_member_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.active_foreign_member_count.get_name_leafdata())
                        if (self.active_member_count.is_set or self.active_member_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.active_member_count.get_name_leafdata())
                        if (self.available_bandwidth.is_set or self.available_bandwidth.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.available_bandwidth.get_name_leafdata())
                        if (self.bundle_interface_name.is_set or self.bundle_interface_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bundle_interface_name.get_name_leafdata())
                        if (self.bundle_status.is_set or self.bundle_status.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bundle_status.get_name_leafdata())
                        if (self.cisco_extensions.is_set or self.cisco_extensions.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.cisco_extensions.get_name_leafdata())
                        if (self.collector_max_delay.is_set or self.collector_max_delay.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.collector_max_delay.get_name_leafdata())
                        if (self.configured_bandwidth.is_set or self.configured_bandwidth.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.configured_bandwidth.get_name_leafdata())
                        if (self.configured_foreign_member_count.is_set or self.configured_foreign_member_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.configured_foreign_member_count.get_name_leafdata())
                        if (self.configured_member_count.is_set or self.configured_member_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.configured_member_count.get_name_leafdata())
                        if (self.effective_bandwidth.is_set or self.effective_bandwidth.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.effective_bandwidth.get_name_leafdata())
                        if (self.iccp_group_id.is_set or self.iccp_group_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.iccp_group_id.get_name_leafdata())
                        if (self.inter_chassis.is_set or self.inter_chassis.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.inter_chassis.get_name_leafdata())
                        if (self.ipv4bfd_status.is_set or self.ipv4bfd_status.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.ipv4bfd_status.get_name_leafdata())
                        if (self.ipv6bfd_status.is_set or self.ipv6bfd_status.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.ipv6bfd_status.get_name_leafdata())
                        if (self.is_active.is_set or self.is_active.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_active.get_name_leafdata())
                        if (self.lacp_nonrevertive.is_set or self.lacp_nonrevertive.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.lacp_nonrevertive.get_name_leafdata())
                        if (self.lacp_status.is_set or self.lacp_status.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.lacp_status.get_name_leafdata())
                        if (self.link_order_status.is_set or self.link_order_status.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.link_order_status.get_name_leafdata())
                        if (self.load_balance_hash_type.is_set or self.load_balance_hash_type.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.load_balance_hash_type.get_name_leafdata())
                        if (self.load_balance_locality_threshold.is_set or self.load_balance_locality_threshold.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.load_balance_locality_threshold.get_name_leafdata())
                        if (self.mac_source.is_set or self.mac_source.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mac_source.get_name_leafdata())
                        if (self.mac_source_member.is_set or self.mac_source_member.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mac_source_member.get_name_leafdata())
                        if (self.maximize_threshold_value_band_width.is_set or self.maximize_threshold_value_band_width.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.maximize_threshold_value_band_width.get_name_leafdata())
                        if (self.maximize_threshold_value_links.is_set or self.maximize_threshold_value_links.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.maximize_threshold_value_links.get_name_leafdata())
                        if (self.maximum_active_links.is_set or self.maximum_active_links.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.maximum_active_links.get_name_leafdata())
                        if (self.maximum_active_links_source.is_set or self.maximum_active_links_source.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.maximum_active_links_source.get_name_leafdata())
                        if (self.minimum_active_links.is_set or self.minimum_active_links.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.minimum_active_links.get_name_leafdata())
                        if (self.minimum_bandwidth.is_set or self.minimum_bandwidth.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.minimum_bandwidth.get_name_leafdata())
                        if (self.mlacp_mode.is_set or self.mlacp_mode.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mlacp_mode.get_name_leafdata())
                        if (self.mlacp_status.is_set or self.mlacp_status.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mlacp_status.get_name_leafdata())
                        if (self.primary_member.is_set or self.primary_member.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.primary_member.get_name_leafdata())
                        if (self.recovery_delay.is_set or self.recovery_delay.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.recovery_delay.get_name_leafdata())
                        if (self.singleton.is_set or self.singleton.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.singleton.get_name_leafdata())
                        if (self.standby_member_count.is_set or self.standby_member_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.standby_member_count.get_name_leafdata())
                        if (self.suppression_timer.is_set or self.suppression_timer.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.suppression_timer.get_name_leafdata())
                        if (self.switchover_type.is_set or self.switchover_type.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.switchover_type.get_name_leafdata())
                        if (self.wait_while_timer.is_set or self.wait_while_timer.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.wait_while_timer.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "bfd-config"):
                            for c in self.bfd_config:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = LacpBundles.Bundles.Bundle.Data.ActorBundleData.BfdConfig()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.bfd_config.append(c)
                            return c

                        if (child_yang_name == "mac-address"):
                            if (self.mac_address is None):
                                self.mac_address = LacpBundles.Bundles.Bundle.Data.ActorBundleData.MacAddress()
                                self.mac_address.parent = self
                                self._children_name_map["mac_address"] = "mac-address"
                            return self.mac_address

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "bfd-config" or name == "mac-address" or name == "active-foreign-member-count" or name == "active-member-count" or name == "available-bandwidth" or name == "bundle-interface-name" or name == "bundle-status" or name == "cisco-extensions" or name == "collector-max-delay" or name == "configured-bandwidth" or name == "configured-foreign-member-count" or name == "configured-member-count" or name == "effective-bandwidth" or name == "iccp-group-id" or name == "inter-chassis" or name == "ipv4bfd-status" or name == "ipv6bfd-status" or name == "is-active" or name == "lacp-nonrevertive" or name == "lacp-status" or name == "link-order-status" or name == "load-balance-hash-type" or name == "load-balance-locality-threshold" or name == "mac-source" or name == "mac-source-member" or name == "maximize-threshold-value-band-width" or name == "maximize-threshold-value-links" or name == "maximum-active-links" or name == "maximum-active-links-source" or name == "minimum-active-links" or name == "minimum-bandwidth" or name == "mlacp-mode" or name == "mlacp-status" or name == "primary-member" or name == "recovery-delay" or name == "singleton" or name == "standby-member-count" or name == "suppression-timer" or name == "switchover-type" or name == "wait-while-timer"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "active-foreign-member-count"):
                            self.active_foreign_member_count = value
                            self.active_foreign_member_count.value_namespace = name_space
                            self.active_foreign_member_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "active-member-count"):
                            self.active_member_count = value
                            self.active_member_count.value_namespace = name_space
                            self.active_member_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "available-bandwidth"):
                            self.available_bandwidth = value
                            self.available_bandwidth.value_namespace = name_space
                            self.available_bandwidth.value_namespace_prefix = name_space_prefix
                        if(value_path == "bundle-interface-name"):
                            self.bundle_interface_name = value
                            self.bundle_interface_name.value_namespace = name_space
                            self.bundle_interface_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "bundle-status"):
                            self.bundle_status = value
                            self.bundle_status.value_namespace = name_space
                            self.bundle_status.value_namespace_prefix = name_space_prefix
                        if(value_path == "cisco-extensions"):
                            self.cisco_extensions = value
                            self.cisco_extensions.value_namespace = name_space
                            self.cisco_extensions.value_namespace_prefix = name_space_prefix
                        if(value_path == "collector-max-delay"):
                            self.collector_max_delay = value
                            self.collector_max_delay.value_namespace = name_space
                            self.collector_max_delay.value_namespace_prefix = name_space_prefix
                        if(value_path == "configured-bandwidth"):
                            self.configured_bandwidth = value
                            self.configured_bandwidth.value_namespace = name_space
                            self.configured_bandwidth.value_namespace_prefix = name_space_prefix
                        if(value_path == "configured-foreign-member-count"):
                            self.configured_foreign_member_count = value
                            self.configured_foreign_member_count.value_namespace = name_space
                            self.configured_foreign_member_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "configured-member-count"):
                            self.configured_member_count = value
                            self.configured_member_count.value_namespace = name_space
                            self.configured_member_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "effective-bandwidth"):
                            self.effective_bandwidth = value
                            self.effective_bandwidth.value_namespace = name_space
                            self.effective_bandwidth.value_namespace_prefix = name_space_prefix
                        if(value_path == "iccp-group-id"):
                            self.iccp_group_id = value
                            self.iccp_group_id.value_namespace = name_space
                            self.iccp_group_id.value_namespace_prefix = name_space_prefix
                        if(value_path == "inter-chassis"):
                            self.inter_chassis = value
                            self.inter_chassis.value_namespace = name_space
                            self.inter_chassis.value_namespace_prefix = name_space_prefix
                        if(value_path == "ipv4bfd-status"):
                            self.ipv4bfd_status = value
                            self.ipv4bfd_status.value_namespace = name_space
                            self.ipv4bfd_status.value_namespace_prefix = name_space_prefix
                        if(value_path == "ipv6bfd-status"):
                            self.ipv6bfd_status = value
                            self.ipv6bfd_status.value_namespace = name_space
                            self.ipv6bfd_status.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-active"):
                            self.is_active = value
                            self.is_active.value_namespace = name_space
                            self.is_active.value_namespace_prefix = name_space_prefix
                        if(value_path == "lacp-nonrevertive"):
                            self.lacp_nonrevertive = value
                            self.lacp_nonrevertive.value_namespace = name_space
                            self.lacp_nonrevertive.value_namespace_prefix = name_space_prefix
                        if(value_path == "lacp-status"):
                            self.lacp_status = value
                            self.lacp_status.value_namespace = name_space
                            self.lacp_status.value_namespace_prefix = name_space_prefix
                        if(value_path == "link-order-status"):
                            self.link_order_status = value
                            self.link_order_status.value_namespace = name_space
                            self.link_order_status.value_namespace_prefix = name_space_prefix
                        if(value_path == "load-balance-hash-type"):
                            self.load_balance_hash_type = value
                            self.load_balance_hash_type.value_namespace = name_space
                            self.load_balance_hash_type.value_namespace_prefix = name_space_prefix
                        if(value_path == "load-balance-locality-threshold"):
                            self.load_balance_locality_threshold = value
                            self.load_balance_locality_threshold.value_namespace = name_space
                            self.load_balance_locality_threshold.value_namespace_prefix = name_space_prefix
                        if(value_path == "mac-source"):
                            self.mac_source = value
                            self.mac_source.value_namespace = name_space
                            self.mac_source.value_namespace_prefix = name_space_prefix
                        if(value_path == "mac-source-member"):
                            self.mac_source_member = value
                            self.mac_source_member.value_namespace = name_space
                            self.mac_source_member.value_namespace_prefix = name_space_prefix
                        if(value_path == "maximize-threshold-value-band-width"):
                            self.maximize_threshold_value_band_width = value
                            self.maximize_threshold_value_band_width.value_namespace = name_space
                            self.maximize_threshold_value_band_width.value_namespace_prefix = name_space_prefix
                        if(value_path == "maximize-threshold-value-links"):
                            self.maximize_threshold_value_links = value
                            self.maximize_threshold_value_links.value_namespace = name_space
                            self.maximize_threshold_value_links.value_namespace_prefix = name_space_prefix
                        if(value_path == "maximum-active-links"):
                            self.maximum_active_links = value
                            self.maximum_active_links.value_namespace = name_space
                            self.maximum_active_links.value_namespace_prefix = name_space_prefix
                        if(value_path == "maximum-active-links-source"):
                            self.maximum_active_links_source = value
                            self.maximum_active_links_source.value_namespace = name_space
                            self.maximum_active_links_source.value_namespace_prefix = name_space_prefix
                        if(value_path == "minimum-active-links"):
                            self.minimum_active_links = value
                            self.minimum_active_links.value_namespace = name_space
                            self.minimum_active_links.value_namespace_prefix = name_space_prefix
                        if(value_path == "minimum-bandwidth"):
                            self.minimum_bandwidth = value
                            self.minimum_bandwidth.value_namespace = name_space
                            self.minimum_bandwidth.value_namespace_prefix = name_space_prefix
                        if(value_path == "mlacp-mode"):
                            self.mlacp_mode = value
                            self.mlacp_mode.value_namespace = name_space
                            self.mlacp_mode.value_namespace_prefix = name_space_prefix
                        if(value_path == "mlacp-status"):
                            self.mlacp_status = value
                            self.mlacp_status.value_namespace = name_space
                            self.mlacp_status.value_namespace_prefix = name_space_prefix
                        if(value_path == "primary-member"):
                            self.primary_member = value
                            self.primary_member.value_namespace = name_space
                            self.primary_member.value_namespace_prefix = name_space_prefix
                        if(value_path == "recovery-delay"):
                            self.recovery_delay = value
                            self.recovery_delay.value_namespace = name_space
                            self.recovery_delay.value_namespace_prefix = name_space_prefix
                        if(value_path == "singleton"):
                            self.singleton = value
                            self.singleton.value_namespace = name_space
                            self.singleton.value_namespace_prefix = name_space_prefix
                        if(value_path == "standby-member-count"):
                            self.standby_member_count = value
                            self.standby_member_count.value_namespace = name_space
                            self.standby_member_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "suppression-timer"):
                            self.suppression_timer = value
                            self.suppression_timer.value_namespace = name_space
                            self.suppression_timer.value_namespace_prefix = name_space_prefix
                        if(value_path == "switchover-type"):
                            self.switchover_type = value
                            self.switchover_type.value_namespace = name_space
                            self.switchover_type.value_namespace_prefix = name_space_prefix
                        if(value_path == "wait-while-timer"):
                            self.wait_while_timer = value
                            self.wait_while_timer.value_namespace = name_space
                            self.wait_while_timer.value_namespace_prefix = name_space_prefix


                class BundleSystemId(Entity):
                    """
                    System ID for the bundle
                    
                    .. attribute:: system_mac_addr
                    
                    	MAC Address used to identify the system
                    	**type**\:   :py:class:`SystemMacAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.LacpBundles.Bundles.Bundle.Data.BundleSystemId.SystemMacAddr>`
                    
                    .. attribute:: system_prio
                    
                    	Priority of the system
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'bundlemgr-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(LacpBundles.Bundles.Bundle.Data.BundleSystemId, self).__init__()

                        self.yang_name = "bundle-system-id"
                        self.yang_parent_name = "data"

                        self.system_prio = YLeaf(YType.uint16, "system-prio")

                        self.system_mac_addr = LacpBundles.Bundles.Bundle.Data.BundleSystemId.SystemMacAddr()
                        self.system_mac_addr.parent = self
                        self._children_name_map["system_mac_addr"] = "system-mac-addr"
                        self._children_yang_names.add("system-mac-addr")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("system_prio") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(LacpBundles.Bundles.Bundle.Data.BundleSystemId, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(LacpBundles.Bundles.Bundle.Data.BundleSystemId, self).__setattr__(name, value)


                    class SystemMacAddr(Entity):
                        """
                        MAC Address used to identify the system
                        
                        .. attribute:: macaddr
                        
                        	macaddr
                        	**type**\:  str
                        
                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                        
                        

                        """

                        _prefix = 'bundlemgr-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(LacpBundles.Bundles.Bundle.Data.BundleSystemId.SystemMacAddr, self).__init__()

                            self.yang_name = "system-mac-addr"
                            self.yang_parent_name = "bundle-system-id"

                            self.macaddr = YLeaf(YType.str, "macaddr")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("macaddr") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(LacpBundles.Bundles.Bundle.Data.BundleSystemId.SystemMacAddr, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(LacpBundles.Bundles.Bundle.Data.BundleSystemId.SystemMacAddr, self).__setattr__(name, value)

                        def has_data(self):
                            return self.macaddr.is_set

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.macaddr.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "system-mac-addr" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.macaddr.is_set or self.macaddr.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.macaddr.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "macaddr"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "macaddr"):
                                self.macaddr = value
                                self.macaddr.value_namespace = name_space
                                self.macaddr.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.system_prio.is_set or
                            (self.system_mac_addr is not None and self.system_mac_addr.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.system_prio.yfilter != YFilter.not_set or
                            (self.system_mac_addr is not None and self.system_mac_addr.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "bundle-system-id" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.system_prio.is_set or self.system_prio.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.system_prio.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "system-mac-addr"):
                            if (self.system_mac_addr is None):
                                self.system_mac_addr = LacpBundles.Bundles.Bundle.Data.BundleSystemId.SystemMacAddr()
                                self.system_mac_addr.parent = self
                                self._children_name_map["system_mac_addr"] = "system-mac-addr"
                            return self.system_mac_addr

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "system-mac-addr" or name == "system-prio"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "system-prio"):
                            self.system_prio = value
                            self.system_prio.value_namespace = name_space
                            self.system_prio.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    return (
                        self.actor_operational_key.is_set or
                        self.partner_operational_key.is_set or
                        self.partner_system_mac_address.is_set or
                        self.partner_system_priority.is_set or
                        (self.actor_bundle_data is not None and self.actor_bundle_data.has_data()) or
                        (self.bundle_system_id is not None and self.bundle_system_id.has_data()))

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.actor_operational_key.yfilter != YFilter.not_set or
                        self.partner_operational_key.yfilter != YFilter.not_set or
                        self.partner_system_mac_address.yfilter != YFilter.not_set or
                        self.partner_system_priority.yfilter != YFilter.not_set or
                        (self.actor_bundle_data is not None and self.actor_bundle_data.has_operation()) or
                        (self.bundle_system_id is not None and self.bundle_system_id.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "data" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.actor_operational_key.is_set or self.actor_operational_key.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.actor_operational_key.get_name_leafdata())
                    if (self.partner_operational_key.is_set or self.partner_operational_key.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.partner_operational_key.get_name_leafdata())
                    if (self.partner_system_mac_address.is_set or self.partner_system_mac_address.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.partner_system_mac_address.get_name_leafdata())
                    if (self.partner_system_priority.is_set or self.partner_system_priority.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.partner_system_priority.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "actor-bundle-data"):
                        if (self.actor_bundle_data is None):
                            self.actor_bundle_data = LacpBundles.Bundles.Bundle.Data.ActorBundleData()
                            self.actor_bundle_data.parent = self
                            self._children_name_map["actor_bundle_data"] = "actor-bundle-data"
                        return self.actor_bundle_data

                    if (child_yang_name == "bundle-system-id"):
                        if (self.bundle_system_id is None):
                            self.bundle_system_id = LacpBundles.Bundles.Bundle.Data.BundleSystemId()
                            self.bundle_system_id.parent = self
                            self._children_name_map["bundle_system_id"] = "bundle-system-id"
                        return self.bundle_system_id

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "actor-bundle-data" or name == "bundle-system-id" or name == "actor-operational-key" or name == "partner-operational-key" or name == "partner-system-mac-address" or name == "partner-system-priority"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "actor-operational-key"):
                        self.actor_operational_key = value
                        self.actor_operational_key.value_namespace = name_space
                        self.actor_operational_key.value_namespace_prefix = name_space_prefix
                    if(value_path == "partner-operational-key"):
                        self.partner_operational_key = value
                        self.partner_operational_key.value_namespace = name_space
                        self.partner_operational_key.value_namespace_prefix = name_space_prefix
                    if(value_path == "partner-system-mac-address"):
                        self.partner_system_mac_address = value
                        self.partner_system_mac_address.value_namespace = name_space
                        self.partner_system_mac_address.value_namespace_prefix = name_space_prefix
                    if(value_path == "partner-system-priority"):
                        self.partner_system_priority = value
                        self.partner_system_priority.value_namespace = name_space
                        self.partner_system_priority.value_namespace_prefix = name_space_prefix


            class Members(Entity):
                """
                LACP Member interface
                
                .. attribute:: member
                
                	Member information
                	**type**\: list of    :py:class:`Member <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.LacpBundles.Bundles.Bundle.Members.Member>`
                
                

                """

                _prefix = 'bundlemgr-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(LacpBundles.Bundles.Bundle.Members, self).__init__()

                    self.yang_name = "members"
                    self.yang_parent_name = "bundle"

                    self.member = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(LacpBundles.Bundles.Bundle.Members, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(LacpBundles.Bundles.Bundle.Members, self).__setattr__(name, value)


                class Member(Entity):
                    """
                    Member information
                    
                    .. attribute:: member_interface  <key>
                    
                    	Member interface
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: bandwidth
                    
                    	Bandwidth of this member (kbps)
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: kbit/s
                    
                    .. attribute:: counters
                    
                    	Counters data about member link
                    	**type**\:   :py:class:`Counters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.LacpBundles.Bundles.Bundle.Members.Member.Counters>`
                    
                    .. attribute:: iccp_node
                    
                    	Location of member
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: interface_name
                    
                    	Member's interface name
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: link_data
                    
                    	Lacp data about member link
                    	**type**\:   :py:class:`LinkData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.LacpBundles.Bundles.Bundle.Members.Member.LinkData>`
                    
                    .. attribute:: link_order_number
                    
                    	Member's link order number
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: mac_address
                    
                    	MAC address of this member (deprecated)
                    	**type**\:   :py:class:`MacAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.LacpBundles.Bundles.Bundle.Members.Member.MacAddress>`
                    
                    .. attribute:: member_mux_data
                    
                    	Mux state machine data
                    	**type**\:   :py:class:`MemberMuxData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.LacpBundles.Bundles.Bundle.Members.Member.MemberMuxData>`
                    
                    .. attribute:: member_name
                    
                    	Member's (short form) name
                    	**type**\:  str
                    
                    .. attribute:: member_type
                    
                    	Member's type (local/foreign)
                    	**type**\:   :py:class:`BmdMemberTypeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmdMemberTypeEnum>`
                    
                    .. attribute:: port_number
                    
                    	Member's link number
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: port_priority
                    
                    	The priority of this member
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: underlying_link_id
                    
                    	Member's underlying link ID
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'bundlemgr-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(LacpBundles.Bundles.Bundle.Members.Member, self).__init__()

                        self.yang_name = "member"
                        self.yang_parent_name = "members"

                        self.member_interface = YLeaf(YType.str, "member-interface")

                        self.bandwidth = YLeaf(YType.uint32, "bandwidth")

                        self.iccp_node = YLeaf(YType.uint32, "iccp-node")

                        self.interface_name = YLeaf(YType.str, "interface-name")

                        self.link_order_number = YLeaf(YType.uint16, "link-order-number")

                        self.member_name = YLeaf(YType.str, "member-name")

                        self.member_type = YLeaf(YType.enumeration, "member-type")

                        self.port_number = YLeaf(YType.uint16, "port-number")

                        self.port_priority = YLeaf(YType.uint16, "port-priority")

                        self.underlying_link_id = YLeaf(YType.uint16, "underlying-link-id")

                        self.counters = LacpBundles.Bundles.Bundle.Members.Member.Counters()
                        self.counters.parent = self
                        self._children_name_map["counters"] = "counters"
                        self._children_yang_names.add("counters")

                        self.link_data = LacpBundles.Bundles.Bundle.Members.Member.LinkData()
                        self.link_data.parent = self
                        self._children_name_map["link_data"] = "link-data"
                        self._children_yang_names.add("link-data")

                        self.mac_address = LacpBundles.Bundles.Bundle.Members.Member.MacAddress()
                        self.mac_address.parent = self
                        self._children_name_map["mac_address"] = "mac-address"
                        self._children_yang_names.add("mac-address")

                        self.member_mux_data = LacpBundles.Bundles.Bundle.Members.Member.MemberMuxData()
                        self.member_mux_data.parent = self
                        self._children_name_map["member_mux_data"] = "member-mux-data"
                        self._children_yang_names.add("member-mux-data")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("member_interface",
                                        "bandwidth",
                                        "iccp_node",
                                        "interface_name",
                                        "link_order_number",
                                        "member_name",
                                        "member_type",
                                        "port_number",
                                        "port_priority",
                                        "underlying_link_id") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(LacpBundles.Bundles.Bundle.Members.Member, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(LacpBundles.Bundles.Bundle.Members.Member, self).__setattr__(name, value)


                    class Counters(Entity):
                        """
                        Counters data about member link
                        
                        .. attribute:: defaulted
                        
                        	State flag set to Defaulted
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: excess_lacpd_us_received
                        
                        	LACPDUs received that exceed the rate limit
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: excess_marker_packets_received
                        
                        	Marker packets received that exceed the rate limit
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: expired
                        
                        	State flag set to Expired
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: illegal_packets_received
                        
                        	Illegal and unknown packets received
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: lacpd_us_received
                        
                        	LACPDUs received
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: lacpd_us_transmitted
                        
                        	LACPDUs transmitted
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: last_cleared_nsec
                        
                        	Last time counters cleared (nsec) (deprecated)
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: last_cleared_sec
                        
                        	Last time counters cleared (s) (deprecated)
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: marker_packets_received
                        
                        	Marker packets received
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: marker_responses_transmitted
                        
                        	Marker response packets transmitted
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'bundlemgr-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(LacpBundles.Bundles.Bundle.Members.Member.Counters, self).__init__()

                            self.yang_name = "counters"
                            self.yang_parent_name = "member"

                            self.defaulted = YLeaf(YType.uint32, "defaulted")

                            self.excess_lacpd_us_received = YLeaf(YType.uint32, "excess-lacpd-us-received")

                            self.excess_marker_packets_received = YLeaf(YType.uint32, "excess-marker-packets-received")

                            self.expired = YLeaf(YType.uint32, "expired")

                            self.illegal_packets_received = YLeaf(YType.uint32, "illegal-packets-received")

                            self.lacpd_us_received = YLeaf(YType.uint32, "lacpd-us-received")

                            self.lacpd_us_transmitted = YLeaf(YType.uint32, "lacpd-us-transmitted")

                            self.last_cleared_nsec = YLeaf(YType.uint32, "last-cleared-nsec")

                            self.last_cleared_sec = YLeaf(YType.uint32, "last-cleared-sec")

                            self.marker_packets_received = YLeaf(YType.uint32, "marker-packets-received")

                            self.marker_responses_transmitted = YLeaf(YType.uint32, "marker-responses-transmitted")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("defaulted",
                                            "excess_lacpd_us_received",
                                            "excess_marker_packets_received",
                                            "expired",
                                            "illegal_packets_received",
                                            "lacpd_us_received",
                                            "lacpd_us_transmitted",
                                            "last_cleared_nsec",
                                            "last_cleared_sec",
                                            "marker_packets_received",
                                            "marker_responses_transmitted") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(LacpBundles.Bundles.Bundle.Members.Member.Counters, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(LacpBundles.Bundles.Bundle.Members.Member.Counters, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.defaulted.is_set or
                                self.excess_lacpd_us_received.is_set or
                                self.excess_marker_packets_received.is_set or
                                self.expired.is_set or
                                self.illegal_packets_received.is_set or
                                self.lacpd_us_received.is_set or
                                self.lacpd_us_transmitted.is_set or
                                self.last_cleared_nsec.is_set or
                                self.last_cleared_sec.is_set or
                                self.marker_packets_received.is_set or
                                self.marker_responses_transmitted.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.defaulted.yfilter != YFilter.not_set or
                                self.excess_lacpd_us_received.yfilter != YFilter.not_set or
                                self.excess_marker_packets_received.yfilter != YFilter.not_set or
                                self.expired.yfilter != YFilter.not_set or
                                self.illegal_packets_received.yfilter != YFilter.not_set or
                                self.lacpd_us_received.yfilter != YFilter.not_set or
                                self.lacpd_us_transmitted.yfilter != YFilter.not_set or
                                self.last_cleared_nsec.yfilter != YFilter.not_set or
                                self.last_cleared_sec.yfilter != YFilter.not_set or
                                self.marker_packets_received.yfilter != YFilter.not_set or
                                self.marker_responses_transmitted.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "counters" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.defaulted.is_set or self.defaulted.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.defaulted.get_name_leafdata())
                            if (self.excess_lacpd_us_received.is_set or self.excess_lacpd_us_received.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.excess_lacpd_us_received.get_name_leafdata())
                            if (self.excess_marker_packets_received.is_set or self.excess_marker_packets_received.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.excess_marker_packets_received.get_name_leafdata())
                            if (self.expired.is_set or self.expired.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.expired.get_name_leafdata())
                            if (self.illegal_packets_received.is_set or self.illegal_packets_received.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.illegal_packets_received.get_name_leafdata())
                            if (self.lacpd_us_received.is_set or self.lacpd_us_received.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.lacpd_us_received.get_name_leafdata())
                            if (self.lacpd_us_transmitted.is_set or self.lacpd_us_transmitted.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.lacpd_us_transmitted.get_name_leafdata())
                            if (self.last_cleared_nsec.is_set or self.last_cleared_nsec.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.last_cleared_nsec.get_name_leafdata())
                            if (self.last_cleared_sec.is_set or self.last_cleared_sec.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.last_cleared_sec.get_name_leafdata())
                            if (self.marker_packets_received.is_set or self.marker_packets_received.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.marker_packets_received.get_name_leafdata())
                            if (self.marker_responses_transmitted.is_set or self.marker_responses_transmitted.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.marker_responses_transmitted.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "defaulted" or name == "excess-lacpd-us-received" or name == "excess-marker-packets-received" or name == "expired" or name == "illegal-packets-received" or name == "lacpd-us-received" or name == "lacpd-us-transmitted" or name == "last-cleared-nsec" or name == "last-cleared-sec" or name == "marker-packets-received" or name == "marker-responses-transmitted"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "defaulted"):
                                self.defaulted = value
                                self.defaulted.value_namespace = name_space
                                self.defaulted.value_namespace_prefix = name_space_prefix
                            if(value_path == "excess-lacpd-us-received"):
                                self.excess_lacpd_us_received = value
                                self.excess_lacpd_us_received.value_namespace = name_space
                                self.excess_lacpd_us_received.value_namespace_prefix = name_space_prefix
                            if(value_path == "excess-marker-packets-received"):
                                self.excess_marker_packets_received = value
                                self.excess_marker_packets_received.value_namespace = name_space
                                self.excess_marker_packets_received.value_namespace_prefix = name_space_prefix
                            if(value_path == "expired"):
                                self.expired = value
                                self.expired.value_namespace = name_space
                                self.expired.value_namespace_prefix = name_space_prefix
                            if(value_path == "illegal-packets-received"):
                                self.illegal_packets_received = value
                                self.illegal_packets_received.value_namespace = name_space
                                self.illegal_packets_received.value_namespace_prefix = name_space_prefix
                            if(value_path == "lacpd-us-received"):
                                self.lacpd_us_received = value
                                self.lacpd_us_received.value_namespace = name_space
                                self.lacpd_us_received.value_namespace_prefix = name_space_prefix
                            if(value_path == "lacpd-us-transmitted"):
                                self.lacpd_us_transmitted = value
                                self.lacpd_us_transmitted.value_namespace = name_space
                                self.lacpd_us_transmitted.value_namespace_prefix = name_space_prefix
                            if(value_path == "last-cleared-nsec"):
                                self.last_cleared_nsec = value
                                self.last_cleared_nsec.value_namespace = name_space
                                self.last_cleared_nsec.value_namespace_prefix = name_space_prefix
                            if(value_path == "last-cleared-sec"):
                                self.last_cleared_sec = value
                                self.last_cleared_sec.value_namespace = name_space
                                self.last_cleared_sec.value_namespace_prefix = name_space_prefix
                            if(value_path == "marker-packets-received"):
                                self.marker_packets_received = value
                                self.marker_packets_received.value_namespace = name_space
                                self.marker_packets_received.value_namespace_prefix = name_space_prefix
                            if(value_path == "marker-responses-transmitted"):
                                self.marker_responses_transmitted = value
                                self.marker_responses_transmitted.value_namespace = name_space
                                self.marker_responses_transmitted.value_namespace_prefix = name_space_prefix


                    class LinkData(Entity):
                        """
                        Lacp data about member link
                        
                        .. attribute:: actor_operational_key
                        
                        	Operational key for this port
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: actor_port_id
                        
                        	Port number of this port
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: actor_port_priority
                        
                        	Priority of this port
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: actor_port_state
                        
                        	LACP state of this port
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: actor_system_mac_address
                        
                        	MAC Address of the actor system
                        	**type**\:  str
                        
                        	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                        
                        .. attribute:: actor_system_priority
                        
                        	System priority of actor system
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: attached_aggregator_id
                        
                        	MIB ifindex of attached bundle
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: interface_handle
                        
                        	Member's interface handle
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: partner_operational_key
                        
                        	Operational key for partner port
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: partner_port_id
                        
                        	Port number of the partner's port
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: partner_port_priority
                        
                        	Priority of the partner's port
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: partner_port_state
                        
                        	LACP state of the partner's port
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: partner_system_mac_address
                        
                        	MAC Address used to identify the partner system
                        	**type**\:  str
                        
                        	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                        
                        .. attribute:: partner_system_priority
                        
                        	System priority of partner system
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: selected_aggregator_id
                        
                        	MIB ifindex of selected bundle
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'bundlemgr-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(LacpBundles.Bundles.Bundle.Members.Member.LinkData, self).__init__()

                            self.yang_name = "link-data"
                            self.yang_parent_name = "member"

                            self.actor_operational_key = YLeaf(YType.uint16, "actor-operational-key")

                            self.actor_port_id = YLeaf(YType.uint16, "actor-port-id")

                            self.actor_port_priority = YLeaf(YType.uint16, "actor-port-priority")

                            self.actor_port_state = YLeaf(YType.uint8, "actor-port-state")

                            self.actor_system_mac_address = YLeaf(YType.str, "actor-system-mac-address")

                            self.actor_system_priority = YLeaf(YType.uint16, "actor-system-priority")

                            self.attached_aggregator_id = YLeaf(YType.uint32, "attached-aggregator-id")

                            self.interface_handle = YLeaf(YType.str, "interface-handle")

                            self.partner_operational_key = YLeaf(YType.uint16, "partner-operational-key")

                            self.partner_port_id = YLeaf(YType.uint16, "partner-port-id")

                            self.partner_port_priority = YLeaf(YType.uint16, "partner-port-priority")

                            self.partner_port_state = YLeaf(YType.uint8, "partner-port-state")

                            self.partner_system_mac_address = YLeaf(YType.str, "partner-system-mac-address")

                            self.partner_system_priority = YLeaf(YType.uint16, "partner-system-priority")

                            self.selected_aggregator_id = YLeaf(YType.uint32, "selected-aggregator-id")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("actor_operational_key",
                                            "actor_port_id",
                                            "actor_port_priority",
                                            "actor_port_state",
                                            "actor_system_mac_address",
                                            "actor_system_priority",
                                            "attached_aggregator_id",
                                            "interface_handle",
                                            "partner_operational_key",
                                            "partner_port_id",
                                            "partner_port_priority",
                                            "partner_port_state",
                                            "partner_system_mac_address",
                                            "partner_system_priority",
                                            "selected_aggregator_id") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(LacpBundles.Bundles.Bundle.Members.Member.LinkData, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(LacpBundles.Bundles.Bundle.Members.Member.LinkData, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.actor_operational_key.is_set or
                                self.actor_port_id.is_set or
                                self.actor_port_priority.is_set or
                                self.actor_port_state.is_set or
                                self.actor_system_mac_address.is_set or
                                self.actor_system_priority.is_set or
                                self.attached_aggregator_id.is_set or
                                self.interface_handle.is_set or
                                self.partner_operational_key.is_set or
                                self.partner_port_id.is_set or
                                self.partner_port_priority.is_set or
                                self.partner_port_state.is_set or
                                self.partner_system_mac_address.is_set or
                                self.partner_system_priority.is_set or
                                self.selected_aggregator_id.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.actor_operational_key.yfilter != YFilter.not_set or
                                self.actor_port_id.yfilter != YFilter.not_set or
                                self.actor_port_priority.yfilter != YFilter.not_set or
                                self.actor_port_state.yfilter != YFilter.not_set or
                                self.actor_system_mac_address.yfilter != YFilter.not_set or
                                self.actor_system_priority.yfilter != YFilter.not_set or
                                self.attached_aggregator_id.yfilter != YFilter.not_set or
                                self.interface_handle.yfilter != YFilter.not_set or
                                self.partner_operational_key.yfilter != YFilter.not_set or
                                self.partner_port_id.yfilter != YFilter.not_set or
                                self.partner_port_priority.yfilter != YFilter.not_set or
                                self.partner_port_state.yfilter != YFilter.not_set or
                                self.partner_system_mac_address.yfilter != YFilter.not_set or
                                self.partner_system_priority.yfilter != YFilter.not_set or
                                self.selected_aggregator_id.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "link-data" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.actor_operational_key.is_set or self.actor_operational_key.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.actor_operational_key.get_name_leafdata())
                            if (self.actor_port_id.is_set or self.actor_port_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.actor_port_id.get_name_leafdata())
                            if (self.actor_port_priority.is_set or self.actor_port_priority.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.actor_port_priority.get_name_leafdata())
                            if (self.actor_port_state.is_set or self.actor_port_state.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.actor_port_state.get_name_leafdata())
                            if (self.actor_system_mac_address.is_set or self.actor_system_mac_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.actor_system_mac_address.get_name_leafdata())
                            if (self.actor_system_priority.is_set or self.actor_system_priority.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.actor_system_priority.get_name_leafdata())
                            if (self.attached_aggregator_id.is_set or self.attached_aggregator_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.attached_aggregator_id.get_name_leafdata())
                            if (self.interface_handle.is_set or self.interface_handle.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface_handle.get_name_leafdata())
                            if (self.partner_operational_key.is_set or self.partner_operational_key.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.partner_operational_key.get_name_leafdata())
                            if (self.partner_port_id.is_set or self.partner_port_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.partner_port_id.get_name_leafdata())
                            if (self.partner_port_priority.is_set or self.partner_port_priority.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.partner_port_priority.get_name_leafdata())
                            if (self.partner_port_state.is_set or self.partner_port_state.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.partner_port_state.get_name_leafdata())
                            if (self.partner_system_mac_address.is_set or self.partner_system_mac_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.partner_system_mac_address.get_name_leafdata())
                            if (self.partner_system_priority.is_set or self.partner_system_priority.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.partner_system_priority.get_name_leafdata())
                            if (self.selected_aggregator_id.is_set or self.selected_aggregator_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.selected_aggregator_id.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "actor-operational-key" or name == "actor-port-id" or name == "actor-port-priority" or name == "actor-port-state" or name == "actor-system-mac-address" or name == "actor-system-priority" or name == "attached-aggregator-id" or name == "interface-handle" or name == "partner-operational-key" or name == "partner-port-id" or name == "partner-port-priority" or name == "partner-port-state" or name == "partner-system-mac-address" or name == "partner-system-priority" or name == "selected-aggregator-id"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "actor-operational-key"):
                                self.actor_operational_key = value
                                self.actor_operational_key.value_namespace = name_space
                                self.actor_operational_key.value_namespace_prefix = name_space_prefix
                            if(value_path == "actor-port-id"):
                                self.actor_port_id = value
                                self.actor_port_id.value_namespace = name_space
                                self.actor_port_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "actor-port-priority"):
                                self.actor_port_priority = value
                                self.actor_port_priority.value_namespace = name_space
                                self.actor_port_priority.value_namespace_prefix = name_space_prefix
                            if(value_path == "actor-port-state"):
                                self.actor_port_state = value
                                self.actor_port_state.value_namespace = name_space
                                self.actor_port_state.value_namespace_prefix = name_space_prefix
                            if(value_path == "actor-system-mac-address"):
                                self.actor_system_mac_address = value
                                self.actor_system_mac_address.value_namespace = name_space
                                self.actor_system_mac_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "actor-system-priority"):
                                self.actor_system_priority = value
                                self.actor_system_priority.value_namespace = name_space
                                self.actor_system_priority.value_namespace_prefix = name_space_prefix
                            if(value_path == "attached-aggregator-id"):
                                self.attached_aggregator_id = value
                                self.attached_aggregator_id.value_namespace = name_space
                                self.attached_aggregator_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "interface-handle"):
                                self.interface_handle = value
                                self.interface_handle.value_namespace = name_space
                                self.interface_handle.value_namespace_prefix = name_space_prefix
                            if(value_path == "partner-operational-key"):
                                self.partner_operational_key = value
                                self.partner_operational_key.value_namespace = name_space
                                self.partner_operational_key.value_namespace_prefix = name_space_prefix
                            if(value_path == "partner-port-id"):
                                self.partner_port_id = value
                                self.partner_port_id.value_namespace = name_space
                                self.partner_port_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "partner-port-priority"):
                                self.partner_port_priority = value
                                self.partner_port_priority.value_namespace = name_space
                                self.partner_port_priority.value_namespace_prefix = name_space_prefix
                            if(value_path == "partner-port-state"):
                                self.partner_port_state = value
                                self.partner_port_state.value_namespace = name_space
                                self.partner_port_state.value_namespace_prefix = name_space_prefix
                            if(value_path == "partner-system-mac-address"):
                                self.partner_system_mac_address = value
                                self.partner_system_mac_address.value_namespace = name_space
                                self.partner_system_mac_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "partner-system-priority"):
                                self.partner_system_priority = value
                                self.partner_system_priority.value_namespace = name_space
                                self.partner_system_priority.value_namespace_prefix = name_space_prefix
                            if(value_path == "selected-aggregator-id"):
                                self.selected_aggregator_id = value
                                self.selected_aggregator_id.value_namespace = name_space
                                self.selected_aggregator_id.value_namespace_prefix = name_space_prefix


                    class MemberMuxData(Entity):
                        """
                        Mux state machine data
                        
                        .. attribute:: error
                        
                        	Internal value indicating if an error occurred trying to put a link into the desired state
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: member_mux_state_reason
                        
                        	Reason for last Mux state change
                        	**type**\:   :py:class:`BmMbrStateReason <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmMbrStateReason>`
                        
                        .. attribute:: member_mux_state_reason_data
                        
                        	Data regarding the reason for last Mux state change
                        	**type**\:   :py:class:`MemberMuxStateReasonData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.LacpBundles.Bundles.Bundle.Members.Member.MemberMuxData.MemberMuxStateReasonData>`
                        
                        .. attribute:: member_state
                        
                        	Current internal state of this bundle member
                        	**type**\:   :py:class:`BmdMemberState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmdMemberState>`
                        
                        .. attribute:: mux_state
                        
                        	Current state of this bundle member
                        	**type**\:   :py:class:`BmMuxstate <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmMuxstate>`
                        
                        .. attribute:: mux_state_reason
                        
                        	Reason for last Mux state change (Deprecated)
                        	**type**\:   :py:class:`BmMuxreason <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmMuxreason>`
                        
                        

                        """

                        _prefix = 'bundlemgr-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(LacpBundles.Bundles.Bundle.Members.Member.MemberMuxData, self).__init__()

                            self.yang_name = "member-mux-data"
                            self.yang_parent_name = "member"

                            self.error = YLeaf(YType.uint32, "error")

                            self.member_mux_state_reason = YLeaf(YType.enumeration, "member-mux-state-reason")

                            self.member_state = YLeaf(YType.enumeration, "member-state")

                            self.mux_state = YLeaf(YType.enumeration, "mux-state")

                            self.mux_state_reason = YLeaf(YType.enumeration, "mux-state-reason")

                            self.member_mux_state_reason_data = LacpBundles.Bundles.Bundle.Members.Member.MemberMuxData.MemberMuxStateReasonData()
                            self.member_mux_state_reason_data.parent = self
                            self._children_name_map["member_mux_state_reason_data"] = "member-mux-state-reason-data"
                            self._children_yang_names.add("member-mux-state-reason-data")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("error",
                                            "member_mux_state_reason",
                                            "member_state",
                                            "mux_state",
                                            "mux_state_reason") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(LacpBundles.Bundles.Bundle.Members.Member.MemberMuxData, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(LacpBundles.Bundles.Bundle.Members.Member.MemberMuxData, self).__setattr__(name, value)


                        class MemberMuxStateReasonData(Entity):
                            """
                            Data regarding the reason for last Mux state
                            change
                            
                            .. attribute:: reason_type
                            
                            	The item the reason applies to
                            	**type**\:   :py:class:`BmStateReasonTarget <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmStateReasonTarget>`
                            
                            .. attribute:: severity
                            
                            	The severity of the reason
                            	**type**\:   :py:class:`BmSeverity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmSeverity>`
                            
                            

                            """

                            _prefix = 'bundlemgr-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(LacpBundles.Bundles.Bundle.Members.Member.MemberMuxData.MemberMuxStateReasonData, self).__init__()

                                self.yang_name = "member-mux-state-reason-data"
                                self.yang_parent_name = "member-mux-data"

                                self.reason_type = YLeaf(YType.enumeration, "reason-type")

                                self.severity = YLeaf(YType.enumeration, "severity")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("reason_type",
                                                "severity") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(LacpBundles.Bundles.Bundle.Members.Member.MemberMuxData.MemberMuxStateReasonData, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(LacpBundles.Bundles.Bundle.Members.Member.MemberMuxData.MemberMuxStateReasonData, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.reason_type.is_set or
                                    self.severity.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.reason_type.yfilter != YFilter.not_set or
                                    self.severity.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "member-mux-state-reason-data" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.reason_type.is_set or self.reason_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.reason_type.get_name_leafdata())
                                if (self.severity.is_set or self.severity.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.severity.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "reason-type" or name == "severity"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "reason-type"):
                                    self.reason_type = value
                                    self.reason_type.value_namespace = name_space
                                    self.reason_type.value_namespace_prefix = name_space_prefix
                                if(value_path == "severity"):
                                    self.severity = value
                                    self.severity.value_namespace = name_space
                                    self.severity.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.error.is_set or
                                self.member_mux_state_reason.is_set or
                                self.member_state.is_set or
                                self.mux_state.is_set or
                                self.mux_state_reason.is_set or
                                (self.member_mux_state_reason_data is not None and self.member_mux_state_reason_data.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.error.yfilter != YFilter.not_set or
                                self.member_mux_state_reason.yfilter != YFilter.not_set or
                                self.member_state.yfilter != YFilter.not_set or
                                self.mux_state.yfilter != YFilter.not_set or
                                self.mux_state_reason.yfilter != YFilter.not_set or
                                (self.member_mux_state_reason_data is not None and self.member_mux_state_reason_data.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "member-mux-data" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.error.is_set or self.error.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.error.get_name_leafdata())
                            if (self.member_mux_state_reason.is_set or self.member_mux_state_reason.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.member_mux_state_reason.get_name_leafdata())
                            if (self.member_state.is_set or self.member_state.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.member_state.get_name_leafdata())
                            if (self.mux_state.is_set or self.mux_state.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mux_state.get_name_leafdata())
                            if (self.mux_state_reason.is_set or self.mux_state_reason.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mux_state_reason.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "member-mux-state-reason-data"):
                                if (self.member_mux_state_reason_data is None):
                                    self.member_mux_state_reason_data = LacpBundles.Bundles.Bundle.Members.Member.MemberMuxData.MemberMuxStateReasonData()
                                    self.member_mux_state_reason_data.parent = self
                                    self._children_name_map["member_mux_state_reason_data"] = "member-mux-state-reason-data"
                                return self.member_mux_state_reason_data

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "member-mux-state-reason-data" or name == "error" or name == "member-mux-state-reason" or name == "member-state" or name == "mux-state" or name == "mux-state-reason"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "error"):
                                self.error = value
                                self.error.value_namespace = name_space
                                self.error.value_namespace_prefix = name_space_prefix
                            if(value_path == "member-mux-state-reason"):
                                self.member_mux_state_reason = value
                                self.member_mux_state_reason.value_namespace = name_space
                                self.member_mux_state_reason.value_namespace_prefix = name_space_prefix
                            if(value_path == "member-state"):
                                self.member_state = value
                                self.member_state.value_namespace = name_space
                                self.member_state.value_namespace_prefix = name_space_prefix
                            if(value_path == "mux-state"):
                                self.mux_state = value
                                self.mux_state.value_namespace = name_space
                                self.mux_state.value_namespace_prefix = name_space_prefix
                            if(value_path == "mux-state-reason"):
                                self.mux_state_reason = value
                                self.mux_state_reason.value_namespace = name_space
                                self.mux_state_reason.value_namespace_prefix = name_space_prefix


                    class MacAddress(Entity):
                        """
                        MAC address of this member (deprecated)
                        
                        .. attribute:: address
                        
                        	MAC address
                        	**type**\:  str
                        
                        	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                        
                        

                        """

                        _prefix = 'bundlemgr-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(LacpBundles.Bundles.Bundle.Members.Member.MacAddress, self).__init__()

                            self.yang_name = "mac-address"
                            self.yang_parent_name = "member"

                            self.address = YLeaf(YType.str, "address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(LacpBundles.Bundles.Bundle.Members.Member.MacAddress, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(LacpBundles.Bundles.Bundle.Members.Member.MacAddress, self).__setattr__(name, value)

                        def has_data(self):
                            return self.address.is_set

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "mac-address" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.address.is_set or self.address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "address"):
                                self.address = value
                                self.address.value_namespace = name_space
                                self.address.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.member_interface.is_set or
                            self.bandwidth.is_set or
                            self.iccp_node.is_set or
                            self.interface_name.is_set or
                            self.link_order_number.is_set or
                            self.member_name.is_set or
                            self.member_type.is_set or
                            self.port_number.is_set or
                            self.port_priority.is_set or
                            self.underlying_link_id.is_set or
                            (self.counters is not None and self.counters.has_data()) or
                            (self.link_data is not None and self.link_data.has_data()) or
                            (self.mac_address is not None and self.mac_address.has_data()) or
                            (self.member_mux_data is not None and self.member_mux_data.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.member_interface.yfilter != YFilter.not_set or
                            self.bandwidth.yfilter != YFilter.not_set or
                            self.iccp_node.yfilter != YFilter.not_set or
                            self.interface_name.yfilter != YFilter.not_set or
                            self.link_order_number.yfilter != YFilter.not_set or
                            self.member_name.yfilter != YFilter.not_set or
                            self.member_type.yfilter != YFilter.not_set or
                            self.port_number.yfilter != YFilter.not_set or
                            self.port_priority.yfilter != YFilter.not_set or
                            self.underlying_link_id.yfilter != YFilter.not_set or
                            (self.counters is not None and self.counters.has_operation()) or
                            (self.link_data is not None and self.link_data.has_operation()) or
                            (self.mac_address is not None and self.mac_address.has_operation()) or
                            (self.member_mux_data is not None and self.member_mux_data.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "member" + "[member-interface='" + self.member_interface.get() + "']" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.member_interface.is_set or self.member_interface.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.member_interface.get_name_leafdata())
                        if (self.bandwidth.is_set or self.bandwidth.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bandwidth.get_name_leafdata())
                        if (self.iccp_node.is_set or self.iccp_node.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.iccp_node.get_name_leafdata())
                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_name.get_name_leafdata())
                        if (self.link_order_number.is_set or self.link_order_number.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.link_order_number.get_name_leafdata())
                        if (self.member_name.is_set or self.member_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.member_name.get_name_leafdata())
                        if (self.member_type.is_set or self.member_type.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.member_type.get_name_leafdata())
                        if (self.port_number.is_set or self.port_number.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.port_number.get_name_leafdata())
                        if (self.port_priority.is_set or self.port_priority.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.port_priority.get_name_leafdata())
                        if (self.underlying_link_id.is_set or self.underlying_link_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.underlying_link_id.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "counters"):
                            if (self.counters is None):
                                self.counters = LacpBundles.Bundles.Bundle.Members.Member.Counters()
                                self.counters.parent = self
                                self._children_name_map["counters"] = "counters"
                            return self.counters

                        if (child_yang_name == "link-data"):
                            if (self.link_data is None):
                                self.link_data = LacpBundles.Bundles.Bundle.Members.Member.LinkData()
                                self.link_data.parent = self
                                self._children_name_map["link_data"] = "link-data"
                            return self.link_data

                        if (child_yang_name == "mac-address"):
                            if (self.mac_address is None):
                                self.mac_address = LacpBundles.Bundles.Bundle.Members.Member.MacAddress()
                                self.mac_address.parent = self
                                self._children_name_map["mac_address"] = "mac-address"
                            return self.mac_address

                        if (child_yang_name == "member-mux-data"):
                            if (self.member_mux_data is None):
                                self.member_mux_data = LacpBundles.Bundles.Bundle.Members.Member.MemberMuxData()
                                self.member_mux_data.parent = self
                                self._children_name_map["member_mux_data"] = "member-mux-data"
                            return self.member_mux_data

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "counters" or name == "link-data" or name == "mac-address" or name == "member-mux-data" or name == "member-interface" or name == "bandwidth" or name == "iccp-node" or name == "interface-name" or name == "link-order-number" or name == "member-name" or name == "member-type" or name == "port-number" or name == "port-priority" or name == "underlying-link-id"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "member-interface"):
                            self.member_interface = value
                            self.member_interface.value_namespace = name_space
                            self.member_interface.value_namespace_prefix = name_space_prefix
                        if(value_path == "bandwidth"):
                            self.bandwidth = value
                            self.bandwidth.value_namespace = name_space
                            self.bandwidth.value_namespace_prefix = name_space_prefix
                        if(value_path == "iccp-node"):
                            self.iccp_node = value
                            self.iccp_node.value_namespace = name_space
                            self.iccp_node.value_namespace_prefix = name_space_prefix
                        if(value_path == "interface-name"):
                            self.interface_name = value
                            self.interface_name.value_namespace = name_space
                            self.interface_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "link-order-number"):
                            self.link_order_number = value
                            self.link_order_number.value_namespace = name_space
                            self.link_order_number.value_namespace_prefix = name_space_prefix
                        if(value_path == "member-name"):
                            self.member_name = value
                            self.member_name.value_namespace = name_space
                            self.member_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "member-type"):
                            self.member_type = value
                            self.member_type.value_namespace = name_space
                            self.member_type.value_namespace_prefix = name_space_prefix
                        if(value_path == "port-number"):
                            self.port_number = value
                            self.port_number.value_namespace = name_space
                            self.port_number.value_namespace_prefix = name_space_prefix
                        if(value_path == "port-priority"):
                            self.port_priority = value
                            self.port_priority.value_namespace = name_space
                            self.port_priority.value_namespace_prefix = name_space_prefix
                        if(value_path == "underlying-link-id"):
                            self.underlying_link_id = value
                            self.underlying_link_id.value_namespace = name_space
                            self.underlying_link_id.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.member:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.member:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "members" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "member"):
                        for c in self.member:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = LacpBundles.Bundles.Bundle.Members.Member()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.member.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "member"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass

            def has_data(self):
                return (
                    self.bundle_interface.is_set or
                    (self.data is not None and self.data.has_data()) or
                    (self.members is not None and self.members.has_data()))

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    self.bundle_interface.yfilter != YFilter.not_set or
                    (self.data is not None and self.data.has_operation()) or
                    (self.members is not None and self.members.has_operation()))

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "bundle" + "[bundle-interface='" + self.bundle_interface.get() + "']" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-bundlemgr-oper:lacp-bundles/bundles/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()
                if (self.bundle_interface.is_set or self.bundle_interface.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.bundle_interface.get_name_leafdata())

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "data"):
                    if (self.data is None):
                        self.data = LacpBundles.Bundles.Bundle.Data()
                        self.data.parent = self
                        self._children_name_map["data"] = "data"
                    return self.data

                if (child_yang_name == "members"):
                    if (self.members is None):
                        self.members = LacpBundles.Bundles.Bundle.Members()
                        self.members.parent = self
                        self._children_name_map["members"] = "members"
                    return self.members

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "data" or name == "members" or name == "bundle-interface"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                if(value_path == "bundle-interface"):
                    self.bundle_interface = value
                    self.bundle_interface.value_namespace = name_space
                    self.bundle_interface.value_namespace_prefix = name_space_prefix

        def has_data(self):
            for c in self.bundle:
                if (c.has_data()):
                    return True
            return False

        def has_operation(self):
            for c in self.bundle:
                if (c.has_operation()):
                    return True
            return self.yfilter != YFilter.not_set

        def get_segment_path(self):
            path_buffer = ""
            path_buffer = "bundles" + path_buffer

            return path_buffer

        def get_entity_path(self, ancestor):
            path_buffer = ""
            if (ancestor is None):
                path_buffer = "Cisco-IOS-XR-bundlemgr-oper:lacp-bundles/%s" % self.get_segment_path()
            else:
                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

            leaf_name_data = LeafDataList()

            entity_path = EntityPath(path_buffer, leaf_name_data)
            return entity_path

        def get_child_by_name(self, child_yang_name, segment_path):
            child = self._get_child_by_seg_name([child_yang_name, segment_path])
            if child is not None:
                return child

            if (child_yang_name == "bundle"):
                for c in self.bundle:
                    segment = c.get_segment_path()
                    if (segment_path == segment):
                        return c
                c = LacpBundles.Bundles.Bundle()
                c.parent = self
                local_reference_key = "ydk::seg::%s" % segment_path
                self._local_refs[local_reference_key] = c
                self.bundle.append(c)
                return c

            return None

        def has_leaf_or_child_of_name(self, name):
            if(name == "bundle"):
                return True
            return False

        def set_value(self, value_path, value, name_space, name_space_prefix):
            pass

    def has_data(self):
        return (self.bundles is not None and self.bundles.has_data())

    def has_operation(self):
        return (
            self.yfilter != YFilter.not_set or
            (self.bundles is not None and self.bundles.has_operation()))

    def get_segment_path(self):
        path_buffer = ""
        path_buffer = "Cisco-IOS-XR-bundlemgr-oper:lacp-bundles" + path_buffer

        return path_buffer

    def get_entity_path(self, ancestor):
        path_buffer = ""
        if (not ancestor is None):
            raise YPYModelError("ancestor has to be None for top-level node")

        path_buffer = self.get_segment_path()
        leaf_name_data = LeafDataList()

        entity_path = EntityPath(path_buffer, leaf_name_data)
        return entity_path

    def get_child_by_name(self, child_yang_name, segment_path):
        child = self._get_child_by_seg_name([child_yang_name, segment_path])
        if child is not None:
            return child

        if (child_yang_name == "bundles"):
            if (self.bundles is None):
                self.bundles = LacpBundles.Bundles()
                self.bundles.parent = self
                self._children_name_map["bundles"] = "bundles"
            return self.bundles

        return None

    def has_leaf_or_child_of_name(self, name):
        if(name == "bundles"):
            return True
        return False

    def set_value(self, value_path, value, name_space, name_space_prefix):
        pass

    def clone_ptr(self):
        self._top_entity = LacpBundles()
        return self._top_entity

class BundleInformation(Entity):
    """
    bundle information
    
    .. attribute:: bfd_counters
    
    	BFD counters information for bundles and members
    	**type**\:   :py:class:`BfdCounters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.BfdCounters>`
    
    .. attribute:: bundle
    
    	Generic information for bundles and members
    	**type**\:   :py:class:`Bundle <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.Bundle>`
    
    .. attribute:: bundle_briefs
    
    	Bundle interfaces with common bundle information
    	**type**\:   :py:class:`BundleBriefs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.BundleBriefs>`
    
    .. attribute:: events
    
    	Events information for bundles and members
    	**type**\:   :py:class:`Events <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.Events>`
    
    .. attribute:: events_bdl
    
    	Bundle events information for bundles and members
    	**type**\:   :py:class:`EventsBdl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.EventsBdl>`
    
    .. attribute:: events_mbr
    
    	Bundle member events information for bundles and members
    	**type**\:   :py:class:`EventsMbr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.EventsMbr>`
    
    .. attribute:: events_rg
    
    	Bundle ICCP events information for bundles and members
    	**type**\:   :py:class:`EventsRg <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.EventsRg>`
    
    .. attribute:: lacp
    
    	LACP information for bundles and members
    	**type**\:   :py:class:`Lacp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.Lacp>`
    
    .. attribute:: mac_allocation
    
    	Information about allocated MAC addresses that are not in use
    	**type**\:   :py:class:`MacAllocation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.MacAllocation>`
    
    .. attribute:: mlacp
    
    	mLACP Information for Interchassis Groups and bundles
    	**type**\:   :py:class:`Mlacp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.Mlacp>`
    
    .. attribute:: mlacp_brief
    
    	mLACP Information for Interchassis Groups and bundles
    	**type**\:   :py:class:`MlacpBrief <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.MlacpBrief>`
    
    .. attribute:: mlacp_bundle_counters
    
    	Bundle specific counters of mLACP events
    	**type**\:   :py:class:`MlacpBundleCounters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.MlacpBundleCounters>`
    
    .. attribute:: mlacp_iccp_group_counters
    
    	ICCP Group specific counters of mLACP events
    	**type**\:   :py:class:`MlacpIccpGroupCounters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.MlacpIccpGroupCounters>`
    
    .. attribute:: mlacp_member_counters
    
    	Member specific counters of mLACP events
    	**type**\:   :py:class:`MlacpMemberCounters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.MlacpMemberCounters>`
    
    .. attribute:: protect
    
    	Information for bundles and members that are in the protect database
    	**type**\:   :py:class:`Protect <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.Protect>`
    
    .. attribute:: scheduled_actions
    
    	Scheduled actions on a bundle
    	**type**\:   :py:class:`ScheduledActions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.ScheduledActions>`
    
    .. attribute:: system_id
    
    	System Identifiers for the local system and all ICCP Groups
    	**type**\:   :py:class:`SystemId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.SystemId>`
    
    

    """

    _prefix = 'bundlemgr-oper'
    _revision = '2015-11-09'

    def __init__(self):
        super(BundleInformation, self).__init__()
        self._top_entity = None

        self.yang_name = "bundle-information"
        self.yang_parent_name = "Cisco-IOS-XR-bundlemgr-oper"

        self.bfd_counters = BundleInformation.BfdCounters()
        self.bfd_counters.parent = self
        self._children_name_map["bfd_counters"] = "bfd-counters"
        self._children_yang_names.add("bfd-counters")

        self.bundle = BundleInformation.Bundle()
        self.bundle.parent = self
        self._children_name_map["bundle"] = "bundle"
        self._children_yang_names.add("bundle")

        self.bundle_briefs = BundleInformation.BundleBriefs()
        self.bundle_briefs.parent = self
        self._children_name_map["bundle_briefs"] = "bundle-briefs"
        self._children_yang_names.add("bundle-briefs")

        self.events = BundleInformation.Events()
        self.events.parent = self
        self._children_name_map["events"] = "events"
        self._children_yang_names.add("events")

        self.events_bdl = BundleInformation.EventsBdl()
        self.events_bdl.parent = self
        self._children_name_map["events_bdl"] = "events-bdl"
        self._children_yang_names.add("events-bdl")

        self.events_mbr = BundleInformation.EventsMbr()
        self.events_mbr.parent = self
        self._children_name_map["events_mbr"] = "events-mbr"
        self._children_yang_names.add("events-mbr")

        self.events_rg = BundleInformation.EventsRg()
        self.events_rg.parent = self
        self._children_name_map["events_rg"] = "events-rg"
        self._children_yang_names.add("events-rg")

        self.lacp = BundleInformation.Lacp()
        self.lacp.parent = self
        self._children_name_map["lacp"] = "lacp"
        self._children_yang_names.add("lacp")

        self.mac_allocation = BundleInformation.MacAllocation()
        self.mac_allocation.parent = self
        self._children_name_map["mac_allocation"] = "mac-allocation"
        self._children_yang_names.add("mac-allocation")

        self.mlacp = BundleInformation.Mlacp()
        self.mlacp.parent = self
        self._children_name_map["mlacp"] = "mlacp"
        self._children_yang_names.add("mlacp")

        self.mlacp_brief = BundleInformation.MlacpBrief()
        self.mlacp_brief.parent = self
        self._children_name_map["mlacp_brief"] = "mlacp-brief"
        self._children_yang_names.add("mlacp-brief")

        self.mlacp_bundle_counters = BundleInformation.MlacpBundleCounters()
        self.mlacp_bundle_counters.parent = self
        self._children_name_map["mlacp_bundle_counters"] = "mlacp-bundle-counters"
        self._children_yang_names.add("mlacp-bundle-counters")

        self.mlacp_iccp_group_counters = BundleInformation.MlacpIccpGroupCounters()
        self.mlacp_iccp_group_counters.parent = self
        self._children_name_map["mlacp_iccp_group_counters"] = "mlacp-iccp-group-counters"
        self._children_yang_names.add("mlacp-iccp-group-counters")

        self.mlacp_member_counters = BundleInformation.MlacpMemberCounters()
        self.mlacp_member_counters.parent = self
        self._children_name_map["mlacp_member_counters"] = "mlacp-member-counters"
        self._children_yang_names.add("mlacp-member-counters")

        self.protect = BundleInformation.Protect()
        self.protect.parent = self
        self._children_name_map["protect"] = "protect"
        self._children_yang_names.add("protect")

        self.scheduled_actions = BundleInformation.ScheduledActions()
        self.scheduled_actions.parent = self
        self._children_name_map["scheduled_actions"] = "scheduled-actions"
        self._children_yang_names.add("scheduled-actions")

        self.system_id = BundleInformation.SystemId()
        self.system_id.parent = self
        self._children_name_map["system_id"] = "system-id"
        self._children_yang_names.add("system-id")


    class BfdCounters(Entity):
        """
        BFD counters information for bundles and members
        
        .. attribute:: bfd_counters_bundles
        
        	Bundle interfaces with BFD counters information
        	**type**\:   :py:class:`BfdCountersBundles <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.BfdCounters.BfdCountersBundles>`
        
        .. attribute:: bfd_counters_members
        
        	Member interfaces with BFD counters information
        	**type**\:   :py:class:`BfdCountersMembers <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.BfdCounters.BfdCountersMembers>`
        
        

        """

        _prefix = 'bundlemgr-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(BundleInformation.BfdCounters, self).__init__()

            self.yang_name = "bfd-counters"
            self.yang_parent_name = "bundle-information"

            self.bfd_counters_bundles = BundleInformation.BfdCounters.BfdCountersBundles()
            self.bfd_counters_bundles.parent = self
            self._children_name_map["bfd_counters_bundles"] = "bfd-counters-bundles"
            self._children_yang_names.add("bfd-counters-bundles")

            self.bfd_counters_members = BundleInformation.BfdCounters.BfdCountersMembers()
            self.bfd_counters_members.parent = self
            self._children_name_map["bfd_counters_members"] = "bfd-counters-members"
            self._children_yang_names.add("bfd-counters-members")


        class BfdCountersBundles(Entity):
            """
            Bundle interfaces with BFD counters information
            
            .. attribute:: bfd_counters_bundle
            
            	Bundle interface
            	**type**\: list of    :py:class:`BfdCountersBundle <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.BfdCounters.BfdCountersBundles.BfdCountersBundle>`
            
            

            """

            _prefix = 'bundlemgr-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(BundleInformation.BfdCounters.BfdCountersBundles, self).__init__()

                self.yang_name = "bfd-counters-bundles"
                self.yang_parent_name = "bfd-counters"

                self.bfd_counters_bundle = YList(self)

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in () and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(BundleInformation.BfdCounters.BfdCountersBundles, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(BundleInformation.BfdCounters.BfdCountersBundles, self).__setattr__(name, value)


            class BfdCountersBundle(Entity):
                """
                Bundle interface
                
                .. attribute:: bundle_interface  <key>
                
                	Bundle interface
                	**type**\:  str
                
                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                
                .. attribute:: bfd_counters_bundle_children_members
                
                	Children of bundle with BFD counters information
                	**type**\:   :py:class:`BfdCountersBundleChildrenMembers <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.BfdCounters.BfdCountersBundles.BfdCountersBundle.BfdCountersBundleChildrenMembers>`
                
                .. attribute:: bfd_counters_bundle_descendant
                
                	Data for this item and all its members
                	**type**\:   :py:class:`BfdCountersBundleDescendant <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.BfdCounters.BfdCountersBundles.BfdCountersBundle.BfdCountersBundleDescendant>`
                
                .. attribute:: bfd_counters_bundle_item
                
                	Data for this item
                	**type**\:   :py:class:`BfdCountersBundleItem <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.BfdCounters.BfdCountersBundles.BfdCountersBundle.BfdCountersBundleItem>`
                
                

                """

                _prefix = 'bundlemgr-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(BundleInformation.BfdCounters.BfdCountersBundles.BfdCountersBundle, self).__init__()

                    self.yang_name = "bfd-counters-bundle"
                    self.yang_parent_name = "bfd-counters-bundles"

                    self.bundle_interface = YLeaf(YType.str, "bundle-interface")

                    self.bfd_counters_bundle_children_members = BundleInformation.BfdCounters.BfdCountersBundles.BfdCountersBundle.BfdCountersBundleChildrenMembers()
                    self.bfd_counters_bundle_children_members.parent = self
                    self._children_name_map["bfd_counters_bundle_children_members"] = "bfd-counters-bundle-children-members"
                    self._children_yang_names.add("bfd-counters-bundle-children-members")

                    self.bfd_counters_bundle_descendant = BundleInformation.BfdCounters.BfdCountersBundles.BfdCountersBundle.BfdCountersBundleDescendant()
                    self.bfd_counters_bundle_descendant.parent = self
                    self._children_name_map["bfd_counters_bundle_descendant"] = "bfd-counters-bundle-descendant"
                    self._children_yang_names.add("bfd-counters-bundle-descendant")

                    self.bfd_counters_bundle_item = BundleInformation.BfdCounters.BfdCountersBundles.BfdCountersBundle.BfdCountersBundleItem()
                    self.bfd_counters_bundle_item.parent = self
                    self._children_name_map["bfd_counters_bundle_item"] = "bfd-counters-bundle-item"
                    self._children_yang_names.add("bfd-counters-bundle-item")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("bundle_interface") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(BundleInformation.BfdCounters.BfdCountersBundles.BfdCountersBundle, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(BundleInformation.BfdCounters.BfdCountersBundles.BfdCountersBundle, self).__setattr__(name, value)


                class BfdCountersBundleDescendant(Entity):
                    """
                    Data for this item and all its members
                    
                    .. attribute:: bfd_counter
                    
                    	BFD event counters
                    	**type**\: list of    :py:class:`BfdCounter <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.BfdCounters.BfdCountersBundles.BfdCountersBundle.BfdCountersBundleDescendant.BfdCounter>`
                    
                    .. attribute:: bundle_name
                    
                    	Name of the bundle this information is for
                    	**type**\:   :py:class:`BundleName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.BfdCounters.BfdCountersBundles.BfdCountersBundle.BfdCountersBundleDescendant.BundleName>`
                    
                    

                    """

                    _prefix = 'bundlemgr-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(BundleInformation.BfdCounters.BfdCountersBundles.BfdCountersBundle.BfdCountersBundleDescendant, self).__init__()

                        self.yang_name = "bfd-counters-bundle-descendant"
                        self.yang_parent_name = "bfd-counters-bundle"

                        self.bundle_name = BundleInformation.BfdCounters.BfdCountersBundles.BfdCountersBundle.BfdCountersBundleDescendant.BundleName()
                        self.bundle_name.parent = self
                        self._children_name_map["bundle_name"] = "bundle-name"
                        self._children_yang_names.add("bundle-name")

                        self.bfd_counter = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(BundleInformation.BfdCounters.BfdCountersBundles.BfdCountersBundle.BfdCountersBundleDescendant, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(BundleInformation.BfdCounters.BfdCountersBundles.BfdCountersBundle.BfdCountersBundleDescendant, self).__setattr__(name, value)


                    class BundleName(Entity):
                        """
                        Name of the bundle this information is for
                        
                        .. attribute:: item_name
                        
                        	Name of item
                        	**type**\:  str
                        
                        

                        """

                        _prefix = 'bundlemgr-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(BundleInformation.BfdCounters.BfdCountersBundles.BfdCountersBundle.BfdCountersBundleDescendant.BundleName, self).__init__()

                            self.yang_name = "bundle-name"
                            self.yang_parent_name = "bfd-counters-bundle-descendant"

                            self.item_name = YLeaf(YType.str, "item-name")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("item_name") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(BundleInformation.BfdCounters.BfdCountersBundles.BfdCountersBundle.BfdCountersBundleDescendant.BundleName, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(BundleInformation.BfdCounters.BfdCountersBundles.BfdCountersBundle.BfdCountersBundleDescendant.BundleName, self).__setattr__(name, value)

                        def has_data(self):
                            return self.item_name.is_set

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.item_name.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "bundle-name" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.item_name.is_set or self.item_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.item_name.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "item-name"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "item-name"):
                                self.item_name = value
                                self.item_name.value_namespace = name_space
                                self.item_name.value_namespace_prefix = name_space_prefix


                    class BfdCounter(Entity):
                        """
                        BFD event counters
                        
                        .. attribute:: down
                        
                        	Number of times member state changed to down
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: last_time_cleared
                        
                        	Timestamp when counters were last cleared (deprecated)
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: member_name
                        
                        	Name of the member this information is for
                        	**type**\:  str
                        
                        .. attribute:: neighbor_unconfigured
                        
                        	Number of times member state changed to neighbor unconfigured
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: neighbor_unconfigured_timeouts
                        
                        	Number of timeouts waiting for neighbor to become unconfigured
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: start_timeouts
                        
                        	Number of timeouts waiting for BFD to start
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: starting
                        
                        	Number of times member state changed to starting
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: time_since_cleared
                        
                        	Elapsed time in nsecs since counters were last cleared
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: nanosecond
                        
                        .. attribute:: up
                        
                        	Number of times member state changed to up
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'bundlemgr-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(BundleInformation.BfdCounters.BfdCountersBundles.BfdCountersBundle.BfdCountersBundleDescendant.BfdCounter, self).__init__()

                            self.yang_name = "bfd-counter"
                            self.yang_parent_name = "bfd-counters-bundle-descendant"

                            self.down = YLeaf(YType.uint32, "down")

                            self.last_time_cleared = YLeaf(YType.uint64, "last-time-cleared")

                            self.member_name = YLeaf(YType.str, "member-name")

                            self.neighbor_unconfigured = YLeaf(YType.uint32, "neighbor-unconfigured")

                            self.neighbor_unconfigured_timeouts = YLeaf(YType.uint32, "neighbor-unconfigured-timeouts")

                            self.start_timeouts = YLeaf(YType.uint32, "start-timeouts")

                            self.starting = YLeaf(YType.uint32, "starting")

                            self.time_since_cleared = YLeaf(YType.uint64, "time-since-cleared")

                            self.up = YLeaf(YType.uint32, "up")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("down",
                                            "last_time_cleared",
                                            "member_name",
                                            "neighbor_unconfigured",
                                            "neighbor_unconfigured_timeouts",
                                            "start_timeouts",
                                            "starting",
                                            "time_since_cleared",
                                            "up") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(BundleInformation.BfdCounters.BfdCountersBundles.BfdCountersBundle.BfdCountersBundleDescendant.BfdCounter, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(BundleInformation.BfdCounters.BfdCountersBundles.BfdCountersBundle.BfdCountersBundleDescendant.BfdCounter, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.down.is_set or
                                self.last_time_cleared.is_set or
                                self.member_name.is_set or
                                self.neighbor_unconfigured.is_set or
                                self.neighbor_unconfigured_timeouts.is_set or
                                self.start_timeouts.is_set or
                                self.starting.is_set or
                                self.time_since_cleared.is_set or
                                self.up.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.down.yfilter != YFilter.not_set or
                                self.last_time_cleared.yfilter != YFilter.not_set or
                                self.member_name.yfilter != YFilter.not_set or
                                self.neighbor_unconfigured.yfilter != YFilter.not_set or
                                self.neighbor_unconfigured_timeouts.yfilter != YFilter.not_set or
                                self.start_timeouts.yfilter != YFilter.not_set or
                                self.starting.yfilter != YFilter.not_set or
                                self.time_since_cleared.yfilter != YFilter.not_set or
                                self.up.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "bfd-counter" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.down.is_set or self.down.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.down.get_name_leafdata())
                            if (self.last_time_cleared.is_set or self.last_time_cleared.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.last_time_cleared.get_name_leafdata())
                            if (self.member_name.is_set or self.member_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.member_name.get_name_leafdata())
                            if (self.neighbor_unconfigured.is_set or self.neighbor_unconfigured.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.neighbor_unconfigured.get_name_leafdata())
                            if (self.neighbor_unconfigured_timeouts.is_set or self.neighbor_unconfigured_timeouts.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.neighbor_unconfigured_timeouts.get_name_leafdata())
                            if (self.start_timeouts.is_set or self.start_timeouts.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.start_timeouts.get_name_leafdata())
                            if (self.starting.is_set or self.starting.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.starting.get_name_leafdata())
                            if (self.time_since_cleared.is_set or self.time_since_cleared.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.time_since_cleared.get_name_leafdata())
                            if (self.up.is_set or self.up.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.up.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "down" or name == "last-time-cleared" or name == "member-name" or name == "neighbor-unconfigured" or name == "neighbor-unconfigured-timeouts" or name == "start-timeouts" or name == "starting" or name == "time-since-cleared" or name == "up"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "down"):
                                self.down = value
                                self.down.value_namespace = name_space
                                self.down.value_namespace_prefix = name_space_prefix
                            if(value_path == "last-time-cleared"):
                                self.last_time_cleared = value
                                self.last_time_cleared.value_namespace = name_space
                                self.last_time_cleared.value_namespace_prefix = name_space_prefix
                            if(value_path == "member-name"):
                                self.member_name = value
                                self.member_name.value_namespace = name_space
                                self.member_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "neighbor-unconfigured"):
                                self.neighbor_unconfigured = value
                                self.neighbor_unconfigured.value_namespace = name_space
                                self.neighbor_unconfigured.value_namespace_prefix = name_space_prefix
                            if(value_path == "neighbor-unconfigured-timeouts"):
                                self.neighbor_unconfigured_timeouts = value
                                self.neighbor_unconfigured_timeouts.value_namespace = name_space
                                self.neighbor_unconfigured_timeouts.value_namespace_prefix = name_space_prefix
                            if(value_path == "start-timeouts"):
                                self.start_timeouts = value
                                self.start_timeouts.value_namespace = name_space
                                self.start_timeouts.value_namespace_prefix = name_space_prefix
                            if(value_path == "starting"):
                                self.starting = value
                                self.starting.value_namespace = name_space
                                self.starting.value_namespace_prefix = name_space_prefix
                            if(value_path == "time-since-cleared"):
                                self.time_since_cleared = value
                                self.time_since_cleared.value_namespace = name_space
                                self.time_since_cleared.value_namespace_prefix = name_space_prefix
                            if(value_path == "up"):
                                self.up = value
                                self.up.value_namespace = name_space
                                self.up.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.bfd_counter:
                            if (c.has_data()):
                                return True
                        return (self.bundle_name is not None and self.bundle_name.has_data())

                    def has_operation(self):
                        for c in self.bfd_counter:
                            if (c.has_operation()):
                                return True
                        return (
                            self.yfilter != YFilter.not_set or
                            (self.bundle_name is not None and self.bundle_name.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "bfd-counters-bundle-descendant" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "bfd-counter"):
                            for c in self.bfd_counter:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = BundleInformation.BfdCounters.BfdCountersBundles.BfdCountersBundle.BfdCountersBundleDescendant.BfdCounter()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.bfd_counter.append(c)
                            return c

                        if (child_yang_name == "bundle-name"):
                            if (self.bundle_name is None):
                                self.bundle_name = BundleInformation.BfdCounters.BfdCountersBundles.BfdCountersBundle.BfdCountersBundleDescendant.BundleName()
                                self.bundle_name.parent = self
                                self._children_name_map["bundle_name"] = "bundle-name"
                            return self.bundle_name

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "bfd-counter" or name == "bundle-name"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class BfdCountersBundleChildrenMembers(Entity):
                    """
                    Children of bundle with BFD counters
                    information
                    
                    .. attribute:: bfd_counters_bundle_children_member
                    
                    	Bundle member item with BFD counters information
                    	**type**\: list of    :py:class:`BfdCountersBundleChildrenMember <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.BfdCounters.BfdCountersBundles.BfdCountersBundle.BfdCountersBundleChildrenMembers.BfdCountersBundleChildrenMember>`
                    
                    

                    """

                    _prefix = 'bundlemgr-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(BundleInformation.BfdCounters.BfdCountersBundles.BfdCountersBundle.BfdCountersBundleChildrenMembers, self).__init__()

                        self.yang_name = "bfd-counters-bundle-children-members"
                        self.yang_parent_name = "bfd-counters-bundle"

                        self.bfd_counters_bundle_children_member = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(BundleInformation.BfdCounters.BfdCountersBundles.BfdCountersBundle.BfdCountersBundleChildrenMembers, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(BundleInformation.BfdCounters.BfdCountersBundles.BfdCountersBundle.BfdCountersBundleChildrenMembers, self).__setattr__(name, value)


                    class BfdCountersBundleChildrenMember(Entity):
                        """
                        Bundle member item with BFD counters
                        information
                        
                        .. attribute:: member_interface  <key>
                        
                        	Member interface
                        	**type**\:  str
                        
                        .. attribute:: down
                        
                        	Number of times member state changed to down
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: last_time_cleared
                        
                        	Timestamp when counters were last cleared (deprecated)
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: member_name
                        
                        	Name of the member this information is for
                        	**type**\:  str
                        
                        .. attribute:: neighbor_unconfigured
                        
                        	Number of times member state changed to neighbor unconfigured
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: neighbor_unconfigured_timeouts
                        
                        	Number of timeouts waiting for neighbor to become unconfigured
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: start_timeouts
                        
                        	Number of timeouts waiting for BFD to start
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: starting
                        
                        	Number of times member state changed to starting
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: time_since_cleared
                        
                        	Elapsed time in nsecs since counters were last cleared
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: nanosecond
                        
                        .. attribute:: up
                        
                        	Number of times member state changed to up
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'bundlemgr-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(BundleInformation.BfdCounters.BfdCountersBundles.BfdCountersBundle.BfdCountersBundleChildrenMembers.BfdCountersBundleChildrenMember, self).__init__()

                            self.yang_name = "bfd-counters-bundle-children-member"
                            self.yang_parent_name = "bfd-counters-bundle-children-members"

                            self.member_interface = YLeaf(YType.str, "member-interface")

                            self.down = YLeaf(YType.uint32, "down")

                            self.last_time_cleared = YLeaf(YType.uint64, "last-time-cleared")

                            self.member_name = YLeaf(YType.str, "member-name")

                            self.neighbor_unconfigured = YLeaf(YType.uint32, "neighbor-unconfigured")

                            self.neighbor_unconfigured_timeouts = YLeaf(YType.uint32, "neighbor-unconfigured-timeouts")

                            self.start_timeouts = YLeaf(YType.uint32, "start-timeouts")

                            self.starting = YLeaf(YType.uint32, "starting")

                            self.time_since_cleared = YLeaf(YType.uint64, "time-since-cleared")

                            self.up = YLeaf(YType.uint32, "up")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("member_interface",
                                            "down",
                                            "last_time_cleared",
                                            "member_name",
                                            "neighbor_unconfigured",
                                            "neighbor_unconfigured_timeouts",
                                            "start_timeouts",
                                            "starting",
                                            "time_since_cleared",
                                            "up") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(BundleInformation.BfdCounters.BfdCountersBundles.BfdCountersBundle.BfdCountersBundleChildrenMembers.BfdCountersBundleChildrenMember, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(BundleInformation.BfdCounters.BfdCountersBundles.BfdCountersBundle.BfdCountersBundleChildrenMembers.BfdCountersBundleChildrenMember, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.member_interface.is_set or
                                self.down.is_set or
                                self.last_time_cleared.is_set or
                                self.member_name.is_set or
                                self.neighbor_unconfigured.is_set or
                                self.neighbor_unconfigured_timeouts.is_set or
                                self.start_timeouts.is_set or
                                self.starting.is_set or
                                self.time_since_cleared.is_set or
                                self.up.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.member_interface.yfilter != YFilter.not_set or
                                self.down.yfilter != YFilter.not_set or
                                self.last_time_cleared.yfilter != YFilter.not_set or
                                self.member_name.yfilter != YFilter.not_set or
                                self.neighbor_unconfigured.yfilter != YFilter.not_set or
                                self.neighbor_unconfigured_timeouts.yfilter != YFilter.not_set or
                                self.start_timeouts.yfilter != YFilter.not_set or
                                self.starting.yfilter != YFilter.not_set or
                                self.time_since_cleared.yfilter != YFilter.not_set or
                                self.up.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "bfd-counters-bundle-children-member" + "[member-interface='" + self.member_interface.get() + "']" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.member_interface.is_set or self.member_interface.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.member_interface.get_name_leafdata())
                            if (self.down.is_set or self.down.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.down.get_name_leafdata())
                            if (self.last_time_cleared.is_set or self.last_time_cleared.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.last_time_cleared.get_name_leafdata())
                            if (self.member_name.is_set or self.member_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.member_name.get_name_leafdata())
                            if (self.neighbor_unconfigured.is_set or self.neighbor_unconfigured.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.neighbor_unconfigured.get_name_leafdata())
                            if (self.neighbor_unconfigured_timeouts.is_set or self.neighbor_unconfigured_timeouts.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.neighbor_unconfigured_timeouts.get_name_leafdata())
                            if (self.start_timeouts.is_set or self.start_timeouts.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.start_timeouts.get_name_leafdata())
                            if (self.starting.is_set or self.starting.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.starting.get_name_leafdata())
                            if (self.time_since_cleared.is_set or self.time_since_cleared.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.time_since_cleared.get_name_leafdata())
                            if (self.up.is_set or self.up.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.up.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "member-interface" or name == "down" or name == "last-time-cleared" or name == "member-name" or name == "neighbor-unconfigured" or name == "neighbor-unconfigured-timeouts" or name == "start-timeouts" or name == "starting" or name == "time-since-cleared" or name == "up"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "member-interface"):
                                self.member_interface = value
                                self.member_interface.value_namespace = name_space
                                self.member_interface.value_namespace_prefix = name_space_prefix
                            if(value_path == "down"):
                                self.down = value
                                self.down.value_namespace = name_space
                                self.down.value_namespace_prefix = name_space_prefix
                            if(value_path == "last-time-cleared"):
                                self.last_time_cleared = value
                                self.last_time_cleared.value_namespace = name_space
                                self.last_time_cleared.value_namespace_prefix = name_space_prefix
                            if(value_path == "member-name"):
                                self.member_name = value
                                self.member_name.value_namespace = name_space
                                self.member_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "neighbor-unconfigured"):
                                self.neighbor_unconfigured = value
                                self.neighbor_unconfigured.value_namespace = name_space
                                self.neighbor_unconfigured.value_namespace_prefix = name_space_prefix
                            if(value_path == "neighbor-unconfigured-timeouts"):
                                self.neighbor_unconfigured_timeouts = value
                                self.neighbor_unconfigured_timeouts.value_namespace = name_space
                                self.neighbor_unconfigured_timeouts.value_namespace_prefix = name_space_prefix
                            if(value_path == "start-timeouts"):
                                self.start_timeouts = value
                                self.start_timeouts.value_namespace = name_space
                                self.start_timeouts.value_namespace_prefix = name_space_prefix
                            if(value_path == "starting"):
                                self.starting = value
                                self.starting.value_namespace = name_space
                                self.starting.value_namespace_prefix = name_space_prefix
                            if(value_path == "time-since-cleared"):
                                self.time_since_cleared = value
                                self.time_since_cleared.value_namespace = name_space
                                self.time_since_cleared.value_namespace_prefix = name_space_prefix
                            if(value_path == "up"):
                                self.up = value
                                self.up.value_namespace = name_space
                                self.up.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.bfd_counters_bundle_children_member:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.bfd_counters_bundle_children_member:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "bfd-counters-bundle-children-members" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "bfd-counters-bundle-children-member"):
                            for c in self.bfd_counters_bundle_children_member:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = BundleInformation.BfdCounters.BfdCountersBundles.BfdCountersBundle.BfdCountersBundleChildrenMembers.BfdCountersBundleChildrenMember()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.bfd_counters_bundle_children_member.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "bfd-counters-bundle-children-member"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class BfdCountersBundleItem(Entity):
                    """
                    Data for this item
                    
                    .. attribute:: item_name
                    
                    	Name of item
                    	**type**\:  str
                    
                    

                    """

                    _prefix = 'bundlemgr-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(BundleInformation.BfdCounters.BfdCountersBundles.BfdCountersBundle.BfdCountersBundleItem, self).__init__()

                        self.yang_name = "bfd-counters-bundle-item"
                        self.yang_parent_name = "bfd-counters-bundle"

                        self.item_name = YLeaf(YType.str, "item-name")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("item_name") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(BundleInformation.BfdCounters.BfdCountersBundles.BfdCountersBundle.BfdCountersBundleItem, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(BundleInformation.BfdCounters.BfdCountersBundles.BfdCountersBundle.BfdCountersBundleItem, self).__setattr__(name, value)

                    def has_data(self):
                        return self.item_name.is_set

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.item_name.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "bfd-counters-bundle-item" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.item_name.is_set or self.item_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.item_name.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "item-name"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "item-name"):
                            self.item_name = value
                            self.item_name.value_namespace = name_space
                            self.item_name.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    return (
                        self.bundle_interface.is_set or
                        (self.bfd_counters_bundle_children_members is not None and self.bfd_counters_bundle_children_members.has_data()) or
                        (self.bfd_counters_bundle_descendant is not None and self.bfd_counters_bundle_descendant.has_data()) or
                        (self.bfd_counters_bundle_item is not None and self.bfd_counters_bundle_item.has_data()))

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.bundle_interface.yfilter != YFilter.not_set or
                        (self.bfd_counters_bundle_children_members is not None and self.bfd_counters_bundle_children_members.has_operation()) or
                        (self.bfd_counters_bundle_descendant is not None and self.bfd_counters_bundle_descendant.has_operation()) or
                        (self.bfd_counters_bundle_item is not None and self.bfd_counters_bundle_item.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "bfd-counters-bundle" + "[bundle-interface='" + self.bundle_interface.get() + "']" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-bundlemgr-oper:bundle-information/bfd-counters/bfd-counters-bundles/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.bundle_interface.is_set or self.bundle_interface.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.bundle_interface.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "bfd-counters-bundle-children-members"):
                        if (self.bfd_counters_bundle_children_members is None):
                            self.bfd_counters_bundle_children_members = BundleInformation.BfdCounters.BfdCountersBundles.BfdCountersBundle.BfdCountersBundleChildrenMembers()
                            self.bfd_counters_bundle_children_members.parent = self
                            self._children_name_map["bfd_counters_bundle_children_members"] = "bfd-counters-bundle-children-members"
                        return self.bfd_counters_bundle_children_members

                    if (child_yang_name == "bfd-counters-bundle-descendant"):
                        if (self.bfd_counters_bundle_descendant is None):
                            self.bfd_counters_bundle_descendant = BundleInformation.BfdCounters.BfdCountersBundles.BfdCountersBundle.BfdCountersBundleDescendant()
                            self.bfd_counters_bundle_descendant.parent = self
                            self._children_name_map["bfd_counters_bundle_descendant"] = "bfd-counters-bundle-descendant"
                        return self.bfd_counters_bundle_descendant

                    if (child_yang_name == "bfd-counters-bundle-item"):
                        if (self.bfd_counters_bundle_item is None):
                            self.bfd_counters_bundle_item = BundleInformation.BfdCounters.BfdCountersBundles.BfdCountersBundle.BfdCountersBundleItem()
                            self.bfd_counters_bundle_item.parent = self
                            self._children_name_map["bfd_counters_bundle_item"] = "bfd-counters-bundle-item"
                        return self.bfd_counters_bundle_item

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "bfd-counters-bundle-children-members" or name == "bfd-counters-bundle-descendant" or name == "bfd-counters-bundle-item" or name == "bundle-interface"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "bundle-interface"):
                        self.bundle_interface = value
                        self.bundle_interface.value_namespace = name_space
                        self.bundle_interface.value_namespace_prefix = name_space_prefix

            def has_data(self):
                for c in self.bfd_counters_bundle:
                    if (c.has_data()):
                        return True
                return False

            def has_operation(self):
                for c in self.bfd_counters_bundle:
                    if (c.has_operation()):
                        return True
                return self.yfilter != YFilter.not_set

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "bfd-counters-bundles" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-bundlemgr-oper:bundle-information/bfd-counters/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "bfd-counters-bundle"):
                    for c in self.bfd_counters_bundle:
                        segment = c.get_segment_path()
                        if (segment_path == segment):
                            return c
                    c = BundleInformation.BfdCounters.BfdCountersBundles.BfdCountersBundle()
                    c.parent = self
                    local_reference_key = "ydk::seg::%s" % segment_path
                    self._local_refs[local_reference_key] = c
                    self.bfd_counters_bundle.append(c)
                    return c

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "bfd-counters-bundle"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                pass


        class BfdCountersMembers(Entity):
            """
            Member interfaces with BFD counters information
            
            .. attribute:: bfd_counters_member
            
            	Member interface
            	**type**\: list of    :py:class:`BfdCountersMember <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.BfdCounters.BfdCountersMembers.BfdCountersMember>`
            
            

            """

            _prefix = 'bundlemgr-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(BundleInformation.BfdCounters.BfdCountersMembers, self).__init__()

                self.yang_name = "bfd-counters-members"
                self.yang_parent_name = "bfd-counters"

                self.bfd_counters_member = YList(self)

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in () and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(BundleInformation.BfdCounters.BfdCountersMembers, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(BundleInformation.BfdCounters.BfdCountersMembers, self).__setattr__(name, value)


            class BfdCountersMember(Entity):
                """
                Member interface
                
                .. attribute:: member_interface  <key>
                
                	Member interface
                	**type**\:  str
                
                .. attribute:: bfd_counters_member_item
                
                	Data for this item
                	**type**\:   :py:class:`BfdCountersMemberItem <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.BfdCounters.BfdCountersMembers.BfdCountersMember.BfdCountersMemberItem>`
                
                

                """

                _prefix = 'bundlemgr-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(BundleInformation.BfdCounters.BfdCountersMembers.BfdCountersMember, self).__init__()

                    self.yang_name = "bfd-counters-member"
                    self.yang_parent_name = "bfd-counters-members"

                    self.member_interface = YLeaf(YType.str, "member-interface")

                    self.bfd_counters_member_item = BundleInformation.BfdCounters.BfdCountersMembers.BfdCountersMember.BfdCountersMemberItem()
                    self.bfd_counters_member_item.parent = self
                    self._children_name_map["bfd_counters_member_item"] = "bfd-counters-member-item"
                    self._children_yang_names.add("bfd-counters-member-item")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("member_interface") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(BundleInformation.BfdCounters.BfdCountersMembers.BfdCountersMember, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(BundleInformation.BfdCounters.BfdCountersMembers.BfdCountersMember, self).__setattr__(name, value)


                class BfdCountersMemberItem(Entity):
                    """
                    Data for this item
                    
                    .. attribute:: down
                    
                    	Number of times member state changed to down
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: last_time_cleared
                    
                    	Timestamp when counters were last cleared (deprecated)
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: member_name
                    
                    	Name of the member this information is for
                    	**type**\:  str
                    
                    .. attribute:: neighbor_unconfigured
                    
                    	Number of times member state changed to neighbor unconfigured
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: neighbor_unconfigured_timeouts
                    
                    	Number of timeouts waiting for neighbor to become unconfigured
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: start_timeouts
                    
                    	Number of timeouts waiting for BFD to start
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: starting
                    
                    	Number of times member state changed to starting
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: time_since_cleared
                    
                    	Elapsed time in nsecs since counters were last cleared
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: nanosecond
                    
                    .. attribute:: up
                    
                    	Number of times member state changed to up
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'bundlemgr-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(BundleInformation.BfdCounters.BfdCountersMembers.BfdCountersMember.BfdCountersMemberItem, self).__init__()

                        self.yang_name = "bfd-counters-member-item"
                        self.yang_parent_name = "bfd-counters-member"

                        self.down = YLeaf(YType.uint32, "down")

                        self.last_time_cleared = YLeaf(YType.uint64, "last-time-cleared")

                        self.member_name = YLeaf(YType.str, "member-name")

                        self.neighbor_unconfigured = YLeaf(YType.uint32, "neighbor-unconfigured")

                        self.neighbor_unconfigured_timeouts = YLeaf(YType.uint32, "neighbor-unconfigured-timeouts")

                        self.start_timeouts = YLeaf(YType.uint32, "start-timeouts")

                        self.starting = YLeaf(YType.uint32, "starting")

                        self.time_since_cleared = YLeaf(YType.uint64, "time-since-cleared")

                        self.up = YLeaf(YType.uint32, "up")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("down",
                                        "last_time_cleared",
                                        "member_name",
                                        "neighbor_unconfigured",
                                        "neighbor_unconfigured_timeouts",
                                        "start_timeouts",
                                        "starting",
                                        "time_since_cleared",
                                        "up") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(BundleInformation.BfdCounters.BfdCountersMembers.BfdCountersMember.BfdCountersMemberItem, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(BundleInformation.BfdCounters.BfdCountersMembers.BfdCountersMember.BfdCountersMemberItem, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.down.is_set or
                            self.last_time_cleared.is_set or
                            self.member_name.is_set or
                            self.neighbor_unconfigured.is_set or
                            self.neighbor_unconfigured_timeouts.is_set or
                            self.start_timeouts.is_set or
                            self.starting.is_set or
                            self.time_since_cleared.is_set or
                            self.up.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.down.yfilter != YFilter.not_set or
                            self.last_time_cleared.yfilter != YFilter.not_set or
                            self.member_name.yfilter != YFilter.not_set or
                            self.neighbor_unconfigured.yfilter != YFilter.not_set or
                            self.neighbor_unconfigured_timeouts.yfilter != YFilter.not_set or
                            self.start_timeouts.yfilter != YFilter.not_set or
                            self.starting.yfilter != YFilter.not_set or
                            self.time_since_cleared.yfilter != YFilter.not_set or
                            self.up.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "bfd-counters-member-item" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.down.is_set or self.down.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.down.get_name_leafdata())
                        if (self.last_time_cleared.is_set or self.last_time_cleared.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.last_time_cleared.get_name_leafdata())
                        if (self.member_name.is_set or self.member_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.member_name.get_name_leafdata())
                        if (self.neighbor_unconfigured.is_set or self.neighbor_unconfigured.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.neighbor_unconfigured.get_name_leafdata())
                        if (self.neighbor_unconfigured_timeouts.is_set or self.neighbor_unconfigured_timeouts.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.neighbor_unconfigured_timeouts.get_name_leafdata())
                        if (self.start_timeouts.is_set or self.start_timeouts.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.start_timeouts.get_name_leafdata())
                        if (self.starting.is_set or self.starting.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.starting.get_name_leafdata())
                        if (self.time_since_cleared.is_set or self.time_since_cleared.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.time_since_cleared.get_name_leafdata())
                        if (self.up.is_set or self.up.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.up.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "down" or name == "last-time-cleared" or name == "member-name" or name == "neighbor-unconfigured" or name == "neighbor-unconfigured-timeouts" or name == "start-timeouts" or name == "starting" or name == "time-since-cleared" or name == "up"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "down"):
                            self.down = value
                            self.down.value_namespace = name_space
                            self.down.value_namespace_prefix = name_space_prefix
                        if(value_path == "last-time-cleared"):
                            self.last_time_cleared = value
                            self.last_time_cleared.value_namespace = name_space
                            self.last_time_cleared.value_namespace_prefix = name_space_prefix
                        if(value_path == "member-name"):
                            self.member_name = value
                            self.member_name.value_namespace = name_space
                            self.member_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "neighbor-unconfigured"):
                            self.neighbor_unconfigured = value
                            self.neighbor_unconfigured.value_namespace = name_space
                            self.neighbor_unconfigured.value_namespace_prefix = name_space_prefix
                        if(value_path == "neighbor-unconfigured-timeouts"):
                            self.neighbor_unconfigured_timeouts = value
                            self.neighbor_unconfigured_timeouts.value_namespace = name_space
                            self.neighbor_unconfigured_timeouts.value_namespace_prefix = name_space_prefix
                        if(value_path == "start-timeouts"):
                            self.start_timeouts = value
                            self.start_timeouts.value_namespace = name_space
                            self.start_timeouts.value_namespace_prefix = name_space_prefix
                        if(value_path == "starting"):
                            self.starting = value
                            self.starting.value_namespace = name_space
                            self.starting.value_namespace_prefix = name_space_prefix
                        if(value_path == "time-since-cleared"):
                            self.time_since_cleared = value
                            self.time_since_cleared.value_namespace = name_space
                            self.time_since_cleared.value_namespace_prefix = name_space_prefix
                        if(value_path == "up"):
                            self.up = value
                            self.up.value_namespace = name_space
                            self.up.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    return (
                        self.member_interface.is_set or
                        (self.bfd_counters_member_item is not None and self.bfd_counters_member_item.has_data()))

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.member_interface.yfilter != YFilter.not_set or
                        (self.bfd_counters_member_item is not None and self.bfd_counters_member_item.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "bfd-counters-member" + "[member-interface='" + self.member_interface.get() + "']" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-bundlemgr-oper:bundle-information/bfd-counters/bfd-counters-members/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.member_interface.is_set or self.member_interface.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.member_interface.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "bfd-counters-member-item"):
                        if (self.bfd_counters_member_item is None):
                            self.bfd_counters_member_item = BundleInformation.BfdCounters.BfdCountersMembers.BfdCountersMember.BfdCountersMemberItem()
                            self.bfd_counters_member_item.parent = self
                            self._children_name_map["bfd_counters_member_item"] = "bfd-counters-member-item"
                        return self.bfd_counters_member_item

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "bfd-counters-member-item" or name == "member-interface"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "member-interface"):
                        self.member_interface = value
                        self.member_interface.value_namespace = name_space
                        self.member_interface.value_namespace_prefix = name_space_prefix

            def has_data(self):
                for c in self.bfd_counters_member:
                    if (c.has_data()):
                        return True
                return False

            def has_operation(self):
                for c in self.bfd_counters_member:
                    if (c.has_operation()):
                        return True
                return self.yfilter != YFilter.not_set

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "bfd-counters-members" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-bundlemgr-oper:bundle-information/bfd-counters/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "bfd-counters-member"):
                    for c in self.bfd_counters_member:
                        segment = c.get_segment_path()
                        if (segment_path == segment):
                            return c
                    c = BundleInformation.BfdCounters.BfdCountersMembers.BfdCountersMember()
                    c.parent = self
                    local_reference_key = "ydk::seg::%s" % segment_path
                    self._local_refs[local_reference_key] = c
                    self.bfd_counters_member.append(c)
                    return c

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "bfd-counters-member"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                pass

        def has_data(self):
            return (
                (self.bfd_counters_bundles is not None and self.bfd_counters_bundles.has_data()) or
                (self.bfd_counters_members is not None and self.bfd_counters_members.has_data()))

        def has_operation(self):
            return (
                self.yfilter != YFilter.not_set or
                (self.bfd_counters_bundles is not None and self.bfd_counters_bundles.has_operation()) or
                (self.bfd_counters_members is not None and self.bfd_counters_members.has_operation()))

        def get_segment_path(self):
            path_buffer = ""
            path_buffer = "bfd-counters" + path_buffer

            return path_buffer

        def get_entity_path(self, ancestor):
            path_buffer = ""
            if (ancestor is None):
                path_buffer = "Cisco-IOS-XR-bundlemgr-oper:bundle-information/%s" % self.get_segment_path()
            else:
                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

            leaf_name_data = LeafDataList()

            entity_path = EntityPath(path_buffer, leaf_name_data)
            return entity_path

        def get_child_by_name(self, child_yang_name, segment_path):
            child = self._get_child_by_seg_name([child_yang_name, segment_path])
            if child is not None:
                return child

            if (child_yang_name == "bfd-counters-bundles"):
                if (self.bfd_counters_bundles is None):
                    self.bfd_counters_bundles = BundleInformation.BfdCounters.BfdCountersBundles()
                    self.bfd_counters_bundles.parent = self
                    self._children_name_map["bfd_counters_bundles"] = "bfd-counters-bundles"
                return self.bfd_counters_bundles

            if (child_yang_name == "bfd-counters-members"):
                if (self.bfd_counters_members is None):
                    self.bfd_counters_members = BundleInformation.BfdCounters.BfdCountersMembers()
                    self.bfd_counters_members.parent = self
                    self._children_name_map["bfd_counters_members"] = "bfd-counters-members"
                return self.bfd_counters_members

            return None

        def has_leaf_or_child_of_name(self, name):
            if(name == "bfd-counters-bundles" or name == "bfd-counters-members"):
                return True
            return False

        def set_value(self, value_path, value, name_space, name_space_prefix):
            pass


    class ScheduledActions(Entity):
        """
        Scheduled actions on a bundle
        
        .. attribute:: scheduled_actions_bundles
        
        	Bundles with actions scheduled
        	**type**\:   :py:class:`ScheduledActionsBundles <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.ScheduledActions.ScheduledActionsBundles>`
        
        

        """

        _prefix = 'bundlemgr-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(BundleInformation.ScheduledActions, self).__init__()

            self.yang_name = "scheduled-actions"
            self.yang_parent_name = "bundle-information"

            self.scheduled_actions_bundles = BundleInformation.ScheduledActions.ScheduledActionsBundles()
            self.scheduled_actions_bundles.parent = self
            self._children_name_map["scheduled_actions_bundles"] = "scheduled-actions-bundles"
            self._children_yang_names.add("scheduled-actions-bundles")


        class ScheduledActionsBundles(Entity):
            """
            Bundles with actions scheduled
            
            .. attribute:: scheduled_actions_bundle
            
            	Bundle interface
            	**type**\: list of    :py:class:`ScheduledActionsBundle <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.ScheduledActions.ScheduledActionsBundles.ScheduledActionsBundle>`
            
            

            """

            _prefix = 'bundlemgr-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(BundleInformation.ScheduledActions.ScheduledActionsBundles, self).__init__()

                self.yang_name = "scheduled-actions-bundles"
                self.yang_parent_name = "scheduled-actions"

                self.scheduled_actions_bundle = YList(self)

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in () and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(BundleInformation.ScheduledActions.ScheduledActionsBundles, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(BundleInformation.ScheduledActions.ScheduledActionsBundles, self).__setattr__(name, value)


            class ScheduledActionsBundle(Entity):
                """
                Bundle interface
                
                .. attribute:: bundle_interface  <key>
                
                	Bundle interface
                	**type**\:  str
                
                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                
                .. attribute:: scheduled_actions_bundle_item
                
                	Data for this item
                	**type**\:   :py:class:`ScheduledActionsBundleItem <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.ScheduledActions.ScheduledActionsBundles.ScheduledActionsBundle.ScheduledActionsBundleItem>`
                
                

                """

                _prefix = 'bundlemgr-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(BundleInformation.ScheduledActions.ScheduledActionsBundles.ScheduledActionsBundle, self).__init__()

                    self.yang_name = "scheduled-actions-bundle"
                    self.yang_parent_name = "scheduled-actions-bundles"

                    self.bundle_interface = YLeaf(YType.str, "bundle-interface")

                    self.scheduled_actions_bundle_item = BundleInformation.ScheduledActions.ScheduledActionsBundles.ScheduledActionsBundle.ScheduledActionsBundleItem()
                    self.scheduled_actions_bundle_item.parent = self
                    self._children_name_map["scheduled_actions_bundle_item"] = "scheduled-actions-bundle-item"
                    self._children_yang_names.add("scheduled-actions-bundle-item")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("bundle_interface") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(BundleInformation.ScheduledActions.ScheduledActionsBundles.ScheduledActionsBundle, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(BundleInformation.ScheduledActions.ScheduledActionsBundles.ScheduledActionsBundle, self).__setattr__(name, value)


                class ScheduledActionsBundleItem(Entity):
                    """
                    Data for this item
                    
                    .. attribute:: bundle_name
                    
                    	Name of the bundle
                    	**type**\:  str
                    
                    .. attribute:: scheduled_action
                    
                    	Scheduled actions
                    	**type**\: list of    :py:class:`ScheduledAction <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.ScheduledActions.ScheduledActionsBundles.ScheduledActionsBundle.ScheduledActionsBundleItem.ScheduledAction>`
                    
                    

                    """

                    _prefix = 'bundlemgr-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(BundleInformation.ScheduledActions.ScheduledActionsBundles.ScheduledActionsBundle.ScheduledActionsBundleItem, self).__init__()

                        self.yang_name = "scheduled-actions-bundle-item"
                        self.yang_parent_name = "scheduled-actions-bundle"

                        self.bundle_name = YLeaf(YType.str, "bundle-name")

                        self.scheduled_action = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("bundle_name") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(BundleInformation.ScheduledActions.ScheduledActionsBundles.ScheduledActionsBundle.ScheduledActionsBundleItem, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(BundleInformation.ScheduledActions.ScheduledActionsBundles.ScheduledActionsBundle.ScheduledActionsBundleItem, self).__setattr__(name, value)


                    class ScheduledAction(Entity):
                        """
                        Scheduled actions
                        
                        .. attribute:: action_state
                        
                        	Details whether the switch action is viable
                        	**type**\:   :py:class:`BmdSwitchReason <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmdSwitchReason>`
                        
                        .. attribute:: mlacp_action
                        
                        	Type of mLACP scheduled action for a bundle
                        	**type**\:   :py:class:`BmdBagMlacpSchActionItem <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmdBagMlacpSchActionItem>`
                        
                        .. attribute:: time_remaining
                        
                        	Seconds left before action
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        

                        """

                        _prefix = 'bundlemgr-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(BundleInformation.ScheduledActions.ScheduledActionsBundles.ScheduledActionsBundle.ScheduledActionsBundleItem.ScheduledAction, self).__init__()

                            self.yang_name = "scheduled-action"
                            self.yang_parent_name = "scheduled-actions-bundle-item"

                            self.action_state = YLeaf(YType.enumeration, "action-state")

                            self.mlacp_action = YLeaf(YType.enumeration, "mlacp-action")

                            self.time_remaining = YLeaf(YType.uint64, "time-remaining")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("action_state",
                                            "mlacp_action",
                                            "time_remaining") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(BundleInformation.ScheduledActions.ScheduledActionsBundles.ScheduledActionsBundle.ScheduledActionsBundleItem.ScheduledAction, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(BundleInformation.ScheduledActions.ScheduledActionsBundles.ScheduledActionsBundle.ScheduledActionsBundleItem.ScheduledAction, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.action_state.is_set or
                                self.mlacp_action.is_set or
                                self.time_remaining.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.action_state.yfilter != YFilter.not_set or
                                self.mlacp_action.yfilter != YFilter.not_set or
                                self.time_remaining.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "scheduled-action" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.action_state.is_set or self.action_state.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.action_state.get_name_leafdata())
                            if (self.mlacp_action.is_set or self.mlacp_action.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mlacp_action.get_name_leafdata())
                            if (self.time_remaining.is_set or self.time_remaining.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.time_remaining.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "action-state" or name == "mlacp-action" or name == "time-remaining"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "action-state"):
                                self.action_state = value
                                self.action_state.value_namespace = name_space
                                self.action_state.value_namespace_prefix = name_space_prefix
                            if(value_path == "mlacp-action"):
                                self.mlacp_action = value
                                self.mlacp_action.value_namespace = name_space
                                self.mlacp_action.value_namespace_prefix = name_space_prefix
                            if(value_path == "time-remaining"):
                                self.time_remaining = value
                                self.time_remaining.value_namespace = name_space
                                self.time_remaining.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.scheduled_action:
                            if (c.has_data()):
                                return True
                        return self.bundle_name.is_set

                    def has_operation(self):
                        for c in self.scheduled_action:
                            if (c.has_operation()):
                                return True
                        return (
                            self.yfilter != YFilter.not_set or
                            self.bundle_name.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "scheduled-actions-bundle-item" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.bundle_name.is_set or self.bundle_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bundle_name.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "scheduled-action"):
                            for c in self.scheduled_action:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = BundleInformation.ScheduledActions.ScheduledActionsBundles.ScheduledActionsBundle.ScheduledActionsBundleItem.ScheduledAction()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.scheduled_action.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "scheduled-action" or name == "bundle-name"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "bundle-name"):
                            self.bundle_name = value
                            self.bundle_name.value_namespace = name_space
                            self.bundle_name.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    return (
                        self.bundle_interface.is_set or
                        (self.scheduled_actions_bundle_item is not None and self.scheduled_actions_bundle_item.has_data()))

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.bundle_interface.yfilter != YFilter.not_set or
                        (self.scheduled_actions_bundle_item is not None and self.scheduled_actions_bundle_item.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "scheduled-actions-bundle" + "[bundle-interface='" + self.bundle_interface.get() + "']" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-bundlemgr-oper:bundle-information/scheduled-actions/scheduled-actions-bundles/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.bundle_interface.is_set or self.bundle_interface.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.bundle_interface.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "scheduled-actions-bundle-item"):
                        if (self.scheduled_actions_bundle_item is None):
                            self.scheduled_actions_bundle_item = BundleInformation.ScheduledActions.ScheduledActionsBundles.ScheduledActionsBundle.ScheduledActionsBundleItem()
                            self.scheduled_actions_bundle_item.parent = self
                            self._children_name_map["scheduled_actions_bundle_item"] = "scheduled-actions-bundle-item"
                        return self.scheduled_actions_bundle_item

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "scheduled-actions-bundle-item" or name == "bundle-interface"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "bundle-interface"):
                        self.bundle_interface = value
                        self.bundle_interface.value_namespace = name_space
                        self.bundle_interface.value_namespace_prefix = name_space_prefix

            def has_data(self):
                for c in self.scheduled_actions_bundle:
                    if (c.has_data()):
                        return True
                return False

            def has_operation(self):
                for c in self.scheduled_actions_bundle:
                    if (c.has_operation()):
                        return True
                return self.yfilter != YFilter.not_set

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "scheduled-actions-bundles" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-bundlemgr-oper:bundle-information/scheduled-actions/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "scheduled-actions-bundle"):
                    for c in self.scheduled_actions_bundle:
                        segment = c.get_segment_path()
                        if (segment_path == segment):
                            return c
                    c = BundleInformation.ScheduledActions.ScheduledActionsBundles.ScheduledActionsBundle()
                    c.parent = self
                    local_reference_key = "ydk::seg::%s" % segment_path
                    self._local_refs[local_reference_key] = c
                    self.scheduled_actions_bundle.append(c)
                    return c

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "scheduled-actions-bundle"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                pass

        def has_data(self):
            return (self.scheduled_actions_bundles is not None and self.scheduled_actions_bundles.has_data())

        def has_operation(self):
            return (
                self.yfilter != YFilter.not_set or
                (self.scheduled_actions_bundles is not None and self.scheduled_actions_bundles.has_operation()))

        def get_segment_path(self):
            path_buffer = ""
            path_buffer = "scheduled-actions" + path_buffer

            return path_buffer

        def get_entity_path(self, ancestor):
            path_buffer = ""
            if (ancestor is None):
                path_buffer = "Cisco-IOS-XR-bundlemgr-oper:bundle-information/%s" % self.get_segment_path()
            else:
                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

            leaf_name_data = LeafDataList()

            entity_path = EntityPath(path_buffer, leaf_name_data)
            return entity_path

        def get_child_by_name(self, child_yang_name, segment_path):
            child = self._get_child_by_seg_name([child_yang_name, segment_path])
            if child is not None:
                return child

            if (child_yang_name == "scheduled-actions-bundles"):
                if (self.scheduled_actions_bundles is None):
                    self.scheduled_actions_bundles = BundleInformation.ScheduledActions.ScheduledActionsBundles()
                    self.scheduled_actions_bundles.parent = self
                    self._children_name_map["scheduled_actions_bundles"] = "scheduled-actions-bundles"
                return self.scheduled_actions_bundles

            return None

        def has_leaf_or_child_of_name(self, name):
            if(name == "scheduled-actions-bundles"):
                return True
            return False

        def set_value(self, value_path, value, name_space, name_space_prefix):
            pass


    class Bundle(Entity):
        """
        Generic information for bundles and members
        
        .. attribute:: bundle_bundles
        
        	Bundle interfaces with common bundle information
        	**type**\:   :py:class:`BundleBundles <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.Bundle.BundleBundles>`
        
        .. attribute:: bundle_members
        
        	Member interfaces with common bundle information
        	**type**\:   :py:class:`BundleMembers <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.Bundle.BundleMembers>`
        
        

        """

        _prefix = 'bundlemgr-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(BundleInformation.Bundle, self).__init__()

            self.yang_name = "bundle"
            self.yang_parent_name = "bundle-information"

            self.bundle_bundles = BundleInformation.Bundle.BundleBundles()
            self.bundle_bundles.parent = self
            self._children_name_map["bundle_bundles"] = "bundle-bundles"
            self._children_yang_names.add("bundle-bundles")

            self.bundle_members = BundleInformation.Bundle.BundleMembers()
            self.bundle_members.parent = self
            self._children_name_map["bundle_members"] = "bundle-members"
            self._children_yang_names.add("bundle-members")


        class BundleBundles(Entity):
            """
            Bundle interfaces with common bundle
            information
            
            .. attribute:: bundle_bundle
            
            	Bundle interface
            	**type**\: list of    :py:class:`BundleBundle <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.Bundle.BundleBundles.BundleBundle>`
            
            

            """

            _prefix = 'bundlemgr-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(BundleInformation.Bundle.BundleBundles, self).__init__()

                self.yang_name = "bundle-bundles"
                self.yang_parent_name = "bundle"

                self.bundle_bundle = YList(self)

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in () and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(BundleInformation.Bundle.BundleBundles, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(BundleInformation.Bundle.BundleBundles, self).__setattr__(name, value)


            class BundleBundle(Entity):
                """
                Bundle interface
                
                .. attribute:: bundle_interface  <key>
                
                	Bundle interface
                	**type**\:  str
                
                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                
                .. attribute:: bundle_bundle_children_members
                
                	Children of bundle with common bundle information
                	**type**\:   :py:class:`BundleBundleChildrenMembers <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.Bundle.BundleBundles.BundleBundle.BundleBundleChildrenMembers>`
                
                .. attribute:: bundle_bundle_descendant
                
                	Data for this item and all its members
                	**type**\:   :py:class:`BundleBundleDescendant <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.Bundle.BundleBundles.BundleBundle.BundleBundleDescendant>`
                
                .. attribute:: bundle_bundle_item
                
                	Data for this item
                	**type**\:   :py:class:`BundleBundleItem <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.Bundle.BundleBundles.BundleBundle.BundleBundleItem>`
                
                

                """

                _prefix = 'bundlemgr-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(BundleInformation.Bundle.BundleBundles.BundleBundle, self).__init__()

                    self.yang_name = "bundle-bundle"
                    self.yang_parent_name = "bundle-bundles"

                    self.bundle_interface = YLeaf(YType.str, "bundle-interface")

                    self.bundle_bundle_children_members = BundleInformation.Bundle.BundleBundles.BundleBundle.BundleBundleChildrenMembers()
                    self.bundle_bundle_children_members.parent = self
                    self._children_name_map["bundle_bundle_children_members"] = "bundle-bundle-children-members"
                    self._children_yang_names.add("bundle-bundle-children-members")

                    self.bundle_bundle_descendant = BundleInformation.Bundle.BundleBundles.BundleBundle.BundleBundleDescendant()
                    self.bundle_bundle_descendant.parent = self
                    self._children_name_map["bundle_bundle_descendant"] = "bundle-bundle-descendant"
                    self._children_yang_names.add("bundle-bundle-descendant")

                    self.bundle_bundle_item = BundleInformation.Bundle.BundleBundles.BundleBundle.BundleBundleItem()
                    self.bundle_bundle_item.parent = self
                    self._children_name_map["bundle_bundle_item"] = "bundle-bundle-item"
                    self._children_yang_names.add("bundle-bundle-item")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("bundle_interface") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(BundleInformation.Bundle.BundleBundles.BundleBundle, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(BundleInformation.Bundle.BundleBundles.BundleBundle, self).__setattr__(name, value)


                class BundleBundleDescendant(Entity):
                    """
                    Data for this item and all its members
                    
                    .. attribute:: bundle_data
                    
                    	Bundle information
                    	**type**\:   :py:class:`BundleData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.Bundle.BundleBundles.BundleBundle.BundleBundleDescendant.BundleData>`
                    
                    .. attribute:: member_data
                    
                    	Member information
                    	**type**\: list of    :py:class:`MemberData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.Bundle.BundleBundles.BundleBundle.BundleBundleDescendant.MemberData>`
                    
                    

                    """

                    _prefix = 'bundlemgr-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(BundleInformation.Bundle.BundleBundles.BundleBundle.BundleBundleDescendant, self).__init__()

                        self.yang_name = "bundle-bundle-descendant"
                        self.yang_parent_name = "bundle-bundle"

                        self.bundle_data = BundleInformation.Bundle.BundleBundles.BundleBundle.BundleBundleDescendant.BundleData()
                        self.bundle_data.parent = self
                        self._children_name_map["bundle_data"] = "bundle-data"
                        self._children_yang_names.add("bundle-data")

                        self.member_data = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(BundleInformation.Bundle.BundleBundles.BundleBundle.BundleBundleDescendant, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(BundleInformation.Bundle.BundleBundles.BundleBundle.BundleBundleDescendant, self).__setattr__(name, value)


                    class BundleData(Entity):
                        """
                        Bundle information
                        
                        .. attribute:: active_foreign_member_count
                        
                        	The number of active foreign members on the bundle
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: active_member_count
                        
                        	The number of active local members on the bundle
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: available_bandwidth
                        
                        	Bandwidth available to the bundle interface (kbps)
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: kbit/s
                        
                        .. attribute:: bfd_config
                        
                        	Configuration values for BFD on bundle members
                        	**type**\: list of    :py:class:`BfdConfig <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.Bundle.BundleBundles.BundleBundle.BundleBundleDescendant.BundleData.BfdConfig>`
                        
                        .. attribute:: bundle_interface_name
                        
                        	Bundle interface name
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: bundle_status
                        
                        	The state of the bundle
                        	**type**\:   :py:class:`BmBdlState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmBdlState>`
                        
                        .. attribute:: cisco_extensions
                        
                        	The status of the Cisco Extensions feature (1 = enabled, 0 = not enabled)
                        	**type**\:  bool
                        
                        .. attribute:: collector_max_delay
                        
                        	Collector Max Delay
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: configured_bandwidth
                        
                        	Bandwidth configured on the bundle interface (kbps)
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: kbit/s
                        
                        .. attribute:: configured_foreign_member_count
                        
                        	The number of configured local members on the bundle
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: configured_member_count
                        
                        	The number of configured local members on the bundle
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: effective_bandwidth
                        
                        	Effective bandwidth on the bundle interface (kbps)
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: kbit/s
                        
                        .. attribute:: iccp_group_id
                        
                        	ICCP Group that the bundle is configured to
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: inter_chassis
                        
                        	Indicates if this bundle is operating as an inter\-chassis link (1 = I\-C link, 0 = normal)
                        	**type**\:  bool
                        
                        .. attribute:: ipv4bfd_status
                        
                        	The status of the BFD (IPv4) feature on the bundle
                        	**type**\:   :py:class:`BmFeatureStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmFeatureStatus>`
                        
                        .. attribute:: ipv6bfd_status
                        
                        	The status of the BFD (IPv6) feature on the bundle
                        	**type**\:   :py:class:`BmFeatureStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmFeatureStatus>`
                        
                        .. attribute:: is_active
                        
                        	Indicates the active/standby redundancy state of the device for the bundle
                        	**type**\:  bool
                        
                        .. attribute:: lacp_nonrevertive
                        
                        	The status of the LACP nonrevertive feature (1 = enable, 0 = not enabled)
                        	**type**\:  bool
                        
                        .. attribute:: lacp_status
                        
                        	The status of the LACP feature on the bundle
                        	**type**\:   :py:class:`BmFeatureStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmFeatureStatus>`
                        
                        .. attribute:: link_order_status
                        
                        	The status of the link order signaling feature on the bundle
                        	**type**\:   :py:class:`BmFeatureStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmFeatureStatus>`
                        
                        .. attribute:: load_balance_hash_type
                        
                        	The type of hash to use for load balancing
                        	**type**\:  str
                        
                        .. attribute:: load_balance_locality_threshold
                        
                        	The number of links required per rack for localized load balancing
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: mac_address
                        
                        	MAC address of this member
                        	**type**\:   :py:class:`MacAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.Bundle.BundleBundles.BundleBundle.BundleBundleDescendant.BundleData.MacAddress>`
                        
                        .. attribute:: mac_source
                        
                        	The source of the MAC Address
                        	**type**\:   :py:class:`BmBdlMacSource <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmBdlMacSource>`
                        
                        .. attribute:: mac_source_member
                        
                        	The name of the member that supplied the MAC address
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: maximize_threshold_value_band_width
                        
                        	Attempt to maximize the bundle if bandwidth is below this value
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: maximize_threshold_value_links
                        
                        	Attempt to maximize the bundle if links are below this value
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: maximum_active_links
                        
                        	Maximum number of active links in the bundle
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: maximum_active_links_source
                        
                        	Source of maximum active links value
                        	**type**\:   :py:class:`BmWhichSystem <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmWhichSystem>`
                        
                        .. attribute:: minimum_active_links
                        
                        	Minimum number of active links for bundle to go up
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: minimum_bandwidth
                        
                        	Minimum bundle bandwidth for bundle to go up (kbps)
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: kbit/s
                        
                        .. attribute:: mlacp_mode
                        
                        	Indicates the mode of the device for the bundle
                        	**type**\:   :py:class:`BundleMlacpMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleMlacpMode>`
                        
                        .. attribute:: mlacp_status
                        
                        	The status of the mLACP feature on the bundle
                        	**type**\:   :py:class:`BmFeatureStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmFeatureStatus>`
                        
                        .. attribute:: primary_member
                        
                        	Primary bundle member (no longer applicable)
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: recovery_delay
                        
                        	Number of seconds to wait before becoming active after recovering from a failure
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        	**units**\: second
                        
                        .. attribute:: singleton
                        
                        	Is the ICCP group of the bundle in singleton mode (1 = singleton; 0 = not singleton)
                        	**type**\:  bool
                        
                        .. attribute:: standby_member_count
                        
                        	The number of standby local members on the bundle
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: suppression_timer
                        
                        	Timer for suppressing bundle state flaps
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: switchover_type
                        
                        	How a switchover of the bundle from this device will occur
                        	**type**\:   :py:class:`BmdMlacpSwitchover <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmdMlacpSwitchover>`
                        
                        .. attribute:: wait_while_timer
                        
                        	The wait while time used for member ports
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'bundlemgr-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(BundleInformation.Bundle.BundleBundles.BundleBundle.BundleBundleDescendant.BundleData, self).__init__()

                            self.yang_name = "bundle-data"
                            self.yang_parent_name = "bundle-bundle-descendant"

                            self.active_foreign_member_count = YLeaf(YType.uint16, "active-foreign-member-count")

                            self.active_member_count = YLeaf(YType.uint16, "active-member-count")

                            self.available_bandwidth = YLeaf(YType.uint32, "available-bandwidth")

                            self.bundle_interface_name = YLeaf(YType.str, "bundle-interface-name")

                            self.bundle_status = YLeaf(YType.enumeration, "bundle-status")

                            self.cisco_extensions = YLeaf(YType.boolean, "cisco-extensions")

                            self.collector_max_delay = YLeaf(YType.uint16, "collector-max-delay")

                            self.configured_bandwidth = YLeaf(YType.uint32, "configured-bandwidth")

                            self.configured_foreign_member_count = YLeaf(YType.uint16, "configured-foreign-member-count")

                            self.configured_member_count = YLeaf(YType.uint16, "configured-member-count")

                            self.effective_bandwidth = YLeaf(YType.uint32, "effective-bandwidth")

                            self.iccp_group_id = YLeaf(YType.uint32, "iccp-group-id")

                            self.inter_chassis = YLeaf(YType.boolean, "inter-chassis")

                            self.ipv4bfd_status = YLeaf(YType.enumeration, "ipv4bfd-status")

                            self.ipv6bfd_status = YLeaf(YType.enumeration, "ipv6bfd-status")

                            self.is_active = YLeaf(YType.boolean, "is-active")

                            self.lacp_nonrevertive = YLeaf(YType.boolean, "lacp-nonrevertive")

                            self.lacp_status = YLeaf(YType.enumeration, "lacp-status")

                            self.link_order_status = YLeaf(YType.enumeration, "link-order-status")

                            self.load_balance_hash_type = YLeaf(YType.str, "load-balance-hash-type")

                            self.load_balance_locality_threshold = YLeaf(YType.uint16, "load-balance-locality-threshold")

                            self.mac_source = YLeaf(YType.enumeration, "mac-source")

                            self.mac_source_member = YLeaf(YType.str, "mac-source-member")

                            self.maximize_threshold_value_band_width = YLeaf(YType.uint32, "maximize-threshold-value-band-width")

                            self.maximize_threshold_value_links = YLeaf(YType.uint32, "maximize-threshold-value-links")

                            self.maximum_active_links = YLeaf(YType.uint8, "maximum-active-links")

                            self.maximum_active_links_source = YLeaf(YType.enumeration, "maximum-active-links-source")

                            self.minimum_active_links = YLeaf(YType.uint8, "minimum-active-links")

                            self.minimum_bandwidth = YLeaf(YType.uint32, "minimum-bandwidth")

                            self.mlacp_mode = YLeaf(YType.enumeration, "mlacp-mode")

                            self.mlacp_status = YLeaf(YType.enumeration, "mlacp-status")

                            self.primary_member = YLeaf(YType.str, "primary-member")

                            self.recovery_delay = YLeaf(YType.uint16, "recovery-delay")

                            self.singleton = YLeaf(YType.boolean, "singleton")

                            self.standby_member_count = YLeaf(YType.uint16, "standby-member-count")

                            self.suppression_timer = YLeaf(YType.uint16, "suppression-timer")

                            self.switchover_type = YLeaf(YType.enumeration, "switchover-type")

                            self.wait_while_timer = YLeaf(YType.uint16, "wait-while-timer")

                            self.mac_address = BundleInformation.Bundle.BundleBundles.BundleBundle.BundleBundleDescendant.BundleData.MacAddress()
                            self.mac_address.parent = self
                            self._children_name_map["mac_address"] = "mac-address"
                            self._children_yang_names.add("mac-address")

                            self.bfd_config = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("active_foreign_member_count",
                                            "active_member_count",
                                            "available_bandwidth",
                                            "bundle_interface_name",
                                            "bundle_status",
                                            "cisco_extensions",
                                            "collector_max_delay",
                                            "configured_bandwidth",
                                            "configured_foreign_member_count",
                                            "configured_member_count",
                                            "effective_bandwidth",
                                            "iccp_group_id",
                                            "inter_chassis",
                                            "ipv4bfd_status",
                                            "ipv6bfd_status",
                                            "is_active",
                                            "lacp_nonrevertive",
                                            "lacp_status",
                                            "link_order_status",
                                            "load_balance_hash_type",
                                            "load_balance_locality_threshold",
                                            "mac_source",
                                            "mac_source_member",
                                            "maximize_threshold_value_band_width",
                                            "maximize_threshold_value_links",
                                            "maximum_active_links",
                                            "maximum_active_links_source",
                                            "minimum_active_links",
                                            "minimum_bandwidth",
                                            "mlacp_mode",
                                            "mlacp_status",
                                            "primary_member",
                                            "recovery_delay",
                                            "singleton",
                                            "standby_member_count",
                                            "suppression_timer",
                                            "switchover_type",
                                            "wait_while_timer") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(BundleInformation.Bundle.BundleBundles.BundleBundle.BundleBundleDescendant.BundleData, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(BundleInformation.Bundle.BundleBundles.BundleBundle.BundleBundleDescendant.BundleData, self).__setattr__(name, value)


                        class MacAddress(Entity):
                            """
                            MAC address of this member
                            
                            .. attribute:: address
                            
                            	MAC address
                            	**type**\:  str
                            
                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                            
                            

                            """

                            _prefix = 'bundlemgr-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(BundleInformation.Bundle.BundleBundles.BundleBundle.BundleBundleDescendant.BundleData.MacAddress, self).__init__()

                                self.yang_name = "mac-address"
                                self.yang_parent_name = "bundle-data"

                                self.address = YLeaf(YType.str, "address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(BundleInformation.Bundle.BundleBundles.BundleBundle.BundleBundleDescendant.BundleData.MacAddress, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(BundleInformation.Bundle.BundleBundles.BundleBundle.BundleBundleDescendant.BundleData.MacAddress, self).__setattr__(name, value)

                            def has_data(self):
                                return self.address.is_set

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "mac-address" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.address.is_set or self.address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "address"):
                                    self.address = value
                                    self.address.value_namespace = name_space
                                    self.address.value_namespace_prefix = name_space_prefix


                        class BfdConfig(Entity):
                            """
                            Configuration values for BFD on bundle members
                            
                            .. attribute:: bundle_status
                            
                            	Status of BFD on the bundle
                            	**type**\:   :py:class:`BmdBfdBdlState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmdBfdBdlState>`
                            
                            .. attribute:: destination_address
                            
                            	Configured destination address for BFD session
                            	**type**\:   :py:class:`DestinationAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.Bundle.BundleBundles.BundleBundle.BundleBundleDescendant.BundleData.BfdConfig.DestinationAddress>`
                            
                            .. attribute:: fast_detect
                            
                            	Flag indicating if BFD is enabled (1 = enabled; 0 = not enabled)
                            	**type**\:  bool
                            
                            .. attribute:: mode_info
                            
                            	Standard used for per\-member BFD
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nbr_unconfig_timer
                            
                            	Time to wait on session NBR\_UNCONFIG before declaring DOWN
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: pref_echo_min_interval
                            
                            	Preferred echo minimum interval for the BFD session (ms)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: pref_min_interval
                            
                            	Preferred minimum interval for the BFD session (ms)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: pref_multiplier
                            
                            	Preferred multiplier for the BFD session
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: start_timer
                            
                            	Time to wait on session start before declaring DOWN
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'bundlemgr-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(BundleInformation.Bundle.BundleBundles.BundleBundle.BundleBundleDescendant.BundleData.BfdConfig, self).__init__()

                                self.yang_name = "bfd-config"
                                self.yang_parent_name = "bundle-data"

                                self.bundle_status = YLeaf(YType.enumeration, "bundle-status")

                                self.fast_detect = YLeaf(YType.boolean, "fast-detect")

                                self.mode_info = YLeaf(YType.uint32, "mode-info")

                                self.nbr_unconfig_timer = YLeaf(YType.uint32, "nbr-unconfig-timer")

                                self.pref_echo_min_interval = YLeaf(YType.uint32, "pref-echo-min-interval")

                                self.pref_min_interval = YLeaf(YType.uint32, "pref-min-interval")

                                self.pref_multiplier = YLeaf(YType.uint16, "pref-multiplier")

                                self.start_timer = YLeaf(YType.uint32, "start-timer")

                                self.destination_address = BundleInformation.Bundle.BundleBundles.BundleBundle.BundleBundleDescendant.BundleData.BfdConfig.DestinationAddress()
                                self.destination_address.parent = self
                                self._children_name_map["destination_address"] = "destination-address"
                                self._children_yang_names.add("destination-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("bundle_status",
                                                "fast_detect",
                                                "mode_info",
                                                "nbr_unconfig_timer",
                                                "pref_echo_min_interval",
                                                "pref_min_interval",
                                                "pref_multiplier",
                                                "start_timer") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(BundleInformation.Bundle.BundleBundles.BundleBundle.BundleBundleDescendant.BundleData.BfdConfig, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(BundleInformation.Bundle.BundleBundles.BundleBundle.BundleBundleDescendant.BundleData.BfdConfig, self).__setattr__(name, value)


                            class DestinationAddress(Entity):
                                """
                                Configured destination address for BFD session
                                
                                .. attribute:: af
                                
                                	AF
                                	**type**\:   :py:class:`BmAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmAfId>`
                                
                                .. attribute:: ipv4
                                
                                	IPv4 address type
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6
                                
                                	IPv6 address type
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'bundlemgr-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(BundleInformation.Bundle.BundleBundles.BundleBundle.BundleBundleDescendant.BundleData.BfdConfig.DestinationAddress, self).__init__()

                                    self.yang_name = "destination-address"
                                    self.yang_parent_name = "bfd-config"

                                    self.af = YLeaf(YType.enumeration, "af")

                                    self.ipv4 = YLeaf(YType.str, "ipv4")

                                    self.ipv6 = YLeaf(YType.str, "ipv6")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("af",
                                                    "ipv4",
                                                    "ipv6") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(BundleInformation.Bundle.BundleBundles.BundleBundle.BundleBundleDescendant.BundleData.BfdConfig.DestinationAddress, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(BundleInformation.Bundle.BundleBundles.BundleBundle.BundleBundleDescendant.BundleData.BfdConfig.DestinationAddress, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.af.is_set or
                                        self.ipv4.is_set or
                                        self.ipv6.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.af.yfilter != YFilter.not_set or
                                        self.ipv4.yfilter != YFilter.not_set or
                                        self.ipv6.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "destination-address" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.af.is_set or self.af.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.af.get_name_leafdata())
                                    if (self.ipv4.is_set or self.ipv4.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv4.get_name_leafdata())
                                    if (self.ipv6.is_set or self.ipv6.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv6.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "af" or name == "ipv4" or name == "ipv6"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "af"):
                                        self.af = value
                                        self.af.value_namespace = name_space
                                        self.af.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv4"):
                                        self.ipv4 = value
                                        self.ipv4.value_namespace = name_space
                                        self.ipv4.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv6"):
                                        self.ipv6 = value
                                        self.ipv6.value_namespace = name_space
                                        self.ipv6.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.bundle_status.is_set or
                                    self.fast_detect.is_set or
                                    self.mode_info.is_set or
                                    self.nbr_unconfig_timer.is_set or
                                    self.pref_echo_min_interval.is_set or
                                    self.pref_min_interval.is_set or
                                    self.pref_multiplier.is_set or
                                    self.start_timer.is_set or
                                    (self.destination_address is not None and self.destination_address.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.bundle_status.yfilter != YFilter.not_set or
                                    self.fast_detect.yfilter != YFilter.not_set or
                                    self.mode_info.yfilter != YFilter.not_set or
                                    self.nbr_unconfig_timer.yfilter != YFilter.not_set or
                                    self.pref_echo_min_interval.yfilter != YFilter.not_set or
                                    self.pref_min_interval.yfilter != YFilter.not_set or
                                    self.pref_multiplier.yfilter != YFilter.not_set or
                                    self.start_timer.yfilter != YFilter.not_set or
                                    (self.destination_address is not None and self.destination_address.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "bfd-config" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.bundle_status.is_set or self.bundle_status.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.bundle_status.get_name_leafdata())
                                if (self.fast_detect.is_set or self.fast_detect.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.fast_detect.get_name_leafdata())
                                if (self.mode_info.is_set or self.mode_info.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mode_info.get_name_leafdata())
                                if (self.nbr_unconfig_timer.is_set or self.nbr_unconfig_timer.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.nbr_unconfig_timer.get_name_leafdata())
                                if (self.pref_echo_min_interval.is_set or self.pref_echo_min_interval.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pref_echo_min_interval.get_name_leafdata())
                                if (self.pref_min_interval.is_set or self.pref_min_interval.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pref_min_interval.get_name_leafdata())
                                if (self.pref_multiplier.is_set or self.pref_multiplier.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pref_multiplier.get_name_leafdata())
                                if (self.start_timer.is_set or self.start_timer.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.start_timer.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "destination-address"):
                                    if (self.destination_address is None):
                                        self.destination_address = BundleInformation.Bundle.BundleBundles.BundleBundle.BundleBundleDescendant.BundleData.BfdConfig.DestinationAddress()
                                        self.destination_address.parent = self
                                        self._children_name_map["destination_address"] = "destination-address"
                                    return self.destination_address

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "destination-address" or name == "bundle-status" or name == "fast-detect" or name == "mode-info" or name == "nbr-unconfig-timer" or name == "pref-echo-min-interval" or name == "pref-min-interval" or name == "pref-multiplier" or name == "start-timer"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "bundle-status"):
                                    self.bundle_status = value
                                    self.bundle_status.value_namespace = name_space
                                    self.bundle_status.value_namespace_prefix = name_space_prefix
                                if(value_path == "fast-detect"):
                                    self.fast_detect = value
                                    self.fast_detect.value_namespace = name_space
                                    self.fast_detect.value_namespace_prefix = name_space_prefix
                                if(value_path == "mode-info"):
                                    self.mode_info = value
                                    self.mode_info.value_namespace = name_space
                                    self.mode_info.value_namespace_prefix = name_space_prefix
                                if(value_path == "nbr-unconfig-timer"):
                                    self.nbr_unconfig_timer = value
                                    self.nbr_unconfig_timer.value_namespace = name_space
                                    self.nbr_unconfig_timer.value_namespace_prefix = name_space_prefix
                                if(value_path == "pref-echo-min-interval"):
                                    self.pref_echo_min_interval = value
                                    self.pref_echo_min_interval.value_namespace = name_space
                                    self.pref_echo_min_interval.value_namespace_prefix = name_space_prefix
                                if(value_path == "pref-min-interval"):
                                    self.pref_min_interval = value
                                    self.pref_min_interval.value_namespace = name_space
                                    self.pref_min_interval.value_namespace_prefix = name_space_prefix
                                if(value_path == "pref-multiplier"):
                                    self.pref_multiplier = value
                                    self.pref_multiplier.value_namespace = name_space
                                    self.pref_multiplier.value_namespace_prefix = name_space_prefix
                                if(value_path == "start-timer"):
                                    self.start_timer = value
                                    self.start_timer.value_namespace = name_space
                                    self.start_timer.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.bfd_config:
                                if (c.has_data()):
                                    return True
                            return (
                                self.active_foreign_member_count.is_set or
                                self.active_member_count.is_set or
                                self.available_bandwidth.is_set or
                                self.bundle_interface_name.is_set or
                                self.bundle_status.is_set or
                                self.cisco_extensions.is_set or
                                self.collector_max_delay.is_set or
                                self.configured_bandwidth.is_set or
                                self.configured_foreign_member_count.is_set or
                                self.configured_member_count.is_set or
                                self.effective_bandwidth.is_set or
                                self.iccp_group_id.is_set or
                                self.inter_chassis.is_set or
                                self.ipv4bfd_status.is_set or
                                self.ipv6bfd_status.is_set or
                                self.is_active.is_set or
                                self.lacp_nonrevertive.is_set or
                                self.lacp_status.is_set or
                                self.link_order_status.is_set or
                                self.load_balance_hash_type.is_set or
                                self.load_balance_locality_threshold.is_set or
                                self.mac_source.is_set or
                                self.mac_source_member.is_set or
                                self.maximize_threshold_value_band_width.is_set or
                                self.maximize_threshold_value_links.is_set or
                                self.maximum_active_links.is_set or
                                self.maximum_active_links_source.is_set or
                                self.minimum_active_links.is_set or
                                self.minimum_bandwidth.is_set or
                                self.mlacp_mode.is_set or
                                self.mlacp_status.is_set or
                                self.primary_member.is_set or
                                self.recovery_delay.is_set or
                                self.singleton.is_set or
                                self.standby_member_count.is_set or
                                self.suppression_timer.is_set or
                                self.switchover_type.is_set or
                                self.wait_while_timer.is_set or
                                (self.mac_address is not None and self.mac_address.has_data()))

                        def has_operation(self):
                            for c in self.bfd_config:
                                if (c.has_operation()):
                                    return True
                            return (
                                self.yfilter != YFilter.not_set or
                                self.active_foreign_member_count.yfilter != YFilter.not_set or
                                self.active_member_count.yfilter != YFilter.not_set or
                                self.available_bandwidth.yfilter != YFilter.not_set or
                                self.bundle_interface_name.yfilter != YFilter.not_set or
                                self.bundle_status.yfilter != YFilter.not_set or
                                self.cisco_extensions.yfilter != YFilter.not_set or
                                self.collector_max_delay.yfilter != YFilter.not_set or
                                self.configured_bandwidth.yfilter != YFilter.not_set or
                                self.configured_foreign_member_count.yfilter != YFilter.not_set or
                                self.configured_member_count.yfilter != YFilter.not_set or
                                self.effective_bandwidth.yfilter != YFilter.not_set or
                                self.iccp_group_id.yfilter != YFilter.not_set or
                                self.inter_chassis.yfilter != YFilter.not_set or
                                self.ipv4bfd_status.yfilter != YFilter.not_set or
                                self.ipv6bfd_status.yfilter != YFilter.not_set or
                                self.is_active.yfilter != YFilter.not_set or
                                self.lacp_nonrevertive.yfilter != YFilter.not_set or
                                self.lacp_status.yfilter != YFilter.not_set or
                                self.link_order_status.yfilter != YFilter.not_set or
                                self.load_balance_hash_type.yfilter != YFilter.not_set or
                                self.load_balance_locality_threshold.yfilter != YFilter.not_set or
                                self.mac_source.yfilter != YFilter.not_set or
                                self.mac_source_member.yfilter != YFilter.not_set or
                                self.maximize_threshold_value_band_width.yfilter != YFilter.not_set or
                                self.maximize_threshold_value_links.yfilter != YFilter.not_set or
                                self.maximum_active_links.yfilter != YFilter.not_set or
                                self.maximum_active_links_source.yfilter != YFilter.not_set or
                                self.minimum_active_links.yfilter != YFilter.not_set or
                                self.minimum_bandwidth.yfilter != YFilter.not_set or
                                self.mlacp_mode.yfilter != YFilter.not_set or
                                self.mlacp_status.yfilter != YFilter.not_set or
                                self.primary_member.yfilter != YFilter.not_set or
                                self.recovery_delay.yfilter != YFilter.not_set or
                                self.singleton.yfilter != YFilter.not_set or
                                self.standby_member_count.yfilter != YFilter.not_set or
                                self.suppression_timer.yfilter != YFilter.not_set or
                                self.switchover_type.yfilter != YFilter.not_set or
                                self.wait_while_timer.yfilter != YFilter.not_set or
                                (self.mac_address is not None and self.mac_address.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "bundle-data" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.active_foreign_member_count.is_set or self.active_foreign_member_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.active_foreign_member_count.get_name_leafdata())
                            if (self.active_member_count.is_set or self.active_member_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.active_member_count.get_name_leafdata())
                            if (self.available_bandwidth.is_set or self.available_bandwidth.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.available_bandwidth.get_name_leafdata())
                            if (self.bundle_interface_name.is_set or self.bundle_interface_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.bundle_interface_name.get_name_leafdata())
                            if (self.bundle_status.is_set or self.bundle_status.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.bundle_status.get_name_leafdata())
                            if (self.cisco_extensions.is_set or self.cisco_extensions.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.cisco_extensions.get_name_leafdata())
                            if (self.collector_max_delay.is_set or self.collector_max_delay.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.collector_max_delay.get_name_leafdata())
                            if (self.configured_bandwidth.is_set or self.configured_bandwidth.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.configured_bandwidth.get_name_leafdata())
                            if (self.configured_foreign_member_count.is_set or self.configured_foreign_member_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.configured_foreign_member_count.get_name_leafdata())
                            if (self.configured_member_count.is_set or self.configured_member_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.configured_member_count.get_name_leafdata())
                            if (self.effective_bandwidth.is_set or self.effective_bandwidth.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.effective_bandwidth.get_name_leafdata())
                            if (self.iccp_group_id.is_set or self.iccp_group_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.iccp_group_id.get_name_leafdata())
                            if (self.inter_chassis.is_set or self.inter_chassis.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.inter_chassis.get_name_leafdata())
                            if (self.ipv4bfd_status.is_set or self.ipv4bfd_status.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4bfd_status.get_name_leafdata())
                            if (self.ipv6bfd_status.is_set or self.ipv6bfd_status.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6bfd_status.get_name_leafdata())
                            if (self.is_active.is_set or self.is_active.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_active.get_name_leafdata())
                            if (self.lacp_nonrevertive.is_set or self.lacp_nonrevertive.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.lacp_nonrevertive.get_name_leafdata())
                            if (self.lacp_status.is_set or self.lacp_status.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.lacp_status.get_name_leafdata())
                            if (self.link_order_status.is_set or self.link_order_status.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.link_order_status.get_name_leafdata())
                            if (self.load_balance_hash_type.is_set or self.load_balance_hash_type.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.load_balance_hash_type.get_name_leafdata())
                            if (self.load_balance_locality_threshold.is_set or self.load_balance_locality_threshold.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.load_balance_locality_threshold.get_name_leafdata())
                            if (self.mac_source.is_set or self.mac_source.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mac_source.get_name_leafdata())
                            if (self.mac_source_member.is_set or self.mac_source_member.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mac_source_member.get_name_leafdata())
                            if (self.maximize_threshold_value_band_width.is_set or self.maximize_threshold_value_band_width.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.maximize_threshold_value_band_width.get_name_leafdata())
                            if (self.maximize_threshold_value_links.is_set or self.maximize_threshold_value_links.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.maximize_threshold_value_links.get_name_leafdata())
                            if (self.maximum_active_links.is_set or self.maximum_active_links.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.maximum_active_links.get_name_leafdata())
                            if (self.maximum_active_links_source.is_set or self.maximum_active_links_source.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.maximum_active_links_source.get_name_leafdata())
                            if (self.minimum_active_links.is_set or self.minimum_active_links.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.minimum_active_links.get_name_leafdata())
                            if (self.minimum_bandwidth.is_set or self.minimum_bandwidth.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.minimum_bandwidth.get_name_leafdata())
                            if (self.mlacp_mode.is_set or self.mlacp_mode.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mlacp_mode.get_name_leafdata())
                            if (self.mlacp_status.is_set or self.mlacp_status.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mlacp_status.get_name_leafdata())
                            if (self.primary_member.is_set or self.primary_member.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.primary_member.get_name_leafdata())
                            if (self.recovery_delay.is_set or self.recovery_delay.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.recovery_delay.get_name_leafdata())
                            if (self.singleton.is_set or self.singleton.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.singleton.get_name_leafdata())
                            if (self.standby_member_count.is_set or self.standby_member_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.standby_member_count.get_name_leafdata())
                            if (self.suppression_timer.is_set or self.suppression_timer.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.suppression_timer.get_name_leafdata())
                            if (self.switchover_type.is_set or self.switchover_type.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.switchover_type.get_name_leafdata())
                            if (self.wait_while_timer.is_set or self.wait_while_timer.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.wait_while_timer.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "bfd-config"):
                                for c in self.bfd_config:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = BundleInformation.Bundle.BundleBundles.BundleBundle.BundleBundleDescendant.BundleData.BfdConfig()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.bfd_config.append(c)
                                return c

                            if (child_yang_name == "mac-address"):
                                if (self.mac_address is None):
                                    self.mac_address = BundleInformation.Bundle.BundleBundles.BundleBundle.BundleBundleDescendant.BundleData.MacAddress()
                                    self.mac_address.parent = self
                                    self._children_name_map["mac_address"] = "mac-address"
                                return self.mac_address

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "bfd-config" or name == "mac-address" or name == "active-foreign-member-count" or name == "active-member-count" or name == "available-bandwidth" or name == "bundle-interface-name" or name == "bundle-status" or name == "cisco-extensions" or name == "collector-max-delay" or name == "configured-bandwidth" or name == "configured-foreign-member-count" or name == "configured-member-count" or name == "effective-bandwidth" or name == "iccp-group-id" or name == "inter-chassis" or name == "ipv4bfd-status" or name == "ipv6bfd-status" or name == "is-active" or name == "lacp-nonrevertive" or name == "lacp-status" or name == "link-order-status" or name == "load-balance-hash-type" or name == "load-balance-locality-threshold" or name == "mac-source" or name == "mac-source-member" or name == "maximize-threshold-value-band-width" or name == "maximize-threshold-value-links" or name == "maximum-active-links" or name == "maximum-active-links-source" or name == "minimum-active-links" or name == "minimum-bandwidth" or name == "mlacp-mode" or name == "mlacp-status" or name == "primary-member" or name == "recovery-delay" or name == "singleton" or name == "standby-member-count" or name == "suppression-timer" or name == "switchover-type" or name == "wait-while-timer"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "active-foreign-member-count"):
                                self.active_foreign_member_count = value
                                self.active_foreign_member_count.value_namespace = name_space
                                self.active_foreign_member_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "active-member-count"):
                                self.active_member_count = value
                                self.active_member_count.value_namespace = name_space
                                self.active_member_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "available-bandwidth"):
                                self.available_bandwidth = value
                                self.available_bandwidth.value_namespace = name_space
                                self.available_bandwidth.value_namespace_prefix = name_space_prefix
                            if(value_path == "bundle-interface-name"):
                                self.bundle_interface_name = value
                                self.bundle_interface_name.value_namespace = name_space
                                self.bundle_interface_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "bundle-status"):
                                self.bundle_status = value
                                self.bundle_status.value_namespace = name_space
                                self.bundle_status.value_namespace_prefix = name_space_prefix
                            if(value_path == "cisco-extensions"):
                                self.cisco_extensions = value
                                self.cisco_extensions.value_namespace = name_space
                                self.cisco_extensions.value_namespace_prefix = name_space_prefix
                            if(value_path == "collector-max-delay"):
                                self.collector_max_delay = value
                                self.collector_max_delay.value_namespace = name_space
                                self.collector_max_delay.value_namespace_prefix = name_space_prefix
                            if(value_path == "configured-bandwidth"):
                                self.configured_bandwidth = value
                                self.configured_bandwidth.value_namespace = name_space
                                self.configured_bandwidth.value_namespace_prefix = name_space_prefix
                            if(value_path == "configured-foreign-member-count"):
                                self.configured_foreign_member_count = value
                                self.configured_foreign_member_count.value_namespace = name_space
                                self.configured_foreign_member_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "configured-member-count"):
                                self.configured_member_count = value
                                self.configured_member_count.value_namespace = name_space
                                self.configured_member_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "effective-bandwidth"):
                                self.effective_bandwidth = value
                                self.effective_bandwidth.value_namespace = name_space
                                self.effective_bandwidth.value_namespace_prefix = name_space_prefix
                            if(value_path == "iccp-group-id"):
                                self.iccp_group_id = value
                                self.iccp_group_id.value_namespace = name_space
                                self.iccp_group_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "inter-chassis"):
                                self.inter_chassis = value
                                self.inter_chassis.value_namespace = name_space
                                self.inter_chassis.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4bfd-status"):
                                self.ipv4bfd_status = value
                                self.ipv4bfd_status.value_namespace = name_space
                                self.ipv4bfd_status.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6bfd-status"):
                                self.ipv6bfd_status = value
                                self.ipv6bfd_status.value_namespace = name_space
                                self.ipv6bfd_status.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-active"):
                                self.is_active = value
                                self.is_active.value_namespace = name_space
                                self.is_active.value_namespace_prefix = name_space_prefix
                            if(value_path == "lacp-nonrevertive"):
                                self.lacp_nonrevertive = value
                                self.lacp_nonrevertive.value_namespace = name_space
                                self.lacp_nonrevertive.value_namespace_prefix = name_space_prefix
                            if(value_path == "lacp-status"):
                                self.lacp_status = value
                                self.lacp_status.value_namespace = name_space
                                self.lacp_status.value_namespace_prefix = name_space_prefix
                            if(value_path == "link-order-status"):
                                self.link_order_status = value
                                self.link_order_status.value_namespace = name_space
                                self.link_order_status.value_namespace_prefix = name_space_prefix
                            if(value_path == "load-balance-hash-type"):
                                self.load_balance_hash_type = value
                                self.load_balance_hash_type.value_namespace = name_space
                                self.load_balance_hash_type.value_namespace_prefix = name_space_prefix
                            if(value_path == "load-balance-locality-threshold"):
                                self.load_balance_locality_threshold = value
                                self.load_balance_locality_threshold.value_namespace = name_space
                                self.load_balance_locality_threshold.value_namespace_prefix = name_space_prefix
                            if(value_path == "mac-source"):
                                self.mac_source = value
                                self.mac_source.value_namespace = name_space
                                self.mac_source.value_namespace_prefix = name_space_prefix
                            if(value_path == "mac-source-member"):
                                self.mac_source_member = value
                                self.mac_source_member.value_namespace = name_space
                                self.mac_source_member.value_namespace_prefix = name_space_prefix
                            if(value_path == "maximize-threshold-value-band-width"):
                                self.maximize_threshold_value_band_width = value
                                self.maximize_threshold_value_band_width.value_namespace = name_space
                                self.maximize_threshold_value_band_width.value_namespace_prefix = name_space_prefix
                            if(value_path == "maximize-threshold-value-links"):
                                self.maximize_threshold_value_links = value
                                self.maximize_threshold_value_links.value_namespace = name_space
                                self.maximize_threshold_value_links.value_namespace_prefix = name_space_prefix
                            if(value_path == "maximum-active-links"):
                                self.maximum_active_links = value
                                self.maximum_active_links.value_namespace = name_space
                                self.maximum_active_links.value_namespace_prefix = name_space_prefix
                            if(value_path == "maximum-active-links-source"):
                                self.maximum_active_links_source = value
                                self.maximum_active_links_source.value_namespace = name_space
                                self.maximum_active_links_source.value_namespace_prefix = name_space_prefix
                            if(value_path == "minimum-active-links"):
                                self.minimum_active_links = value
                                self.minimum_active_links.value_namespace = name_space
                                self.minimum_active_links.value_namespace_prefix = name_space_prefix
                            if(value_path == "minimum-bandwidth"):
                                self.minimum_bandwidth = value
                                self.minimum_bandwidth.value_namespace = name_space
                                self.minimum_bandwidth.value_namespace_prefix = name_space_prefix
                            if(value_path == "mlacp-mode"):
                                self.mlacp_mode = value
                                self.mlacp_mode.value_namespace = name_space
                                self.mlacp_mode.value_namespace_prefix = name_space_prefix
                            if(value_path == "mlacp-status"):
                                self.mlacp_status = value
                                self.mlacp_status.value_namespace = name_space
                                self.mlacp_status.value_namespace_prefix = name_space_prefix
                            if(value_path == "primary-member"):
                                self.primary_member = value
                                self.primary_member.value_namespace = name_space
                                self.primary_member.value_namespace_prefix = name_space_prefix
                            if(value_path == "recovery-delay"):
                                self.recovery_delay = value
                                self.recovery_delay.value_namespace = name_space
                                self.recovery_delay.value_namespace_prefix = name_space_prefix
                            if(value_path == "singleton"):
                                self.singleton = value
                                self.singleton.value_namespace = name_space
                                self.singleton.value_namespace_prefix = name_space_prefix
                            if(value_path == "standby-member-count"):
                                self.standby_member_count = value
                                self.standby_member_count.value_namespace = name_space
                                self.standby_member_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "suppression-timer"):
                                self.suppression_timer = value
                                self.suppression_timer.value_namespace = name_space
                                self.suppression_timer.value_namespace_prefix = name_space_prefix
                            if(value_path == "switchover-type"):
                                self.switchover_type = value
                                self.switchover_type.value_namespace = name_space
                                self.switchover_type.value_namespace_prefix = name_space_prefix
                            if(value_path == "wait-while-timer"):
                                self.wait_while_timer = value
                                self.wait_while_timer.value_namespace = name_space
                                self.wait_while_timer.value_namespace_prefix = name_space_prefix


                    class MemberData(Entity):
                        """
                        Member information
                        
                        .. attribute:: bandwidth
                        
                        	Bandwidth of this member (kbps)
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: kbit/s
                        
                        .. attribute:: counters
                        
                        	Counters data about member link
                        	**type**\:   :py:class:`Counters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.Bundle.BundleBundles.BundleBundle.BundleBundleDescendant.MemberData.Counters>`
                        
                        .. attribute:: iccp_node
                        
                        	Location of member
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: interface_name
                        
                        	Member's interface name
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: link_data
                        
                        	Lacp data about member link
                        	**type**\:   :py:class:`LinkData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.Bundle.BundleBundles.BundleBundle.BundleBundleDescendant.MemberData.LinkData>`
                        
                        .. attribute:: link_order_number
                        
                        	Member's link order number
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: mac_address
                        
                        	MAC address of this member (deprecated)
                        	**type**\:   :py:class:`MacAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.Bundle.BundleBundles.BundleBundle.BundleBundleDescendant.MemberData.MacAddress>`
                        
                        .. attribute:: member_mux_data
                        
                        	Mux state machine data
                        	**type**\:   :py:class:`MemberMuxData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.Bundle.BundleBundles.BundleBundle.BundleBundleDescendant.MemberData.MemberMuxData>`
                        
                        .. attribute:: member_name
                        
                        	Member's (short form) name
                        	**type**\:  str
                        
                        .. attribute:: member_type
                        
                        	Member's type (local/foreign)
                        	**type**\:   :py:class:`BmdMemberTypeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmdMemberTypeEnum>`
                        
                        .. attribute:: port_number
                        
                        	Member's link number
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: port_priority
                        
                        	The priority of this member
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: underlying_link_id
                        
                        	Member's underlying link ID
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'bundlemgr-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(BundleInformation.Bundle.BundleBundles.BundleBundle.BundleBundleDescendant.MemberData, self).__init__()

                            self.yang_name = "member-data"
                            self.yang_parent_name = "bundle-bundle-descendant"

                            self.bandwidth = YLeaf(YType.uint32, "bandwidth")

                            self.iccp_node = YLeaf(YType.uint32, "iccp-node")

                            self.interface_name = YLeaf(YType.str, "interface-name")

                            self.link_order_number = YLeaf(YType.uint16, "link-order-number")

                            self.member_name = YLeaf(YType.str, "member-name")

                            self.member_type = YLeaf(YType.enumeration, "member-type")

                            self.port_number = YLeaf(YType.uint16, "port-number")

                            self.port_priority = YLeaf(YType.uint16, "port-priority")

                            self.underlying_link_id = YLeaf(YType.uint16, "underlying-link-id")

                            self.counters = BundleInformation.Bundle.BundleBundles.BundleBundle.BundleBundleDescendant.MemberData.Counters()
                            self.counters.parent = self
                            self._children_name_map["counters"] = "counters"
                            self._children_yang_names.add("counters")

                            self.link_data = BundleInformation.Bundle.BundleBundles.BundleBundle.BundleBundleDescendant.MemberData.LinkData()
                            self.link_data.parent = self
                            self._children_name_map["link_data"] = "link-data"
                            self._children_yang_names.add("link-data")

                            self.mac_address = BundleInformation.Bundle.BundleBundles.BundleBundle.BundleBundleDescendant.MemberData.MacAddress()
                            self.mac_address.parent = self
                            self._children_name_map["mac_address"] = "mac-address"
                            self._children_yang_names.add("mac-address")

                            self.member_mux_data = BundleInformation.Bundle.BundleBundles.BundleBundle.BundleBundleDescendant.MemberData.MemberMuxData()
                            self.member_mux_data.parent = self
                            self._children_name_map["member_mux_data"] = "member-mux-data"
                            self._children_yang_names.add("member-mux-data")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("bandwidth",
                                            "iccp_node",
                                            "interface_name",
                                            "link_order_number",
                                            "member_name",
                                            "member_type",
                                            "port_number",
                                            "port_priority",
                                            "underlying_link_id") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(BundleInformation.Bundle.BundleBundles.BundleBundle.BundleBundleDescendant.MemberData, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(BundleInformation.Bundle.BundleBundles.BundleBundle.BundleBundleDescendant.MemberData, self).__setattr__(name, value)


                        class Counters(Entity):
                            """
                            Counters data about member link
                            
                            .. attribute:: defaulted
                            
                            	State flag set to Defaulted
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: excess_lacpd_us_received
                            
                            	LACPDUs received that exceed the rate limit
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: excess_marker_packets_received
                            
                            	Marker packets received that exceed the rate limit
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: expired
                            
                            	State flag set to Expired
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: illegal_packets_received
                            
                            	Illegal and unknown packets received
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: lacpd_us_received
                            
                            	LACPDUs received
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: lacpd_us_transmitted
                            
                            	LACPDUs transmitted
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: last_cleared_nsec
                            
                            	Last time counters cleared (nsec) (deprecated)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: last_cleared_sec
                            
                            	Last time counters cleared (s) (deprecated)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: marker_packets_received
                            
                            	Marker packets received
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: marker_responses_transmitted
                            
                            	Marker response packets transmitted
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'bundlemgr-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(BundleInformation.Bundle.BundleBundles.BundleBundle.BundleBundleDescendant.MemberData.Counters, self).__init__()

                                self.yang_name = "counters"
                                self.yang_parent_name = "member-data"

                                self.defaulted = YLeaf(YType.uint32, "defaulted")

                                self.excess_lacpd_us_received = YLeaf(YType.uint32, "excess-lacpd-us-received")

                                self.excess_marker_packets_received = YLeaf(YType.uint32, "excess-marker-packets-received")

                                self.expired = YLeaf(YType.uint32, "expired")

                                self.illegal_packets_received = YLeaf(YType.uint32, "illegal-packets-received")

                                self.lacpd_us_received = YLeaf(YType.uint32, "lacpd-us-received")

                                self.lacpd_us_transmitted = YLeaf(YType.uint32, "lacpd-us-transmitted")

                                self.last_cleared_nsec = YLeaf(YType.uint32, "last-cleared-nsec")

                                self.last_cleared_sec = YLeaf(YType.uint32, "last-cleared-sec")

                                self.marker_packets_received = YLeaf(YType.uint32, "marker-packets-received")

                                self.marker_responses_transmitted = YLeaf(YType.uint32, "marker-responses-transmitted")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("defaulted",
                                                "excess_lacpd_us_received",
                                                "excess_marker_packets_received",
                                                "expired",
                                                "illegal_packets_received",
                                                "lacpd_us_received",
                                                "lacpd_us_transmitted",
                                                "last_cleared_nsec",
                                                "last_cleared_sec",
                                                "marker_packets_received",
                                                "marker_responses_transmitted") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(BundleInformation.Bundle.BundleBundles.BundleBundle.BundleBundleDescendant.MemberData.Counters, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(BundleInformation.Bundle.BundleBundles.BundleBundle.BundleBundleDescendant.MemberData.Counters, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.defaulted.is_set or
                                    self.excess_lacpd_us_received.is_set or
                                    self.excess_marker_packets_received.is_set or
                                    self.expired.is_set or
                                    self.illegal_packets_received.is_set or
                                    self.lacpd_us_received.is_set or
                                    self.lacpd_us_transmitted.is_set or
                                    self.last_cleared_nsec.is_set or
                                    self.last_cleared_sec.is_set or
                                    self.marker_packets_received.is_set or
                                    self.marker_responses_transmitted.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.defaulted.yfilter != YFilter.not_set or
                                    self.excess_lacpd_us_received.yfilter != YFilter.not_set or
                                    self.excess_marker_packets_received.yfilter != YFilter.not_set or
                                    self.expired.yfilter != YFilter.not_set or
                                    self.illegal_packets_received.yfilter != YFilter.not_set or
                                    self.lacpd_us_received.yfilter != YFilter.not_set or
                                    self.lacpd_us_transmitted.yfilter != YFilter.not_set or
                                    self.last_cleared_nsec.yfilter != YFilter.not_set or
                                    self.last_cleared_sec.yfilter != YFilter.not_set or
                                    self.marker_packets_received.yfilter != YFilter.not_set or
                                    self.marker_responses_transmitted.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "counters" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.defaulted.is_set or self.defaulted.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.defaulted.get_name_leafdata())
                                if (self.excess_lacpd_us_received.is_set or self.excess_lacpd_us_received.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.excess_lacpd_us_received.get_name_leafdata())
                                if (self.excess_marker_packets_received.is_set or self.excess_marker_packets_received.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.excess_marker_packets_received.get_name_leafdata())
                                if (self.expired.is_set or self.expired.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.expired.get_name_leafdata())
                                if (self.illegal_packets_received.is_set or self.illegal_packets_received.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.illegal_packets_received.get_name_leafdata())
                                if (self.lacpd_us_received.is_set or self.lacpd_us_received.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.lacpd_us_received.get_name_leafdata())
                                if (self.lacpd_us_transmitted.is_set or self.lacpd_us_transmitted.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.lacpd_us_transmitted.get_name_leafdata())
                                if (self.last_cleared_nsec.is_set or self.last_cleared_nsec.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.last_cleared_nsec.get_name_leafdata())
                                if (self.last_cleared_sec.is_set or self.last_cleared_sec.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.last_cleared_sec.get_name_leafdata())
                                if (self.marker_packets_received.is_set or self.marker_packets_received.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.marker_packets_received.get_name_leafdata())
                                if (self.marker_responses_transmitted.is_set or self.marker_responses_transmitted.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.marker_responses_transmitted.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "defaulted" or name == "excess-lacpd-us-received" or name == "excess-marker-packets-received" or name == "expired" or name == "illegal-packets-received" or name == "lacpd-us-received" or name == "lacpd-us-transmitted" or name == "last-cleared-nsec" or name == "last-cleared-sec" or name == "marker-packets-received" or name == "marker-responses-transmitted"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "defaulted"):
                                    self.defaulted = value
                                    self.defaulted.value_namespace = name_space
                                    self.defaulted.value_namespace_prefix = name_space_prefix
                                if(value_path == "excess-lacpd-us-received"):
                                    self.excess_lacpd_us_received = value
                                    self.excess_lacpd_us_received.value_namespace = name_space
                                    self.excess_lacpd_us_received.value_namespace_prefix = name_space_prefix
                                if(value_path == "excess-marker-packets-received"):
                                    self.excess_marker_packets_received = value
                                    self.excess_marker_packets_received.value_namespace = name_space
                                    self.excess_marker_packets_received.value_namespace_prefix = name_space_prefix
                                if(value_path == "expired"):
                                    self.expired = value
                                    self.expired.value_namespace = name_space
                                    self.expired.value_namespace_prefix = name_space_prefix
                                if(value_path == "illegal-packets-received"):
                                    self.illegal_packets_received = value
                                    self.illegal_packets_received.value_namespace = name_space
                                    self.illegal_packets_received.value_namespace_prefix = name_space_prefix
                                if(value_path == "lacpd-us-received"):
                                    self.lacpd_us_received = value
                                    self.lacpd_us_received.value_namespace = name_space
                                    self.lacpd_us_received.value_namespace_prefix = name_space_prefix
                                if(value_path == "lacpd-us-transmitted"):
                                    self.lacpd_us_transmitted = value
                                    self.lacpd_us_transmitted.value_namespace = name_space
                                    self.lacpd_us_transmitted.value_namespace_prefix = name_space_prefix
                                if(value_path == "last-cleared-nsec"):
                                    self.last_cleared_nsec = value
                                    self.last_cleared_nsec.value_namespace = name_space
                                    self.last_cleared_nsec.value_namespace_prefix = name_space_prefix
                                if(value_path == "last-cleared-sec"):
                                    self.last_cleared_sec = value
                                    self.last_cleared_sec.value_namespace = name_space
                                    self.last_cleared_sec.value_namespace_prefix = name_space_prefix
                                if(value_path == "marker-packets-received"):
                                    self.marker_packets_received = value
                                    self.marker_packets_received.value_namespace = name_space
                                    self.marker_packets_received.value_namespace_prefix = name_space_prefix
                                if(value_path == "marker-responses-transmitted"):
                                    self.marker_responses_transmitted = value
                                    self.marker_responses_transmitted.value_namespace = name_space
                                    self.marker_responses_transmitted.value_namespace_prefix = name_space_prefix


                        class LinkData(Entity):
                            """
                            Lacp data about member link
                            
                            .. attribute:: actor_operational_key
                            
                            	Operational key for this port
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: actor_port_id
                            
                            	Port number of this port
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: actor_port_priority
                            
                            	Priority of this port
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: actor_port_state
                            
                            	LACP state of this port
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: actor_system_mac_address
                            
                            	MAC Address of the actor system
                            	**type**\:  str
                            
                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                            
                            .. attribute:: actor_system_priority
                            
                            	System priority of actor system
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: attached_aggregator_id
                            
                            	MIB ifindex of attached bundle
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: interface_handle
                            
                            	Member's interface handle
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: partner_operational_key
                            
                            	Operational key for partner port
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: partner_port_id
                            
                            	Port number of the partner's port
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: partner_port_priority
                            
                            	Priority of the partner's port
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: partner_port_state
                            
                            	LACP state of the partner's port
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: partner_system_mac_address
                            
                            	MAC Address used to identify the partner system
                            	**type**\:  str
                            
                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                            
                            .. attribute:: partner_system_priority
                            
                            	System priority of partner system
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: selected_aggregator_id
                            
                            	MIB ifindex of selected bundle
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'bundlemgr-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(BundleInformation.Bundle.BundleBundles.BundleBundle.BundleBundleDescendant.MemberData.LinkData, self).__init__()

                                self.yang_name = "link-data"
                                self.yang_parent_name = "member-data"

                                self.actor_operational_key = YLeaf(YType.uint16, "actor-operational-key")

                                self.actor_port_id = YLeaf(YType.uint16, "actor-port-id")

                                self.actor_port_priority = YLeaf(YType.uint16, "actor-port-priority")

                                self.actor_port_state = YLeaf(YType.uint8, "actor-port-state")

                                self.actor_system_mac_address = YLeaf(YType.str, "actor-system-mac-address")

                                self.actor_system_priority = YLeaf(YType.uint16, "actor-system-priority")

                                self.attached_aggregator_id = YLeaf(YType.uint32, "attached-aggregator-id")

                                self.interface_handle = YLeaf(YType.str, "interface-handle")

                                self.partner_operational_key = YLeaf(YType.uint16, "partner-operational-key")

                                self.partner_port_id = YLeaf(YType.uint16, "partner-port-id")

                                self.partner_port_priority = YLeaf(YType.uint16, "partner-port-priority")

                                self.partner_port_state = YLeaf(YType.uint8, "partner-port-state")

                                self.partner_system_mac_address = YLeaf(YType.str, "partner-system-mac-address")

                                self.partner_system_priority = YLeaf(YType.uint16, "partner-system-priority")

                                self.selected_aggregator_id = YLeaf(YType.uint32, "selected-aggregator-id")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("actor_operational_key",
                                                "actor_port_id",
                                                "actor_port_priority",
                                                "actor_port_state",
                                                "actor_system_mac_address",
                                                "actor_system_priority",
                                                "attached_aggregator_id",
                                                "interface_handle",
                                                "partner_operational_key",
                                                "partner_port_id",
                                                "partner_port_priority",
                                                "partner_port_state",
                                                "partner_system_mac_address",
                                                "partner_system_priority",
                                                "selected_aggregator_id") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(BundleInformation.Bundle.BundleBundles.BundleBundle.BundleBundleDescendant.MemberData.LinkData, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(BundleInformation.Bundle.BundleBundles.BundleBundle.BundleBundleDescendant.MemberData.LinkData, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.actor_operational_key.is_set or
                                    self.actor_port_id.is_set or
                                    self.actor_port_priority.is_set or
                                    self.actor_port_state.is_set or
                                    self.actor_system_mac_address.is_set or
                                    self.actor_system_priority.is_set or
                                    self.attached_aggregator_id.is_set or
                                    self.interface_handle.is_set or
                                    self.partner_operational_key.is_set or
                                    self.partner_port_id.is_set or
                                    self.partner_port_priority.is_set or
                                    self.partner_port_state.is_set or
                                    self.partner_system_mac_address.is_set or
                                    self.partner_system_priority.is_set or
                                    self.selected_aggregator_id.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.actor_operational_key.yfilter != YFilter.not_set or
                                    self.actor_port_id.yfilter != YFilter.not_set or
                                    self.actor_port_priority.yfilter != YFilter.not_set or
                                    self.actor_port_state.yfilter != YFilter.not_set or
                                    self.actor_system_mac_address.yfilter != YFilter.not_set or
                                    self.actor_system_priority.yfilter != YFilter.not_set or
                                    self.attached_aggregator_id.yfilter != YFilter.not_set or
                                    self.interface_handle.yfilter != YFilter.not_set or
                                    self.partner_operational_key.yfilter != YFilter.not_set or
                                    self.partner_port_id.yfilter != YFilter.not_set or
                                    self.partner_port_priority.yfilter != YFilter.not_set or
                                    self.partner_port_state.yfilter != YFilter.not_set or
                                    self.partner_system_mac_address.yfilter != YFilter.not_set or
                                    self.partner_system_priority.yfilter != YFilter.not_set or
                                    self.selected_aggregator_id.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "link-data" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.actor_operational_key.is_set or self.actor_operational_key.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.actor_operational_key.get_name_leafdata())
                                if (self.actor_port_id.is_set or self.actor_port_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.actor_port_id.get_name_leafdata())
                                if (self.actor_port_priority.is_set or self.actor_port_priority.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.actor_port_priority.get_name_leafdata())
                                if (self.actor_port_state.is_set or self.actor_port_state.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.actor_port_state.get_name_leafdata())
                                if (self.actor_system_mac_address.is_set or self.actor_system_mac_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.actor_system_mac_address.get_name_leafdata())
                                if (self.actor_system_priority.is_set or self.actor_system_priority.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.actor_system_priority.get_name_leafdata())
                                if (self.attached_aggregator_id.is_set or self.attached_aggregator_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.attached_aggregator_id.get_name_leafdata())
                                if (self.interface_handle.is_set or self.interface_handle.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.interface_handle.get_name_leafdata())
                                if (self.partner_operational_key.is_set or self.partner_operational_key.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.partner_operational_key.get_name_leafdata())
                                if (self.partner_port_id.is_set or self.partner_port_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.partner_port_id.get_name_leafdata())
                                if (self.partner_port_priority.is_set or self.partner_port_priority.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.partner_port_priority.get_name_leafdata())
                                if (self.partner_port_state.is_set or self.partner_port_state.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.partner_port_state.get_name_leafdata())
                                if (self.partner_system_mac_address.is_set or self.partner_system_mac_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.partner_system_mac_address.get_name_leafdata())
                                if (self.partner_system_priority.is_set or self.partner_system_priority.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.partner_system_priority.get_name_leafdata())
                                if (self.selected_aggregator_id.is_set or self.selected_aggregator_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.selected_aggregator_id.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "actor-operational-key" or name == "actor-port-id" or name == "actor-port-priority" or name == "actor-port-state" or name == "actor-system-mac-address" or name == "actor-system-priority" or name == "attached-aggregator-id" or name == "interface-handle" or name == "partner-operational-key" or name == "partner-port-id" or name == "partner-port-priority" or name == "partner-port-state" or name == "partner-system-mac-address" or name == "partner-system-priority" or name == "selected-aggregator-id"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "actor-operational-key"):
                                    self.actor_operational_key = value
                                    self.actor_operational_key.value_namespace = name_space
                                    self.actor_operational_key.value_namespace_prefix = name_space_prefix
                                if(value_path == "actor-port-id"):
                                    self.actor_port_id = value
                                    self.actor_port_id.value_namespace = name_space
                                    self.actor_port_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "actor-port-priority"):
                                    self.actor_port_priority = value
                                    self.actor_port_priority.value_namespace = name_space
                                    self.actor_port_priority.value_namespace_prefix = name_space_prefix
                                if(value_path == "actor-port-state"):
                                    self.actor_port_state = value
                                    self.actor_port_state.value_namespace = name_space
                                    self.actor_port_state.value_namespace_prefix = name_space_prefix
                                if(value_path == "actor-system-mac-address"):
                                    self.actor_system_mac_address = value
                                    self.actor_system_mac_address.value_namespace = name_space
                                    self.actor_system_mac_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "actor-system-priority"):
                                    self.actor_system_priority = value
                                    self.actor_system_priority.value_namespace = name_space
                                    self.actor_system_priority.value_namespace_prefix = name_space_prefix
                                if(value_path == "attached-aggregator-id"):
                                    self.attached_aggregator_id = value
                                    self.attached_aggregator_id.value_namespace = name_space
                                    self.attached_aggregator_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "interface-handle"):
                                    self.interface_handle = value
                                    self.interface_handle.value_namespace = name_space
                                    self.interface_handle.value_namespace_prefix = name_space_prefix
                                if(value_path == "partner-operational-key"):
                                    self.partner_operational_key = value
                                    self.partner_operational_key.value_namespace = name_space
                                    self.partner_operational_key.value_namespace_prefix = name_space_prefix
                                if(value_path == "partner-port-id"):
                                    self.partner_port_id = value
                                    self.partner_port_id.value_namespace = name_space
                                    self.partner_port_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "partner-port-priority"):
                                    self.partner_port_priority = value
                                    self.partner_port_priority.value_namespace = name_space
                                    self.partner_port_priority.value_namespace_prefix = name_space_prefix
                                if(value_path == "partner-port-state"):
                                    self.partner_port_state = value
                                    self.partner_port_state.value_namespace = name_space
                                    self.partner_port_state.value_namespace_prefix = name_space_prefix
                                if(value_path == "partner-system-mac-address"):
                                    self.partner_system_mac_address = value
                                    self.partner_system_mac_address.value_namespace = name_space
                                    self.partner_system_mac_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "partner-system-priority"):
                                    self.partner_system_priority = value
                                    self.partner_system_priority.value_namespace = name_space
                                    self.partner_system_priority.value_namespace_prefix = name_space_prefix
                                if(value_path == "selected-aggregator-id"):
                                    self.selected_aggregator_id = value
                                    self.selected_aggregator_id.value_namespace = name_space
                                    self.selected_aggregator_id.value_namespace_prefix = name_space_prefix


                        class MemberMuxData(Entity):
                            """
                            Mux state machine data
                            
                            .. attribute:: error
                            
                            	Internal value indicating if an error occurred trying to put a link into the desired state
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: member_mux_state_reason
                            
                            	Reason for last Mux state change
                            	**type**\:   :py:class:`BmMbrStateReason <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmMbrStateReason>`
                            
                            .. attribute:: member_mux_state_reason_data
                            
                            	Data regarding the reason for last Mux state change
                            	**type**\:   :py:class:`MemberMuxStateReasonData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.Bundle.BundleBundles.BundleBundle.BundleBundleDescendant.MemberData.MemberMuxData.MemberMuxStateReasonData>`
                            
                            .. attribute:: member_state
                            
                            	Current internal state of this bundle member
                            	**type**\:   :py:class:`BmdMemberState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmdMemberState>`
                            
                            .. attribute:: mux_state
                            
                            	Current state of this bundle member
                            	**type**\:   :py:class:`BmMuxstate <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmMuxstate>`
                            
                            .. attribute:: mux_state_reason
                            
                            	Reason for last Mux state change (Deprecated)
                            	**type**\:   :py:class:`BmMuxreason <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmMuxreason>`
                            
                            

                            """

                            _prefix = 'bundlemgr-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(BundleInformation.Bundle.BundleBundles.BundleBundle.BundleBundleDescendant.MemberData.MemberMuxData, self).__init__()

                                self.yang_name = "member-mux-data"
                                self.yang_parent_name = "member-data"

                                self.error = YLeaf(YType.uint32, "error")

                                self.member_mux_state_reason = YLeaf(YType.enumeration, "member-mux-state-reason")

                                self.member_state = YLeaf(YType.enumeration, "member-state")

                                self.mux_state = YLeaf(YType.enumeration, "mux-state")

                                self.mux_state_reason = YLeaf(YType.enumeration, "mux-state-reason")

                                self.member_mux_state_reason_data = BundleInformation.Bundle.BundleBundles.BundleBundle.BundleBundleDescendant.MemberData.MemberMuxData.MemberMuxStateReasonData()
                                self.member_mux_state_reason_data.parent = self
                                self._children_name_map["member_mux_state_reason_data"] = "member-mux-state-reason-data"
                                self._children_yang_names.add("member-mux-state-reason-data")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("error",
                                                "member_mux_state_reason",
                                                "member_state",
                                                "mux_state",
                                                "mux_state_reason") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(BundleInformation.Bundle.BundleBundles.BundleBundle.BundleBundleDescendant.MemberData.MemberMuxData, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(BundleInformation.Bundle.BundleBundles.BundleBundle.BundleBundleDescendant.MemberData.MemberMuxData, self).__setattr__(name, value)


                            class MemberMuxStateReasonData(Entity):
                                """
                                Data regarding the reason for last Mux state
                                change
                                
                                .. attribute:: reason_type
                                
                                	The item the reason applies to
                                	**type**\:   :py:class:`BmStateReasonTarget <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmStateReasonTarget>`
                                
                                .. attribute:: severity
                                
                                	The severity of the reason
                                	**type**\:   :py:class:`BmSeverity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmSeverity>`
                                
                                

                                """

                                _prefix = 'bundlemgr-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(BundleInformation.Bundle.BundleBundles.BundleBundle.BundleBundleDescendant.MemberData.MemberMuxData.MemberMuxStateReasonData, self).__init__()

                                    self.yang_name = "member-mux-state-reason-data"
                                    self.yang_parent_name = "member-mux-data"

                                    self.reason_type = YLeaf(YType.enumeration, "reason-type")

                                    self.severity = YLeaf(YType.enumeration, "severity")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("reason_type",
                                                    "severity") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(BundleInformation.Bundle.BundleBundles.BundleBundle.BundleBundleDescendant.MemberData.MemberMuxData.MemberMuxStateReasonData, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(BundleInformation.Bundle.BundleBundles.BundleBundle.BundleBundleDescendant.MemberData.MemberMuxData.MemberMuxStateReasonData, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.reason_type.is_set or
                                        self.severity.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.reason_type.yfilter != YFilter.not_set or
                                        self.severity.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "member-mux-state-reason-data" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.reason_type.is_set or self.reason_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.reason_type.get_name_leafdata())
                                    if (self.severity.is_set or self.severity.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.severity.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "reason-type" or name == "severity"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "reason-type"):
                                        self.reason_type = value
                                        self.reason_type.value_namespace = name_space
                                        self.reason_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "severity"):
                                        self.severity = value
                                        self.severity.value_namespace = name_space
                                        self.severity.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.error.is_set or
                                    self.member_mux_state_reason.is_set or
                                    self.member_state.is_set or
                                    self.mux_state.is_set or
                                    self.mux_state_reason.is_set or
                                    (self.member_mux_state_reason_data is not None and self.member_mux_state_reason_data.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.error.yfilter != YFilter.not_set or
                                    self.member_mux_state_reason.yfilter != YFilter.not_set or
                                    self.member_state.yfilter != YFilter.not_set or
                                    self.mux_state.yfilter != YFilter.not_set or
                                    self.mux_state_reason.yfilter != YFilter.not_set or
                                    (self.member_mux_state_reason_data is not None and self.member_mux_state_reason_data.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "member-mux-data" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.error.is_set or self.error.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.error.get_name_leafdata())
                                if (self.member_mux_state_reason.is_set or self.member_mux_state_reason.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.member_mux_state_reason.get_name_leafdata())
                                if (self.member_state.is_set or self.member_state.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.member_state.get_name_leafdata())
                                if (self.mux_state.is_set or self.mux_state.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mux_state.get_name_leafdata())
                                if (self.mux_state_reason.is_set or self.mux_state_reason.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mux_state_reason.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "member-mux-state-reason-data"):
                                    if (self.member_mux_state_reason_data is None):
                                        self.member_mux_state_reason_data = BundleInformation.Bundle.BundleBundles.BundleBundle.BundleBundleDescendant.MemberData.MemberMuxData.MemberMuxStateReasonData()
                                        self.member_mux_state_reason_data.parent = self
                                        self._children_name_map["member_mux_state_reason_data"] = "member-mux-state-reason-data"
                                    return self.member_mux_state_reason_data

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "member-mux-state-reason-data" or name == "error" or name == "member-mux-state-reason" or name == "member-state" or name == "mux-state" or name == "mux-state-reason"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "error"):
                                    self.error = value
                                    self.error.value_namespace = name_space
                                    self.error.value_namespace_prefix = name_space_prefix
                                if(value_path == "member-mux-state-reason"):
                                    self.member_mux_state_reason = value
                                    self.member_mux_state_reason.value_namespace = name_space
                                    self.member_mux_state_reason.value_namespace_prefix = name_space_prefix
                                if(value_path == "member-state"):
                                    self.member_state = value
                                    self.member_state.value_namespace = name_space
                                    self.member_state.value_namespace_prefix = name_space_prefix
                                if(value_path == "mux-state"):
                                    self.mux_state = value
                                    self.mux_state.value_namespace = name_space
                                    self.mux_state.value_namespace_prefix = name_space_prefix
                                if(value_path == "mux-state-reason"):
                                    self.mux_state_reason = value
                                    self.mux_state_reason.value_namespace = name_space
                                    self.mux_state_reason.value_namespace_prefix = name_space_prefix


                        class MacAddress(Entity):
                            """
                            MAC address of this member (deprecated)
                            
                            .. attribute:: address
                            
                            	MAC address
                            	**type**\:  str
                            
                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                            
                            

                            """

                            _prefix = 'bundlemgr-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(BundleInformation.Bundle.BundleBundles.BundleBundle.BundleBundleDescendant.MemberData.MacAddress, self).__init__()

                                self.yang_name = "mac-address"
                                self.yang_parent_name = "member-data"

                                self.address = YLeaf(YType.str, "address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(BundleInformation.Bundle.BundleBundles.BundleBundle.BundleBundleDescendant.MemberData.MacAddress, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(BundleInformation.Bundle.BundleBundles.BundleBundle.BundleBundleDescendant.MemberData.MacAddress, self).__setattr__(name, value)

                            def has_data(self):
                                return self.address.is_set

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "mac-address" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.address.is_set or self.address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "address"):
                                    self.address = value
                                    self.address.value_namespace = name_space
                                    self.address.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.bandwidth.is_set or
                                self.iccp_node.is_set or
                                self.interface_name.is_set or
                                self.link_order_number.is_set or
                                self.member_name.is_set or
                                self.member_type.is_set or
                                self.port_number.is_set or
                                self.port_priority.is_set or
                                self.underlying_link_id.is_set or
                                (self.counters is not None and self.counters.has_data()) or
                                (self.link_data is not None and self.link_data.has_data()) or
                                (self.mac_address is not None and self.mac_address.has_data()) or
                                (self.member_mux_data is not None and self.member_mux_data.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.bandwidth.yfilter != YFilter.not_set or
                                self.iccp_node.yfilter != YFilter.not_set or
                                self.interface_name.yfilter != YFilter.not_set or
                                self.link_order_number.yfilter != YFilter.not_set or
                                self.member_name.yfilter != YFilter.not_set or
                                self.member_type.yfilter != YFilter.not_set or
                                self.port_number.yfilter != YFilter.not_set or
                                self.port_priority.yfilter != YFilter.not_set or
                                self.underlying_link_id.yfilter != YFilter.not_set or
                                (self.counters is not None and self.counters.has_operation()) or
                                (self.link_data is not None and self.link_data.has_operation()) or
                                (self.mac_address is not None and self.mac_address.has_operation()) or
                                (self.member_mux_data is not None and self.member_mux_data.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "member-data" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.bandwidth.is_set or self.bandwidth.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.bandwidth.get_name_leafdata())
                            if (self.iccp_node.is_set or self.iccp_node.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.iccp_node.get_name_leafdata())
                            if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface_name.get_name_leafdata())
                            if (self.link_order_number.is_set or self.link_order_number.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.link_order_number.get_name_leafdata())
                            if (self.member_name.is_set or self.member_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.member_name.get_name_leafdata())
                            if (self.member_type.is_set or self.member_type.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.member_type.get_name_leafdata())
                            if (self.port_number.is_set or self.port_number.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.port_number.get_name_leafdata())
                            if (self.port_priority.is_set or self.port_priority.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.port_priority.get_name_leafdata())
                            if (self.underlying_link_id.is_set or self.underlying_link_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.underlying_link_id.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "counters"):
                                if (self.counters is None):
                                    self.counters = BundleInformation.Bundle.BundleBundles.BundleBundle.BundleBundleDescendant.MemberData.Counters()
                                    self.counters.parent = self
                                    self._children_name_map["counters"] = "counters"
                                return self.counters

                            if (child_yang_name == "link-data"):
                                if (self.link_data is None):
                                    self.link_data = BundleInformation.Bundle.BundleBundles.BundleBundle.BundleBundleDescendant.MemberData.LinkData()
                                    self.link_data.parent = self
                                    self._children_name_map["link_data"] = "link-data"
                                return self.link_data

                            if (child_yang_name == "mac-address"):
                                if (self.mac_address is None):
                                    self.mac_address = BundleInformation.Bundle.BundleBundles.BundleBundle.BundleBundleDescendant.MemberData.MacAddress()
                                    self.mac_address.parent = self
                                    self._children_name_map["mac_address"] = "mac-address"
                                return self.mac_address

                            if (child_yang_name == "member-mux-data"):
                                if (self.member_mux_data is None):
                                    self.member_mux_data = BundleInformation.Bundle.BundleBundles.BundleBundle.BundleBundleDescendant.MemberData.MemberMuxData()
                                    self.member_mux_data.parent = self
                                    self._children_name_map["member_mux_data"] = "member-mux-data"
                                return self.member_mux_data

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "counters" or name == "link-data" or name == "mac-address" or name == "member-mux-data" or name == "bandwidth" or name == "iccp-node" or name == "interface-name" or name == "link-order-number" or name == "member-name" or name == "member-type" or name == "port-number" or name == "port-priority" or name == "underlying-link-id"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "bandwidth"):
                                self.bandwidth = value
                                self.bandwidth.value_namespace = name_space
                                self.bandwidth.value_namespace_prefix = name_space_prefix
                            if(value_path == "iccp-node"):
                                self.iccp_node = value
                                self.iccp_node.value_namespace = name_space
                                self.iccp_node.value_namespace_prefix = name_space_prefix
                            if(value_path == "interface-name"):
                                self.interface_name = value
                                self.interface_name.value_namespace = name_space
                                self.interface_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "link-order-number"):
                                self.link_order_number = value
                                self.link_order_number.value_namespace = name_space
                                self.link_order_number.value_namespace_prefix = name_space_prefix
                            if(value_path == "member-name"):
                                self.member_name = value
                                self.member_name.value_namespace = name_space
                                self.member_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "member-type"):
                                self.member_type = value
                                self.member_type.value_namespace = name_space
                                self.member_type.value_namespace_prefix = name_space_prefix
                            if(value_path == "port-number"):
                                self.port_number = value
                                self.port_number.value_namespace = name_space
                                self.port_number.value_namespace_prefix = name_space_prefix
                            if(value_path == "port-priority"):
                                self.port_priority = value
                                self.port_priority.value_namespace = name_space
                                self.port_priority.value_namespace_prefix = name_space_prefix
                            if(value_path == "underlying-link-id"):
                                self.underlying_link_id = value
                                self.underlying_link_id.value_namespace = name_space
                                self.underlying_link_id.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.member_data:
                            if (c.has_data()):
                                return True
                        return (self.bundle_data is not None and self.bundle_data.has_data())

                    def has_operation(self):
                        for c in self.member_data:
                            if (c.has_operation()):
                                return True
                        return (
                            self.yfilter != YFilter.not_set or
                            (self.bundle_data is not None and self.bundle_data.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "bundle-bundle-descendant" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "bundle-data"):
                            if (self.bundle_data is None):
                                self.bundle_data = BundleInformation.Bundle.BundleBundles.BundleBundle.BundleBundleDescendant.BundleData()
                                self.bundle_data.parent = self
                                self._children_name_map["bundle_data"] = "bundle-data"
                            return self.bundle_data

                        if (child_yang_name == "member-data"):
                            for c in self.member_data:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = BundleInformation.Bundle.BundleBundles.BundleBundle.BundleBundleDescendant.MemberData()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.member_data.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "bundle-data" or name == "member-data"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class BundleBundleChildrenMembers(Entity):
                    """
                    Children of bundle with common bundle
                    information
                    
                    .. attribute:: bundle_bundle_children_member
                    
                    	Bundle member item with common bundle information
                    	**type**\: list of    :py:class:`BundleBundleChildrenMember <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.Bundle.BundleBundles.BundleBundle.BundleBundleChildrenMembers.BundleBundleChildrenMember>`
                    
                    

                    """

                    _prefix = 'bundlemgr-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(BundleInformation.Bundle.BundleBundles.BundleBundle.BundleBundleChildrenMembers, self).__init__()

                        self.yang_name = "bundle-bundle-children-members"
                        self.yang_parent_name = "bundle-bundle"

                        self.bundle_bundle_children_member = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(BundleInformation.Bundle.BundleBundles.BundleBundle.BundleBundleChildrenMembers, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(BundleInformation.Bundle.BundleBundles.BundleBundle.BundleBundleChildrenMembers, self).__setattr__(name, value)


                    class BundleBundleChildrenMember(Entity):
                        """
                        Bundle member item with common bundle
                        information
                        
                        .. attribute:: member_interface  <key>
                        
                        	Member interface
                        	**type**\:  str
                        
                        .. attribute:: bandwidth
                        
                        	Bandwidth of this member (kbps)
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: kbit/s
                        
                        .. attribute:: counters
                        
                        	Counters data about member link
                        	**type**\:   :py:class:`Counters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.Bundle.BundleBundles.BundleBundle.BundleBundleChildrenMembers.BundleBundleChildrenMember.Counters>`
                        
                        .. attribute:: iccp_node
                        
                        	Location of member
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: interface_name
                        
                        	Member's interface name
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: link_data
                        
                        	Lacp data about member link
                        	**type**\:   :py:class:`LinkData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.Bundle.BundleBundles.BundleBundle.BundleBundleChildrenMembers.BundleBundleChildrenMember.LinkData>`
                        
                        .. attribute:: link_order_number
                        
                        	Member's link order number
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: mac_address
                        
                        	MAC address of this member (deprecated)
                        	**type**\:   :py:class:`MacAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.Bundle.BundleBundles.BundleBundle.BundleBundleChildrenMembers.BundleBundleChildrenMember.MacAddress>`
                        
                        .. attribute:: member_mux_data
                        
                        	Mux state machine data
                        	**type**\:   :py:class:`MemberMuxData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.Bundle.BundleBundles.BundleBundle.BundleBundleChildrenMembers.BundleBundleChildrenMember.MemberMuxData>`
                        
                        .. attribute:: member_name
                        
                        	Member's (short form) name
                        	**type**\:  str
                        
                        .. attribute:: member_type
                        
                        	Member's type (local/foreign)
                        	**type**\:   :py:class:`BmdMemberTypeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmdMemberTypeEnum>`
                        
                        .. attribute:: port_number
                        
                        	Member's link number
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: port_priority
                        
                        	The priority of this member
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: underlying_link_id
                        
                        	Member's underlying link ID
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'bundlemgr-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(BundleInformation.Bundle.BundleBundles.BundleBundle.BundleBundleChildrenMembers.BundleBundleChildrenMember, self).__init__()

                            self.yang_name = "bundle-bundle-children-member"
                            self.yang_parent_name = "bundle-bundle-children-members"

                            self.member_interface = YLeaf(YType.str, "member-interface")

                            self.bandwidth = YLeaf(YType.uint32, "bandwidth")

                            self.iccp_node = YLeaf(YType.uint32, "iccp-node")

                            self.interface_name = YLeaf(YType.str, "interface-name")

                            self.link_order_number = YLeaf(YType.uint16, "link-order-number")

                            self.member_name = YLeaf(YType.str, "member-name")

                            self.member_type = YLeaf(YType.enumeration, "member-type")

                            self.port_number = YLeaf(YType.uint16, "port-number")

                            self.port_priority = YLeaf(YType.uint16, "port-priority")

                            self.underlying_link_id = YLeaf(YType.uint16, "underlying-link-id")

                            self.counters = BundleInformation.Bundle.BundleBundles.BundleBundle.BundleBundleChildrenMembers.BundleBundleChildrenMember.Counters()
                            self.counters.parent = self
                            self._children_name_map["counters"] = "counters"
                            self._children_yang_names.add("counters")

                            self.link_data = BundleInformation.Bundle.BundleBundles.BundleBundle.BundleBundleChildrenMembers.BundleBundleChildrenMember.LinkData()
                            self.link_data.parent = self
                            self._children_name_map["link_data"] = "link-data"
                            self._children_yang_names.add("link-data")

                            self.mac_address = BundleInformation.Bundle.BundleBundles.BundleBundle.BundleBundleChildrenMembers.BundleBundleChildrenMember.MacAddress()
                            self.mac_address.parent = self
                            self._children_name_map["mac_address"] = "mac-address"
                            self._children_yang_names.add("mac-address")

                            self.member_mux_data = BundleInformation.Bundle.BundleBundles.BundleBundle.BundleBundleChildrenMembers.BundleBundleChildrenMember.MemberMuxData()
                            self.member_mux_data.parent = self
                            self._children_name_map["member_mux_data"] = "member-mux-data"
                            self._children_yang_names.add("member-mux-data")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("member_interface",
                                            "bandwidth",
                                            "iccp_node",
                                            "interface_name",
                                            "link_order_number",
                                            "member_name",
                                            "member_type",
                                            "port_number",
                                            "port_priority",
                                            "underlying_link_id") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(BundleInformation.Bundle.BundleBundles.BundleBundle.BundleBundleChildrenMembers.BundleBundleChildrenMember, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(BundleInformation.Bundle.BundleBundles.BundleBundle.BundleBundleChildrenMembers.BundleBundleChildrenMember, self).__setattr__(name, value)


                        class Counters(Entity):
                            """
                            Counters data about member link
                            
                            .. attribute:: defaulted
                            
                            	State flag set to Defaulted
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: excess_lacpd_us_received
                            
                            	LACPDUs received that exceed the rate limit
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: excess_marker_packets_received
                            
                            	Marker packets received that exceed the rate limit
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: expired
                            
                            	State flag set to Expired
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: illegal_packets_received
                            
                            	Illegal and unknown packets received
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: lacpd_us_received
                            
                            	LACPDUs received
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: lacpd_us_transmitted
                            
                            	LACPDUs transmitted
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: last_cleared_nsec
                            
                            	Last time counters cleared (nsec) (deprecated)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: last_cleared_sec
                            
                            	Last time counters cleared (s) (deprecated)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: marker_packets_received
                            
                            	Marker packets received
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: marker_responses_transmitted
                            
                            	Marker response packets transmitted
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'bundlemgr-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(BundleInformation.Bundle.BundleBundles.BundleBundle.BundleBundleChildrenMembers.BundleBundleChildrenMember.Counters, self).__init__()

                                self.yang_name = "counters"
                                self.yang_parent_name = "bundle-bundle-children-member"

                                self.defaulted = YLeaf(YType.uint32, "defaulted")

                                self.excess_lacpd_us_received = YLeaf(YType.uint32, "excess-lacpd-us-received")

                                self.excess_marker_packets_received = YLeaf(YType.uint32, "excess-marker-packets-received")

                                self.expired = YLeaf(YType.uint32, "expired")

                                self.illegal_packets_received = YLeaf(YType.uint32, "illegal-packets-received")

                                self.lacpd_us_received = YLeaf(YType.uint32, "lacpd-us-received")

                                self.lacpd_us_transmitted = YLeaf(YType.uint32, "lacpd-us-transmitted")

                                self.last_cleared_nsec = YLeaf(YType.uint32, "last-cleared-nsec")

                                self.last_cleared_sec = YLeaf(YType.uint32, "last-cleared-sec")

                                self.marker_packets_received = YLeaf(YType.uint32, "marker-packets-received")

                                self.marker_responses_transmitted = YLeaf(YType.uint32, "marker-responses-transmitted")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("defaulted",
                                                "excess_lacpd_us_received",
                                                "excess_marker_packets_received",
                                                "expired",
                                                "illegal_packets_received",
                                                "lacpd_us_received",
                                                "lacpd_us_transmitted",
                                                "last_cleared_nsec",
                                                "last_cleared_sec",
                                                "marker_packets_received",
                                                "marker_responses_transmitted") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(BundleInformation.Bundle.BundleBundles.BundleBundle.BundleBundleChildrenMembers.BundleBundleChildrenMember.Counters, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(BundleInformation.Bundle.BundleBundles.BundleBundle.BundleBundleChildrenMembers.BundleBundleChildrenMember.Counters, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.defaulted.is_set or
                                    self.excess_lacpd_us_received.is_set or
                                    self.excess_marker_packets_received.is_set or
                                    self.expired.is_set or
                                    self.illegal_packets_received.is_set or
                                    self.lacpd_us_received.is_set or
                                    self.lacpd_us_transmitted.is_set or
                                    self.last_cleared_nsec.is_set or
                                    self.last_cleared_sec.is_set or
                                    self.marker_packets_received.is_set or
                                    self.marker_responses_transmitted.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.defaulted.yfilter != YFilter.not_set or
                                    self.excess_lacpd_us_received.yfilter != YFilter.not_set or
                                    self.excess_marker_packets_received.yfilter != YFilter.not_set or
                                    self.expired.yfilter != YFilter.not_set or
                                    self.illegal_packets_received.yfilter != YFilter.not_set or
                                    self.lacpd_us_received.yfilter != YFilter.not_set or
                                    self.lacpd_us_transmitted.yfilter != YFilter.not_set or
                                    self.last_cleared_nsec.yfilter != YFilter.not_set or
                                    self.last_cleared_sec.yfilter != YFilter.not_set or
                                    self.marker_packets_received.yfilter != YFilter.not_set or
                                    self.marker_responses_transmitted.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "counters" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.defaulted.is_set or self.defaulted.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.defaulted.get_name_leafdata())
                                if (self.excess_lacpd_us_received.is_set or self.excess_lacpd_us_received.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.excess_lacpd_us_received.get_name_leafdata())
                                if (self.excess_marker_packets_received.is_set or self.excess_marker_packets_received.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.excess_marker_packets_received.get_name_leafdata())
                                if (self.expired.is_set or self.expired.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.expired.get_name_leafdata())
                                if (self.illegal_packets_received.is_set or self.illegal_packets_received.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.illegal_packets_received.get_name_leafdata())
                                if (self.lacpd_us_received.is_set or self.lacpd_us_received.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.lacpd_us_received.get_name_leafdata())
                                if (self.lacpd_us_transmitted.is_set or self.lacpd_us_transmitted.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.lacpd_us_transmitted.get_name_leafdata())
                                if (self.last_cleared_nsec.is_set or self.last_cleared_nsec.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.last_cleared_nsec.get_name_leafdata())
                                if (self.last_cleared_sec.is_set or self.last_cleared_sec.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.last_cleared_sec.get_name_leafdata())
                                if (self.marker_packets_received.is_set or self.marker_packets_received.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.marker_packets_received.get_name_leafdata())
                                if (self.marker_responses_transmitted.is_set or self.marker_responses_transmitted.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.marker_responses_transmitted.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "defaulted" or name == "excess-lacpd-us-received" or name == "excess-marker-packets-received" or name == "expired" or name == "illegal-packets-received" or name == "lacpd-us-received" or name == "lacpd-us-transmitted" or name == "last-cleared-nsec" or name == "last-cleared-sec" or name == "marker-packets-received" or name == "marker-responses-transmitted"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "defaulted"):
                                    self.defaulted = value
                                    self.defaulted.value_namespace = name_space
                                    self.defaulted.value_namespace_prefix = name_space_prefix
                                if(value_path == "excess-lacpd-us-received"):
                                    self.excess_lacpd_us_received = value
                                    self.excess_lacpd_us_received.value_namespace = name_space
                                    self.excess_lacpd_us_received.value_namespace_prefix = name_space_prefix
                                if(value_path == "excess-marker-packets-received"):
                                    self.excess_marker_packets_received = value
                                    self.excess_marker_packets_received.value_namespace = name_space
                                    self.excess_marker_packets_received.value_namespace_prefix = name_space_prefix
                                if(value_path == "expired"):
                                    self.expired = value
                                    self.expired.value_namespace = name_space
                                    self.expired.value_namespace_prefix = name_space_prefix
                                if(value_path == "illegal-packets-received"):
                                    self.illegal_packets_received = value
                                    self.illegal_packets_received.value_namespace = name_space
                                    self.illegal_packets_received.value_namespace_prefix = name_space_prefix
                                if(value_path == "lacpd-us-received"):
                                    self.lacpd_us_received = value
                                    self.lacpd_us_received.value_namespace = name_space
                                    self.lacpd_us_received.value_namespace_prefix = name_space_prefix
                                if(value_path == "lacpd-us-transmitted"):
                                    self.lacpd_us_transmitted = value
                                    self.lacpd_us_transmitted.value_namespace = name_space
                                    self.lacpd_us_transmitted.value_namespace_prefix = name_space_prefix
                                if(value_path == "last-cleared-nsec"):
                                    self.last_cleared_nsec = value
                                    self.last_cleared_nsec.value_namespace = name_space
                                    self.last_cleared_nsec.value_namespace_prefix = name_space_prefix
                                if(value_path == "last-cleared-sec"):
                                    self.last_cleared_sec = value
                                    self.last_cleared_sec.value_namespace = name_space
                                    self.last_cleared_sec.value_namespace_prefix = name_space_prefix
                                if(value_path == "marker-packets-received"):
                                    self.marker_packets_received = value
                                    self.marker_packets_received.value_namespace = name_space
                                    self.marker_packets_received.value_namespace_prefix = name_space_prefix
                                if(value_path == "marker-responses-transmitted"):
                                    self.marker_responses_transmitted = value
                                    self.marker_responses_transmitted.value_namespace = name_space
                                    self.marker_responses_transmitted.value_namespace_prefix = name_space_prefix


                        class LinkData(Entity):
                            """
                            Lacp data about member link
                            
                            .. attribute:: actor_operational_key
                            
                            	Operational key for this port
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: actor_port_id
                            
                            	Port number of this port
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: actor_port_priority
                            
                            	Priority of this port
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: actor_port_state
                            
                            	LACP state of this port
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: actor_system_mac_address
                            
                            	MAC Address of the actor system
                            	**type**\:  str
                            
                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                            
                            .. attribute:: actor_system_priority
                            
                            	System priority of actor system
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: attached_aggregator_id
                            
                            	MIB ifindex of attached bundle
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: interface_handle
                            
                            	Member's interface handle
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: partner_operational_key
                            
                            	Operational key for partner port
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: partner_port_id
                            
                            	Port number of the partner's port
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: partner_port_priority
                            
                            	Priority of the partner's port
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: partner_port_state
                            
                            	LACP state of the partner's port
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: partner_system_mac_address
                            
                            	MAC Address used to identify the partner system
                            	**type**\:  str
                            
                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                            
                            .. attribute:: partner_system_priority
                            
                            	System priority of partner system
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: selected_aggregator_id
                            
                            	MIB ifindex of selected bundle
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'bundlemgr-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(BundleInformation.Bundle.BundleBundles.BundleBundle.BundleBundleChildrenMembers.BundleBundleChildrenMember.LinkData, self).__init__()

                                self.yang_name = "link-data"
                                self.yang_parent_name = "bundle-bundle-children-member"

                                self.actor_operational_key = YLeaf(YType.uint16, "actor-operational-key")

                                self.actor_port_id = YLeaf(YType.uint16, "actor-port-id")

                                self.actor_port_priority = YLeaf(YType.uint16, "actor-port-priority")

                                self.actor_port_state = YLeaf(YType.uint8, "actor-port-state")

                                self.actor_system_mac_address = YLeaf(YType.str, "actor-system-mac-address")

                                self.actor_system_priority = YLeaf(YType.uint16, "actor-system-priority")

                                self.attached_aggregator_id = YLeaf(YType.uint32, "attached-aggregator-id")

                                self.interface_handle = YLeaf(YType.str, "interface-handle")

                                self.partner_operational_key = YLeaf(YType.uint16, "partner-operational-key")

                                self.partner_port_id = YLeaf(YType.uint16, "partner-port-id")

                                self.partner_port_priority = YLeaf(YType.uint16, "partner-port-priority")

                                self.partner_port_state = YLeaf(YType.uint8, "partner-port-state")

                                self.partner_system_mac_address = YLeaf(YType.str, "partner-system-mac-address")

                                self.partner_system_priority = YLeaf(YType.uint16, "partner-system-priority")

                                self.selected_aggregator_id = YLeaf(YType.uint32, "selected-aggregator-id")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("actor_operational_key",
                                                "actor_port_id",
                                                "actor_port_priority",
                                                "actor_port_state",
                                                "actor_system_mac_address",
                                                "actor_system_priority",
                                                "attached_aggregator_id",
                                                "interface_handle",
                                                "partner_operational_key",
                                                "partner_port_id",
                                                "partner_port_priority",
                                                "partner_port_state",
                                                "partner_system_mac_address",
                                                "partner_system_priority",
                                                "selected_aggregator_id") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(BundleInformation.Bundle.BundleBundles.BundleBundle.BundleBundleChildrenMembers.BundleBundleChildrenMember.LinkData, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(BundleInformation.Bundle.BundleBundles.BundleBundle.BundleBundleChildrenMembers.BundleBundleChildrenMember.LinkData, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.actor_operational_key.is_set or
                                    self.actor_port_id.is_set or
                                    self.actor_port_priority.is_set or
                                    self.actor_port_state.is_set or
                                    self.actor_system_mac_address.is_set or
                                    self.actor_system_priority.is_set or
                                    self.attached_aggregator_id.is_set or
                                    self.interface_handle.is_set or
                                    self.partner_operational_key.is_set or
                                    self.partner_port_id.is_set or
                                    self.partner_port_priority.is_set or
                                    self.partner_port_state.is_set or
                                    self.partner_system_mac_address.is_set or
                                    self.partner_system_priority.is_set or
                                    self.selected_aggregator_id.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.actor_operational_key.yfilter != YFilter.not_set or
                                    self.actor_port_id.yfilter != YFilter.not_set or
                                    self.actor_port_priority.yfilter != YFilter.not_set or
                                    self.actor_port_state.yfilter != YFilter.not_set or
                                    self.actor_system_mac_address.yfilter != YFilter.not_set or
                                    self.actor_system_priority.yfilter != YFilter.not_set or
                                    self.attached_aggregator_id.yfilter != YFilter.not_set or
                                    self.interface_handle.yfilter != YFilter.not_set or
                                    self.partner_operational_key.yfilter != YFilter.not_set or
                                    self.partner_port_id.yfilter != YFilter.not_set or
                                    self.partner_port_priority.yfilter != YFilter.not_set or
                                    self.partner_port_state.yfilter != YFilter.not_set or
                                    self.partner_system_mac_address.yfilter != YFilter.not_set or
                                    self.partner_system_priority.yfilter != YFilter.not_set or
                                    self.selected_aggregator_id.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "link-data" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.actor_operational_key.is_set or self.actor_operational_key.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.actor_operational_key.get_name_leafdata())
                                if (self.actor_port_id.is_set or self.actor_port_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.actor_port_id.get_name_leafdata())
                                if (self.actor_port_priority.is_set or self.actor_port_priority.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.actor_port_priority.get_name_leafdata())
                                if (self.actor_port_state.is_set or self.actor_port_state.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.actor_port_state.get_name_leafdata())
                                if (self.actor_system_mac_address.is_set or self.actor_system_mac_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.actor_system_mac_address.get_name_leafdata())
                                if (self.actor_system_priority.is_set or self.actor_system_priority.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.actor_system_priority.get_name_leafdata())
                                if (self.attached_aggregator_id.is_set or self.attached_aggregator_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.attached_aggregator_id.get_name_leafdata())
                                if (self.interface_handle.is_set or self.interface_handle.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.interface_handle.get_name_leafdata())
                                if (self.partner_operational_key.is_set or self.partner_operational_key.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.partner_operational_key.get_name_leafdata())
                                if (self.partner_port_id.is_set or self.partner_port_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.partner_port_id.get_name_leafdata())
                                if (self.partner_port_priority.is_set or self.partner_port_priority.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.partner_port_priority.get_name_leafdata())
                                if (self.partner_port_state.is_set or self.partner_port_state.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.partner_port_state.get_name_leafdata())
                                if (self.partner_system_mac_address.is_set or self.partner_system_mac_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.partner_system_mac_address.get_name_leafdata())
                                if (self.partner_system_priority.is_set or self.partner_system_priority.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.partner_system_priority.get_name_leafdata())
                                if (self.selected_aggregator_id.is_set or self.selected_aggregator_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.selected_aggregator_id.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "actor-operational-key" or name == "actor-port-id" or name == "actor-port-priority" or name == "actor-port-state" or name == "actor-system-mac-address" or name == "actor-system-priority" or name == "attached-aggregator-id" or name == "interface-handle" or name == "partner-operational-key" or name == "partner-port-id" or name == "partner-port-priority" or name == "partner-port-state" or name == "partner-system-mac-address" or name == "partner-system-priority" or name == "selected-aggregator-id"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "actor-operational-key"):
                                    self.actor_operational_key = value
                                    self.actor_operational_key.value_namespace = name_space
                                    self.actor_operational_key.value_namespace_prefix = name_space_prefix
                                if(value_path == "actor-port-id"):
                                    self.actor_port_id = value
                                    self.actor_port_id.value_namespace = name_space
                                    self.actor_port_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "actor-port-priority"):
                                    self.actor_port_priority = value
                                    self.actor_port_priority.value_namespace = name_space
                                    self.actor_port_priority.value_namespace_prefix = name_space_prefix
                                if(value_path == "actor-port-state"):
                                    self.actor_port_state = value
                                    self.actor_port_state.value_namespace = name_space
                                    self.actor_port_state.value_namespace_prefix = name_space_prefix
                                if(value_path == "actor-system-mac-address"):
                                    self.actor_system_mac_address = value
                                    self.actor_system_mac_address.value_namespace = name_space
                                    self.actor_system_mac_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "actor-system-priority"):
                                    self.actor_system_priority = value
                                    self.actor_system_priority.value_namespace = name_space
                                    self.actor_system_priority.value_namespace_prefix = name_space_prefix
                                if(value_path == "attached-aggregator-id"):
                                    self.attached_aggregator_id = value
                                    self.attached_aggregator_id.value_namespace = name_space
                                    self.attached_aggregator_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "interface-handle"):
                                    self.interface_handle = value
                                    self.interface_handle.value_namespace = name_space
                                    self.interface_handle.value_namespace_prefix = name_space_prefix
                                if(value_path == "partner-operational-key"):
                                    self.partner_operational_key = value
                                    self.partner_operational_key.value_namespace = name_space
                                    self.partner_operational_key.value_namespace_prefix = name_space_prefix
                                if(value_path == "partner-port-id"):
                                    self.partner_port_id = value
                                    self.partner_port_id.value_namespace = name_space
                                    self.partner_port_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "partner-port-priority"):
                                    self.partner_port_priority = value
                                    self.partner_port_priority.value_namespace = name_space
                                    self.partner_port_priority.value_namespace_prefix = name_space_prefix
                                if(value_path == "partner-port-state"):
                                    self.partner_port_state = value
                                    self.partner_port_state.value_namespace = name_space
                                    self.partner_port_state.value_namespace_prefix = name_space_prefix
                                if(value_path == "partner-system-mac-address"):
                                    self.partner_system_mac_address = value
                                    self.partner_system_mac_address.value_namespace = name_space
                                    self.partner_system_mac_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "partner-system-priority"):
                                    self.partner_system_priority = value
                                    self.partner_system_priority.value_namespace = name_space
                                    self.partner_system_priority.value_namespace_prefix = name_space_prefix
                                if(value_path == "selected-aggregator-id"):
                                    self.selected_aggregator_id = value
                                    self.selected_aggregator_id.value_namespace = name_space
                                    self.selected_aggregator_id.value_namespace_prefix = name_space_prefix


                        class MemberMuxData(Entity):
                            """
                            Mux state machine data
                            
                            .. attribute:: error
                            
                            	Internal value indicating if an error occurred trying to put a link into the desired state
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: member_mux_state_reason
                            
                            	Reason for last Mux state change
                            	**type**\:   :py:class:`BmMbrStateReason <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmMbrStateReason>`
                            
                            .. attribute:: member_mux_state_reason_data
                            
                            	Data regarding the reason for last Mux state change
                            	**type**\:   :py:class:`MemberMuxStateReasonData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.Bundle.BundleBundles.BundleBundle.BundleBundleChildrenMembers.BundleBundleChildrenMember.MemberMuxData.MemberMuxStateReasonData>`
                            
                            .. attribute:: member_state
                            
                            	Current internal state of this bundle member
                            	**type**\:   :py:class:`BmdMemberState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmdMemberState>`
                            
                            .. attribute:: mux_state
                            
                            	Current state of this bundle member
                            	**type**\:   :py:class:`BmMuxstate <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmMuxstate>`
                            
                            .. attribute:: mux_state_reason
                            
                            	Reason for last Mux state change (Deprecated)
                            	**type**\:   :py:class:`BmMuxreason <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmMuxreason>`
                            
                            

                            """

                            _prefix = 'bundlemgr-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(BundleInformation.Bundle.BundleBundles.BundleBundle.BundleBundleChildrenMembers.BundleBundleChildrenMember.MemberMuxData, self).__init__()

                                self.yang_name = "member-mux-data"
                                self.yang_parent_name = "bundle-bundle-children-member"

                                self.error = YLeaf(YType.uint32, "error")

                                self.member_mux_state_reason = YLeaf(YType.enumeration, "member-mux-state-reason")

                                self.member_state = YLeaf(YType.enumeration, "member-state")

                                self.mux_state = YLeaf(YType.enumeration, "mux-state")

                                self.mux_state_reason = YLeaf(YType.enumeration, "mux-state-reason")

                                self.member_mux_state_reason_data = BundleInformation.Bundle.BundleBundles.BundleBundle.BundleBundleChildrenMembers.BundleBundleChildrenMember.MemberMuxData.MemberMuxStateReasonData()
                                self.member_mux_state_reason_data.parent = self
                                self._children_name_map["member_mux_state_reason_data"] = "member-mux-state-reason-data"
                                self._children_yang_names.add("member-mux-state-reason-data")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("error",
                                                "member_mux_state_reason",
                                                "member_state",
                                                "mux_state",
                                                "mux_state_reason") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(BundleInformation.Bundle.BundleBundles.BundleBundle.BundleBundleChildrenMembers.BundleBundleChildrenMember.MemberMuxData, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(BundleInformation.Bundle.BundleBundles.BundleBundle.BundleBundleChildrenMembers.BundleBundleChildrenMember.MemberMuxData, self).__setattr__(name, value)


                            class MemberMuxStateReasonData(Entity):
                                """
                                Data regarding the reason for last Mux state
                                change
                                
                                .. attribute:: reason_type
                                
                                	The item the reason applies to
                                	**type**\:   :py:class:`BmStateReasonTarget <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmStateReasonTarget>`
                                
                                .. attribute:: severity
                                
                                	The severity of the reason
                                	**type**\:   :py:class:`BmSeverity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmSeverity>`
                                
                                

                                """

                                _prefix = 'bundlemgr-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(BundleInformation.Bundle.BundleBundles.BundleBundle.BundleBundleChildrenMembers.BundleBundleChildrenMember.MemberMuxData.MemberMuxStateReasonData, self).__init__()

                                    self.yang_name = "member-mux-state-reason-data"
                                    self.yang_parent_name = "member-mux-data"

                                    self.reason_type = YLeaf(YType.enumeration, "reason-type")

                                    self.severity = YLeaf(YType.enumeration, "severity")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("reason_type",
                                                    "severity") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(BundleInformation.Bundle.BundleBundles.BundleBundle.BundleBundleChildrenMembers.BundleBundleChildrenMember.MemberMuxData.MemberMuxStateReasonData, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(BundleInformation.Bundle.BundleBundles.BundleBundle.BundleBundleChildrenMembers.BundleBundleChildrenMember.MemberMuxData.MemberMuxStateReasonData, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.reason_type.is_set or
                                        self.severity.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.reason_type.yfilter != YFilter.not_set or
                                        self.severity.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "member-mux-state-reason-data" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.reason_type.is_set or self.reason_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.reason_type.get_name_leafdata())
                                    if (self.severity.is_set or self.severity.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.severity.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "reason-type" or name == "severity"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "reason-type"):
                                        self.reason_type = value
                                        self.reason_type.value_namespace = name_space
                                        self.reason_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "severity"):
                                        self.severity = value
                                        self.severity.value_namespace = name_space
                                        self.severity.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.error.is_set or
                                    self.member_mux_state_reason.is_set or
                                    self.member_state.is_set or
                                    self.mux_state.is_set or
                                    self.mux_state_reason.is_set or
                                    (self.member_mux_state_reason_data is not None and self.member_mux_state_reason_data.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.error.yfilter != YFilter.not_set or
                                    self.member_mux_state_reason.yfilter != YFilter.not_set or
                                    self.member_state.yfilter != YFilter.not_set or
                                    self.mux_state.yfilter != YFilter.not_set or
                                    self.mux_state_reason.yfilter != YFilter.not_set or
                                    (self.member_mux_state_reason_data is not None and self.member_mux_state_reason_data.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "member-mux-data" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.error.is_set or self.error.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.error.get_name_leafdata())
                                if (self.member_mux_state_reason.is_set or self.member_mux_state_reason.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.member_mux_state_reason.get_name_leafdata())
                                if (self.member_state.is_set or self.member_state.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.member_state.get_name_leafdata())
                                if (self.mux_state.is_set or self.mux_state.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mux_state.get_name_leafdata())
                                if (self.mux_state_reason.is_set or self.mux_state_reason.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mux_state_reason.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "member-mux-state-reason-data"):
                                    if (self.member_mux_state_reason_data is None):
                                        self.member_mux_state_reason_data = BundleInformation.Bundle.BundleBundles.BundleBundle.BundleBundleChildrenMembers.BundleBundleChildrenMember.MemberMuxData.MemberMuxStateReasonData()
                                        self.member_mux_state_reason_data.parent = self
                                        self._children_name_map["member_mux_state_reason_data"] = "member-mux-state-reason-data"
                                    return self.member_mux_state_reason_data

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "member-mux-state-reason-data" or name == "error" or name == "member-mux-state-reason" or name == "member-state" or name == "mux-state" or name == "mux-state-reason"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "error"):
                                    self.error = value
                                    self.error.value_namespace = name_space
                                    self.error.value_namespace_prefix = name_space_prefix
                                if(value_path == "member-mux-state-reason"):
                                    self.member_mux_state_reason = value
                                    self.member_mux_state_reason.value_namespace = name_space
                                    self.member_mux_state_reason.value_namespace_prefix = name_space_prefix
                                if(value_path == "member-state"):
                                    self.member_state = value
                                    self.member_state.value_namespace = name_space
                                    self.member_state.value_namespace_prefix = name_space_prefix
                                if(value_path == "mux-state"):
                                    self.mux_state = value
                                    self.mux_state.value_namespace = name_space
                                    self.mux_state.value_namespace_prefix = name_space_prefix
                                if(value_path == "mux-state-reason"):
                                    self.mux_state_reason = value
                                    self.mux_state_reason.value_namespace = name_space
                                    self.mux_state_reason.value_namespace_prefix = name_space_prefix


                        class MacAddress(Entity):
                            """
                            MAC address of this member (deprecated)
                            
                            .. attribute:: address
                            
                            	MAC address
                            	**type**\:  str
                            
                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                            
                            

                            """

                            _prefix = 'bundlemgr-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(BundleInformation.Bundle.BundleBundles.BundleBundle.BundleBundleChildrenMembers.BundleBundleChildrenMember.MacAddress, self).__init__()

                                self.yang_name = "mac-address"
                                self.yang_parent_name = "bundle-bundle-children-member"

                                self.address = YLeaf(YType.str, "address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(BundleInformation.Bundle.BundleBundles.BundleBundle.BundleBundleChildrenMembers.BundleBundleChildrenMember.MacAddress, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(BundleInformation.Bundle.BundleBundles.BundleBundle.BundleBundleChildrenMembers.BundleBundleChildrenMember.MacAddress, self).__setattr__(name, value)

                            def has_data(self):
                                return self.address.is_set

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "mac-address" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.address.is_set or self.address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "address"):
                                    self.address = value
                                    self.address.value_namespace = name_space
                                    self.address.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.member_interface.is_set or
                                self.bandwidth.is_set or
                                self.iccp_node.is_set or
                                self.interface_name.is_set or
                                self.link_order_number.is_set or
                                self.member_name.is_set or
                                self.member_type.is_set or
                                self.port_number.is_set or
                                self.port_priority.is_set or
                                self.underlying_link_id.is_set or
                                (self.counters is not None and self.counters.has_data()) or
                                (self.link_data is not None and self.link_data.has_data()) or
                                (self.mac_address is not None and self.mac_address.has_data()) or
                                (self.member_mux_data is not None and self.member_mux_data.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.member_interface.yfilter != YFilter.not_set or
                                self.bandwidth.yfilter != YFilter.not_set or
                                self.iccp_node.yfilter != YFilter.not_set or
                                self.interface_name.yfilter != YFilter.not_set or
                                self.link_order_number.yfilter != YFilter.not_set or
                                self.member_name.yfilter != YFilter.not_set or
                                self.member_type.yfilter != YFilter.not_set or
                                self.port_number.yfilter != YFilter.not_set or
                                self.port_priority.yfilter != YFilter.not_set or
                                self.underlying_link_id.yfilter != YFilter.not_set or
                                (self.counters is not None and self.counters.has_operation()) or
                                (self.link_data is not None and self.link_data.has_operation()) or
                                (self.mac_address is not None and self.mac_address.has_operation()) or
                                (self.member_mux_data is not None and self.member_mux_data.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "bundle-bundle-children-member" + "[member-interface='" + self.member_interface.get() + "']" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.member_interface.is_set or self.member_interface.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.member_interface.get_name_leafdata())
                            if (self.bandwidth.is_set or self.bandwidth.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.bandwidth.get_name_leafdata())
                            if (self.iccp_node.is_set or self.iccp_node.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.iccp_node.get_name_leafdata())
                            if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface_name.get_name_leafdata())
                            if (self.link_order_number.is_set or self.link_order_number.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.link_order_number.get_name_leafdata())
                            if (self.member_name.is_set or self.member_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.member_name.get_name_leafdata())
                            if (self.member_type.is_set or self.member_type.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.member_type.get_name_leafdata())
                            if (self.port_number.is_set or self.port_number.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.port_number.get_name_leafdata())
                            if (self.port_priority.is_set or self.port_priority.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.port_priority.get_name_leafdata())
                            if (self.underlying_link_id.is_set or self.underlying_link_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.underlying_link_id.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "counters"):
                                if (self.counters is None):
                                    self.counters = BundleInformation.Bundle.BundleBundles.BundleBundle.BundleBundleChildrenMembers.BundleBundleChildrenMember.Counters()
                                    self.counters.parent = self
                                    self._children_name_map["counters"] = "counters"
                                return self.counters

                            if (child_yang_name == "link-data"):
                                if (self.link_data is None):
                                    self.link_data = BundleInformation.Bundle.BundleBundles.BundleBundle.BundleBundleChildrenMembers.BundleBundleChildrenMember.LinkData()
                                    self.link_data.parent = self
                                    self._children_name_map["link_data"] = "link-data"
                                return self.link_data

                            if (child_yang_name == "mac-address"):
                                if (self.mac_address is None):
                                    self.mac_address = BundleInformation.Bundle.BundleBundles.BundleBundle.BundleBundleChildrenMembers.BundleBundleChildrenMember.MacAddress()
                                    self.mac_address.parent = self
                                    self._children_name_map["mac_address"] = "mac-address"
                                return self.mac_address

                            if (child_yang_name == "member-mux-data"):
                                if (self.member_mux_data is None):
                                    self.member_mux_data = BundleInformation.Bundle.BundleBundles.BundleBundle.BundleBundleChildrenMembers.BundleBundleChildrenMember.MemberMuxData()
                                    self.member_mux_data.parent = self
                                    self._children_name_map["member_mux_data"] = "member-mux-data"
                                return self.member_mux_data

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "counters" or name == "link-data" or name == "mac-address" or name == "member-mux-data" or name == "member-interface" or name == "bandwidth" or name == "iccp-node" or name == "interface-name" or name == "link-order-number" or name == "member-name" or name == "member-type" or name == "port-number" or name == "port-priority" or name == "underlying-link-id"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "member-interface"):
                                self.member_interface = value
                                self.member_interface.value_namespace = name_space
                                self.member_interface.value_namespace_prefix = name_space_prefix
                            if(value_path == "bandwidth"):
                                self.bandwidth = value
                                self.bandwidth.value_namespace = name_space
                                self.bandwidth.value_namespace_prefix = name_space_prefix
                            if(value_path == "iccp-node"):
                                self.iccp_node = value
                                self.iccp_node.value_namespace = name_space
                                self.iccp_node.value_namespace_prefix = name_space_prefix
                            if(value_path == "interface-name"):
                                self.interface_name = value
                                self.interface_name.value_namespace = name_space
                                self.interface_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "link-order-number"):
                                self.link_order_number = value
                                self.link_order_number.value_namespace = name_space
                                self.link_order_number.value_namespace_prefix = name_space_prefix
                            if(value_path == "member-name"):
                                self.member_name = value
                                self.member_name.value_namespace = name_space
                                self.member_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "member-type"):
                                self.member_type = value
                                self.member_type.value_namespace = name_space
                                self.member_type.value_namespace_prefix = name_space_prefix
                            if(value_path == "port-number"):
                                self.port_number = value
                                self.port_number.value_namespace = name_space
                                self.port_number.value_namespace_prefix = name_space_prefix
                            if(value_path == "port-priority"):
                                self.port_priority = value
                                self.port_priority.value_namespace = name_space
                                self.port_priority.value_namespace_prefix = name_space_prefix
                            if(value_path == "underlying-link-id"):
                                self.underlying_link_id = value
                                self.underlying_link_id.value_namespace = name_space
                                self.underlying_link_id.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.bundle_bundle_children_member:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.bundle_bundle_children_member:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "bundle-bundle-children-members" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "bundle-bundle-children-member"):
                            for c in self.bundle_bundle_children_member:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = BundleInformation.Bundle.BundleBundles.BundleBundle.BundleBundleChildrenMembers.BundleBundleChildrenMember()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.bundle_bundle_children_member.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "bundle-bundle-children-member"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class BundleBundleItem(Entity):
                    """
                    Data for this item
                    
                    .. attribute:: active_foreign_member_count
                    
                    	The number of active foreign members on the bundle
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: active_member_count
                    
                    	The number of active local members on the bundle
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: available_bandwidth
                    
                    	Bandwidth available to the bundle interface (kbps)
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: kbit/s
                    
                    .. attribute:: bfd_config
                    
                    	Configuration values for BFD on bundle members
                    	**type**\: list of    :py:class:`BfdConfig <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.Bundle.BundleBundles.BundleBundle.BundleBundleItem.BfdConfig>`
                    
                    .. attribute:: bundle_interface_name
                    
                    	Bundle interface name
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: bundle_status
                    
                    	The state of the bundle
                    	**type**\:   :py:class:`BmBdlState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmBdlState>`
                    
                    .. attribute:: cisco_extensions
                    
                    	The status of the Cisco Extensions feature (1 = enabled, 0 = not enabled)
                    	**type**\:  bool
                    
                    .. attribute:: collector_max_delay
                    
                    	Collector Max Delay
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: configured_bandwidth
                    
                    	Bandwidth configured on the bundle interface (kbps)
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: kbit/s
                    
                    .. attribute:: configured_foreign_member_count
                    
                    	The number of configured local members on the bundle
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: configured_member_count
                    
                    	The number of configured local members on the bundle
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: effective_bandwidth
                    
                    	Effective bandwidth on the bundle interface (kbps)
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: kbit/s
                    
                    .. attribute:: iccp_group_id
                    
                    	ICCP Group that the bundle is configured to
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: inter_chassis
                    
                    	Indicates if this bundle is operating as an inter\-chassis link (1 = I\-C link, 0 = normal)
                    	**type**\:  bool
                    
                    .. attribute:: ipv4bfd_status
                    
                    	The status of the BFD (IPv4) feature on the bundle
                    	**type**\:   :py:class:`BmFeatureStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmFeatureStatus>`
                    
                    .. attribute:: ipv6bfd_status
                    
                    	The status of the BFD (IPv6) feature on the bundle
                    	**type**\:   :py:class:`BmFeatureStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmFeatureStatus>`
                    
                    .. attribute:: is_active
                    
                    	Indicates the active/standby redundancy state of the device for the bundle
                    	**type**\:  bool
                    
                    .. attribute:: lacp_nonrevertive
                    
                    	The status of the LACP nonrevertive feature (1 = enable, 0 = not enabled)
                    	**type**\:  bool
                    
                    .. attribute:: lacp_status
                    
                    	The status of the LACP feature on the bundle
                    	**type**\:   :py:class:`BmFeatureStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmFeatureStatus>`
                    
                    .. attribute:: link_order_status
                    
                    	The status of the link order signaling feature on the bundle
                    	**type**\:   :py:class:`BmFeatureStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmFeatureStatus>`
                    
                    .. attribute:: load_balance_hash_type
                    
                    	The type of hash to use for load balancing
                    	**type**\:  str
                    
                    .. attribute:: load_balance_locality_threshold
                    
                    	The number of links required per rack for localized load balancing
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: mac_address
                    
                    	MAC address of this member
                    	**type**\:   :py:class:`MacAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.Bundle.BundleBundles.BundleBundle.BundleBundleItem.MacAddress>`
                    
                    .. attribute:: mac_source
                    
                    	The source of the MAC Address
                    	**type**\:   :py:class:`BmBdlMacSource <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmBdlMacSource>`
                    
                    .. attribute:: mac_source_member
                    
                    	The name of the member that supplied the MAC address
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: maximize_threshold_value_band_width
                    
                    	Attempt to maximize the bundle if bandwidth is below this value
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: maximize_threshold_value_links
                    
                    	Attempt to maximize the bundle if links are below this value
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: maximum_active_links
                    
                    	Maximum number of active links in the bundle
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: maximum_active_links_source
                    
                    	Source of maximum active links value
                    	**type**\:   :py:class:`BmWhichSystem <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmWhichSystem>`
                    
                    .. attribute:: minimum_active_links
                    
                    	Minimum number of active links for bundle to go up
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: minimum_bandwidth
                    
                    	Minimum bundle bandwidth for bundle to go up (kbps)
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: kbit/s
                    
                    .. attribute:: mlacp_mode
                    
                    	Indicates the mode of the device for the bundle
                    	**type**\:   :py:class:`BundleMlacpMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleMlacpMode>`
                    
                    .. attribute:: mlacp_status
                    
                    	The status of the mLACP feature on the bundle
                    	**type**\:   :py:class:`BmFeatureStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmFeatureStatus>`
                    
                    .. attribute:: primary_member
                    
                    	Primary bundle member (no longer applicable)
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: recovery_delay
                    
                    	Number of seconds to wait before becoming active after recovering from a failure
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    	**units**\: second
                    
                    .. attribute:: singleton
                    
                    	Is the ICCP group of the bundle in singleton mode (1 = singleton; 0 = not singleton)
                    	**type**\:  bool
                    
                    .. attribute:: standby_member_count
                    
                    	The number of standby local members on the bundle
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: suppression_timer
                    
                    	Timer for suppressing bundle state flaps
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: switchover_type
                    
                    	How a switchover of the bundle from this device will occur
                    	**type**\:   :py:class:`BmdMlacpSwitchover <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmdMlacpSwitchover>`
                    
                    .. attribute:: wait_while_timer
                    
                    	The wait while time used for member ports
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'bundlemgr-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(BundleInformation.Bundle.BundleBundles.BundleBundle.BundleBundleItem, self).__init__()

                        self.yang_name = "bundle-bundle-item"
                        self.yang_parent_name = "bundle-bundle"

                        self.active_foreign_member_count = YLeaf(YType.uint16, "active-foreign-member-count")

                        self.active_member_count = YLeaf(YType.uint16, "active-member-count")

                        self.available_bandwidth = YLeaf(YType.uint32, "available-bandwidth")

                        self.bundle_interface_name = YLeaf(YType.str, "bundle-interface-name")

                        self.bundle_status = YLeaf(YType.enumeration, "bundle-status")

                        self.cisco_extensions = YLeaf(YType.boolean, "cisco-extensions")

                        self.collector_max_delay = YLeaf(YType.uint16, "collector-max-delay")

                        self.configured_bandwidth = YLeaf(YType.uint32, "configured-bandwidth")

                        self.configured_foreign_member_count = YLeaf(YType.uint16, "configured-foreign-member-count")

                        self.configured_member_count = YLeaf(YType.uint16, "configured-member-count")

                        self.effective_bandwidth = YLeaf(YType.uint32, "effective-bandwidth")

                        self.iccp_group_id = YLeaf(YType.uint32, "iccp-group-id")

                        self.inter_chassis = YLeaf(YType.boolean, "inter-chassis")

                        self.ipv4bfd_status = YLeaf(YType.enumeration, "ipv4bfd-status")

                        self.ipv6bfd_status = YLeaf(YType.enumeration, "ipv6bfd-status")

                        self.is_active = YLeaf(YType.boolean, "is-active")

                        self.lacp_nonrevertive = YLeaf(YType.boolean, "lacp-nonrevertive")

                        self.lacp_status = YLeaf(YType.enumeration, "lacp-status")

                        self.link_order_status = YLeaf(YType.enumeration, "link-order-status")

                        self.load_balance_hash_type = YLeaf(YType.str, "load-balance-hash-type")

                        self.load_balance_locality_threshold = YLeaf(YType.uint16, "load-balance-locality-threshold")

                        self.mac_source = YLeaf(YType.enumeration, "mac-source")

                        self.mac_source_member = YLeaf(YType.str, "mac-source-member")

                        self.maximize_threshold_value_band_width = YLeaf(YType.uint32, "maximize-threshold-value-band-width")

                        self.maximize_threshold_value_links = YLeaf(YType.uint32, "maximize-threshold-value-links")

                        self.maximum_active_links = YLeaf(YType.uint8, "maximum-active-links")

                        self.maximum_active_links_source = YLeaf(YType.enumeration, "maximum-active-links-source")

                        self.minimum_active_links = YLeaf(YType.uint8, "minimum-active-links")

                        self.minimum_bandwidth = YLeaf(YType.uint32, "minimum-bandwidth")

                        self.mlacp_mode = YLeaf(YType.enumeration, "mlacp-mode")

                        self.mlacp_status = YLeaf(YType.enumeration, "mlacp-status")

                        self.primary_member = YLeaf(YType.str, "primary-member")

                        self.recovery_delay = YLeaf(YType.uint16, "recovery-delay")

                        self.singleton = YLeaf(YType.boolean, "singleton")

                        self.standby_member_count = YLeaf(YType.uint16, "standby-member-count")

                        self.suppression_timer = YLeaf(YType.uint16, "suppression-timer")

                        self.switchover_type = YLeaf(YType.enumeration, "switchover-type")

                        self.wait_while_timer = YLeaf(YType.uint16, "wait-while-timer")

                        self.mac_address = BundleInformation.Bundle.BundleBundles.BundleBundle.BundleBundleItem.MacAddress()
                        self.mac_address.parent = self
                        self._children_name_map["mac_address"] = "mac-address"
                        self._children_yang_names.add("mac-address")

                        self.bfd_config = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("active_foreign_member_count",
                                        "active_member_count",
                                        "available_bandwidth",
                                        "bundle_interface_name",
                                        "bundle_status",
                                        "cisco_extensions",
                                        "collector_max_delay",
                                        "configured_bandwidth",
                                        "configured_foreign_member_count",
                                        "configured_member_count",
                                        "effective_bandwidth",
                                        "iccp_group_id",
                                        "inter_chassis",
                                        "ipv4bfd_status",
                                        "ipv6bfd_status",
                                        "is_active",
                                        "lacp_nonrevertive",
                                        "lacp_status",
                                        "link_order_status",
                                        "load_balance_hash_type",
                                        "load_balance_locality_threshold",
                                        "mac_source",
                                        "mac_source_member",
                                        "maximize_threshold_value_band_width",
                                        "maximize_threshold_value_links",
                                        "maximum_active_links",
                                        "maximum_active_links_source",
                                        "minimum_active_links",
                                        "minimum_bandwidth",
                                        "mlacp_mode",
                                        "mlacp_status",
                                        "primary_member",
                                        "recovery_delay",
                                        "singleton",
                                        "standby_member_count",
                                        "suppression_timer",
                                        "switchover_type",
                                        "wait_while_timer") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(BundleInformation.Bundle.BundleBundles.BundleBundle.BundleBundleItem, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(BundleInformation.Bundle.BundleBundles.BundleBundle.BundleBundleItem, self).__setattr__(name, value)


                    class MacAddress(Entity):
                        """
                        MAC address of this member
                        
                        .. attribute:: address
                        
                        	MAC address
                        	**type**\:  str
                        
                        	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                        
                        

                        """

                        _prefix = 'bundlemgr-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(BundleInformation.Bundle.BundleBundles.BundleBundle.BundleBundleItem.MacAddress, self).__init__()

                            self.yang_name = "mac-address"
                            self.yang_parent_name = "bundle-bundle-item"

                            self.address = YLeaf(YType.str, "address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(BundleInformation.Bundle.BundleBundles.BundleBundle.BundleBundleItem.MacAddress, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(BundleInformation.Bundle.BundleBundles.BundleBundle.BundleBundleItem.MacAddress, self).__setattr__(name, value)

                        def has_data(self):
                            return self.address.is_set

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "mac-address" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.address.is_set or self.address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "address"):
                                self.address = value
                                self.address.value_namespace = name_space
                                self.address.value_namespace_prefix = name_space_prefix


                    class BfdConfig(Entity):
                        """
                        Configuration values for BFD on bundle members
                        
                        .. attribute:: bundle_status
                        
                        	Status of BFD on the bundle
                        	**type**\:   :py:class:`BmdBfdBdlState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmdBfdBdlState>`
                        
                        .. attribute:: destination_address
                        
                        	Configured destination address for BFD session
                        	**type**\:   :py:class:`DestinationAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.Bundle.BundleBundles.BundleBundle.BundleBundleItem.BfdConfig.DestinationAddress>`
                        
                        .. attribute:: fast_detect
                        
                        	Flag indicating if BFD is enabled (1 = enabled; 0 = not enabled)
                        	**type**\:  bool
                        
                        .. attribute:: mode_info
                        
                        	Standard used for per\-member BFD
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: nbr_unconfig_timer
                        
                        	Time to wait on session NBR\_UNCONFIG before declaring DOWN
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: pref_echo_min_interval
                        
                        	Preferred echo minimum interval for the BFD session (ms)
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: pref_min_interval
                        
                        	Preferred minimum interval for the BFD session (ms)
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: pref_multiplier
                        
                        	Preferred multiplier for the BFD session
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: start_timer
                        
                        	Time to wait on session start before declaring DOWN
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'bundlemgr-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(BundleInformation.Bundle.BundleBundles.BundleBundle.BundleBundleItem.BfdConfig, self).__init__()

                            self.yang_name = "bfd-config"
                            self.yang_parent_name = "bundle-bundle-item"

                            self.bundle_status = YLeaf(YType.enumeration, "bundle-status")

                            self.fast_detect = YLeaf(YType.boolean, "fast-detect")

                            self.mode_info = YLeaf(YType.uint32, "mode-info")

                            self.nbr_unconfig_timer = YLeaf(YType.uint32, "nbr-unconfig-timer")

                            self.pref_echo_min_interval = YLeaf(YType.uint32, "pref-echo-min-interval")

                            self.pref_min_interval = YLeaf(YType.uint32, "pref-min-interval")

                            self.pref_multiplier = YLeaf(YType.uint16, "pref-multiplier")

                            self.start_timer = YLeaf(YType.uint32, "start-timer")

                            self.destination_address = BundleInformation.Bundle.BundleBundles.BundleBundle.BundleBundleItem.BfdConfig.DestinationAddress()
                            self.destination_address.parent = self
                            self._children_name_map["destination_address"] = "destination-address"
                            self._children_yang_names.add("destination-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("bundle_status",
                                            "fast_detect",
                                            "mode_info",
                                            "nbr_unconfig_timer",
                                            "pref_echo_min_interval",
                                            "pref_min_interval",
                                            "pref_multiplier",
                                            "start_timer") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(BundleInformation.Bundle.BundleBundles.BundleBundle.BundleBundleItem.BfdConfig, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(BundleInformation.Bundle.BundleBundles.BundleBundle.BundleBundleItem.BfdConfig, self).__setattr__(name, value)


                        class DestinationAddress(Entity):
                            """
                            Configured destination address for BFD session
                            
                            .. attribute:: af
                            
                            	AF
                            	**type**\:   :py:class:`BmAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmAfId>`
                            
                            .. attribute:: ipv4
                            
                            	IPv4 address type
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6
                            
                            	IPv6 address type
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'bundlemgr-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(BundleInformation.Bundle.BundleBundles.BundleBundle.BundleBundleItem.BfdConfig.DestinationAddress, self).__init__()

                                self.yang_name = "destination-address"
                                self.yang_parent_name = "bfd-config"

                                self.af = YLeaf(YType.enumeration, "af")

                                self.ipv4 = YLeaf(YType.str, "ipv4")

                                self.ipv6 = YLeaf(YType.str, "ipv6")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af",
                                                "ipv4",
                                                "ipv6") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(BundleInformation.Bundle.BundleBundles.BundleBundle.BundleBundleItem.BfdConfig.DestinationAddress, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(BundleInformation.Bundle.BundleBundles.BundleBundle.BundleBundleItem.BfdConfig.DestinationAddress, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af.is_set or
                                    self.ipv4.is_set or
                                    self.ipv6.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af.yfilter != YFilter.not_set or
                                    self.ipv4.yfilter != YFilter.not_set or
                                    self.ipv6.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "destination-address" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af.is_set or self.af.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af.get_name_leafdata())
                                if (self.ipv4.is_set or self.ipv4.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4.get_name_leafdata())
                                if (self.ipv6.is_set or self.ipv6.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af" or name == "ipv4" or name == "ipv6"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af"):
                                    self.af = value
                                    self.af.value_namespace = name_space
                                    self.af.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4"):
                                    self.ipv4 = value
                                    self.ipv4.value_namespace = name_space
                                    self.ipv4.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6"):
                                    self.ipv6 = value
                                    self.ipv6.value_namespace = name_space
                                    self.ipv6.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.bundle_status.is_set or
                                self.fast_detect.is_set or
                                self.mode_info.is_set or
                                self.nbr_unconfig_timer.is_set or
                                self.pref_echo_min_interval.is_set or
                                self.pref_min_interval.is_set or
                                self.pref_multiplier.is_set or
                                self.start_timer.is_set or
                                (self.destination_address is not None and self.destination_address.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.bundle_status.yfilter != YFilter.not_set or
                                self.fast_detect.yfilter != YFilter.not_set or
                                self.mode_info.yfilter != YFilter.not_set or
                                self.nbr_unconfig_timer.yfilter != YFilter.not_set or
                                self.pref_echo_min_interval.yfilter != YFilter.not_set or
                                self.pref_min_interval.yfilter != YFilter.not_set or
                                self.pref_multiplier.yfilter != YFilter.not_set or
                                self.start_timer.yfilter != YFilter.not_set or
                                (self.destination_address is not None and self.destination_address.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "bfd-config" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.bundle_status.is_set or self.bundle_status.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.bundle_status.get_name_leafdata())
                            if (self.fast_detect.is_set or self.fast_detect.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.fast_detect.get_name_leafdata())
                            if (self.mode_info.is_set or self.mode_info.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mode_info.get_name_leafdata())
                            if (self.nbr_unconfig_timer.is_set or self.nbr_unconfig_timer.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.nbr_unconfig_timer.get_name_leafdata())
                            if (self.pref_echo_min_interval.is_set or self.pref_echo_min_interval.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.pref_echo_min_interval.get_name_leafdata())
                            if (self.pref_min_interval.is_set or self.pref_min_interval.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.pref_min_interval.get_name_leafdata())
                            if (self.pref_multiplier.is_set or self.pref_multiplier.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.pref_multiplier.get_name_leafdata())
                            if (self.start_timer.is_set or self.start_timer.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.start_timer.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "destination-address"):
                                if (self.destination_address is None):
                                    self.destination_address = BundleInformation.Bundle.BundleBundles.BundleBundle.BundleBundleItem.BfdConfig.DestinationAddress()
                                    self.destination_address.parent = self
                                    self._children_name_map["destination_address"] = "destination-address"
                                return self.destination_address

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "destination-address" or name == "bundle-status" or name == "fast-detect" or name == "mode-info" or name == "nbr-unconfig-timer" or name == "pref-echo-min-interval" or name == "pref-min-interval" or name == "pref-multiplier" or name == "start-timer"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "bundle-status"):
                                self.bundle_status = value
                                self.bundle_status.value_namespace = name_space
                                self.bundle_status.value_namespace_prefix = name_space_prefix
                            if(value_path == "fast-detect"):
                                self.fast_detect = value
                                self.fast_detect.value_namespace = name_space
                                self.fast_detect.value_namespace_prefix = name_space_prefix
                            if(value_path == "mode-info"):
                                self.mode_info = value
                                self.mode_info.value_namespace = name_space
                                self.mode_info.value_namespace_prefix = name_space_prefix
                            if(value_path == "nbr-unconfig-timer"):
                                self.nbr_unconfig_timer = value
                                self.nbr_unconfig_timer.value_namespace = name_space
                                self.nbr_unconfig_timer.value_namespace_prefix = name_space_prefix
                            if(value_path == "pref-echo-min-interval"):
                                self.pref_echo_min_interval = value
                                self.pref_echo_min_interval.value_namespace = name_space
                                self.pref_echo_min_interval.value_namespace_prefix = name_space_prefix
                            if(value_path == "pref-min-interval"):
                                self.pref_min_interval = value
                                self.pref_min_interval.value_namespace = name_space
                                self.pref_min_interval.value_namespace_prefix = name_space_prefix
                            if(value_path == "pref-multiplier"):
                                self.pref_multiplier = value
                                self.pref_multiplier.value_namespace = name_space
                                self.pref_multiplier.value_namespace_prefix = name_space_prefix
                            if(value_path == "start-timer"):
                                self.start_timer = value
                                self.start_timer.value_namespace = name_space
                                self.start_timer.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.bfd_config:
                            if (c.has_data()):
                                return True
                        return (
                            self.active_foreign_member_count.is_set or
                            self.active_member_count.is_set or
                            self.available_bandwidth.is_set or
                            self.bundle_interface_name.is_set or
                            self.bundle_status.is_set or
                            self.cisco_extensions.is_set or
                            self.collector_max_delay.is_set or
                            self.configured_bandwidth.is_set or
                            self.configured_foreign_member_count.is_set or
                            self.configured_member_count.is_set or
                            self.effective_bandwidth.is_set or
                            self.iccp_group_id.is_set or
                            self.inter_chassis.is_set or
                            self.ipv4bfd_status.is_set or
                            self.ipv6bfd_status.is_set or
                            self.is_active.is_set or
                            self.lacp_nonrevertive.is_set or
                            self.lacp_status.is_set or
                            self.link_order_status.is_set or
                            self.load_balance_hash_type.is_set or
                            self.load_balance_locality_threshold.is_set or
                            self.mac_source.is_set or
                            self.mac_source_member.is_set or
                            self.maximize_threshold_value_band_width.is_set or
                            self.maximize_threshold_value_links.is_set or
                            self.maximum_active_links.is_set or
                            self.maximum_active_links_source.is_set or
                            self.minimum_active_links.is_set or
                            self.minimum_bandwidth.is_set or
                            self.mlacp_mode.is_set or
                            self.mlacp_status.is_set or
                            self.primary_member.is_set or
                            self.recovery_delay.is_set or
                            self.singleton.is_set or
                            self.standby_member_count.is_set or
                            self.suppression_timer.is_set or
                            self.switchover_type.is_set or
                            self.wait_while_timer.is_set or
                            (self.mac_address is not None and self.mac_address.has_data()))

                    def has_operation(self):
                        for c in self.bfd_config:
                            if (c.has_operation()):
                                return True
                        return (
                            self.yfilter != YFilter.not_set or
                            self.active_foreign_member_count.yfilter != YFilter.not_set or
                            self.active_member_count.yfilter != YFilter.not_set or
                            self.available_bandwidth.yfilter != YFilter.not_set or
                            self.bundle_interface_name.yfilter != YFilter.not_set or
                            self.bundle_status.yfilter != YFilter.not_set or
                            self.cisco_extensions.yfilter != YFilter.not_set or
                            self.collector_max_delay.yfilter != YFilter.not_set or
                            self.configured_bandwidth.yfilter != YFilter.not_set or
                            self.configured_foreign_member_count.yfilter != YFilter.not_set or
                            self.configured_member_count.yfilter != YFilter.not_set or
                            self.effective_bandwidth.yfilter != YFilter.not_set or
                            self.iccp_group_id.yfilter != YFilter.not_set or
                            self.inter_chassis.yfilter != YFilter.not_set or
                            self.ipv4bfd_status.yfilter != YFilter.not_set or
                            self.ipv6bfd_status.yfilter != YFilter.not_set or
                            self.is_active.yfilter != YFilter.not_set or
                            self.lacp_nonrevertive.yfilter != YFilter.not_set or
                            self.lacp_status.yfilter != YFilter.not_set or
                            self.link_order_status.yfilter != YFilter.not_set or
                            self.load_balance_hash_type.yfilter != YFilter.not_set or
                            self.load_balance_locality_threshold.yfilter != YFilter.not_set or
                            self.mac_source.yfilter != YFilter.not_set or
                            self.mac_source_member.yfilter != YFilter.not_set or
                            self.maximize_threshold_value_band_width.yfilter != YFilter.not_set or
                            self.maximize_threshold_value_links.yfilter != YFilter.not_set or
                            self.maximum_active_links.yfilter != YFilter.not_set or
                            self.maximum_active_links_source.yfilter != YFilter.not_set or
                            self.minimum_active_links.yfilter != YFilter.not_set or
                            self.minimum_bandwidth.yfilter != YFilter.not_set or
                            self.mlacp_mode.yfilter != YFilter.not_set or
                            self.mlacp_status.yfilter != YFilter.not_set or
                            self.primary_member.yfilter != YFilter.not_set or
                            self.recovery_delay.yfilter != YFilter.not_set or
                            self.singleton.yfilter != YFilter.not_set or
                            self.standby_member_count.yfilter != YFilter.not_set or
                            self.suppression_timer.yfilter != YFilter.not_set or
                            self.switchover_type.yfilter != YFilter.not_set or
                            self.wait_while_timer.yfilter != YFilter.not_set or
                            (self.mac_address is not None and self.mac_address.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "bundle-bundle-item" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.active_foreign_member_count.is_set or self.active_foreign_member_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.active_foreign_member_count.get_name_leafdata())
                        if (self.active_member_count.is_set or self.active_member_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.active_member_count.get_name_leafdata())
                        if (self.available_bandwidth.is_set or self.available_bandwidth.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.available_bandwidth.get_name_leafdata())
                        if (self.bundle_interface_name.is_set or self.bundle_interface_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bundle_interface_name.get_name_leafdata())
                        if (self.bundle_status.is_set or self.bundle_status.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bundle_status.get_name_leafdata())
                        if (self.cisco_extensions.is_set or self.cisco_extensions.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.cisco_extensions.get_name_leafdata())
                        if (self.collector_max_delay.is_set or self.collector_max_delay.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.collector_max_delay.get_name_leafdata())
                        if (self.configured_bandwidth.is_set or self.configured_bandwidth.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.configured_bandwidth.get_name_leafdata())
                        if (self.configured_foreign_member_count.is_set or self.configured_foreign_member_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.configured_foreign_member_count.get_name_leafdata())
                        if (self.configured_member_count.is_set or self.configured_member_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.configured_member_count.get_name_leafdata())
                        if (self.effective_bandwidth.is_set or self.effective_bandwidth.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.effective_bandwidth.get_name_leafdata())
                        if (self.iccp_group_id.is_set or self.iccp_group_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.iccp_group_id.get_name_leafdata())
                        if (self.inter_chassis.is_set or self.inter_chassis.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.inter_chassis.get_name_leafdata())
                        if (self.ipv4bfd_status.is_set or self.ipv4bfd_status.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.ipv4bfd_status.get_name_leafdata())
                        if (self.ipv6bfd_status.is_set or self.ipv6bfd_status.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.ipv6bfd_status.get_name_leafdata())
                        if (self.is_active.is_set or self.is_active.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_active.get_name_leafdata())
                        if (self.lacp_nonrevertive.is_set or self.lacp_nonrevertive.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.lacp_nonrevertive.get_name_leafdata())
                        if (self.lacp_status.is_set or self.lacp_status.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.lacp_status.get_name_leafdata())
                        if (self.link_order_status.is_set or self.link_order_status.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.link_order_status.get_name_leafdata())
                        if (self.load_balance_hash_type.is_set or self.load_balance_hash_type.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.load_balance_hash_type.get_name_leafdata())
                        if (self.load_balance_locality_threshold.is_set or self.load_balance_locality_threshold.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.load_balance_locality_threshold.get_name_leafdata())
                        if (self.mac_source.is_set or self.mac_source.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mac_source.get_name_leafdata())
                        if (self.mac_source_member.is_set or self.mac_source_member.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mac_source_member.get_name_leafdata())
                        if (self.maximize_threshold_value_band_width.is_set or self.maximize_threshold_value_band_width.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.maximize_threshold_value_band_width.get_name_leafdata())
                        if (self.maximize_threshold_value_links.is_set or self.maximize_threshold_value_links.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.maximize_threshold_value_links.get_name_leafdata())
                        if (self.maximum_active_links.is_set or self.maximum_active_links.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.maximum_active_links.get_name_leafdata())
                        if (self.maximum_active_links_source.is_set or self.maximum_active_links_source.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.maximum_active_links_source.get_name_leafdata())
                        if (self.minimum_active_links.is_set or self.minimum_active_links.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.minimum_active_links.get_name_leafdata())
                        if (self.minimum_bandwidth.is_set or self.minimum_bandwidth.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.minimum_bandwidth.get_name_leafdata())
                        if (self.mlacp_mode.is_set or self.mlacp_mode.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mlacp_mode.get_name_leafdata())
                        if (self.mlacp_status.is_set or self.mlacp_status.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mlacp_status.get_name_leafdata())
                        if (self.primary_member.is_set or self.primary_member.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.primary_member.get_name_leafdata())
                        if (self.recovery_delay.is_set or self.recovery_delay.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.recovery_delay.get_name_leafdata())
                        if (self.singleton.is_set or self.singleton.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.singleton.get_name_leafdata())
                        if (self.standby_member_count.is_set or self.standby_member_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.standby_member_count.get_name_leafdata())
                        if (self.suppression_timer.is_set or self.suppression_timer.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.suppression_timer.get_name_leafdata())
                        if (self.switchover_type.is_set or self.switchover_type.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.switchover_type.get_name_leafdata())
                        if (self.wait_while_timer.is_set or self.wait_while_timer.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.wait_while_timer.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "bfd-config"):
                            for c in self.bfd_config:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = BundleInformation.Bundle.BundleBundles.BundleBundle.BundleBundleItem.BfdConfig()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.bfd_config.append(c)
                            return c

                        if (child_yang_name == "mac-address"):
                            if (self.mac_address is None):
                                self.mac_address = BundleInformation.Bundle.BundleBundles.BundleBundle.BundleBundleItem.MacAddress()
                                self.mac_address.parent = self
                                self._children_name_map["mac_address"] = "mac-address"
                            return self.mac_address

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "bfd-config" or name == "mac-address" or name == "active-foreign-member-count" or name == "active-member-count" or name == "available-bandwidth" or name == "bundle-interface-name" or name == "bundle-status" or name == "cisco-extensions" or name == "collector-max-delay" or name == "configured-bandwidth" or name == "configured-foreign-member-count" or name == "configured-member-count" or name == "effective-bandwidth" or name == "iccp-group-id" or name == "inter-chassis" or name == "ipv4bfd-status" or name == "ipv6bfd-status" or name == "is-active" or name == "lacp-nonrevertive" or name == "lacp-status" or name == "link-order-status" or name == "load-balance-hash-type" or name == "load-balance-locality-threshold" or name == "mac-source" or name == "mac-source-member" or name == "maximize-threshold-value-band-width" or name == "maximize-threshold-value-links" or name == "maximum-active-links" or name == "maximum-active-links-source" or name == "minimum-active-links" or name == "minimum-bandwidth" or name == "mlacp-mode" or name == "mlacp-status" or name == "primary-member" or name == "recovery-delay" or name == "singleton" or name == "standby-member-count" or name == "suppression-timer" or name == "switchover-type" or name == "wait-while-timer"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "active-foreign-member-count"):
                            self.active_foreign_member_count = value
                            self.active_foreign_member_count.value_namespace = name_space
                            self.active_foreign_member_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "active-member-count"):
                            self.active_member_count = value
                            self.active_member_count.value_namespace = name_space
                            self.active_member_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "available-bandwidth"):
                            self.available_bandwidth = value
                            self.available_bandwidth.value_namespace = name_space
                            self.available_bandwidth.value_namespace_prefix = name_space_prefix
                        if(value_path == "bundle-interface-name"):
                            self.bundle_interface_name = value
                            self.bundle_interface_name.value_namespace = name_space
                            self.bundle_interface_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "bundle-status"):
                            self.bundle_status = value
                            self.bundle_status.value_namespace = name_space
                            self.bundle_status.value_namespace_prefix = name_space_prefix
                        if(value_path == "cisco-extensions"):
                            self.cisco_extensions = value
                            self.cisco_extensions.value_namespace = name_space
                            self.cisco_extensions.value_namespace_prefix = name_space_prefix
                        if(value_path == "collector-max-delay"):
                            self.collector_max_delay = value
                            self.collector_max_delay.value_namespace = name_space
                            self.collector_max_delay.value_namespace_prefix = name_space_prefix
                        if(value_path == "configured-bandwidth"):
                            self.configured_bandwidth = value
                            self.configured_bandwidth.value_namespace = name_space
                            self.configured_bandwidth.value_namespace_prefix = name_space_prefix
                        if(value_path == "configured-foreign-member-count"):
                            self.configured_foreign_member_count = value
                            self.configured_foreign_member_count.value_namespace = name_space
                            self.configured_foreign_member_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "configured-member-count"):
                            self.configured_member_count = value
                            self.configured_member_count.value_namespace = name_space
                            self.configured_member_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "effective-bandwidth"):
                            self.effective_bandwidth = value
                            self.effective_bandwidth.value_namespace = name_space
                            self.effective_bandwidth.value_namespace_prefix = name_space_prefix
                        if(value_path == "iccp-group-id"):
                            self.iccp_group_id = value
                            self.iccp_group_id.value_namespace = name_space
                            self.iccp_group_id.value_namespace_prefix = name_space_prefix
                        if(value_path == "inter-chassis"):
                            self.inter_chassis = value
                            self.inter_chassis.value_namespace = name_space
                            self.inter_chassis.value_namespace_prefix = name_space_prefix
                        if(value_path == "ipv4bfd-status"):
                            self.ipv4bfd_status = value
                            self.ipv4bfd_status.value_namespace = name_space
                            self.ipv4bfd_status.value_namespace_prefix = name_space_prefix
                        if(value_path == "ipv6bfd-status"):
                            self.ipv6bfd_status = value
                            self.ipv6bfd_status.value_namespace = name_space
                            self.ipv6bfd_status.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-active"):
                            self.is_active = value
                            self.is_active.value_namespace = name_space
                            self.is_active.value_namespace_prefix = name_space_prefix
                        if(value_path == "lacp-nonrevertive"):
                            self.lacp_nonrevertive = value
                            self.lacp_nonrevertive.value_namespace = name_space
                            self.lacp_nonrevertive.value_namespace_prefix = name_space_prefix
                        if(value_path == "lacp-status"):
                            self.lacp_status = value
                            self.lacp_status.value_namespace = name_space
                            self.lacp_status.value_namespace_prefix = name_space_prefix
                        if(value_path == "link-order-status"):
                            self.link_order_status = value
                            self.link_order_status.value_namespace = name_space
                            self.link_order_status.value_namespace_prefix = name_space_prefix
                        if(value_path == "load-balance-hash-type"):
                            self.load_balance_hash_type = value
                            self.load_balance_hash_type.value_namespace = name_space
                            self.load_balance_hash_type.value_namespace_prefix = name_space_prefix
                        if(value_path == "load-balance-locality-threshold"):
                            self.load_balance_locality_threshold = value
                            self.load_balance_locality_threshold.value_namespace = name_space
                            self.load_balance_locality_threshold.value_namespace_prefix = name_space_prefix
                        if(value_path == "mac-source"):
                            self.mac_source = value
                            self.mac_source.value_namespace = name_space
                            self.mac_source.value_namespace_prefix = name_space_prefix
                        if(value_path == "mac-source-member"):
                            self.mac_source_member = value
                            self.mac_source_member.value_namespace = name_space
                            self.mac_source_member.value_namespace_prefix = name_space_prefix
                        if(value_path == "maximize-threshold-value-band-width"):
                            self.maximize_threshold_value_band_width = value
                            self.maximize_threshold_value_band_width.value_namespace = name_space
                            self.maximize_threshold_value_band_width.value_namespace_prefix = name_space_prefix
                        if(value_path == "maximize-threshold-value-links"):
                            self.maximize_threshold_value_links = value
                            self.maximize_threshold_value_links.value_namespace = name_space
                            self.maximize_threshold_value_links.value_namespace_prefix = name_space_prefix
                        if(value_path == "maximum-active-links"):
                            self.maximum_active_links = value
                            self.maximum_active_links.value_namespace = name_space
                            self.maximum_active_links.value_namespace_prefix = name_space_prefix
                        if(value_path == "maximum-active-links-source"):
                            self.maximum_active_links_source = value
                            self.maximum_active_links_source.value_namespace = name_space
                            self.maximum_active_links_source.value_namespace_prefix = name_space_prefix
                        if(value_path == "minimum-active-links"):
                            self.minimum_active_links = value
                            self.minimum_active_links.value_namespace = name_space
                            self.minimum_active_links.value_namespace_prefix = name_space_prefix
                        if(value_path == "minimum-bandwidth"):
                            self.minimum_bandwidth = value
                            self.minimum_bandwidth.value_namespace = name_space
                            self.minimum_bandwidth.value_namespace_prefix = name_space_prefix
                        if(value_path == "mlacp-mode"):
                            self.mlacp_mode = value
                            self.mlacp_mode.value_namespace = name_space
                            self.mlacp_mode.value_namespace_prefix = name_space_prefix
                        if(value_path == "mlacp-status"):
                            self.mlacp_status = value
                            self.mlacp_status.value_namespace = name_space
                            self.mlacp_status.value_namespace_prefix = name_space_prefix
                        if(value_path == "primary-member"):
                            self.primary_member = value
                            self.primary_member.value_namespace = name_space
                            self.primary_member.value_namespace_prefix = name_space_prefix
                        if(value_path == "recovery-delay"):
                            self.recovery_delay = value
                            self.recovery_delay.value_namespace = name_space
                            self.recovery_delay.value_namespace_prefix = name_space_prefix
                        if(value_path == "singleton"):
                            self.singleton = value
                            self.singleton.value_namespace = name_space
                            self.singleton.value_namespace_prefix = name_space_prefix
                        if(value_path == "standby-member-count"):
                            self.standby_member_count = value
                            self.standby_member_count.value_namespace = name_space
                            self.standby_member_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "suppression-timer"):
                            self.suppression_timer = value
                            self.suppression_timer.value_namespace = name_space
                            self.suppression_timer.value_namespace_prefix = name_space_prefix
                        if(value_path == "switchover-type"):
                            self.switchover_type = value
                            self.switchover_type.value_namespace = name_space
                            self.switchover_type.value_namespace_prefix = name_space_prefix
                        if(value_path == "wait-while-timer"):
                            self.wait_while_timer = value
                            self.wait_while_timer.value_namespace = name_space
                            self.wait_while_timer.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    return (
                        self.bundle_interface.is_set or
                        (self.bundle_bundle_children_members is not None and self.bundle_bundle_children_members.has_data()) or
                        (self.bundle_bundle_descendant is not None and self.bundle_bundle_descendant.has_data()) or
                        (self.bundle_bundle_item is not None and self.bundle_bundle_item.has_data()))

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.bundle_interface.yfilter != YFilter.not_set or
                        (self.bundle_bundle_children_members is not None and self.bundle_bundle_children_members.has_operation()) or
                        (self.bundle_bundle_descendant is not None and self.bundle_bundle_descendant.has_operation()) or
                        (self.bundle_bundle_item is not None and self.bundle_bundle_item.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "bundle-bundle" + "[bundle-interface='" + self.bundle_interface.get() + "']" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-bundlemgr-oper:bundle-information/bundle/bundle-bundles/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.bundle_interface.is_set or self.bundle_interface.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.bundle_interface.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "bundle-bundle-children-members"):
                        if (self.bundle_bundle_children_members is None):
                            self.bundle_bundle_children_members = BundleInformation.Bundle.BundleBundles.BundleBundle.BundleBundleChildrenMembers()
                            self.bundle_bundle_children_members.parent = self
                            self._children_name_map["bundle_bundle_children_members"] = "bundle-bundle-children-members"
                        return self.bundle_bundle_children_members

                    if (child_yang_name == "bundle-bundle-descendant"):
                        if (self.bundle_bundle_descendant is None):
                            self.bundle_bundle_descendant = BundleInformation.Bundle.BundleBundles.BundleBundle.BundleBundleDescendant()
                            self.bundle_bundle_descendant.parent = self
                            self._children_name_map["bundle_bundle_descendant"] = "bundle-bundle-descendant"
                        return self.bundle_bundle_descendant

                    if (child_yang_name == "bundle-bundle-item"):
                        if (self.bundle_bundle_item is None):
                            self.bundle_bundle_item = BundleInformation.Bundle.BundleBundles.BundleBundle.BundleBundleItem()
                            self.bundle_bundle_item.parent = self
                            self._children_name_map["bundle_bundle_item"] = "bundle-bundle-item"
                        return self.bundle_bundle_item

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "bundle-bundle-children-members" or name == "bundle-bundle-descendant" or name == "bundle-bundle-item" or name == "bundle-interface"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "bundle-interface"):
                        self.bundle_interface = value
                        self.bundle_interface.value_namespace = name_space
                        self.bundle_interface.value_namespace_prefix = name_space_prefix

            def has_data(self):
                for c in self.bundle_bundle:
                    if (c.has_data()):
                        return True
                return False

            def has_operation(self):
                for c in self.bundle_bundle:
                    if (c.has_operation()):
                        return True
                return self.yfilter != YFilter.not_set

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "bundle-bundles" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-bundlemgr-oper:bundle-information/bundle/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "bundle-bundle"):
                    for c in self.bundle_bundle:
                        segment = c.get_segment_path()
                        if (segment_path == segment):
                            return c
                    c = BundleInformation.Bundle.BundleBundles.BundleBundle()
                    c.parent = self
                    local_reference_key = "ydk::seg::%s" % segment_path
                    self._local_refs[local_reference_key] = c
                    self.bundle_bundle.append(c)
                    return c

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "bundle-bundle"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                pass


        class BundleMembers(Entity):
            """
            Member interfaces with common bundle
            information
            
            .. attribute:: bundle_member
            
            	Member interface
            	**type**\: list of    :py:class:`BundleMember <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.Bundle.BundleMembers.BundleMember>`
            
            

            """

            _prefix = 'bundlemgr-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(BundleInformation.Bundle.BundleMembers, self).__init__()

                self.yang_name = "bundle-members"
                self.yang_parent_name = "bundle"

                self.bundle_member = YList(self)

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in () and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(BundleInformation.Bundle.BundleMembers, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(BundleInformation.Bundle.BundleMembers, self).__setattr__(name, value)


            class BundleMember(Entity):
                """
                Member interface
                
                .. attribute:: member_interface  <key>
                
                	Member interface
                	**type**\:  str
                
                .. attribute:: bundle_member_ancestor
                
                	Data for this item and its parent bundle
                	**type**\:   :py:class:`BundleMemberAncestor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.Bundle.BundleMembers.BundleMember.BundleMemberAncestor>`
                
                .. attribute:: bundle_member_item
                
                	Data for this item
                	**type**\:   :py:class:`BundleMemberItem <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.Bundle.BundleMembers.BundleMember.BundleMemberItem>`
                
                

                """

                _prefix = 'bundlemgr-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(BundleInformation.Bundle.BundleMembers.BundleMember, self).__init__()

                    self.yang_name = "bundle-member"
                    self.yang_parent_name = "bundle-members"

                    self.member_interface = YLeaf(YType.str, "member-interface")

                    self.bundle_member_ancestor = BundleInformation.Bundle.BundleMembers.BundleMember.BundleMemberAncestor()
                    self.bundle_member_ancestor.parent = self
                    self._children_name_map["bundle_member_ancestor"] = "bundle-member-ancestor"
                    self._children_yang_names.add("bundle-member-ancestor")

                    self.bundle_member_item = BundleInformation.Bundle.BundleMembers.BundleMember.BundleMemberItem()
                    self.bundle_member_item.parent = self
                    self._children_name_map["bundle_member_item"] = "bundle-member-item"
                    self._children_yang_names.add("bundle-member-item")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("member_interface") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(BundleInformation.Bundle.BundleMembers.BundleMember, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(BundleInformation.Bundle.BundleMembers.BundleMember, self).__setattr__(name, value)


                class BundleMemberAncestor(Entity):
                    """
                    Data for this item and its parent bundle
                    
                    .. attribute:: bundle_data
                    
                    	Bundle information
                    	**type**\:   :py:class:`BundleData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.Bundle.BundleMembers.BundleMember.BundleMemberAncestor.BundleData>`
                    
                    .. attribute:: member_data
                    
                    	Member information
                    	**type**\: list of    :py:class:`MemberData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.Bundle.BundleMembers.BundleMember.BundleMemberAncestor.MemberData>`
                    
                    

                    """

                    _prefix = 'bundlemgr-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(BundleInformation.Bundle.BundleMembers.BundleMember.BundleMemberAncestor, self).__init__()

                        self.yang_name = "bundle-member-ancestor"
                        self.yang_parent_name = "bundle-member"

                        self.bundle_data = BundleInformation.Bundle.BundleMembers.BundleMember.BundleMemberAncestor.BundleData()
                        self.bundle_data.parent = self
                        self._children_name_map["bundle_data"] = "bundle-data"
                        self._children_yang_names.add("bundle-data")

                        self.member_data = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(BundleInformation.Bundle.BundleMembers.BundleMember.BundleMemberAncestor, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(BundleInformation.Bundle.BundleMembers.BundleMember.BundleMemberAncestor, self).__setattr__(name, value)


                    class BundleData(Entity):
                        """
                        Bundle information
                        
                        .. attribute:: active_foreign_member_count
                        
                        	The number of active foreign members on the bundle
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: active_member_count
                        
                        	The number of active local members on the bundle
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: available_bandwidth
                        
                        	Bandwidth available to the bundle interface (kbps)
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: kbit/s
                        
                        .. attribute:: bfd_config
                        
                        	Configuration values for BFD on bundle members
                        	**type**\: list of    :py:class:`BfdConfig <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.Bundle.BundleMembers.BundleMember.BundleMemberAncestor.BundleData.BfdConfig>`
                        
                        .. attribute:: bundle_interface_name
                        
                        	Bundle interface name
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: bundle_status
                        
                        	The state of the bundle
                        	**type**\:   :py:class:`BmBdlState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmBdlState>`
                        
                        .. attribute:: cisco_extensions
                        
                        	The status of the Cisco Extensions feature (1 = enabled, 0 = not enabled)
                        	**type**\:  bool
                        
                        .. attribute:: collector_max_delay
                        
                        	Collector Max Delay
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: configured_bandwidth
                        
                        	Bandwidth configured on the bundle interface (kbps)
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: kbit/s
                        
                        .. attribute:: configured_foreign_member_count
                        
                        	The number of configured local members on the bundle
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: configured_member_count
                        
                        	The number of configured local members on the bundle
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: effective_bandwidth
                        
                        	Effective bandwidth on the bundle interface (kbps)
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: kbit/s
                        
                        .. attribute:: iccp_group_id
                        
                        	ICCP Group that the bundle is configured to
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: inter_chassis
                        
                        	Indicates if this bundle is operating as an inter\-chassis link (1 = I\-C link, 0 = normal)
                        	**type**\:  bool
                        
                        .. attribute:: ipv4bfd_status
                        
                        	The status of the BFD (IPv4) feature on the bundle
                        	**type**\:   :py:class:`BmFeatureStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmFeatureStatus>`
                        
                        .. attribute:: ipv6bfd_status
                        
                        	The status of the BFD (IPv6) feature on the bundle
                        	**type**\:   :py:class:`BmFeatureStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmFeatureStatus>`
                        
                        .. attribute:: is_active
                        
                        	Indicates the active/standby redundancy state of the device for the bundle
                        	**type**\:  bool
                        
                        .. attribute:: lacp_nonrevertive
                        
                        	The status of the LACP nonrevertive feature (1 = enable, 0 = not enabled)
                        	**type**\:  bool
                        
                        .. attribute:: lacp_status
                        
                        	The status of the LACP feature on the bundle
                        	**type**\:   :py:class:`BmFeatureStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmFeatureStatus>`
                        
                        .. attribute:: link_order_status
                        
                        	The status of the link order signaling feature on the bundle
                        	**type**\:   :py:class:`BmFeatureStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmFeatureStatus>`
                        
                        .. attribute:: load_balance_hash_type
                        
                        	The type of hash to use for load balancing
                        	**type**\:  str
                        
                        .. attribute:: load_balance_locality_threshold
                        
                        	The number of links required per rack for localized load balancing
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: mac_address
                        
                        	MAC address of this member
                        	**type**\:   :py:class:`MacAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.Bundle.BundleMembers.BundleMember.BundleMemberAncestor.BundleData.MacAddress>`
                        
                        .. attribute:: mac_source
                        
                        	The source of the MAC Address
                        	**type**\:   :py:class:`BmBdlMacSource <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmBdlMacSource>`
                        
                        .. attribute:: mac_source_member
                        
                        	The name of the member that supplied the MAC address
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: maximize_threshold_value_band_width
                        
                        	Attempt to maximize the bundle if bandwidth is below this value
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: maximize_threshold_value_links
                        
                        	Attempt to maximize the bundle if links are below this value
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: maximum_active_links
                        
                        	Maximum number of active links in the bundle
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: maximum_active_links_source
                        
                        	Source of maximum active links value
                        	**type**\:   :py:class:`BmWhichSystem <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmWhichSystem>`
                        
                        .. attribute:: minimum_active_links
                        
                        	Minimum number of active links for bundle to go up
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: minimum_bandwidth
                        
                        	Minimum bundle bandwidth for bundle to go up (kbps)
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: kbit/s
                        
                        .. attribute:: mlacp_mode
                        
                        	Indicates the mode of the device for the bundle
                        	**type**\:   :py:class:`BundleMlacpMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleMlacpMode>`
                        
                        .. attribute:: mlacp_status
                        
                        	The status of the mLACP feature on the bundle
                        	**type**\:   :py:class:`BmFeatureStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmFeatureStatus>`
                        
                        .. attribute:: primary_member
                        
                        	Primary bundle member (no longer applicable)
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: recovery_delay
                        
                        	Number of seconds to wait before becoming active after recovering from a failure
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        	**units**\: second
                        
                        .. attribute:: singleton
                        
                        	Is the ICCP group of the bundle in singleton mode (1 = singleton; 0 = not singleton)
                        	**type**\:  bool
                        
                        .. attribute:: standby_member_count
                        
                        	The number of standby local members on the bundle
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: suppression_timer
                        
                        	Timer for suppressing bundle state flaps
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: switchover_type
                        
                        	How a switchover of the bundle from this device will occur
                        	**type**\:   :py:class:`BmdMlacpSwitchover <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmdMlacpSwitchover>`
                        
                        .. attribute:: wait_while_timer
                        
                        	The wait while time used for member ports
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'bundlemgr-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(BundleInformation.Bundle.BundleMembers.BundleMember.BundleMemberAncestor.BundleData, self).__init__()

                            self.yang_name = "bundle-data"
                            self.yang_parent_name = "bundle-member-ancestor"

                            self.active_foreign_member_count = YLeaf(YType.uint16, "active-foreign-member-count")

                            self.active_member_count = YLeaf(YType.uint16, "active-member-count")

                            self.available_bandwidth = YLeaf(YType.uint32, "available-bandwidth")

                            self.bundle_interface_name = YLeaf(YType.str, "bundle-interface-name")

                            self.bundle_status = YLeaf(YType.enumeration, "bundle-status")

                            self.cisco_extensions = YLeaf(YType.boolean, "cisco-extensions")

                            self.collector_max_delay = YLeaf(YType.uint16, "collector-max-delay")

                            self.configured_bandwidth = YLeaf(YType.uint32, "configured-bandwidth")

                            self.configured_foreign_member_count = YLeaf(YType.uint16, "configured-foreign-member-count")

                            self.configured_member_count = YLeaf(YType.uint16, "configured-member-count")

                            self.effective_bandwidth = YLeaf(YType.uint32, "effective-bandwidth")

                            self.iccp_group_id = YLeaf(YType.uint32, "iccp-group-id")

                            self.inter_chassis = YLeaf(YType.boolean, "inter-chassis")

                            self.ipv4bfd_status = YLeaf(YType.enumeration, "ipv4bfd-status")

                            self.ipv6bfd_status = YLeaf(YType.enumeration, "ipv6bfd-status")

                            self.is_active = YLeaf(YType.boolean, "is-active")

                            self.lacp_nonrevertive = YLeaf(YType.boolean, "lacp-nonrevertive")

                            self.lacp_status = YLeaf(YType.enumeration, "lacp-status")

                            self.link_order_status = YLeaf(YType.enumeration, "link-order-status")

                            self.load_balance_hash_type = YLeaf(YType.str, "load-balance-hash-type")

                            self.load_balance_locality_threshold = YLeaf(YType.uint16, "load-balance-locality-threshold")

                            self.mac_source = YLeaf(YType.enumeration, "mac-source")

                            self.mac_source_member = YLeaf(YType.str, "mac-source-member")

                            self.maximize_threshold_value_band_width = YLeaf(YType.uint32, "maximize-threshold-value-band-width")

                            self.maximize_threshold_value_links = YLeaf(YType.uint32, "maximize-threshold-value-links")

                            self.maximum_active_links = YLeaf(YType.uint8, "maximum-active-links")

                            self.maximum_active_links_source = YLeaf(YType.enumeration, "maximum-active-links-source")

                            self.minimum_active_links = YLeaf(YType.uint8, "minimum-active-links")

                            self.minimum_bandwidth = YLeaf(YType.uint32, "minimum-bandwidth")

                            self.mlacp_mode = YLeaf(YType.enumeration, "mlacp-mode")

                            self.mlacp_status = YLeaf(YType.enumeration, "mlacp-status")

                            self.primary_member = YLeaf(YType.str, "primary-member")

                            self.recovery_delay = YLeaf(YType.uint16, "recovery-delay")

                            self.singleton = YLeaf(YType.boolean, "singleton")

                            self.standby_member_count = YLeaf(YType.uint16, "standby-member-count")

                            self.suppression_timer = YLeaf(YType.uint16, "suppression-timer")

                            self.switchover_type = YLeaf(YType.enumeration, "switchover-type")

                            self.wait_while_timer = YLeaf(YType.uint16, "wait-while-timer")

                            self.mac_address = BundleInformation.Bundle.BundleMembers.BundleMember.BundleMemberAncestor.BundleData.MacAddress()
                            self.mac_address.parent = self
                            self._children_name_map["mac_address"] = "mac-address"
                            self._children_yang_names.add("mac-address")

                            self.bfd_config = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("active_foreign_member_count",
                                            "active_member_count",
                                            "available_bandwidth",
                                            "bundle_interface_name",
                                            "bundle_status",
                                            "cisco_extensions",
                                            "collector_max_delay",
                                            "configured_bandwidth",
                                            "configured_foreign_member_count",
                                            "configured_member_count",
                                            "effective_bandwidth",
                                            "iccp_group_id",
                                            "inter_chassis",
                                            "ipv4bfd_status",
                                            "ipv6bfd_status",
                                            "is_active",
                                            "lacp_nonrevertive",
                                            "lacp_status",
                                            "link_order_status",
                                            "load_balance_hash_type",
                                            "load_balance_locality_threshold",
                                            "mac_source",
                                            "mac_source_member",
                                            "maximize_threshold_value_band_width",
                                            "maximize_threshold_value_links",
                                            "maximum_active_links",
                                            "maximum_active_links_source",
                                            "minimum_active_links",
                                            "minimum_bandwidth",
                                            "mlacp_mode",
                                            "mlacp_status",
                                            "primary_member",
                                            "recovery_delay",
                                            "singleton",
                                            "standby_member_count",
                                            "suppression_timer",
                                            "switchover_type",
                                            "wait_while_timer") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(BundleInformation.Bundle.BundleMembers.BundleMember.BundleMemberAncestor.BundleData, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(BundleInformation.Bundle.BundleMembers.BundleMember.BundleMemberAncestor.BundleData, self).__setattr__(name, value)


                        class MacAddress(Entity):
                            """
                            MAC address of this member
                            
                            .. attribute:: address
                            
                            	MAC address
                            	**type**\:  str
                            
                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                            
                            

                            """

                            _prefix = 'bundlemgr-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(BundleInformation.Bundle.BundleMembers.BundleMember.BundleMemberAncestor.BundleData.MacAddress, self).__init__()

                                self.yang_name = "mac-address"
                                self.yang_parent_name = "bundle-data"

                                self.address = YLeaf(YType.str, "address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(BundleInformation.Bundle.BundleMembers.BundleMember.BundleMemberAncestor.BundleData.MacAddress, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(BundleInformation.Bundle.BundleMembers.BundleMember.BundleMemberAncestor.BundleData.MacAddress, self).__setattr__(name, value)

                            def has_data(self):
                                return self.address.is_set

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "mac-address" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.address.is_set or self.address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "address"):
                                    self.address = value
                                    self.address.value_namespace = name_space
                                    self.address.value_namespace_prefix = name_space_prefix


                        class BfdConfig(Entity):
                            """
                            Configuration values for BFD on bundle members
                            
                            .. attribute:: bundle_status
                            
                            	Status of BFD on the bundle
                            	**type**\:   :py:class:`BmdBfdBdlState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmdBfdBdlState>`
                            
                            .. attribute:: destination_address
                            
                            	Configured destination address for BFD session
                            	**type**\:   :py:class:`DestinationAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.Bundle.BundleMembers.BundleMember.BundleMemberAncestor.BundleData.BfdConfig.DestinationAddress>`
                            
                            .. attribute:: fast_detect
                            
                            	Flag indicating if BFD is enabled (1 = enabled; 0 = not enabled)
                            	**type**\:  bool
                            
                            .. attribute:: mode_info
                            
                            	Standard used for per\-member BFD
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nbr_unconfig_timer
                            
                            	Time to wait on session NBR\_UNCONFIG before declaring DOWN
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: pref_echo_min_interval
                            
                            	Preferred echo minimum interval for the BFD session (ms)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: pref_min_interval
                            
                            	Preferred minimum interval for the BFD session (ms)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: pref_multiplier
                            
                            	Preferred multiplier for the BFD session
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: start_timer
                            
                            	Time to wait on session start before declaring DOWN
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'bundlemgr-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(BundleInformation.Bundle.BundleMembers.BundleMember.BundleMemberAncestor.BundleData.BfdConfig, self).__init__()

                                self.yang_name = "bfd-config"
                                self.yang_parent_name = "bundle-data"

                                self.bundle_status = YLeaf(YType.enumeration, "bundle-status")

                                self.fast_detect = YLeaf(YType.boolean, "fast-detect")

                                self.mode_info = YLeaf(YType.uint32, "mode-info")

                                self.nbr_unconfig_timer = YLeaf(YType.uint32, "nbr-unconfig-timer")

                                self.pref_echo_min_interval = YLeaf(YType.uint32, "pref-echo-min-interval")

                                self.pref_min_interval = YLeaf(YType.uint32, "pref-min-interval")

                                self.pref_multiplier = YLeaf(YType.uint16, "pref-multiplier")

                                self.start_timer = YLeaf(YType.uint32, "start-timer")

                                self.destination_address = BundleInformation.Bundle.BundleMembers.BundleMember.BundleMemberAncestor.BundleData.BfdConfig.DestinationAddress()
                                self.destination_address.parent = self
                                self._children_name_map["destination_address"] = "destination-address"
                                self._children_yang_names.add("destination-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("bundle_status",
                                                "fast_detect",
                                                "mode_info",
                                                "nbr_unconfig_timer",
                                                "pref_echo_min_interval",
                                                "pref_min_interval",
                                                "pref_multiplier",
                                                "start_timer") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(BundleInformation.Bundle.BundleMembers.BundleMember.BundleMemberAncestor.BundleData.BfdConfig, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(BundleInformation.Bundle.BundleMembers.BundleMember.BundleMemberAncestor.BundleData.BfdConfig, self).__setattr__(name, value)


                            class DestinationAddress(Entity):
                                """
                                Configured destination address for BFD session
                                
                                .. attribute:: af
                                
                                	AF
                                	**type**\:   :py:class:`BmAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmAfId>`
                                
                                .. attribute:: ipv4
                                
                                	IPv4 address type
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6
                                
                                	IPv6 address type
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'bundlemgr-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(BundleInformation.Bundle.BundleMembers.BundleMember.BundleMemberAncestor.BundleData.BfdConfig.DestinationAddress, self).__init__()

                                    self.yang_name = "destination-address"
                                    self.yang_parent_name = "bfd-config"

                                    self.af = YLeaf(YType.enumeration, "af")

                                    self.ipv4 = YLeaf(YType.str, "ipv4")

                                    self.ipv6 = YLeaf(YType.str, "ipv6")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("af",
                                                    "ipv4",
                                                    "ipv6") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(BundleInformation.Bundle.BundleMembers.BundleMember.BundleMemberAncestor.BundleData.BfdConfig.DestinationAddress, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(BundleInformation.Bundle.BundleMembers.BundleMember.BundleMemberAncestor.BundleData.BfdConfig.DestinationAddress, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.af.is_set or
                                        self.ipv4.is_set or
                                        self.ipv6.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.af.yfilter != YFilter.not_set or
                                        self.ipv4.yfilter != YFilter.not_set or
                                        self.ipv6.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "destination-address" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.af.is_set or self.af.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.af.get_name_leafdata())
                                    if (self.ipv4.is_set or self.ipv4.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv4.get_name_leafdata())
                                    if (self.ipv6.is_set or self.ipv6.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv6.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "af" or name == "ipv4" or name == "ipv6"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "af"):
                                        self.af = value
                                        self.af.value_namespace = name_space
                                        self.af.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv4"):
                                        self.ipv4 = value
                                        self.ipv4.value_namespace = name_space
                                        self.ipv4.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv6"):
                                        self.ipv6 = value
                                        self.ipv6.value_namespace = name_space
                                        self.ipv6.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.bundle_status.is_set or
                                    self.fast_detect.is_set or
                                    self.mode_info.is_set or
                                    self.nbr_unconfig_timer.is_set or
                                    self.pref_echo_min_interval.is_set or
                                    self.pref_min_interval.is_set or
                                    self.pref_multiplier.is_set or
                                    self.start_timer.is_set or
                                    (self.destination_address is not None and self.destination_address.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.bundle_status.yfilter != YFilter.not_set or
                                    self.fast_detect.yfilter != YFilter.not_set or
                                    self.mode_info.yfilter != YFilter.not_set or
                                    self.nbr_unconfig_timer.yfilter != YFilter.not_set or
                                    self.pref_echo_min_interval.yfilter != YFilter.not_set or
                                    self.pref_min_interval.yfilter != YFilter.not_set or
                                    self.pref_multiplier.yfilter != YFilter.not_set or
                                    self.start_timer.yfilter != YFilter.not_set or
                                    (self.destination_address is not None and self.destination_address.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "bfd-config" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.bundle_status.is_set or self.bundle_status.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.bundle_status.get_name_leafdata())
                                if (self.fast_detect.is_set or self.fast_detect.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.fast_detect.get_name_leafdata())
                                if (self.mode_info.is_set or self.mode_info.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mode_info.get_name_leafdata())
                                if (self.nbr_unconfig_timer.is_set or self.nbr_unconfig_timer.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.nbr_unconfig_timer.get_name_leafdata())
                                if (self.pref_echo_min_interval.is_set or self.pref_echo_min_interval.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pref_echo_min_interval.get_name_leafdata())
                                if (self.pref_min_interval.is_set or self.pref_min_interval.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pref_min_interval.get_name_leafdata())
                                if (self.pref_multiplier.is_set or self.pref_multiplier.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pref_multiplier.get_name_leafdata())
                                if (self.start_timer.is_set or self.start_timer.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.start_timer.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "destination-address"):
                                    if (self.destination_address is None):
                                        self.destination_address = BundleInformation.Bundle.BundleMembers.BundleMember.BundleMemberAncestor.BundleData.BfdConfig.DestinationAddress()
                                        self.destination_address.parent = self
                                        self._children_name_map["destination_address"] = "destination-address"
                                    return self.destination_address

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "destination-address" or name == "bundle-status" or name == "fast-detect" or name == "mode-info" or name == "nbr-unconfig-timer" or name == "pref-echo-min-interval" or name == "pref-min-interval" or name == "pref-multiplier" or name == "start-timer"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "bundle-status"):
                                    self.bundle_status = value
                                    self.bundle_status.value_namespace = name_space
                                    self.bundle_status.value_namespace_prefix = name_space_prefix
                                if(value_path == "fast-detect"):
                                    self.fast_detect = value
                                    self.fast_detect.value_namespace = name_space
                                    self.fast_detect.value_namespace_prefix = name_space_prefix
                                if(value_path == "mode-info"):
                                    self.mode_info = value
                                    self.mode_info.value_namespace = name_space
                                    self.mode_info.value_namespace_prefix = name_space_prefix
                                if(value_path == "nbr-unconfig-timer"):
                                    self.nbr_unconfig_timer = value
                                    self.nbr_unconfig_timer.value_namespace = name_space
                                    self.nbr_unconfig_timer.value_namespace_prefix = name_space_prefix
                                if(value_path == "pref-echo-min-interval"):
                                    self.pref_echo_min_interval = value
                                    self.pref_echo_min_interval.value_namespace = name_space
                                    self.pref_echo_min_interval.value_namespace_prefix = name_space_prefix
                                if(value_path == "pref-min-interval"):
                                    self.pref_min_interval = value
                                    self.pref_min_interval.value_namespace = name_space
                                    self.pref_min_interval.value_namespace_prefix = name_space_prefix
                                if(value_path == "pref-multiplier"):
                                    self.pref_multiplier = value
                                    self.pref_multiplier.value_namespace = name_space
                                    self.pref_multiplier.value_namespace_prefix = name_space_prefix
                                if(value_path == "start-timer"):
                                    self.start_timer = value
                                    self.start_timer.value_namespace = name_space
                                    self.start_timer.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.bfd_config:
                                if (c.has_data()):
                                    return True
                            return (
                                self.active_foreign_member_count.is_set or
                                self.active_member_count.is_set or
                                self.available_bandwidth.is_set or
                                self.bundle_interface_name.is_set or
                                self.bundle_status.is_set or
                                self.cisco_extensions.is_set or
                                self.collector_max_delay.is_set or
                                self.configured_bandwidth.is_set or
                                self.configured_foreign_member_count.is_set or
                                self.configured_member_count.is_set or
                                self.effective_bandwidth.is_set or
                                self.iccp_group_id.is_set or
                                self.inter_chassis.is_set or
                                self.ipv4bfd_status.is_set or
                                self.ipv6bfd_status.is_set or
                                self.is_active.is_set or
                                self.lacp_nonrevertive.is_set or
                                self.lacp_status.is_set or
                                self.link_order_status.is_set or
                                self.load_balance_hash_type.is_set or
                                self.load_balance_locality_threshold.is_set or
                                self.mac_source.is_set or
                                self.mac_source_member.is_set or
                                self.maximize_threshold_value_band_width.is_set or
                                self.maximize_threshold_value_links.is_set or
                                self.maximum_active_links.is_set or
                                self.maximum_active_links_source.is_set or
                                self.minimum_active_links.is_set or
                                self.minimum_bandwidth.is_set or
                                self.mlacp_mode.is_set or
                                self.mlacp_status.is_set or
                                self.primary_member.is_set or
                                self.recovery_delay.is_set or
                                self.singleton.is_set or
                                self.standby_member_count.is_set or
                                self.suppression_timer.is_set or
                                self.switchover_type.is_set or
                                self.wait_while_timer.is_set or
                                (self.mac_address is not None and self.mac_address.has_data()))

                        def has_operation(self):
                            for c in self.bfd_config:
                                if (c.has_operation()):
                                    return True
                            return (
                                self.yfilter != YFilter.not_set or
                                self.active_foreign_member_count.yfilter != YFilter.not_set or
                                self.active_member_count.yfilter != YFilter.not_set or
                                self.available_bandwidth.yfilter != YFilter.not_set or
                                self.bundle_interface_name.yfilter != YFilter.not_set or
                                self.bundle_status.yfilter != YFilter.not_set or
                                self.cisco_extensions.yfilter != YFilter.not_set or
                                self.collector_max_delay.yfilter != YFilter.not_set or
                                self.configured_bandwidth.yfilter != YFilter.not_set or
                                self.configured_foreign_member_count.yfilter != YFilter.not_set or
                                self.configured_member_count.yfilter != YFilter.not_set or
                                self.effective_bandwidth.yfilter != YFilter.not_set or
                                self.iccp_group_id.yfilter != YFilter.not_set or
                                self.inter_chassis.yfilter != YFilter.not_set or
                                self.ipv4bfd_status.yfilter != YFilter.not_set or
                                self.ipv6bfd_status.yfilter != YFilter.not_set or
                                self.is_active.yfilter != YFilter.not_set or
                                self.lacp_nonrevertive.yfilter != YFilter.not_set or
                                self.lacp_status.yfilter != YFilter.not_set or
                                self.link_order_status.yfilter != YFilter.not_set or
                                self.load_balance_hash_type.yfilter != YFilter.not_set or
                                self.load_balance_locality_threshold.yfilter != YFilter.not_set or
                                self.mac_source.yfilter != YFilter.not_set or
                                self.mac_source_member.yfilter != YFilter.not_set or
                                self.maximize_threshold_value_band_width.yfilter != YFilter.not_set or
                                self.maximize_threshold_value_links.yfilter != YFilter.not_set or
                                self.maximum_active_links.yfilter != YFilter.not_set or
                                self.maximum_active_links_source.yfilter != YFilter.not_set or
                                self.minimum_active_links.yfilter != YFilter.not_set or
                                self.minimum_bandwidth.yfilter != YFilter.not_set or
                                self.mlacp_mode.yfilter != YFilter.not_set or
                                self.mlacp_status.yfilter != YFilter.not_set or
                                self.primary_member.yfilter != YFilter.not_set or
                                self.recovery_delay.yfilter != YFilter.not_set or
                                self.singleton.yfilter != YFilter.not_set or
                                self.standby_member_count.yfilter != YFilter.not_set or
                                self.suppression_timer.yfilter != YFilter.not_set or
                                self.switchover_type.yfilter != YFilter.not_set or
                                self.wait_while_timer.yfilter != YFilter.not_set or
                                (self.mac_address is not None and self.mac_address.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "bundle-data" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.active_foreign_member_count.is_set or self.active_foreign_member_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.active_foreign_member_count.get_name_leafdata())
                            if (self.active_member_count.is_set or self.active_member_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.active_member_count.get_name_leafdata())
                            if (self.available_bandwidth.is_set or self.available_bandwidth.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.available_bandwidth.get_name_leafdata())
                            if (self.bundle_interface_name.is_set or self.bundle_interface_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.bundle_interface_name.get_name_leafdata())
                            if (self.bundle_status.is_set or self.bundle_status.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.bundle_status.get_name_leafdata())
                            if (self.cisco_extensions.is_set or self.cisco_extensions.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.cisco_extensions.get_name_leafdata())
                            if (self.collector_max_delay.is_set or self.collector_max_delay.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.collector_max_delay.get_name_leafdata())
                            if (self.configured_bandwidth.is_set or self.configured_bandwidth.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.configured_bandwidth.get_name_leafdata())
                            if (self.configured_foreign_member_count.is_set or self.configured_foreign_member_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.configured_foreign_member_count.get_name_leafdata())
                            if (self.configured_member_count.is_set or self.configured_member_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.configured_member_count.get_name_leafdata())
                            if (self.effective_bandwidth.is_set or self.effective_bandwidth.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.effective_bandwidth.get_name_leafdata())
                            if (self.iccp_group_id.is_set or self.iccp_group_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.iccp_group_id.get_name_leafdata())
                            if (self.inter_chassis.is_set or self.inter_chassis.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.inter_chassis.get_name_leafdata())
                            if (self.ipv4bfd_status.is_set or self.ipv4bfd_status.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4bfd_status.get_name_leafdata())
                            if (self.ipv6bfd_status.is_set or self.ipv6bfd_status.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6bfd_status.get_name_leafdata())
                            if (self.is_active.is_set or self.is_active.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_active.get_name_leafdata())
                            if (self.lacp_nonrevertive.is_set or self.lacp_nonrevertive.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.lacp_nonrevertive.get_name_leafdata())
                            if (self.lacp_status.is_set or self.lacp_status.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.lacp_status.get_name_leafdata())
                            if (self.link_order_status.is_set or self.link_order_status.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.link_order_status.get_name_leafdata())
                            if (self.load_balance_hash_type.is_set or self.load_balance_hash_type.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.load_balance_hash_type.get_name_leafdata())
                            if (self.load_balance_locality_threshold.is_set or self.load_balance_locality_threshold.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.load_balance_locality_threshold.get_name_leafdata())
                            if (self.mac_source.is_set or self.mac_source.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mac_source.get_name_leafdata())
                            if (self.mac_source_member.is_set or self.mac_source_member.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mac_source_member.get_name_leafdata())
                            if (self.maximize_threshold_value_band_width.is_set or self.maximize_threshold_value_band_width.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.maximize_threshold_value_band_width.get_name_leafdata())
                            if (self.maximize_threshold_value_links.is_set or self.maximize_threshold_value_links.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.maximize_threshold_value_links.get_name_leafdata())
                            if (self.maximum_active_links.is_set or self.maximum_active_links.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.maximum_active_links.get_name_leafdata())
                            if (self.maximum_active_links_source.is_set or self.maximum_active_links_source.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.maximum_active_links_source.get_name_leafdata())
                            if (self.minimum_active_links.is_set or self.minimum_active_links.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.minimum_active_links.get_name_leafdata())
                            if (self.minimum_bandwidth.is_set or self.minimum_bandwidth.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.minimum_bandwidth.get_name_leafdata())
                            if (self.mlacp_mode.is_set or self.mlacp_mode.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mlacp_mode.get_name_leafdata())
                            if (self.mlacp_status.is_set or self.mlacp_status.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mlacp_status.get_name_leafdata())
                            if (self.primary_member.is_set or self.primary_member.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.primary_member.get_name_leafdata())
                            if (self.recovery_delay.is_set or self.recovery_delay.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.recovery_delay.get_name_leafdata())
                            if (self.singleton.is_set or self.singleton.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.singleton.get_name_leafdata())
                            if (self.standby_member_count.is_set or self.standby_member_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.standby_member_count.get_name_leafdata())
                            if (self.suppression_timer.is_set or self.suppression_timer.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.suppression_timer.get_name_leafdata())
                            if (self.switchover_type.is_set or self.switchover_type.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.switchover_type.get_name_leafdata())
                            if (self.wait_while_timer.is_set or self.wait_while_timer.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.wait_while_timer.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "bfd-config"):
                                for c in self.bfd_config:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = BundleInformation.Bundle.BundleMembers.BundleMember.BundleMemberAncestor.BundleData.BfdConfig()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.bfd_config.append(c)
                                return c

                            if (child_yang_name == "mac-address"):
                                if (self.mac_address is None):
                                    self.mac_address = BundleInformation.Bundle.BundleMembers.BundleMember.BundleMemberAncestor.BundleData.MacAddress()
                                    self.mac_address.parent = self
                                    self._children_name_map["mac_address"] = "mac-address"
                                return self.mac_address

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "bfd-config" or name == "mac-address" or name == "active-foreign-member-count" or name == "active-member-count" or name == "available-bandwidth" or name == "bundle-interface-name" or name == "bundle-status" or name == "cisco-extensions" or name == "collector-max-delay" or name == "configured-bandwidth" or name == "configured-foreign-member-count" or name == "configured-member-count" or name == "effective-bandwidth" or name == "iccp-group-id" or name == "inter-chassis" or name == "ipv4bfd-status" or name == "ipv6bfd-status" or name == "is-active" or name == "lacp-nonrevertive" or name == "lacp-status" or name == "link-order-status" or name == "load-balance-hash-type" or name == "load-balance-locality-threshold" or name == "mac-source" or name == "mac-source-member" or name == "maximize-threshold-value-band-width" or name == "maximize-threshold-value-links" or name == "maximum-active-links" or name == "maximum-active-links-source" or name == "minimum-active-links" or name == "minimum-bandwidth" or name == "mlacp-mode" or name == "mlacp-status" or name == "primary-member" or name == "recovery-delay" or name == "singleton" or name == "standby-member-count" or name == "suppression-timer" or name == "switchover-type" or name == "wait-while-timer"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "active-foreign-member-count"):
                                self.active_foreign_member_count = value
                                self.active_foreign_member_count.value_namespace = name_space
                                self.active_foreign_member_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "active-member-count"):
                                self.active_member_count = value
                                self.active_member_count.value_namespace = name_space
                                self.active_member_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "available-bandwidth"):
                                self.available_bandwidth = value
                                self.available_bandwidth.value_namespace = name_space
                                self.available_bandwidth.value_namespace_prefix = name_space_prefix
                            if(value_path == "bundle-interface-name"):
                                self.bundle_interface_name = value
                                self.bundle_interface_name.value_namespace = name_space
                                self.bundle_interface_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "bundle-status"):
                                self.bundle_status = value
                                self.bundle_status.value_namespace = name_space
                                self.bundle_status.value_namespace_prefix = name_space_prefix
                            if(value_path == "cisco-extensions"):
                                self.cisco_extensions = value
                                self.cisco_extensions.value_namespace = name_space
                                self.cisco_extensions.value_namespace_prefix = name_space_prefix
                            if(value_path == "collector-max-delay"):
                                self.collector_max_delay = value
                                self.collector_max_delay.value_namespace = name_space
                                self.collector_max_delay.value_namespace_prefix = name_space_prefix
                            if(value_path == "configured-bandwidth"):
                                self.configured_bandwidth = value
                                self.configured_bandwidth.value_namespace = name_space
                                self.configured_bandwidth.value_namespace_prefix = name_space_prefix
                            if(value_path == "configured-foreign-member-count"):
                                self.configured_foreign_member_count = value
                                self.configured_foreign_member_count.value_namespace = name_space
                                self.configured_foreign_member_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "configured-member-count"):
                                self.configured_member_count = value
                                self.configured_member_count.value_namespace = name_space
                                self.configured_member_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "effective-bandwidth"):
                                self.effective_bandwidth = value
                                self.effective_bandwidth.value_namespace = name_space
                                self.effective_bandwidth.value_namespace_prefix = name_space_prefix
                            if(value_path == "iccp-group-id"):
                                self.iccp_group_id = value
                                self.iccp_group_id.value_namespace = name_space
                                self.iccp_group_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "inter-chassis"):
                                self.inter_chassis = value
                                self.inter_chassis.value_namespace = name_space
                                self.inter_chassis.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4bfd-status"):
                                self.ipv4bfd_status = value
                                self.ipv4bfd_status.value_namespace = name_space
                                self.ipv4bfd_status.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6bfd-status"):
                                self.ipv6bfd_status = value
                                self.ipv6bfd_status.value_namespace = name_space
                                self.ipv6bfd_status.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-active"):
                                self.is_active = value
                                self.is_active.value_namespace = name_space
                                self.is_active.value_namespace_prefix = name_space_prefix
                            if(value_path == "lacp-nonrevertive"):
                                self.lacp_nonrevertive = value
                                self.lacp_nonrevertive.value_namespace = name_space
                                self.lacp_nonrevertive.value_namespace_prefix = name_space_prefix
                            if(value_path == "lacp-status"):
                                self.lacp_status = value
                                self.lacp_status.value_namespace = name_space
                                self.lacp_status.value_namespace_prefix = name_space_prefix
                            if(value_path == "link-order-status"):
                                self.link_order_status = value
                                self.link_order_status.value_namespace = name_space
                                self.link_order_status.value_namespace_prefix = name_space_prefix
                            if(value_path == "load-balance-hash-type"):
                                self.load_balance_hash_type = value
                                self.load_balance_hash_type.value_namespace = name_space
                                self.load_balance_hash_type.value_namespace_prefix = name_space_prefix
                            if(value_path == "load-balance-locality-threshold"):
                                self.load_balance_locality_threshold = value
                                self.load_balance_locality_threshold.value_namespace = name_space
                                self.load_balance_locality_threshold.value_namespace_prefix = name_space_prefix
                            if(value_path == "mac-source"):
                                self.mac_source = value
                                self.mac_source.value_namespace = name_space
                                self.mac_source.value_namespace_prefix = name_space_prefix
                            if(value_path == "mac-source-member"):
                                self.mac_source_member = value
                                self.mac_source_member.value_namespace = name_space
                                self.mac_source_member.value_namespace_prefix = name_space_prefix
                            if(value_path == "maximize-threshold-value-band-width"):
                                self.maximize_threshold_value_band_width = value
                                self.maximize_threshold_value_band_width.value_namespace = name_space
                                self.maximize_threshold_value_band_width.value_namespace_prefix = name_space_prefix
                            if(value_path == "maximize-threshold-value-links"):
                                self.maximize_threshold_value_links = value
                                self.maximize_threshold_value_links.value_namespace = name_space
                                self.maximize_threshold_value_links.value_namespace_prefix = name_space_prefix
                            if(value_path == "maximum-active-links"):
                                self.maximum_active_links = value
                                self.maximum_active_links.value_namespace = name_space
                                self.maximum_active_links.value_namespace_prefix = name_space_prefix
                            if(value_path == "maximum-active-links-source"):
                                self.maximum_active_links_source = value
                                self.maximum_active_links_source.value_namespace = name_space
                                self.maximum_active_links_source.value_namespace_prefix = name_space_prefix
                            if(value_path == "minimum-active-links"):
                                self.minimum_active_links = value
                                self.minimum_active_links.value_namespace = name_space
                                self.minimum_active_links.value_namespace_prefix = name_space_prefix
                            if(value_path == "minimum-bandwidth"):
                                self.minimum_bandwidth = value
                                self.minimum_bandwidth.value_namespace = name_space
                                self.minimum_bandwidth.value_namespace_prefix = name_space_prefix
                            if(value_path == "mlacp-mode"):
                                self.mlacp_mode = value
                                self.mlacp_mode.value_namespace = name_space
                                self.mlacp_mode.value_namespace_prefix = name_space_prefix
                            if(value_path == "mlacp-status"):
                                self.mlacp_status = value
                                self.mlacp_status.value_namespace = name_space
                                self.mlacp_status.value_namespace_prefix = name_space_prefix
                            if(value_path == "primary-member"):
                                self.primary_member = value
                                self.primary_member.value_namespace = name_space
                                self.primary_member.value_namespace_prefix = name_space_prefix
                            if(value_path == "recovery-delay"):
                                self.recovery_delay = value
                                self.recovery_delay.value_namespace = name_space
                                self.recovery_delay.value_namespace_prefix = name_space_prefix
                            if(value_path == "singleton"):
                                self.singleton = value
                                self.singleton.value_namespace = name_space
                                self.singleton.value_namespace_prefix = name_space_prefix
                            if(value_path == "standby-member-count"):
                                self.standby_member_count = value
                                self.standby_member_count.value_namespace = name_space
                                self.standby_member_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "suppression-timer"):
                                self.suppression_timer = value
                                self.suppression_timer.value_namespace = name_space
                                self.suppression_timer.value_namespace_prefix = name_space_prefix
                            if(value_path == "switchover-type"):
                                self.switchover_type = value
                                self.switchover_type.value_namespace = name_space
                                self.switchover_type.value_namespace_prefix = name_space_prefix
                            if(value_path == "wait-while-timer"):
                                self.wait_while_timer = value
                                self.wait_while_timer.value_namespace = name_space
                                self.wait_while_timer.value_namespace_prefix = name_space_prefix


                    class MemberData(Entity):
                        """
                        Member information
                        
                        .. attribute:: bandwidth
                        
                        	Bandwidth of this member (kbps)
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: kbit/s
                        
                        .. attribute:: counters
                        
                        	Counters data about member link
                        	**type**\:   :py:class:`Counters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.Bundle.BundleMembers.BundleMember.BundleMemberAncestor.MemberData.Counters>`
                        
                        .. attribute:: iccp_node
                        
                        	Location of member
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: interface_name
                        
                        	Member's interface name
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: link_data
                        
                        	Lacp data about member link
                        	**type**\:   :py:class:`LinkData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.Bundle.BundleMembers.BundleMember.BundleMemberAncestor.MemberData.LinkData>`
                        
                        .. attribute:: link_order_number
                        
                        	Member's link order number
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: mac_address
                        
                        	MAC address of this member (deprecated)
                        	**type**\:   :py:class:`MacAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.Bundle.BundleMembers.BundleMember.BundleMemberAncestor.MemberData.MacAddress>`
                        
                        .. attribute:: member_mux_data
                        
                        	Mux state machine data
                        	**type**\:   :py:class:`MemberMuxData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.Bundle.BundleMembers.BundleMember.BundleMemberAncestor.MemberData.MemberMuxData>`
                        
                        .. attribute:: member_name
                        
                        	Member's (short form) name
                        	**type**\:  str
                        
                        .. attribute:: member_type
                        
                        	Member's type (local/foreign)
                        	**type**\:   :py:class:`BmdMemberTypeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmdMemberTypeEnum>`
                        
                        .. attribute:: port_number
                        
                        	Member's link number
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: port_priority
                        
                        	The priority of this member
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: underlying_link_id
                        
                        	Member's underlying link ID
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'bundlemgr-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(BundleInformation.Bundle.BundleMembers.BundleMember.BundleMemberAncestor.MemberData, self).__init__()

                            self.yang_name = "member-data"
                            self.yang_parent_name = "bundle-member-ancestor"

                            self.bandwidth = YLeaf(YType.uint32, "bandwidth")

                            self.iccp_node = YLeaf(YType.uint32, "iccp-node")

                            self.interface_name = YLeaf(YType.str, "interface-name")

                            self.link_order_number = YLeaf(YType.uint16, "link-order-number")

                            self.member_name = YLeaf(YType.str, "member-name")

                            self.member_type = YLeaf(YType.enumeration, "member-type")

                            self.port_number = YLeaf(YType.uint16, "port-number")

                            self.port_priority = YLeaf(YType.uint16, "port-priority")

                            self.underlying_link_id = YLeaf(YType.uint16, "underlying-link-id")

                            self.counters = BundleInformation.Bundle.BundleMembers.BundleMember.BundleMemberAncestor.MemberData.Counters()
                            self.counters.parent = self
                            self._children_name_map["counters"] = "counters"
                            self._children_yang_names.add("counters")

                            self.link_data = BundleInformation.Bundle.BundleMembers.BundleMember.BundleMemberAncestor.MemberData.LinkData()
                            self.link_data.parent = self
                            self._children_name_map["link_data"] = "link-data"
                            self._children_yang_names.add("link-data")

                            self.mac_address = BundleInformation.Bundle.BundleMembers.BundleMember.BundleMemberAncestor.MemberData.MacAddress()
                            self.mac_address.parent = self
                            self._children_name_map["mac_address"] = "mac-address"
                            self._children_yang_names.add("mac-address")

                            self.member_mux_data = BundleInformation.Bundle.BundleMembers.BundleMember.BundleMemberAncestor.MemberData.MemberMuxData()
                            self.member_mux_data.parent = self
                            self._children_name_map["member_mux_data"] = "member-mux-data"
                            self._children_yang_names.add("member-mux-data")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("bandwidth",
                                            "iccp_node",
                                            "interface_name",
                                            "link_order_number",
                                            "member_name",
                                            "member_type",
                                            "port_number",
                                            "port_priority",
                                            "underlying_link_id") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(BundleInformation.Bundle.BundleMembers.BundleMember.BundleMemberAncestor.MemberData, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(BundleInformation.Bundle.BundleMembers.BundleMember.BundleMemberAncestor.MemberData, self).__setattr__(name, value)


                        class Counters(Entity):
                            """
                            Counters data about member link
                            
                            .. attribute:: defaulted
                            
                            	State flag set to Defaulted
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: excess_lacpd_us_received
                            
                            	LACPDUs received that exceed the rate limit
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: excess_marker_packets_received
                            
                            	Marker packets received that exceed the rate limit
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: expired
                            
                            	State flag set to Expired
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: illegal_packets_received
                            
                            	Illegal and unknown packets received
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: lacpd_us_received
                            
                            	LACPDUs received
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: lacpd_us_transmitted
                            
                            	LACPDUs transmitted
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: last_cleared_nsec
                            
                            	Last time counters cleared (nsec) (deprecated)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: last_cleared_sec
                            
                            	Last time counters cleared (s) (deprecated)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: marker_packets_received
                            
                            	Marker packets received
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: marker_responses_transmitted
                            
                            	Marker response packets transmitted
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'bundlemgr-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(BundleInformation.Bundle.BundleMembers.BundleMember.BundleMemberAncestor.MemberData.Counters, self).__init__()

                                self.yang_name = "counters"
                                self.yang_parent_name = "member-data"

                                self.defaulted = YLeaf(YType.uint32, "defaulted")

                                self.excess_lacpd_us_received = YLeaf(YType.uint32, "excess-lacpd-us-received")

                                self.excess_marker_packets_received = YLeaf(YType.uint32, "excess-marker-packets-received")

                                self.expired = YLeaf(YType.uint32, "expired")

                                self.illegal_packets_received = YLeaf(YType.uint32, "illegal-packets-received")

                                self.lacpd_us_received = YLeaf(YType.uint32, "lacpd-us-received")

                                self.lacpd_us_transmitted = YLeaf(YType.uint32, "lacpd-us-transmitted")

                                self.last_cleared_nsec = YLeaf(YType.uint32, "last-cleared-nsec")

                                self.last_cleared_sec = YLeaf(YType.uint32, "last-cleared-sec")

                                self.marker_packets_received = YLeaf(YType.uint32, "marker-packets-received")

                                self.marker_responses_transmitted = YLeaf(YType.uint32, "marker-responses-transmitted")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("defaulted",
                                                "excess_lacpd_us_received",
                                                "excess_marker_packets_received",
                                                "expired",
                                                "illegal_packets_received",
                                                "lacpd_us_received",
                                                "lacpd_us_transmitted",
                                                "last_cleared_nsec",
                                                "last_cleared_sec",
                                                "marker_packets_received",
                                                "marker_responses_transmitted") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(BundleInformation.Bundle.BundleMembers.BundleMember.BundleMemberAncestor.MemberData.Counters, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(BundleInformation.Bundle.BundleMembers.BundleMember.BundleMemberAncestor.MemberData.Counters, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.defaulted.is_set or
                                    self.excess_lacpd_us_received.is_set or
                                    self.excess_marker_packets_received.is_set or
                                    self.expired.is_set or
                                    self.illegal_packets_received.is_set or
                                    self.lacpd_us_received.is_set or
                                    self.lacpd_us_transmitted.is_set or
                                    self.last_cleared_nsec.is_set or
                                    self.last_cleared_sec.is_set or
                                    self.marker_packets_received.is_set or
                                    self.marker_responses_transmitted.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.defaulted.yfilter != YFilter.not_set or
                                    self.excess_lacpd_us_received.yfilter != YFilter.not_set or
                                    self.excess_marker_packets_received.yfilter != YFilter.not_set or
                                    self.expired.yfilter != YFilter.not_set or
                                    self.illegal_packets_received.yfilter != YFilter.not_set or
                                    self.lacpd_us_received.yfilter != YFilter.not_set or
                                    self.lacpd_us_transmitted.yfilter != YFilter.not_set or
                                    self.last_cleared_nsec.yfilter != YFilter.not_set or
                                    self.last_cleared_sec.yfilter != YFilter.not_set or
                                    self.marker_packets_received.yfilter != YFilter.not_set or
                                    self.marker_responses_transmitted.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "counters" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.defaulted.is_set or self.defaulted.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.defaulted.get_name_leafdata())
                                if (self.excess_lacpd_us_received.is_set or self.excess_lacpd_us_received.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.excess_lacpd_us_received.get_name_leafdata())
                                if (self.excess_marker_packets_received.is_set or self.excess_marker_packets_received.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.excess_marker_packets_received.get_name_leafdata())
                                if (self.expired.is_set or self.expired.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.expired.get_name_leafdata())
                                if (self.illegal_packets_received.is_set or self.illegal_packets_received.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.illegal_packets_received.get_name_leafdata())
                                if (self.lacpd_us_received.is_set or self.lacpd_us_received.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.lacpd_us_received.get_name_leafdata())
                                if (self.lacpd_us_transmitted.is_set or self.lacpd_us_transmitted.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.lacpd_us_transmitted.get_name_leafdata())
                                if (self.last_cleared_nsec.is_set or self.last_cleared_nsec.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.last_cleared_nsec.get_name_leafdata())
                                if (self.last_cleared_sec.is_set or self.last_cleared_sec.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.last_cleared_sec.get_name_leafdata())
                                if (self.marker_packets_received.is_set or self.marker_packets_received.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.marker_packets_received.get_name_leafdata())
                                if (self.marker_responses_transmitted.is_set or self.marker_responses_transmitted.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.marker_responses_transmitted.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "defaulted" or name == "excess-lacpd-us-received" or name == "excess-marker-packets-received" or name == "expired" or name == "illegal-packets-received" or name == "lacpd-us-received" or name == "lacpd-us-transmitted" or name == "last-cleared-nsec" or name == "last-cleared-sec" or name == "marker-packets-received" or name == "marker-responses-transmitted"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "defaulted"):
                                    self.defaulted = value
                                    self.defaulted.value_namespace = name_space
                                    self.defaulted.value_namespace_prefix = name_space_prefix
                                if(value_path == "excess-lacpd-us-received"):
                                    self.excess_lacpd_us_received = value
                                    self.excess_lacpd_us_received.value_namespace = name_space
                                    self.excess_lacpd_us_received.value_namespace_prefix = name_space_prefix
                                if(value_path == "excess-marker-packets-received"):
                                    self.excess_marker_packets_received = value
                                    self.excess_marker_packets_received.value_namespace = name_space
                                    self.excess_marker_packets_received.value_namespace_prefix = name_space_prefix
                                if(value_path == "expired"):
                                    self.expired = value
                                    self.expired.value_namespace = name_space
                                    self.expired.value_namespace_prefix = name_space_prefix
                                if(value_path == "illegal-packets-received"):
                                    self.illegal_packets_received = value
                                    self.illegal_packets_received.value_namespace = name_space
                                    self.illegal_packets_received.value_namespace_prefix = name_space_prefix
                                if(value_path == "lacpd-us-received"):
                                    self.lacpd_us_received = value
                                    self.lacpd_us_received.value_namespace = name_space
                                    self.lacpd_us_received.value_namespace_prefix = name_space_prefix
                                if(value_path == "lacpd-us-transmitted"):
                                    self.lacpd_us_transmitted = value
                                    self.lacpd_us_transmitted.value_namespace = name_space
                                    self.lacpd_us_transmitted.value_namespace_prefix = name_space_prefix
                                if(value_path == "last-cleared-nsec"):
                                    self.last_cleared_nsec = value
                                    self.last_cleared_nsec.value_namespace = name_space
                                    self.last_cleared_nsec.value_namespace_prefix = name_space_prefix
                                if(value_path == "last-cleared-sec"):
                                    self.last_cleared_sec = value
                                    self.last_cleared_sec.value_namespace = name_space
                                    self.last_cleared_sec.value_namespace_prefix = name_space_prefix
                                if(value_path == "marker-packets-received"):
                                    self.marker_packets_received = value
                                    self.marker_packets_received.value_namespace = name_space
                                    self.marker_packets_received.value_namespace_prefix = name_space_prefix
                                if(value_path == "marker-responses-transmitted"):
                                    self.marker_responses_transmitted = value
                                    self.marker_responses_transmitted.value_namespace = name_space
                                    self.marker_responses_transmitted.value_namespace_prefix = name_space_prefix


                        class LinkData(Entity):
                            """
                            Lacp data about member link
                            
                            .. attribute:: actor_operational_key
                            
                            	Operational key for this port
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: actor_port_id
                            
                            	Port number of this port
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: actor_port_priority
                            
                            	Priority of this port
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: actor_port_state
                            
                            	LACP state of this port
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: actor_system_mac_address
                            
                            	MAC Address of the actor system
                            	**type**\:  str
                            
                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                            
                            .. attribute:: actor_system_priority
                            
                            	System priority of actor system
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: attached_aggregator_id
                            
                            	MIB ifindex of attached bundle
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: interface_handle
                            
                            	Member's interface handle
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: partner_operational_key
                            
                            	Operational key for partner port
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: partner_port_id
                            
                            	Port number of the partner's port
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: partner_port_priority
                            
                            	Priority of the partner's port
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: partner_port_state
                            
                            	LACP state of the partner's port
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: partner_system_mac_address
                            
                            	MAC Address used to identify the partner system
                            	**type**\:  str
                            
                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                            
                            .. attribute:: partner_system_priority
                            
                            	System priority of partner system
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: selected_aggregator_id
                            
                            	MIB ifindex of selected bundle
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'bundlemgr-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(BundleInformation.Bundle.BundleMembers.BundleMember.BundleMemberAncestor.MemberData.LinkData, self).__init__()

                                self.yang_name = "link-data"
                                self.yang_parent_name = "member-data"

                                self.actor_operational_key = YLeaf(YType.uint16, "actor-operational-key")

                                self.actor_port_id = YLeaf(YType.uint16, "actor-port-id")

                                self.actor_port_priority = YLeaf(YType.uint16, "actor-port-priority")

                                self.actor_port_state = YLeaf(YType.uint8, "actor-port-state")

                                self.actor_system_mac_address = YLeaf(YType.str, "actor-system-mac-address")

                                self.actor_system_priority = YLeaf(YType.uint16, "actor-system-priority")

                                self.attached_aggregator_id = YLeaf(YType.uint32, "attached-aggregator-id")

                                self.interface_handle = YLeaf(YType.str, "interface-handle")

                                self.partner_operational_key = YLeaf(YType.uint16, "partner-operational-key")

                                self.partner_port_id = YLeaf(YType.uint16, "partner-port-id")

                                self.partner_port_priority = YLeaf(YType.uint16, "partner-port-priority")

                                self.partner_port_state = YLeaf(YType.uint8, "partner-port-state")

                                self.partner_system_mac_address = YLeaf(YType.str, "partner-system-mac-address")

                                self.partner_system_priority = YLeaf(YType.uint16, "partner-system-priority")

                                self.selected_aggregator_id = YLeaf(YType.uint32, "selected-aggregator-id")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("actor_operational_key",
                                                "actor_port_id",
                                                "actor_port_priority",
                                                "actor_port_state",
                                                "actor_system_mac_address",
                                                "actor_system_priority",
                                                "attached_aggregator_id",
                                                "interface_handle",
                                                "partner_operational_key",
                                                "partner_port_id",
                                                "partner_port_priority",
                                                "partner_port_state",
                                                "partner_system_mac_address",
                                                "partner_system_priority",
                                                "selected_aggregator_id") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(BundleInformation.Bundle.BundleMembers.BundleMember.BundleMemberAncestor.MemberData.LinkData, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(BundleInformation.Bundle.BundleMembers.BundleMember.BundleMemberAncestor.MemberData.LinkData, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.actor_operational_key.is_set or
                                    self.actor_port_id.is_set or
                                    self.actor_port_priority.is_set or
                                    self.actor_port_state.is_set or
                                    self.actor_system_mac_address.is_set or
                                    self.actor_system_priority.is_set or
                                    self.attached_aggregator_id.is_set or
                                    self.interface_handle.is_set or
                                    self.partner_operational_key.is_set or
                                    self.partner_port_id.is_set or
                                    self.partner_port_priority.is_set or
                                    self.partner_port_state.is_set or
                                    self.partner_system_mac_address.is_set or
                                    self.partner_system_priority.is_set or
                                    self.selected_aggregator_id.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.actor_operational_key.yfilter != YFilter.not_set or
                                    self.actor_port_id.yfilter != YFilter.not_set or
                                    self.actor_port_priority.yfilter != YFilter.not_set or
                                    self.actor_port_state.yfilter != YFilter.not_set or
                                    self.actor_system_mac_address.yfilter != YFilter.not_set or
                                    self.actor_system_priority.yfilter != YFilter.not_set or
                                    self.attached_aggregator_id.yfilter != YFilter.not_set or
                                    self.interface_handle.yfilter != YFilter.not_set or
                                    self.partner_operational_key.yfilter != YFilter.not_set or
                                    self.partner_port_id.yfilter != YFilter.not_set or
                                    self.partner_port_priority.yfilter != YFilter.not_set or
                                    self.partner_port_state.yfilter != YFilter.not_set or
                                    self.partner_system_mac_address.yfilter != YFilter.not_set or
                                    self.partner_system_priority.yfilter != YFilter.not_set or
                                    self.selected_aggregator_id.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "link-data" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.actor_operational_key.is_set or self.actor_operational_key.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.actor_operational_key.get_name_leafdata())
                                if (self.actor_port_id.is_set or self.actor_port_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.actor_port_id.get_name_leafdata())
                                if (self.actor_port_priority.is_set or self.actor_port_priority.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.actor_port_priority.get_name_leafdata())
                                if (self.actor_port_state.is_set or self.actor_port_state.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.actor_port_state.get_name_leafdata())
                                if (self.actor_system_mac_address.is_set or self.actor_system_mac_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.actor_system_mac_address.get_name_leafdata())
                                if (self.actor_system_priority.is_set or self.actor_system_priority.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.actor_system_priority.get_name_leafdata())
                                if (self.attached_aggregator_id.is_set or self.attached_aggregator_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.attached_aggregator_id.get_name_leafdata())
                                if (self.interface_handle.is_set or self.interface_handle.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.interface_handle.get_name_leafdata())
                                if (self.partner_operational_key.is_set or self.partner_operational_key.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.partner_operational_key.get_name_leafdata())
                                if (self.partner_port_id.is_set or self.partner_port_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.partner_port_id.get_name_leafdata())
                                if (self.partner_port_priority.is_set or self.partner_port_priority.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.partner_port_priority.get_name_leafdata())
                                if (self.partner_port_state.is_set or self.partner_port_state.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.partner_port_state.get_name_leafdata())
                                if (self.partner_system_mac_address.is_set or self.partner_system_mac_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.partner_system_mac_address.get_name_leafdata())
                                if (self.partner_system_priority.is_set or self.partner_system_priority.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.partner_system_priority.get_name_leafdata())
                                if (self.selected_aggregator_id.is_set or self.selected_aggregator_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.selected_aggregator_id.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "actor-operational-key" or name == "actor-port-id" or name == "actor-port-priority" or name == "actor-port-state" or name == "actor-system-mac-address" or name == "actor-system-priority" or name == "attached-aggregator-id" or name == "interface-handle" or name == "partner-operational-key" or name == "partner-port-id" or name == "partner-port-priority" or name == "partner-port-state" or name == "partner-system-mac-address" or name == "partner-system-priority" or name == "selected-aggregator-id"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "actor-operational-key"):
                                    self.actor_operational_key = value
                                    self.actor_operational_key.value_namespace = name_space
                                    self.actor_operational_key.value_namespace_prefix = name_space_prefix
                                if(value_path == "actor-port-id"):
                                    self.actor_port_id = value
                                    self.actor_port_id.value_namespace = name_space
                                    self.actor_port_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "actor-port-priority"):
                                    self.actor_port_priority = value
                                    self.actor_port_priority.value_namespace = name_space
                                    self.actor_port_priority.value_namespace_prefix = name_space_prefix
                                if(value_path == "actor-port-state"):
                                    self.actor_port_state = value
                                    self.actor_port_state.value_namespace = name_space
                                    self.actor_port_state.value_namespace_prefix = name_space_prefix
                                if(value_path == "actor-system-mac-address"):
                                    self.actor_system_mac_address = value
                                    self.actor_system_mac_address.value_namespace = name_space
                                    self.actor_system_mac_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "actor-system-priority"):
                                    self.actor_system_priority = value
                                    self.actor_system_priority.value_namespace = name_space
                                    self.actor_system_priority.value_namespace_prefix = name_space_prefix
                                if(value_path == "attached-aggregator-id"):
                                    self.attached_aggregator_id = value
                                    self.attached_aggregator_id.value_namespace = name_space
                                    self.attached_aggregator_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "interface-handle"):
                                    self.interface_handle = value
                                    self.interface_handle.value_namespace = name_space
                                    self.interface_handle.value_namespace_prefix = name_space_prefix
                                if(value_path == "partner-operational-key"):
                                    self.partner_operational_key = value
                                    self.partner_operational_key.value_namespace = name_space
                                    self.partner_operational_key.value_namespace_prefix = name_space_prefix
                                if(value_path == "partner-port-id"):
                                    self.partner_port_id = value
                                    self.partner_port_id.value_namespace = name_space
                                    self.partner_port_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "partner-port-priority"):
                                    self.partner_port_priority = value
                                    self.partner_port_priority.value_namespace = name_space
                                    self.partner_port_priority.value_namespace_prefix = name_space_prefix
                                if(value_path == "partner-port-state"):
                                    self.partner_port_state = value
                                    self.partner_port_state.value_namespace = name_space
                                    self.partner_port_state.value_namespace_prefix = name_space_prefix
                                if(value_path == "partner-system-mac-address"):
                                    self.partner_system_mac_address = value
                                    self.partner_system_mac_address.value_namespace = name_space
                                    self.partner_system_mac_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "partner-system-priority"):
                                    self.partner_system_priority = value
                                    self.partner_system_priority.value_namespace = name_space
                                    self.partner_system_priority.value_namespace_prefix = name_space_prefix
                                if(value_path == "selected-aggregator-id"):
                                    self.selected_aggregator_id = value
                                    self.selected_aggregator_id.value_namespace = name_space
                                    self.selected_aggregator_id.value_namespace_prefix = name_space_prefix


                        class MemberMuxData(Entity):
                            """
                            Mux state machine data
                            
                            .. attribute:: error
                            
                            	Internal value indicating if an error occurred trying to put a link into the desired state
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: member_mux_state_reason
                            
                            	Reason for last Mux state change
                            	**type**\:   :py:class:`BmMbrStateReason <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmMbrStateReason>`
                            
                            .. attribute:: member_mux_state_reason_data
                            
                            	Data regarding the reason for last Mux state change
                            	**type**\:   :py:class:`MemberMuxStateReasonData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.Bundle.BundleMembers.BundleMember.BundleMemberAncestor.MemberData.MemberMuxData.MemberMuxStateReasonData>`
                            
                            .. attribute:: member_state
                            
                            	Current internal state of this bundle member
                            	**type**\:   :py:class:`BmdMemberState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmdMemberState>`
                            
                            .. attribute:: mux_state
                            
                            	Current state of this bundle member
                            	**type**\:   :py:class:`BmMuxstate <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmMuxstate>`
                            
                            .. attribute:: mux_state_reason
                            
                            	Reason for last Mux state change (Deprecated)
                            	**type**\:   :py:class:`BmMuxreason <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmMuxreason>`
                            
                            

                            """

                            _prefix = 'bundlemgr-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(BundleInformation.Bundle.BundleMembers.BundleMember.BundleMemberAncestor.MemberData.MemberMuxData, self).__init__()

                                self.yang_name = "member-mux-data"
                                self.yang_parent_name = "member-data"

                                self.error = YLeaf(YType.uint32, "error")

                                self.member_mux_state_reason = YLeaf(YType.enumeration, "member-mux-state-reason")

                                self.member_state = YLeaf(YType.enumeration, "member-state")

                                self.mux_state = YLeaf(YType.enumeration, "mux-state")

                                self.mux_state_reason = YLeaf(YType.enumeration, "mux-state-reason")

                                self.member_mux_state_reason_data = BundleInformation.Bundle.BundleMembers.BundleMember.BundleMemberAncestor.MemberData.MemberMuxData.MemberMuxStateReasonData()
                                self.member_mux_state_reason_data.parent = self
                                self._children_name_map["member_mux_state_reason_data"] = "member-mux-state-reason-data"
                                self._children_yang_names.add("member-mux-state-reason-data")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("error",
                                                "member_mux_state_reason",
                                                "member_state",
                                                "mux_state",
                                                "mux_state_reason") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(BundleInformation.Bundle.BundleMembers.BundleMember.BundleMemberAncestor.MemberData.MemberMuxData, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(BundleInformation.Bundle.BundleMembers.BundleMember.BundleMemberAncestor.MemberData.MemberMuxData, self).__setattr__(name, value)


                            class MemberMuxStateReasonData(Entity):
                                """
                                Data regarding the reason for last Mux state
                                change
                                
                                .. attribute:: reason_type
                                
                                	The item the reason applies to
                                	**type**\:   :py:class:`BmStateReasonTarget <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmStateReasonTarget>`
                                
                                .. attribute:: severity
                                
                                	The severity of the reason
                                	**type**\:   :py:class:`BmSeverity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmSeverity>`
                                
                                

                                """

                                _prefix = 'bundlemgr-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(BundleInformation.Bundle.BundleMembers.BundleMember.BundleMemberAncestor.MemberData.MemberMuxData.MemberMuxStateReasonData, self).__init__()

                                    self.yang_name = "member-mux-state-reason-data"
                                    self.yang_parent_name = "member-mux-data"

                                    self.reason_type = YLeaf(YType.enumeration, "reason-type")

                                    self.severity = YLeaf(YType.enumeration, "severity")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("reason_type",
                                                    "severity") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(BundleInformation.Bundle.BundleMembers.BundleMember.BundleMemberAncestor.MemberData.MemberMuxData.MemberMuxStateReasonData, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(BundleInformation.Bundle.BundleMembers.BundleMember.BundleMemberAncestor.MemberData.MemberMuxData.MemberMuxStateReasonData, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.reason_type.is_set or
                                        self.severity.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.reason_type.yfilter != YFilter.not_set or
                                        self.severity.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "member-mux-state-reason-data" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.reason_type.is_set or self.reason_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.reason_type.get_name_leafdata())
                                    if (self.severity.is_set or self.severity.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.severity.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "reason-type" or name == "severity"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "reason-type"):
                                        self.reason_type = value
                                        self.reason_type.value_namespace = name_space
                                        self.reason_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "severity"):
                                        self.severity = value
                                        self.severity.value_namespace = name_space
                                        self.severity.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.error.is_set or
                                    self.member_mux_state_reason.is_set or
                                    self.member_state.is_set or
                                    self.mux_state.is_set or
                                    self.mux_state_reason.is_set or
                                    (self.member_mux_state_reason_data is not None and self.member_mux_state_reason_data.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.error.yfilter != YFilter.not_set or
                                    self.member_mux_state_reason.yfilter != YFilter.not_set or
                                    self.member_state.yfilter != YFilter.not_set or
                                    self.mux_state.yfilter != YFilter.not_set or
                                    self.mux_state_reason.yfilter != YFilter.not_set or
                                    (self.member_mux_state_reason_data is not None and self.member_mux_state_reason_data.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "member-mux-data" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.error.is_set or self.error.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.error.get_name_leafdata())
                                if (self.member_mux_state_reason.is_set or self.member_mux_state_reason.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.member_mux_state_reason.get_name_leafdata())
                                if (self.member_state.is_set or self.member_state.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.member_state.get_name_leafdata())
                                if (self.mux_state.is_set or self.mux_state.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mux_state.get_name_leafdata())
                                if (self.mux_state_reason.is_set or self.mux_state_reason.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mux_state_reason.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "member-mux-state-reason-data"):
                                    if (self.member_mux_state_reason_data is None):
                                        self.member_mux_state_reason_data = BundleInformation.Bundle.BundleMembers.BundleMember.BundleMemberAncestor.MemberData.MemberMuxData.MemberMuxStateReasonData()
                                        self.member_mux_state_reason_data.parent = self
                                        self._children_name_map["member_mux_state_reason_data"] = "member-mux-state-reason-data"
                                    return self.member_mux_state_reason_data

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "member-mux-state-reason-data" or name == "error" or name == "member-mux-state-reason" or name == "member-state" or name == "mux-state" or name == "mux-state-reason"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "error"):
                                    self.error = value
                                    self.error.value_namespace = name_space
                                    self.error.value_namespace_prefix = name_space_prefix
                                if(value_path == "member-mux-state-reason"):
                                    self.member_mux_state_reason = value
                                    self.member_mux_state_reason.value_namespace = name_space
                                    self.member_mux_state_reason.value_namespace_prefix = name_space_prefix
                                if(value_path == "member-state"):
                                    self.member_state = value
                                    self.member_state.value_namespace = name_space
                                    self.member_state.value_namespace_prefix = name_space_prefix
                                if(value_path == "mux-state"):
                                    self.mux_state = value
                                    self.mux_state.value_namespace = name_space
                                    self.mux_state.value_namespace_prefix = name_space_prefix
                                if(value_path == "mux-state-reason"):
                                    self.mux_state_reason = value
                                    self.mux_state_reason.value_namespace = name_space
                                    self.mux_state_reason.value_namespace_prefix = name_space_prefix


                        class MacAddress(Entity):
                            """
                            MAC address of this member (deprecated)
                            
                            .. attribute:: address
                            
                            	MAC address
                            	**type**\:  str
                            
                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                            
                            

                            """

                            _prefix = 'bundlemgr-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(BundleInformation.Bundle.BundleMembers.BundleMember.BundleMemberAncestor.MemberData.MacAddress, self).__init__()

                                self.yang_name = "mac-address"
                                self.yang_parent_name = "member-data"

                                self.address = YLeaf(YType.str, "address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(BundleInformation.Bundle.BundleMembers.BundleMember.BundleMemberAncestor.MemberData.MacAddress, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(BundleInformation.Bundle.BundleMembers.BundleMember.BundleMemberAncestor.MemberData.MacAddress, self).__setattr__(name, value)

                            def has_data(self):
                                return self.address.is_set

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "mac-address" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.address.is_set or self.address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "address"):
                                    self.address = value
                                    self.address.value_namespace = name_space
                                    self.address.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.bandwidth.is_set or
                                self.iccp_node.is_set or
                                self.interface_name.is_set or
                                self.link_order_number.is_set or
                                self.member_name.is_set or
                                self.member_type.is_set or
                                self.port_number.is_set or
                                self.port_priority.is_set or
                                self.underlying_link_id.is_set or
                                (self.counters is not None and self.counters.has_data()) or
                                (self.link_data is not None and self.link_data.has_data()) or
                                (self.mac_address is not None and self.mac_address.has_data()) or
                                (self.member_mux_data is not None and self.member_mux_data.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.bandwidth.yfilter != YFilter.not_set or
                                self.iccp_node.yfilter != YFilter.not_set or
                                self.interface_name.yfilter != YFilter.not_set or
                                self.link_order_number.yfilter != YFilter.not_set or
                                self.member_name.yfilter != YFilter.not_set or
                                self.member_type.yfilter != YFilter.not_set or
                                self.port_number.yfilter != YFilter.not_set or
                                self.port_priority.yfilter != YFilter.not_set or
                                self.underlying_link_id.yfilter != YFilter.not_set or
                                (self.counters is not None and self.counters.has_operation()) or
                                (self.link_data is not None and self.link_data.has_operation()) or
                                (self.mac_address is not None and self.mac_address.has_operation()) or
                                (self.member_mux_data is not None and self.member_mux_data.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "member-data" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.bandwidth.is_set or self.bandwidth.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.bandwidth.get_name_leafdata())
                            if (self.iccp_node.is_set or self.iccp_node.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.iccp_node.get_name_leafdata())
                            if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface_name.get_name_leafdata())
                            if (self.link_order_number.is_set or self.link_order_number.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.link_order_number.get_name_leafdata())
                            if (self.member_name.is_set or self.member_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.member_name.get_name_leafdata())
                            if (self.member_type.is_set or self.member_type.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.member_type.get_name_leafdata())
                            if (self.port_number.is_set or self.port_number.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.port_number.get_name_leafdata())
                            if (self.port_priority.is_set or self.port_priority.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.port_priority.get_name_leafdata())
                            if (self.underlying_link_id.is_set or self.underlying_link_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.underlying_link_id.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "counters"):
                                if (self.counters is None):
                                    self.counters = BundleInformation.Bundle.BundleMembers.BundleMember.BundleMemberAncestor.MemberData.Counters()
                                    self.counters.parent = self
                                    self._children_name_map["counters"] = "counters"
                                return self.counters

                            if (child_yang_name == "link-data"):
                                if (self.link_data is None):
                                    self.link_data = BundleInformation.Bundle.BundleMembers.BundleMember.BundleMemberAncestor.MemberData.LinkData()
                                    self.link_data.parent = self
                                    self._children_name_map["link_data"] = "link-data"
                                return self.link_data

                            if (child_yang_name == "mac-address"):
                                if (self.mac_address is None):
                                    self.mac_address = BundleInformation.Bundle.BundleMembers.BundleMember.BundleMemberAncestor.MemberData.MacAddress()
                                    self.mac_address.parent = self
                                    self._children_name_map["mac_address"] = "mac-address"
                                return self.mac_address

                            if (child_yang_name == "member-mux-data"):
                                if (self.member_mux_data is None):
                                    self.member_mux_data = BundleInformation.Bundle.BundleMembers.BundleMember.BundleMemberAncestor.MemberData.MemberMuxData()
                                    self.member_mux_data.parent = self
                                    self._children_name_map["member_mux_data"] = "member-mux-data"
                                return self.member_mux_data

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "counters" or name == "link-data" or name == "mac-address" or name == "member-mux-data" or name == "bandwidth" or name == "iccp-node" or name == "interface-name" or name == "link-order-number" or name == "member-name" or name == "member-type" or name == "port-number" or name == "port-priority" or name == "underlying-link-id"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "bandwidth"):
                                self.bandwidth = value
                                self.bandwidth.value_namespace = name_space
                                self.bandwidth.value_namespace_prefix = name_space_prefix
                            if(value_path == "iccp-node"):
                                self.iccp_node = value
                                self.iccp_node.value_namespace = name_space
                                self.iccp_node.value_namespace_prefix = name_space_prefix
                            if(value_path == "interface-name"):
                                self.interface_name = value
                                self.interface_name.value_namespace = name_space
                                self.interface_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "link-order-number"):
                                self.link_order_number = value
                                self.link_order_number.value_namespace = name_space
                                self.link_order_number.value_namespace_prefix = name_space_prefix
                            if(value_path == "member-name"):
                                self.member_name = value
                                self.member_name.value_namespace = name_space
                                self.member_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "member-type"):
                                self.member_type = value
                                self.member_type.value_namespace = name_space
                                self.member_type.value_namespace_prefix = name_space_prefix
                            if(value_path == "port-number"):
                                self.port_number = value
                                self.port_number.value_namespace = name_space
                                self.port_number.value_namespace_prefix = name_space_prefix
                            if(value_path == "port-priority"):
                                self.port_priority = value
                                self.port_priority.value_namespace = name_space
                                self.port_priority.value_namespace_prefix = name_space_prefix
                            if(value_path == "underlying-link-id"):
                                self.underlying_link_id = value
                                self.underlying_link_id.value_namespace = name_space
                                self.underlying_link_id.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.member_data:
                            if (c.has_data()):
                                return True
                        return (self.bundle_data is not None and self.bundle_data.has_data())

                    def has_operation(self):
                        for c in self.member_data:
                            if (c.has_operation()):
                                return True
                        return (
                            self.yfilter != YFilter.not_set or
                            (self.bundle_data is not None and self.bundle_data.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "bundle-member-ancestor" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "bundle-data"):
                            if (self.bundle_data is None):
                                self.bundle_data = BundleInformation.Bundle.BundleMembers.BundleMember.BundleMemberAncestor.BundleData()
                                self.bundle_data.parent = self
                                self._children_name_map["bundle_data"] = "bundle-data"
                            return self.bundle_data

                        if (child_yang_name == "member-data"):
                            for c in self.member_data:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = BundleInformation.Bundle.BundleMembers.BundleMember.BundleMemberAncestor.MemberData()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.member_data.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "bundle-data" or name == "member-data"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class BundleMemberItem(Entity):
                    """
                    Data for this item
                    
                    .. attribute:: bandwidth
                    
                    	Bandwidth of this member (kbps)
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: kbit/s
                    
                    .. attribute:: counters
                    
                    	Counters data about member link
                    	**type**\:   :py:class:`Counters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.Bundle.BundleMembers.BundleMember.BundleMemberItem.Counters>`
                    
                    .. attribute:: iccp_node
                    
                    	Location of member
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: interface_name
                    
                    	Member's interface name
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: link_data
                    
                    	Lacp data about member link
                    	**type**\:   :py:class:`LinkData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.Bundle.BundleMembers.BundleMember.BundleMemberItem.LinkData>`
                    
                    .. attribute:: link_order_number
                    
                    	Member's link order number
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: mac_address
                    
                    	MAC address of this member (deprecated)
                    	**type**\:   :py:class:`MacAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.Bundle.BundleMembers.BundleMember.BundleMemberItem.MacAddress>`
                    
                    .. attribute:: member_mux_data
                    
                    	Mux state machine data
                    	**type**\:   :py:class:`MemberMuxData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.Bundle.BundleMembers.BundleMember.BundleMemberItem.MemberMuxData>`
                    
                    .. attribute:: member_name
                    
                    	Member's (short form) name
                    	**type**\:  str
                    
                    .. attribute:: member_type
                    
                    	Member's type (local/foreign)
                    	**type**\:   :py:class:`BmdMemberTypeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmdMemberTypeEnum>`
                    
                    .. attribute:: port_number
                    
                    	Member's link number
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: port_priority
                    
                    	The priority of this member
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: underlying_link_id
                    
                    	Member's underlying link ID
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'bundlemgr-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(BundleInformation.Bundle.BundleMembers.BundleMember.BundleMemberItem, self).__init__()

                        self.yang_name = "bundle-member-item"
                        self.yang_parent_name = "bundle-member"

                        self.bandwidth = YLeaf(YType.uint32, "bandwidth")

                        self.iccp_node = YLeaf(YType.uint32, "iccp-node")

                        self.interface_name = YLeaf(YType.str, "interface-name")

                        self.link_order_number = YLeaf(YType.uint16, "link-order-number")

                        self.member_name = YLeaf(YType.str, "member-name")

                        self.member_type = YLeaf(YType.enumeration, "member-type")

                        self.port_number = YLeaf(YType.uint16, "port-number")

                        self.port_priority = YLeaf(YType.uint16, "port-priority")

                        self.underlying_link_id = YLeaf(YType.uint16, "underlying-link-id")

                        self.counters = BundleInformation.Bundle.BundleMembers.BundleMember.BundleMemberItem.Counters()
                        self.counters.parent = self
                        self._children_name_map["counters"] = "counters"
                        self._children_yang_names.add("counters")

                        self.link_data = BundleInformation.Bundle.BundleMembers.BundleMember.BundleMemberItem.LinkData()
                        self.link_data.parent = self
                        self._children_name_map["link_data"] = "link-data"
                        self._children_yang_names.add("link-data")

                        self.mac_address = BundleInformation.Bundle.BundleMembers.BundleMember.BundleMemberItem.MacAddress()
                        self.mac_address.parent = self
                        self._children_name_map["mac_address"] = "mac-address"
                        self._children_yang_names.add("mac-address")

                        self.member_mux_data = BundleInformation.Bundle.BundleMembers.BundleMember.BundleMemberItem.MemberMuxData()
                        self.member_mux_data.parent = self
                        self._children_name_map["member_mux_data"] = "member-mux-data"
                        self._children_yang_names.add("member-mux-data")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("bandwidth",
                                        "iccp_node",
                                        "interface_name",
                                        "link_order_number",
                                        "member_name",
                                        "member_type",
                                        "port_number",
                                        "port_priority",
                                        "underlying_link_id") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(BundleInformation.Bundle.BundleMembers.BundleMember.BundleMemberItem, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(BundleInformation.Bundle.BundleMembers.BundleMember.BundleMemberItem, self).__setattr__(name, value)


                    class Counters(Entity):
                        """
                        Counters data about member link
                        
                        .. attribute:: defaulted
                        
                        	State flag set to Defaulted
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: excess_lacpd_us_received
                        
                        	LACPDUs received that exceed the rate limit
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: excess_marker_packets_received
                        
                        	Marker packets received that exceed the rate limit
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: expired
                        
                        	State flag set to Expired
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: illegal_packets_received
                        
                        	Illegal and unknown packets received
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: lacpd_us_received
                        
                        	LACPDUs received
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: lacpd_us_transmitted
                        
                        	LACPDUs transmitted
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: last_cleared_nsec
                        
                        	Last time counters cleared (nsec) (deprecated)
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: last_cleared_sec
                        
                        	Last time counters cleared (s) (deprecated)
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: marker_packets_received
                        
                        	Marker packets received
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: marker_responses_transmitted
                        
                        	Marker response packets transmitted
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'bundlemgr-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(BundleInformation.Bundle.BundleMembers.BundleMember.BundleMemberItem.Counters, self).__init__()

                            self.yang_name = "counters"
                            self.yang_parent_name = "bundle-member-item"

                            self.defaulted = YLeaf(YType.uint32, "defaulted")

                            self.excess_lacpd_us_received = YLeaf(YType.uint32, "excess-lacpd-us-received")

                            self.excess_marker_packets_received = YLeaf(YType.uint32, "excess-marker-packets-received")

                            self.expired = YLeaf(YType.uint32, "expired")

                            self.illegal_packets_received = YLeaf(YType.uint32, "illegal-packets-received")

                            self.lacpd_us_received = YLeaf(YType.uint32, "lacpd-us-received")

                            self.lacpd_us_transmitted = YLeaf(YType.uint32, "lacpd-us-transmitted")

                            self.last_cleared_nsec = YLeaf(YType.uint32, "last-cleared-nsec")

                            self.last_cleared_sec = YLeaf(YType.uint32, "last-cleared-sec")

                            self.marker_packets_received = YLeaf(YType.uint32, "marker-packets-received")

                            self.marker_responses_transmitted = YLeaf(YType.uint32, "marker-responses-transmitted")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("defaulted",
                                            "excess_lacpd_us_received",
                                            "excess_marker_packets_received",
                                            "expired",
                                            "illegal_packets_received",
                                            "lacpd_us_received",
                                            "lacpd_us_transmitted",
                                            "last_cleared_nsec",
                                            "last_cleared_sec",
                                            "marker_packets_received",
                                            "marker_responses_transmitted") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(BundleInformation.Bundle.BundleMembers.BundleMember.BundleMemberItem.Counters, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(BundleInformation.Bundle.BundleMembers.BundleMember.BundleMemberItem.Counters, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.defaulted.is_set or
                                self.excess_lacpd_us_received.is_set or
                                self.excess_marker_packets_received.is_set or
                                self.expired.is_set or
                                self.illegal_packets_received.is_set or
                                self.lacpd_us_received.is_set or
                                self.lacpd_us_transmitted.is_set or
                                self.last_cleared_nsec.is_set or
                                self.last_cleared_sec.is_set or
                                self.marker_packets_received.is_set or
                                self.marker_responses_transmitted.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.defaulted.yfilter != YFilter.not_set or
                                self.excess_lacpd_us_received.yfilter != YFilter.not_set or
                                self.excess_marker_packets_received.yfilter != YFilter.not_set or
                                self.expired.yfilter != YFilter.not_set or
                                self.illegal_packets_received.yfilter != YFilter.not_set or
                                self.lacpd_us_received.yfilter != YFilter.not_set or
                                self.lacpd_us_transmitted.yfilter != YFilter.not_set or
                                self.last_cleared_nsec.yfilter != YFilter.not_set or
                                self.last_cleared_sec.yfilter != YFilter.not_set or
                                self.marker_packets_received.yfilter != YFilter.not_set or
                                self.marker_responses_transmitted.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "counters" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.defaulted.is_set or self.defaulted.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.defaulted.get_name_leafdata())
                            if (self.excess_lacpd_us_received.is_set or self.excess_lacpd_us_received.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.excess_lacpd_us_received.get_name_leafdata())
                            if (self.excess_marker_packets_received.is_set or self.excess_marker_packets_received.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.excess_marker_packets_received.get_name_leafdata())
                            if (self.expired.is_set or self.expired.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.expired.get_name_leafdata())
                            if (self.illegal_packets_received.is_set or self.illegal_packets_received.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.illegal_packets_received.get_name_leafdata())
                            if (self.lacpd_us_received.is_set or self.lacpd_us_received.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.lacpd_us_received.get_name_leafdata())
                            if (self.lacpd_us_transmitted.is_set or self.lacpd_us_transmitted.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.lacpd_us_transmitted.get_name_leafdata())
                            if (self.last_cleared_nsec.is_set or self.last_cleared_nsec.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.last_cleared_nsec.get_name_leafdata())
                            if (self.last_cleared_sec.is_set or self.last_cleared_sec.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.last_cleared_sec.get_name_leafdata())
                            if (self.marker_packets_received.is_set or self.marker_packets_received.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.marker_packets_received.get_name_leafdata())
                            if (self.marker_responses_transmitted.is_set or self.marker_responses_transmitted.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.marker_responses_transmitted.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "defaulted" or name == "excess-lacpd-us-received" or name == "excess-marker-packets-received" or name == "expired" or name == "illegal-packets-received" or name == "lacpd-us-received" or name == "lacpd-us-transmitted" or name == "last-cleared-nsec" or name == "last-cleared-sec" or name == "marker-packets-received" or name == "marker-responses-transmitted"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "defaulted"):
                                self.defaulted = value
                                self.defaulted.value_namespace = name_space
                                self.defaulted.value_namespace_prefix = name_space_prefix
                            if(value_path == "excess-lacpd-us-received"):
                                self.excess_lacpd_us_received = value
                                self.excess_lacpd_us_received.value_namespace = name_space
                                self.excess_lacpd_us_received.value_namespace_prefix = name_space_prefix
                            if(value_path == "excess-marker-packets-received"):
                                self.excess_marker_packets_received = value
                                self.excess_marker_packets_received.value_namespace = name_space
                                self.excess_marker_packets_received.value_namespace_prefix = name_space_prefix
                            if(value_path == "expired"):
                                self.expired = value
                                self.expired.value_namespace = name_space
                                self.expired.value_namespace_prefix = name_space_prefix
                            if(value_path == "illegal-packets-received"):
                                self.illegal_packets_received = value
                                self.illegal_packets_received.value_namespace = name_space
                                self.illegal_packets_received.value_namespace_prefix = name_space_prefix
                            if(value_path == "lacpd-us-received"):
                                self.lacpd_us_received = value
                                self.lacpd_us_received.value_namespace = name_space
                                self.lacpd_us_received.value_namespace_prefix = name_space_prefix
                            if(value_path == "lacpd-us-transmitted"):
                                self.lacpd_us_transmitted = value
                                self.lacpd_us_transmitted.value_namespace = name_space
                                self.lacpd_us_transmitted.value_namespace_prefix = name_space_prefix
                            if(value_path == "last-cleared-nsec"):
                                self.last_cleared_nsec = value
                                self.last_cleared_nsec.value_namespace = name_space
                                self.last_cleared_nsec.value_namespace_prefix = name_space_prefix
                            if(value_path == "last-cleared-sec"):
                                self.last_cleared_sec = value
                                self.last_cleared_sec.value_namespace = name_space
                                self.last_cleared_sec.value_namespace_prefix = name_space_prefix
                            if(value_path == "marker-packets-received"):
                                self.marker_packets_received = value
                                self.marker_packets_received.value_namespace = name_space
                                self.marker_packets_received.value_namespace_prefix = name_space_prefix
                            if(value_path == "marker-responses-transmitted"):
                                self.marker_responses_transmitted = value
                                self.marker_responses_transmitted.value_namespace = name_space
                                self.marker_responses_transmitted.value_namespace_prefix = name_space_prefix


                    class LinkData(Entity):
                        """
                        Lacp data about member link
                        
                        .. attribute:: actor_operational_key
                        
                        	Operational key for this port
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: actor_port_id
                        
                        	Port number of this port
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: actor_port_priority
                        
                        	Priority of this port
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: actor_port_state
                        
                        	LACP state of this port
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: actor_system_mac_address
                        
                        	MAC Address of the actor system
                        	**type**\:  str
                        
                        	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                        
                        .. attribute:: actor_system_priority
                        
                        	System priority of actor system
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: attached_aggregator_id
                        
                        	MIB ifindex of attached bundle
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: interface_handle
                        
                        	Member's interface handle
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: partner_operational_key
                        
                        	Operational key for partner port
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: partner_port_id
                        
                        	Port number of the partner's port
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: partner_port_priority
                        
                        	Priority of the partner's port
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: partner_port_state
                        
                        	LACP state of the partner's port
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: partner_system_mac_address
                        
                        	MAC Address used to identify the partner system
                        	**type**\:  str
                        
                        	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                        
                        .. attribute:: partner_system_priority
                        
                        	System priority of partner system
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: selected_aggregator_id
                        
                        	MIB ifindex of selected bundle
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'bundlemgr-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(BundleInformation.Bundle.BundleMembers.BundleMember.BundleMemberItem.LinkData, self).__init__()

                            self.yang_name = "link-data"
                            self.yang_parent_name = "bundle-member-item"

                            self.actor_operational_key = YLeaf(YType.uint16, "actor-operational-key")

                            self.actor_port_id = YLeaf(YType.uint16, "actor-port-id")

                            self.actor_port_priority = YLeaf(YType.uint16, "actor-port-priority")

                            self.actor_port_state = YLeaf(YType.uint8, "actor-port-state")

                            self.actor_system_mac_address = YLeaf(YType.str, "actor-system-mac-address")

                            self.actor_system_priority = YLeaf(YType.uint16, "actor-system-priority")

                            self.attached_aggregator_id = YLeaf(YType.uint32, "attached-aggregator-id")

                            self.interface_handle = YLeaf(YType.str, "interface-handle")

                            self.partner_operational_key = YLeaf(YType.uint16, "partner-operational-key")

                            self.partner_port_id = YLeaf(YType.uint16, "partner-port-id")

                            self.partner_port_priority = YLeaf(YType.uint16, "partner-port-priority")

                            self.partner_port_state = YLeaf(YType.uint8, "partner-port-state")

                            self.partner_system_mac_address = YLeaf(YType.str, "partner-system-mac-address")

                            self.partner_system_priority = YLeaf(YType.uint16, "partner-system-priority")

                            self.selected_aggregator_id = YLeaf(YType.uint32, "selected-aggregator-id")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("actor_operational_key",
                                            "actor_port_id",
                                            "actor_port_priority",
                                            "actor_port_state",
                                            "actor_system_mac_address",
                                            "actor_system_priority",
                                            "attached_aggregator_id",
                                            "interface_handle",
                                            "partner_operational_key",
                                            "partner_port_id",
                                            "partner_port_priority",
                                            "partner_port_state",
                                            "partner_system_mac_address",
                                            "partner_system_priority",
                                            "selected_aggregator_id") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(BundleInformation.Bundle.BundleMembers.BundleMember.BundleMemberItem.LinkData, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(BundleInformation.Bundle.BundleMembers.BundleMember.BundleMemberItem.LinkData, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.actor_operational_key.is_set or
                                self.actor_port_id.is_set or
                                self.actor_port_priority.is_set or
                                self.actor_port_state.is_set or
                                self.actor_system_mac_address.is_set or
                                self.actor_system_priority.is_set or
                                self.attached_aggregator_id.is_set or
                                self.interface_handle.is_set or
                                self.partner_operational_key.is_set or
                                self.partner_port_id.is_set or
                                self.partner_port_priority.is_set or
                                self.partner_port_state.is_set or
                                self.partner_system_mac_address.is_set or
                                self.partner_system_priority.is_set or
                                self.selected_aggregator_id.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.actor_operational_key.yfilter != YFilter.not_set or
                                self.actor_port_id.yfilter != YFilter.not_set or
                                self.actor_port_priority.yfilter != YFilter.not_set or
                                self.actor_port_state.yfilter != YFilter.not_set or
                                self.actor_system_mac_address.yfilter != YFilter.not_set or
                                self.actor_system_priority.yfilter != YFilter.not_set or
                                self.attached_aggregator_id.yfilter != YFilter.not_set or
                                self.interface_handle.yfilter != YFilter.not_set or
                                self.partner_operational_key.yfilter != YFilter.not_set or
                                self.partner_port_id.yfilter != YFilter.not_set or
                                self.partner_port_priority.yfilter != YFilter.not_set or
                                self.partner_port_state.yfilter != YFilter.not_set or
                                self.partner_system_mac_address.yfilter != YFilter.not_set or
                                self.partner_system_priority.yfilter != YFilter.not_set or
                                self.selected_aggregator_id.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "link-data" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.actor_operational_key.is_set or self.actor_operational_key.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.actor_operational_key.get_name_leafdata())
                            if (self.actor_port_id.is_set or self.actor_port_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.actor_port_id.get_name_leafdata())
                            if (self.actor_port_priority.is_set or self.actor_port_priority.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.actor_port_priority.get_name_leafdata())
                            if (self.actor_port_state.is_set or self.actor_port_state.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.actor_port_state.get_name_leafdata())
                            if (self.actor_system_mac_address.is_set or self.actor_system_mac_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.actor_system_mac_address.get_name_leafdata())
                            if (self.actor_system_priority.is_set or self.actor_system_priority.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.actor_system_priority.get_name_leafdata())
                            if (self.attached_aggregator_id.is_set or self.attached_aggregator_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.attached_aggregator_id.get_name_leafdata())
                            if (self.interface_handle.is_set or self.interface_handle.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface_handle.get_name_leafdata())
                            if (self.partner_operational_key.is_set or self.partner_operational_key.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.partner_operational_key.get_name_leafdata())
                            if (self.partner_port_id.is_set or self.partner_port_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.partner_port_id.get_name_leafdata())
                            if (self.partner_port_priority.is_set or self.partner_port_priority.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.partner_port_priority.get_name_leafdata())
                            if (self.partner_port_state.is_set or self.partner_port_state.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.partner_port_state.get_name_leafdata())
                            if (self.partner_system_mac_address.is_set or self.partner_system_mac_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.partner_system_mac_address.get_name_leafdata())
                            if (self.partner_system_priority.is_set or self.partner_system_priority.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.partner_system_priority.get_name_leafdata())
                            if (self.selected_aggregator_id.is_set or self.selected_aggregator_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.selected_aggregator_id.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "actor-operational-key" or name == "actor-port-id" or name == "actor-port-priority" or name == "actor-port-state" or name == "actor-system-mac-address" or name == "actor-system-priority" or name == "attached-aggregator-id" or name == "interface-handle" or name == "partner-operational-key" or name == "partner-port-id" or name == "partner-port-priority" or name == "partner-port-state" or name == "partner-system-mac-address" or name == "partner-system-priority" or name == "selected-aggregator-id"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "actor-operational-key"):
                                self.actor_operational_key = value
                                self.actor_operational_key.value_namespace = name_space
                                self.actor_operational_key.value_namespace_prefix = name_space_prefix
                            if(value_path == "actor-port-id"):
                                self.actor_port_id = value
                                self.actor_port_id.value_namespace = name_space
                                self.actor_port_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "actor-port-priority"):
                                self.actor_port_priority = value
                                self.actor_port_priority.value_namespace = name_space
                                self.actor_port_priority.value_namespace_prefix = name_space_prefix
                            if(value_path == "actor-port-state"):
                                self.actor_port_state = value
                                self.actor_port_state.value_namespace = name_space
                                self.actor_port_state.value_namespace_prefix = name_space_prefix
                            if(value_path == "actor-system-mac-address"):
                                self.actor_system_mac_address = value
                                self.actor_system_mac_address.value_namespace = name_space
                                self.actor_system_mac_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "actor-system-priority"):
                                self.actor_system_priority = value
                                self.actor_system_priority.value_namespace = name_space
                                self.actor_system_priority.value_namespace_prefix = name_space_prefix
                            if(value_path == "attached-aggregator-id"):
                                self.attached_aggregator_id = value
                                self.attached_aggregator_id.value_namespace = name_space
                                self.attached_aggregator_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "interface-handle"):
                                self.interface_handle = value
                                self.interface_handle.value_namespace = name_space
                                self.interface_handle.value_namespace_prefix = name_space_prefix
                            if(value_path == "partner-operational-key"):
                                self.partner_operational_key = value
                                self.partner_operational_key.value_namespace = name_space
                                self.partner_operational_key.value_namespace_prefix = name_space_prefix
                            if(value_path == "partner-port-id"):
                                self.partner_port_id = value
                                self.partner_port_id.value_namespace = name_space
                                self.partner_port_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "partner-port-priority"):
                                self.partner_port_priority = value
                                self.partner_port_priority.value_namespace = name_space
                                self.partner_port_priority.value_namespace_prefix = name_space_prefix
                            if(value_path == "partner-port-state"):
                                self.partner_port_state = value
                                self.partner_port_state.value_namespace = name_space
                                self.partner_port_state.value_namespace_prefix = name_space_prefix
                            if(value_path == "partner-system-mac-address"):
                                self.partner_system_mac_address = value
                                self.partner_system_mac_address.value_namespace = name_space
                                self.partner_system_mac_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "partner-system-priority"):
                                self.partner_system_priority = value
                                self.partner_system_priority.value_namespace = name_space
                                self.partner_system_priority.value_namespace_prefix = name_space_prefix
                            if(value_path == "selected-aggregator-id"):
                                self.selected_aggregator_id = value
                                self.selected_aggregator_id.value_namespace = name_space
                                self.selected_aggregator_id.value_namespace_prefix = name_space_prefix


                    class MemberMuxData(Entity):
                        """
                        Mux state machine data
                        
                        .. attribute:: error
                        
                        	Internal value indicating if an error occurred trying to put a link into the desired state
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: member_mux_state_reason
                        
                        	Reason for last Mux state change
                        	**type**\:   :py:class:`BmMbrStateReason <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmMbrStateReason>`
                        
                        .. attribute:: member_mux_state_reason_data
                        
                        	Data regarding the reason for last Mux state change
                        	**type**\:   :py:class:`MemberMuxStateReasonData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.Bundle.BundleMembers.BundleMember.BundleMemberItem.MemberMuxData.MemberMuxStateReasonData>`
                        
                        .. attribute:: member_state
                        
                        	Current internal state of this bundle member
                        	**type**\:   :py:class:`BmdMemberState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmdMemberState>`
                        
                        .. attribute:: mux_state
                        
                        	Current state of this bundle member
                        	**type**\:   :py:class:`BmMuxstate <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmMuxstate>`
                        
                        .. attribute:: mux_state_reason
                        
                        	Reason for last Mux state change (Deprecated)
                        	**type**\:   :py:class:`BmMuxreason <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmMuxreason>`
                        
                        

                        """

                        _prefix = 'bundlemgr-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(BundleInformation.Bundle.BundleMembers.BundleMember.BundleMemberItem.MemberMuxData, self).__init__()

                            self.yang_name = "member-mux-data"
                            self.yang_parent_name = "bundle-member-item"

                            self.error = YLeaf(YType.uint32, "error")

                            self.member_mux_state_reason = YLeaf(YType.enumeration, "member-mux-state-reason")

                            self.member_state = YLeaf(YType.enumeration, "member-state")

                            self.mux_state = YLeaf(YType.enumeration, "mux-state")

                            self.mux_state_reason = YLeaf(YType.enumeration, "mux-state-reason")

                            self.member_mux_state_reason_data = BundleInformation.Bundle.BundleMembers.BundleMember.BundleMemberItem.MemberMuxData.MemberMuxStateReasonData()
                            self.member_mux_state_reason_data.parent = self
                            self._children_name_map["member_mux_state_reason_data"] = "member-mux-state-reason-data"
                            self._children_yang_names.add("member-mux-state-reason-data")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("error",
                                            "member_mux_state_reason",
                                            "member_state",
                                            "mux_state",
                                            "mux_state_reason") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(BundleInformation.Bundle.BundleMembers.BundleMember.BundleMemberItem.MemberMuxData, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(BundleInformation.Bundle.BundleMembers.BundleMember.BundleMemberItem.MemberMuxData, self).__setattr__(name, value)


                        class MemberMuxStateReasonData(Entity):
                            """
                            Data regarding the reason for last Mux state
                            change
                            
                            .. attribute:: reason_type
                            
                            	The item the reason applies to
                            	**type**\:   :py:class:`BmStateReasonTarget <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmStateReasonTarget>`
                            
                            .. attribute:: severity
                            
                            	The severity of the reason
                            	**type**\:   :py:class:`BmSeverity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmSeverity>`
                            
                            

                            """

                            _prefix = 'bundlemgr-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(BundleInformation.Bundle.BundleMembers.BundleMember.BundleMemberItem.MemberMuxData.MemberMuxStateReasonData, self).__init__()

                                self.yang_name = "member-mux-state-reason-data"
                                self.yang_parent_name = "member-mux-data"

                                self.reason_type = YLeaf(YType.enumeration, "reason-type")

                                self.severity = YLeaf(YType.enumeration, "severity")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("reason_type",
                                                "severity") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(BundleInformation.Bundle.BundleMembers.BundleMember.BundleMemberItem.MemberMuxData.MemberMuxStateReasonData, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(BundleInformation.Bundle.BundleMembers.BundleMember.BundleMemberItem.MemberMuxData.MemberMuxStateReasonData, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.reason_type.is_set or
                                    self.severity.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.reason_type.yfilter != YFilter.not_set or
                                    self.severity.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "member-mux-state-reason-data" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.reason_type.is_set or self.reason_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.reason_type.get_name_leafdata())
                                if (self.severity.is_set or self.severity.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.severity.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "reason-type" or name == "severity"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "reason-type"):
                                    self.reason_type = value
                                    self.reason_type.value_namespace = name_space
                                    self.reason_type.value_namespace_prefix = name_space_prefix
                                if(value_path == "severity"):
                                    self.severity = value
                                    self.severity.value_namespace = name_space
                                    self.severity.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.error.is_set or
                                self.member_mux_state_reason.is_set or
                                self.member_state.is_set or
                                self.mux_state.is_set or
                                self.mux_state_reason.is_set or
                                (self.member_mux_state_reason_data is not None and self.member_mux_state_reason_data.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.error.yfilter != YFilter.not_set or
                                self.member_mux_state_reason.yfilter != YFilter.not_set or
                                self.member_state.yfilter != YFilter.not_set or
                                self.mux_state.yfilter != YFilter.not_set or
                                self.mux_state_reason.yfilter != YFilter.not_set or
                                (self.member_mux_state_reason_data is not None and self.member_mux_state_reason_data.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "member-mux-data" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.error.is_set or self.error.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.error.get_name_leafdata())
                            if (self.member_mux_state_reason.is_set or self.member_mux_state_reason.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.member_mux_state_reason.get_name_leafdata())
                            if (self.member_state.is_set or self.member_state.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.member_state.get_name_leafdata())
                            if (self.mux_state.is_set or self.mux_state.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mux_state.get_name_leafdata())
                            if (self.mux_state_reason.is_set or self.mux_state_reason.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mux_state_reason.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "member-mux-state-reason-data"):
                                if (self.member_mux_state_reason_data is None):
                                    self.member_mux_state_reason_data = BundleInformation.Bundle.BundleMembers.BundleMember.BundleMemberItem.MemberMuxData.MemberMuxStateReasonData()
                                    self.member_mux_state_reason_data.parent = self
                                    self._children_name_map["member_mux_state_reason_data"] = "member-mux-state-reason-data"
                                return self.member_mux_state_reason_data

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "member-mux-state-reason-data" or name == "error" or name == "member-mux-state-reason" or name == "member-state" or name == "mux-state" or name == "mux-state-reason"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "error"):
                                self.error = value
                                self.error.value_namespace = name_space
                                self.error.value_namespace_prefix = name_space_prefix
                            if(value_path == "member-mux-state-reason"):
                                self.member_mux_state_reason = value
                                self.member_mux_state_reason.value_namespace = name_space
                                self.member_mux_state_reason.value_namespace_prefix = name_space_prefix
                            if(value_path == "member-state"):
                                self.member_state = value
                                self.member_state.value_namespace = name_space
                                self.member_state.value_namespace_prefix = name_space_prefix
                            if(value_path == "mux-state"):
                                self.mux_state = value
                                self.mux_state.value_namespace = name_space
                                self.mux_state.value_namespace_prefix = name_space_prefix
                            if(value_path == "mux-state-reason"):
                                self.mux_state_reason = value
                                self.mux_state_reason.value_namespace = name_space
                                self.mux_state_reason.value_namespace_prefix = name_space_prefix


                    class MacAddress(Entity):
                        """
                        MAC address of this member (deprecated)
                        
                        .. attribute:: address
                        
                        	MAC address
                        	**type**\:  str
                        
                        	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                        
                        

                        """

                        _prefix = 'bundlemgr-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(BundleInformation.Bundle.BundleMembers.BundleMember.BundleMemberItem.MacAddress, self).__init__()

                            self.yang_name = "mac-address"
                            self.yang_parent_name = "bundle-member-item"

                            self.address = YLeaf(YType.str, "address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(BundleInformation.Bundle.BundleMembers.BundleMember.BundleMemberItem.MacAddress, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(BundleInformation.Bundle.BundleMembers.BundleMember.BundleMemberItem.MacAddress, self).__setattr__(name, value)

                        def has_data(self):
                            return self.address.is_set

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "mac-address" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.address.is_set or self.address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "address"):
                                self.address = value
                                self.address.value_namespace = name_space
                                self.address.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.bandwidth.is_set or
                            self.iccp_node.is_set or
                            self.interface_name.is_set or
                            self.link_order_number.is_set or
                            self.member_name.is_set or
                            self.member_type.is_set or
                            self.port_number.is_set or
                            self.port_priority.is_set or
                            self.underlying_link_id.is_set or
                            (self.counters is not None and self.counters.has_data()) or
                            (self.link_data is not None and self.link_data.has_data()) or
                            (self.mac_address is not None and self.mac_address.has_data()) or
                            (self.member_mux_data is not None and self.member_mux_data.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.bandwidth.yfilter != YFilter.not_set or
                            self.iccp_node.yfilter != YFilter.not_set or
                            self.interface_name.yfilter != YFilter.not_set or
                            self.link_order_number.yfilter != YFilter.not_set or
                            self.member_name.yfilter != YFilter.not_set or
                            self.member_type.yfilter != YFilter.not_set or
                            self.port_number.yfilter != YFilter.not_set or
                            self.port_priority.yfilter != YFilter.not_set or
                            self.underlying_link_id.yfilter != YFilter.not_set or
                            (self.counters is not None and self.counters.has_operation()) or
                            (self.link_data is not None and self.link_data.has_operation()) or
                            (self.mac_address is not None and self.mac_address.has_operation()) or
                            (self.member_mux_data is not None and self.member_mux_data.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "bundle-member-item" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.bandwidth.is_set or self.bandwidth.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bandwidth.get_name_leafdata())
                        if (self.iccp_node.is_set or self.iccp_node.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.iccp_node.get_name_leafdata())
                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_name.get_name_leafdata())
                        if (self.link_order_number.is_set or self.link_order_number.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.link_order_number.get_name_leafdata())
                        if (self.member_name.is_set or self.member_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.member_name.get_name_leafdata())
                        if (self.member_type.is_set or self.member_type.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.member_type.get_name_leafdata())
                        if (self.port_number.is_set or self.port_number.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.port_number.get_name_leafdata())
                        if (self.port_priority.is_set or self.port_priority.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.port_priority.get_name_leafdata())
                        if (self.underlying_link_id.is_set or self.underlying_link_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.underlying_link_id.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "counters"):
                            if (self.counters is None):
                                self.counters = BundleInformation.Bundle.BundleMembers.BundleMember.BundleMemberItem.Counters()
                                self.counters.parent = self
                                self._children_name_map["counters"] = "counters"
                            return self.counters

                        if (child_yang_name == "link-data"):
                            if (self.link_data is None):
                                self.link_data = BundleInformation.Bundle.BundleMembers.BundleMember.BundleMemberItem.LinkData()
                                self.link_data.parent = self
                                self._children_name_map["link_data"] = "link-data"
                            return self.link_data

                        if (child_yang_name == "mac-address"):
                            if (self.mac_address is None):
                                self.mac_address = BundleInformation.Bundle.BundleMembers.BundleMember.BundleMemberItem.MacAddress()
                                self.mac_address.parent = self
                                self._children_name_map["mac_address"] = "mac-address"
                            return self.mac_address

                        if (child_yang_name == "member-mux-data"):
                            if (self.member_mux_data is None):
                                self.member_mux_data = BundleInformation.Bundle.BundleMembers.BundleMember.BundleMemberItem.MemberMuxData()
                                self.member_mux_data.parent = self
                                self._children_name_map["member_mux_data"] = "member-mux-data"
                            return self.member_mux_data

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "counters" or name == "link-data" or name == "mac-address" or name == "member-mux-data" or name == "bandwidth" or name == "iccp-node" or name == "interface-name" or name == "link-order-number" or name == "member-name" or name == "member-type" or name == "port-number" or name == "port-priority" or name == "underlying-link-id"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "bandwidth"):
                            self.bandwidth = value
                            self.bandwidth.value_namespace = name_space
                            self.bandwidth.value_namespace_prefix = name_space_prefix
                        if(value_path == "iccp-node"):
                            self.iccp_node = value
                            self.iccp_node.value_namespace = name_space
                            self.iccp_node.value_namespace_prefix = name_space_prefix
                        if(value_path == "interface-name"):
                            self.interface_name = value
                            self.interface_name.value_namespace = name_space
                            self.interface_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "link-order-number"):
                            self.link_order_number = value
                            self.link_order_number.value_namespace = name_space
                            self.link_order_number.value_namespace_prefix = name_space_prefix
                        if(value_path == "member-name"):
                            self.member_name = value
                            self.member_name.value_namespace = name_space
                            self.member_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "member-type"):
                            self.member_type = value
                            self.member_type.value_namespace = name_space
                            self.member_type.value_namespace_prefix = name_space_prefix
                        if(value_path == "port-number"):
                            self.port_number = value
                            self.port_number.value_namespace = name_space
                            self.port_number.value_namespace_prefix = name_space_prefix
                        if(value_path == "port-priority"):
                            self.port_priority = value
                            self.port_priority.value_namespace = name_space
                            self.port_priority.value_namespace_prefix = name_space_prefix
                        if(value_path == "underlying-link-id"):
                            self.underlying_link_id = value
                            self.underlying_link_id.value_namespace = name_space
                            self.underlying_link_id.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    return (
                        self.member_interface.is_set or
                        (self.bundle_member_ancestor is not None and self.bundle_member_ancestor.has_data()) or
                        (self.bundle_member_item is not None and self.bundle_member_item.has_data()))

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.member_interface.yfilter != YFilter.not_set or
                        (self.bundle_member_ancestor is not None and self.bundle_member_ancestor.has_operation()) or
                        (self.bundle_member_item is not None and self.bundle_member_item.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "bundle-member" + "[member-interface='" + self.member_interface.get() + "']" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-bundlemgr-oper:bundle-information/bundle/bundle-members/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.member_interface.is_set or self.member_interface.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.member_interface.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "bundle-member-ancestor"):
                        if (self.bundle_member_ancestor is None):
                            self.bundle_member_ancestor = BundleInformation.Bundle.BundleMembers.BundleMember.BundleMemberAncestor()
                            self.bundle_member_ancestor.parent = self
                            self._children_name_map["bundle_member_ancestor"] = "bundle-member-ancestor"
                        return self.bundle_member_ancestor

                    if (child_yang_name == "bundle-member-item"):
                        if (self.bundle_member_item is None):
                            self.bundle_member_item = BundleInformation.Bundle.BundleMembers.BundleMember.BundleMemberItem()
                            self.bundle_member_item.parent = self
                            self._children_name_map["bundle_member_item"] = "bundle-member-item"
                        return self.bundle_member_item

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "bundle-member-ancestor" or name == "bundle-member-item" or name == "member-interface"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "member-interface"):
                        self.member_interface = value
                        self.member_interface.value_namespace = name_space
                        self.member_interface.value_namespace_prefix = name_space_prefix

            def has_data(self):
                for c in self.bundle_member:
                    if (c.has_data()):
                        return True
                return False

            def has_operation(self):
                for c in self.bundle_member:
                    if (c.has_operation()):
                        return True
                return self.yfilter != YFilter.not_set

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "bundle-members" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-bundlemgr-oper:bundle-information/bundle/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "bundle-member"):
                    for c in self.bundle_member:
                        segment = c.get_segment_path()
                        if (segment_path == segment):
                            return c
                    c = BundleInformation.Bundle.BundleMembers.BundleMember()
                    c.parent = self
                    local_reference_key = "ydk::seg::%s" % segment_path
                    self._local_refs[local_reference_key] = c
                    self.bundle_member.append(c)
                    return c

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "bundle-member"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                pass

        def has_data(self):
            return (
                (self.bundle_bundles is not None and self.bundle_bundles.has_data()) or
                (self.bundle_members is not None and self.bundle_members.has_data()))

        def has_operation(self):
            return (
                self.yfilter != YFilter.not_set or
                (self.bundle_bundles is not None and self.bundle_bundles.has_operation()) or
                (self.bundle_members is not None and self.bundle_members.has_operation()))

        def get_segment_path(self):
            path_buffer = ""
            path_buffer = "bundle" + path_buffer

            return path_buffer

        def get_entity_path(self, ancestor):
            path_buffer = ""
            if (ancestor is None):
                path_buffer = "Cisco-IOS-XR-bundlemgr-oper:bundle-information/%s" % self.get_segment_path()
            else:
                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

            leaf_name_data = LeafDataList()

            entity_path = EntityPath(path_buffer, leaf_name_data)
            return entity_path

        def get_child_by_name(self, child_yang_name, segment_path):
            child = self._get_child_by_seg_name([child_yang_name, segment_path])
            if child is not None:
                return child

            if (child_yang_name == "bundle-bundles"):
                if (self.bundle_bundles is None):
                    self.bundle_bundles = BundleInformation.Bundle.BundleBundles()
                    self.bundle_bundles.parent = self
                    self._children_name_map["bundle_bundles"] = "bundle-bundles"
                return self.bundle_bundles

            if (child_yang_name == "bundle-members"):
                if (self.bundle_members is None):
                    self.bundle_members = BundleInformation.Bundle.BundleMembers()
                    self.bundle_members.parent = self
                    self._children_name_map["bundle_members"] = "bundle-members"
                return self.bundle_members

            return None

        def has_leaf_or_child_of_name(self, name):
            if(name == "bundle-bundles" or name == "bundle-members"):
                return True
            return False

        def set_value(self, value_path, value, name_space, name_space_prefix):
            pass


    class EventsRg(Entity):
        """
        Bundle ICCP events information for bundles and
        members
        
        .. attribute:: events_rg_bundles
        
        	Bundle interfaces with ICCP events information
        	**type**\:   :py:class:`EventsRgBundles <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.EventsRg.EventsRgBundles>`
        
        .. attribute:: events_rg_iccp_groups
        
        	ICCP events for all ICCP Groups
        	**type**\:   :py:class:`EventsRgIccpGroups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.EventsRg.EventsRgIccpGroups>`
        
        .. attribute:: events_rg_members
        
        	Bundle Member interfaces with ICCP events information
        	**type**\:   :py:class:`EventsRgMembers <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.EventsRg.EventsRgMembers>`
        
        

        """

        _prefix = 'bundlemgr-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(BundleInformation.EventsRg, self).__init__()

            self.yang_name = "events-rg"
            self.yang_parent_name = "bundle-information"

            self.events_rg_bundles = BundleInformation.EventsRg.EventsRgBundles()
            self.events_rg_bundles.parent = self
            self._children_name_map["events_rg_bundles"] = "events-rg-bundles"
            self._children_yang_names.add("events-rg-bundles")

            self.events_rg_iccp_groups = BundleInformation.EventsRg.EventsRgIccpGroups()
            self.events_rg_iccp_groups.parent = self
            self._children_name_map["events_rg_iccp_groups"] = "events-rg-iccp-groups"
            self._children_yang_names.add("events-rg-iccp-groups")

            self.events_rg_members = BundleInformation.EventsRg.EventsRgMembers()
            self.events_rg_members.parent = self
            self._children_name_map["events_rg_members"] = "events-rg-members"
            self._children_yang_names.add("events-rg-members")


        class EventsRgMembers(Entity):
            """
            Bundle Member interfaces with ICCP events
            information
            
            .. attribute:: events_rg_member
            
            	Member interface
            	**type**\: list of    :py:class:`EventsRgMember <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.EventsRg.EventsRgMembers.EventsRgMember>`
            
            

            """

            _prefix = 'bundlemgr-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(BundleInformation.EventsRg.EventsRgMembers, self).__init__()

                self.yang_name = "events-rg-members"
                self.yang_parent_name = "events-rg"

                self.events_rg_member = YList(self)

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in () and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(BundleInformation.EventsRg.EventsRgMembers, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(BundleInformation.EventsRg.EventsRgMembers, self).__setattr__(name, value)


            class EventsRgMember(Entity):
                """
                Member interface
                
                .. attribute:: member_interface  <key>
                
                	Member interface
                	**type**\:  str
                
                .. attribute:: events_rg_member_ancestor
                
                	Data for this item and its parent bundle
                	**type**\:   :py:class:`EventsRgMemberAncestor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.EventsRg.EventsRgMembers.EventsRgMember.EventsRgMemberAncestor>`
                
                

                """

                _prefix = 'bundlemgr-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(BundleInformation.EventsRg.EventsRgMembers.EventsRgMember, self).__init__()

                    self.yang_name = "events-rg-member"
                    self.yang_parent_name = "events-rg-members"

                    self.member_interface = YLeaf(YType.str, "member-interface")

                    self.events_rg_member_ancestor = BundleInformation.EventsRg.EventsRgMembers.EventsRgMember.EventsRgMemberAncestor()
                    self.events_rg_member_ancestor.parent = self
                    self._children_name_map["events_rg_member_ancestor"] = "events-rg-member-ancestor"
                    self._children_yang_names.add("events-rg-member-ancestor")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("member_interface") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(BundleInformation.EventsRg.EventsRgMembers.EventsRgMember, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(BundleInformation.EventsRg.EventsRgMembers.EventsRgMember, self).__setattr__(name, value)


                class EventsRgMemberAncestor(Entity):
                    """
                    Data for this item and its parent bundle
                    
                    .. attribute:: item_name
                    
                    	Name for the current item to use
                    	**type**\:  str
                    
                    .. attribute:: items
                    
                    	Event items
                    	**type**\: list of    :py:class:`Items <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.EventsRg.EventsRgMembers.EventsRgMember.EventsRgMemberAncestor.Items>`
                    
                    

                    """

                    _prefix = 'bundlemgr-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(BundleInformation.EventsRg.EventsRgMembers.EventsRgMember.EventsRgMemberAncestor, self).__init__()

                        self.yang_name = "events-rg-member-ancestor"
                        self.yang_parent_name = "events-rg-member"

                        self.item_name = YLeaf(YType.str, "item-name")

                        self.items = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("item_name") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(BundleInformation.EventsRg.EventsRgMembers.EventsRgMember.EventsRgMemberAncestor, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(BundleInformation.EventsRg.EventsRgMembers.EventsRgMember.EventsRgMemberAncestor, self).__setattr__(name, value)


                    class Items(Entity):
                        """
                        Event items
                        
                        .. attribute:: bundle_evt_info
                        
                        	Event information for a bundle
                        	**type**\:   :py:class:`BundleEvtInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.EventsRg.EventsRgMembers.EventsRgMember.EventsRgMemberAncestor.Items.BundleEvtInfo>`
                        
                        .. attribute:: event_type
                        
                        	EventType
                        	**type**\:   :py:class:`BmdBagTarget <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmdBagTarget>`
                        
                        .. attribute:: member_evt_info
                        
                        	Event information for a member
                        	**type**\:   :py:class:`MemberEvtInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.EventsRg.EventsRgMembers.EventsRgMember.EventsRgMemberAncestor.Items.MemberEvtInfo>`
                        
                        .. attribute:: rg_evt_info
                        
                        	Event information for an RG
                        	**type**\:   :py:class:`RgEvtInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.EventsRg.EventsRgMembers.EventsRgMember.EventsRgMemberAncestor.Items.RgEvtInfo>`
                        
                        

                        """

                        _prefix = 'bundlemgr-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(BundleInformation.EventsRg.EventsRgMembers.EventsRgMember.EventsRgMemberAncestor.Items, self).__init__()

                            self.yang_name = "items"
                            self.yang_parent_name = "events-rg-member-ancestor"

                            self.event_type = YLeaf(YType.enumeration, "event-type")

                            self.bundle_evt_info = BundleInformation.EventsRg.EventsRgMembers.EventsRgMember.EventsRgMemberAncestor.Items.BundleEvtInfo()
                            self.bundle_evt_info.parent = self
                            self._children_name_map["bundle_evt_info"] = "bundle-evt-info"
                            self._children_yang_names.add("bundle-evt-info")

                            self.member_evt_info = BundleInformation.EventsRg.EventsRgMembers.EventsRgMember.EventsRgMemberAncestor.Items.MemberEvtInfo()
                            self.member_evt_info.parent = self
                            self._children_name_map["member_evt_info"] = "member-evt-info"
                            self._children_yang_names.add("member-evt-info")

                            self.rg_evt_info = BundleInformation.EventsRg.EventsRgMembers.EventsRgMember.EventsRgMemberAncestor.Items.RgEvtInfo()
                            self.rg_evt_info.parent = self
                            self._children_name_map["rg_evt_info"] = "rg-evt-info"
                            self._children_yang_names.add("rg-evt-info")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("event_type") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(BundleInformation.EventsRg.EventsRgMembers.EventsRgMember.EventsRgMemberAncestor.Items, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(BundleInformation.EventsRg.EventsRgMembers.EventsRgMember.EventsRgMemberAncestor.Items, self).__setattr__(name, value)


                        class MemberEvtInfo(Entity):
                            """
                            Event information for a member
                            
                            .. attribute:: data
                            
                            	Additional data for the event
                            	**type**\:   :py:class:`Data <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.EventsRg.EventsRgMembers.EventsRgMember.EventsRgMemberAncestor.Items.MemberEvtInfo.Data>`
                            
                            .. attribute:: member_event_type
                            
                            	Type of event for member
                            	**type**\:   :py:class:`BmdBagEventMbrItem <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmdBagEventMbrItem>`
                            
                            .. attribute:: time_stamp
                            
                            	Time stamp of the event
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            

                            """

                            _prefix = 'bundlemgr-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(BundleInformation.EventsRg.EventsRgMembers.EventsRgMember.EventsRgMemberAncestor.Items.MemberEvtInfo, self).__init__()

                                self.yang_name = "member-evt-info"
                                self.yang_parent_name = "items"

                                self.member_event_type = YLeaf(YType.enumeration, "member-event-type")

                                self.time_stamp = YLeaf(YType.uint64, "time-stamp")

                                self.data = BundleInformation.EventsRg.EventsRgMembers.EventsRgMember.EventsRgMemberAncestor.Items.MemberEvtInfo.Data()
                                self.data.parent = self
                                self._children_name_map["data"] = "data"
                                self._children_yang_names.add("data")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("member_event_type",
                                                "time_stamp") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(BundleInformation.EventsRg.EventsRgMembers.EventsRgMember.EventsRgMemberAncestor.Items.MemberEvtInfo, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(BundleInformation.EventsRg.EventsRgMembers.EventsRgMember.EventsRgMemberAncestor.Items.MemberEvtInfo, self).__setattr__(name, value)


                            class Data(Entity):
                                """
                                Additional data for the event
                                
                                .. attribute:: data_type
                                
                                	DataType
                                	**type**\:   :py:class:`BmdBagEventData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmdBagEventData>`
                                
                                .. attribute:: error
                                
                                	Error
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: no_data
                                
                                	NoData
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: string_data
                                
                                	StringData
                                	**type**\:  str
                                
                                

                                """

                                _prefix = 'bundlemgr-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(BundleInformation.EventsRg.EventsRgMembers.EventsRgMember.EventsRgMemberAncestor.Items.MemberEvtInfo.Data, self).__init__()

                                    self.yang_name = "data"
                                    self.yang_parent_name = "member-evt-info"

                                    self.data_type = YLeaf(YType.enumeration, "data-type")

                                    self.error = YLeaf(YType.uint32, "error")

                                    self.no_data = YLeaf(YType.uint8, "no-data")

                                    self.string_data = YLeaf(YType.str, "string-data")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("data_type",
                                                    "error",
                                                    "no_data",
                                                    "string_data") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(BundleInformation.EventsRg.EventsRgMembers.EventsRgMember.EventsRgMemberAncestor.Items.MemberEvtInfo.Data, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(BundleInformation.EventsRg.EventsRgMembers.EventsRgMember.EventsRgMemberAncestor.Items.MemberEvtInfo.Data, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.data_type.is_set or
                                        self.error.is_set or
                                        self.no_data.is_set or
                                        self.string_data.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.data_type.yfilter != YFilter.not_set or
                                        self.error.yfilter != YFilter.not_set or
                                        self.no_data.yfilter != YFilter.not_set or
                                        self.string_data.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "data" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.data_type.is_set or self.data_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.data_type.get_name_leafdata())
                                    if (self.error.is_set or self.error.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.error.get_name_leafdata())
                                    if (self.no_data.is_set or self.no_data.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.no_data.get_name_leafdata())
                                    if (self.string_data.is_set or self.string_data.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.string_data.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "data-type" or name == "error" or name == "no-data" or name == "string-data"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "data-type"):
                                        self.data_type = value
                                        self.data_type.value_namespace = name_space
                                        self.data_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "error"):
                                        self.error = value
                                        self.error.value_namespace = name_space
                                        self.error.value_namespace_prefix = name_space_prefix
                                    if(value_path == "no-data"):
                                        self.no_data = value
                                        self.no_data.value_namespace = name_space
                                        self.no_data.value_namespace_prefix = name_space_prefix
                                    if(value_path == "string-data"):
                                        self.string_data = value
                                        self.string_data.value_namespace = name_space
                                        self.string_data.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.member_event_type.is_set or
                                    self.time_stamp.is_set or
                                    (self.data is not None and self.data.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.member_event_type.yfilter != YFilter.not_set or
                                    self.time_stamp.yfilter != YFilter.not_set or
                                    (self.data is not None and self.data.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "member-evt-info" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.member_event_type.is_set or self.member_event_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.member_event_type.get_name_leafdata())
                                if (self.time_stamp.is_set or self.time_stamp.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.time_stamp.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "data"):
                                    if (self.data is None):
                                        self.data = BundleInformation.EventsRg.EventsRgMembers.EventsRgMember.EventsRgMemberAncestor.Items.MemberEvtInfo.Data()
                                        self.data.parent = self
                                        self._children_name_map["data"] = "data"
                                    return self.data

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "data" or name == "member-event-type" or name == "time-stamp"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "member-event-type"):
                                    self.member_event_type = value
                                    self.member_event_type.value_namespace = name_space
                                    self.member_event_type.value_namespace_prefix = name_space_prefix
                                if(value_path == "time-stamp"):
                                    self.time_stamp = value
                                    self.time_stamp.value_namespace = name_space
                                    self.time_stamp.value_namespace_prefix = name_space_prefix


                        class BundleEvtInfo(Entity):
                            """
                            Event information for a bundle
                            
                            .. attribute:: bundle_event_type
                            
                            	Type of event for bundle
                            	**type**\:   :py:class:`BmdBagEventBdlItem <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmdBagEventBdlItem>`
                            
                            .. attribute:: data
                            
                            	Additional data for the event
                            	**type**\:   :py:class:`Data <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.EventsRg.EventsRgMembers.EventsRgMember.EventsRgMemberAncestor.Items.BundleEvtInfo.Data>`
                            
                            .. attribute:: time_stamp
                            
                            	Time stamp of the event
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            

                            """

                            _prefix = 'bundlemgr-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(BundleInformation.EventsRg.EventsRgMembers.EventsRgMember.EventsRgMemberAncestor.Items.BundleEvtInfo, self).__init__()

                                self.yang_name = "bundle-evt-info"
                                self.yang_parent_name = "items"

                                self.bundle_event_type = YLeaf(YType.enumeration, "bundle-event-type")

                                self.time_stamp = YLeaf(YType.uint64, "time-stamp")

                                self.data = BundleInformation.EventsRg.EventsRgMembers.EventsRgMember.EventsRgMemberAncestor.Items.BundleEvtInfo.Data()
                                self.data.parent = self
                                self._children_name_map["data"] = "data"
                                self._children_yang_names.add("data")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("bundle_event_type",
                                                "time_stamp") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(BundleInformation.EventsRg.EventsRgMembers.EventsRgMember.EventsRgMemberAncestor.Items.BundleEvtInfo, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(BundleInformation.EventsRg.EventsRgMembers.EventsRgMember.EventsRgMemberAncestor.Items.BundleEvtInfo, self).__setattr__(name, value)


                            class Data(Entity):
                                """
                                Additional data for the event
                                
                                .. attribute:: data_type
                                
                                	DataType
                                	**type**\:   :py:class:`BmdBagEventData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmdBagEventData>`
                                
                                .. attribute:: error
                                
                                	Error
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: no_data
                                
                                	NoData
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: string_data
                                
                                	StringData
                                	**type**\:  str
                                
                                

                                """

                                _prefix = 'bundlemgr-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(BundleInformation.EventsRg.EventsRgMembers.EventsRgMember.EventsRgMemberAncestor.Items.BundleEvtInfo.Data, self).__init__()

                                    self.yang_name = "data"
                                    self.yang_parent_name = "bundle-evt-info"

                                    self.data_type = YLeaf(YType.enumeration, "data-type")

                                    self.error = YLeaf(YType.uint32, "error")

                                    self.no_data = YLeaf(YType.uint8, "no-data")

                                    self.string_data = YLeaf(YType.str, "string-data")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("data_type",
                                                    "error",
                                                    "no_data",
                                                    "string_data") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(BundleInformation.EventsRg.EventsRgMembers.EventsRgMember.EventsRgMemberAncestor.Items.BundleEvtInfo.Data, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(BundleInformation.EventsRg.EventsRgMembers.EventsRgMember.EventsRgMemberAncestor.Items.BundleEvtInfo.Data, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.data_type.is_set or
                                        self.error.is_set or
                                        self.no_data.is_set or
                                        self.string_data.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.data_type.yfilter != YFilter.not_set or
                                        self.error.yfilter != YFilter.not_set or
                                        self.no_data.yfilter != YFilter.not_set or
                                        self.string_data.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "data" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.data_type.is_set or self.data_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.data_type.get_name_leafdata())
                                    if (self.error.is_set or self.error.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.error.get_name_leafdata())
                                    if (self.no_data.is_set or self.no_data.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.no_data.get_name_leafdata())
                                    if (self.string_data.is_set or self.string_data.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.string_data.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "data-type" or name == "error" or name == "no-data" or name == "string-data"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "data-type"):
                                        self.data_type = value
                                        self.data_type.value_namespace = name_space
                                        self.data_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "error"):
                                        self.error = value
                                        self.error.value_namespace = name_space
                                        self.error.value_namespace_prefix = name_space_prefix
                                    if(value_path == "no-data"):
                                        self.no_data = value
                                        self.no_data.value_namespace = name_space
                                        self.no_data.value_namespace_prefix = name_space_prefix
                                    if(value_path == "string-data"):
                                        self.string_data = value
                                        self.string_data.value_namespace = name_space
                                        self.string_data.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.bundle_event_type.is_set or
                                    self.time_stamp.is_set or
                                    (self.data is not None and self.data.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.bundle_event_type.yfilter != YFilter.not_set or
                                    self.time_stamp.yfilter != YFilter.not_set or
                                    (self.data is not None and self.data.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "bundle-evt-info" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.bundle_event_type.is_set or self.bundle_event_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.bundle_event_type.get_name_leafdata())
                                if (self.time_stamp.is_set or self.time_stamp.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.time_stamp.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "data"):
                                    if (self.data is None):
                                        self.data = BundleInformation.EventsRg.EventsRgMembers.EventsRgMember.EventsRgMemberAncestor.Items.BundleEvtInfo.Data()
                                        self.data.parent = self
                                        self._children_name_map["data"] = "data"
                                    return self.data

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "data" or name == "bundle-event-type" or name == "time-stamp"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "bundle-event-type"):
                                    self.bundle_event_type = value
                                    self.bundle_event_type.value_namespace = name_space
                                    self.bundle_event_type.value_namespace_prefix = name_space_prefix
                                if(value_path == "time-stamp"):
                                    self.time_stamp = value
                                    self.time_stamp.value_namespace = name_space
                                    self.time_stamp.value_namespace_prefix = name_space_prefix


                        class RgEvtInfo(Entity):
                            """
                            Event information for an RG
                            
                            .. attribute:: data
                            
                            	Additional data for the event
                            	**type**\:   :py:class:`Data <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.EventsRg.EventsRgMembers.EventsRgMember.EventsRgMemberAncestor.Items.RgEvtInfo.Data>`
                            
                            .. attribute:: rg_event_type
                            
                            	Type of event for RG
                            	**type**\:   :py:class:`BmdBagEventRgItem <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmdBagEventRgItem>`
                            
                            .. attribute:: time_stamp
                            
                            	Time stamp of the event
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            

                            """

                            _prefix = 'bundlemgr-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(BundleInformation.EventsRg.EventsRgMembers.EventsRgMember.EventsRgMemberAncestor.Items.RgEvtInfo, self).__init__()

                                self.yang_name = "rg-evt-info"
                                self.yang_parent_name = "items"

                                self.rg_event_type = YLeaf(YType.enumeration, "rg-event-type")

                                self.time_stamp = YLeaf(YType.uint64, "time-stamp")

                                self.data = BundleInformation.EventsRg.EventsRgMembers.EventsRgMember.EventsRgMemberAncestor.Items.RgEvtInfo.Data()
                                self.data.parent = self
                                self._children_name_map["data"] = "data"
                                self._children_yang_names.add("data")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("rg_event_type",
                                                "time_stamp") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(BundleInformation.EventsRg.EventsRgMembers.EventsRgMember.EventsRgMemberAncestor.Items.RgEvtInfo, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(BundleInformation.EventsRg.EventsRgMembers.EventsRgMember.EventsRgMemberAncestor.Items.RgEvtInfo, self).__setattr__(name, value)


                            class Data(Entity):
                                """
                                Additional data for the event
                                
                                .. attribute:: data_type
                                
                                	DataType
                                	**type**\:   :py:class:`BmdBagEventData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmdBagEventData>`
                                
                                .. attribute:: error
                                
                                	Error
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: no_data
                                
                                	NoData
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: string_data
                                
                                	StringData
                                	**type**\:  str
                                
                                

                                """

                                _prefix = 'bundlemgr-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(BundleInformation.EventsRg.EventsRgMembers.EventsRgMember.EventsRgMemberAncestor.Items.RgEvtInfo.Data, self).__init__()

                                    self.yang_name = "data"
                                    self.yang_parent_name = "rg-evt-info"

                                    self.data_type = YLeaf(YType.enumeration, "data-type")

                                    self.error = YLeaf(YType.uint32, "error")

                                    self.no_data = YLeaf(YType.uint8, "no-data")

                                    self.string_data = YLeaf(YType.str, "string-data")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("data_type",
                                                    "error",
                                                    "no_data",
                                                    "string_data") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(BundleInformation.EventsRg.EventsRgMembers.EventsRgMember.EventsRgMemberAncestor.Items.RgEvtInfo.Data, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(BundleInformation.EventsRg.EventsRgMembers.EventsRgMember.EventsRgMemberAncestor.Items.RgEvtInfo.Data, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.data_type.is_set or
                                        self.error.is_set or
                                        self.no_data.is_set or
                                        self.string_data.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.data_type.yfilter != YFilter.not_set or
                                        self.error.yfilter != YFilter.not_set or
                                        self.no_data.yfilter != YFilter.not_set or
                                        self.string_data.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "data" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.data_type.is_set or self.data_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.data_type.get_name_leafdata())
                                    if (self.error.is_set or self.error.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.error.get_name_leafdata())
                                    if (self.no_data.is_set or self.no_data.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.no_data.get_name_leafdata())
                                    if (self.string_data.is_set or self.string_data.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.string_data.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "data-type" or name == "error" or name == "no-data" or name == "string-data"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "data-type"):
                                        self.data_type = value
                                        self.data_type.value_namespace = name_space
                                        self.data_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "error"):
                                        self.error = value
                                        self.error.value_namespace = name_space
                                        self.error.value_namespace_prefix = name_space_prefix
                                    if(value_path == "no-data"):
                                        self.no_data = value
                                        self.no_data.value_namespace = name_space
                                        self.no_data.value_namespace_prefix = name_space_prefix
                                    if(value_path == "string-data"):
                                        self.string_data = value
                                        self.string_data.value_namespace = name_space
                                        self.string_data.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.rg_event_type.is_set or
                                    self.time_stamp.is_set or
                                    (self.data is not None and self.data.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.rg_event_type.yfilter != YFilter.not_set or
                                    self.time_stamp.yfilter != YFilter.not_set or
                                    (self.data is not None and self.data.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "rg-evt-info" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.rg_event_type.is_set or self.rg_event_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.rg_event_type.get_name_leafdata())
                                if (self.time_stamp.is_set or self.time_stamp.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.time_stamp.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "data"):
                                    if (self.data is None):
                                        self.data = BundleInformation.EventsRg.EventsRgMembers.EventsRgMember.EventsRgMemberAncestor.Items.RgEvtInfo.Data()
                                        self.data.parent = self
                                        self._children_name_map["data"] = "data"
                                    return self.data

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "data" or name == "rg-event-type" or name == "time-stamp"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "rg-event-type"):
                                    self.rg_event_type = value
                                    self.rg_event_type.value_namespace = name_space
                                    self.rg_event_type.value_namespace_prefix = name_space_prefix
                                if(value_path == "time-stamp"):
                                    self.time_stamp = value
                                    self.time_stamp.value_namespace = name_space
                                    self.time_stamp.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.event_type.is_set or
                                (self.bundle_evt_info is not None and self.bundle_evt_info.has_data()) or
                                (self.member_evt_info is not None and self.member_evt_info.has_data()) or
                                (self.rg_evt_info is not None and self.rg_evt_info.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.event_type.yfilter != YFilter.not_set or
                                (self.bundle_evt_info is not None and self.bundle_evt_info.has_operation()) or
                                (self.member_evt_info is not None and self.member_evt_info.has_operation()) or
                                (self.rg_evt_info is not None and self.rg_evt_info.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "items" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.event_type.is_set or self.event_type.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.event_type.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "bundle-evt-info"):
                                if (self.bundle_evt_info is None):
                                    self.bundle_evt_info = BundleInformation.EventsRg.EventsRgMembers.EventsRgMember.EventsRgMemberAncestor.Items.BundleEvtInfo()
                                    self.bundle_evt_info.parent = self
                                    self._children_name_map["bundle_evt_info"] = "bundle-evt-info"
                                return self.bundle_evt_info

                            if (child_yang_name == "member-evt-info"):
                                if (self.member_evt_info is None):
                                    self.member_evt_info = BundleInformation.EventsRg.EventsRgMembers.EventsRgMember.EventsRgMemberAncestor.Items.MemberEvtInfo()
                                    self.member_evt_info.parent = self
                                    self._children_name_map["member_evt_info"] = "member-evt-info"
                                return self.member_evt_info

                            if (child_yang_name == "rg-evt-info"):
                                if (self.rg_evt_info is None):
                                    self.rg_evt_info = BundleInformation.EventsRg.EventsRgMembers.EventsRgMember.EventsRgMemberAncestor.Items.RgEvtInfo()
                                    self.rg_evt_info.parent = self
                                    self._children_name_map["rg_evt_info"] = "rg-evt-info"
                                return self.rg_evt_info

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "bundle-evt-info" or name == "member-evt-info" or name == "rg-evt-info" or name == "event-type"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "event-type"):
                                self.event_type = value
                                self.event_type.value_namespace = name_space
                                self.event_type.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.items:
                            if (c.has_data()):
                                return True
                        return self.item_name.is_set

                    def has_operation(self):
                        for c in self.items:
                            if (c.has_operation()):
                                return True
                        return (
                            self.yfilter != YFilter.not_set or
                            self.item_name.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "events-rg-member-ancestor" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.item_name.is_set or self.item_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.item_name.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "items"):
                            for c in self.items:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = BundleInformation.EventsRg.EventsRgMembers.EventsRgMember.EventsRgMemberAncestor.Items()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.items.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "items" or name == "item-name"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "item-name"):
                            self.item_name = value
                            self.item_name.value_namespace = name_space
                            self.item_name.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    return (
                        self.member_interface.is_set or
                        (self.events_rg_member_ancestor is not None and self.events_rg_member_ancestor.has_data()))

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.member_interface.yfilter != YFilter.not_set or
                        (self.events_rg_member_ancestor is not None and self.events_rg_member_ancestor.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "events-rg-member" + "[member-interface='" + self.member_interface.get() + "']" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-bundlemgr-oper:bundle-information/events-rg/events-rg-members/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.member_interface.is_set or self.member_interface.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.member_interface.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "events-rg-member-ancestor"):
                        if (self.events_rg_member_ancestor is None):
                            self.events_rg_member_ancestor = BundleInformation.EventsRg.EventsRgMembers.EventsRgMember.EventsRgMemberAncestor()
                            self.events_rg_member_ancestor.parent = self
                            self._children_name_map["events_rg_member_ancestor"] = "events-rg-member-ancestor"
                        return self.events_rg_member_ancestor

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "events-rg-member-ancestor" or name == "member-interface"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "member-interface"):
                        self.member_interface = value
                        self.member_interface.value_namespace = name_space
                        self.member_interface.value_namespace_prefix = name_space_prefix

            def has_data(self):
                for c in self.events_rg_member:
                    if (c.has_data()):
                        return True
                return False

            def has_operation(self):
                for c in self.events_rg_member:
                    if (c.has_operation()):
                        return True
                return self.yfilter != YFilter.not_set

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "events-rg-members" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-bundlemgr-oper:bundle-information/events-rg/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "events-rg-member"):
                    for c in self.events_rg_member:
                        segment = c.get_segment_path()
                        if (segment_path == segment):
                            return c
                    c = BundleInformation.EventsRg.EventsRgMembers.EventsRgMember()
                    c.parent = self
                    local_reference_key = "ydk::seg::%s" % segment_path
                    self._local_refs[local_reference_key] = c
                    self.events_rg_member.append(c)
                    return c

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "events-rg-member"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                pass


        class EventsRgIccpGroups(Entity):
            """
            ICCP events for all ICCP Groups
            
            .. attribute:: events_rg_iccp_group
            
            	ICCP Group ID
            	**type**\: list of    :py:class:`EventsRgIccpGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.EventsRg.EventsRgIccpGroups.EventsRgIccpGroup>`
            
            

            """

            _prefix = 'bundlemgr-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(BundleInformation.EventsRg.EventsRgIccpGroups, self).__init__()

                self.yang_name = "events-rg-iccp-groups"
                self.yang_parent_name = "events-rg"

                self.events_rg_iccp_group = YList(self)

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in () and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(BundleInformation.EventsRg.EventsRgIccpGroups, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(BundleInformation.EventsRg.EventsRgIccpGroups, self).__setattr__(name, value)


            class EventsRgIccpGroup(Entity):
                """
                ICCP Group ID
                
                .. attribute:: iccp_group  <key>
                
                	ICCP Group ID
                	**type**\:  int
                
                	**range:** 1..4294967295
                
                .. attribute:: events_rg_bundle_item_iccp_group
                
                	Data for this item
                	**type**\:   :py:class:`EventsRgBundleItemIccpGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.EventsRg.EventsRgIccpGroups.EventsRgIccpGroup.EventsRgBundleItemIccpGroup>`
                
                

                """

                _prefix = 'bundlemgr-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(BundleInformation.EventsRg.EventsRgIccpGroups.EventsRgIccpGroup, self).__init__()

                    self.yang_name = "events-rg-iccp-group"
                    self.yang_parent_name = "events-rg-iccp-groups"

                    self.iccp_group = YLeaf(YType.uint32, "iccp-group")

                    self.events_rg_bundle_item_iccp_group = BundleInformation.EventsRg.EventsRgIccpGroups.EventsRgIccpGroup.EventsRgBundleItemIccpGroup()
                    self.events_rg_bundle_item_iccp_group.parent = self
                    self._children_name_map["events_rg_bundle_item_iccp_group"] = "events-rg-bundle-item-iccp-group"
                    self._children_yang_names.add("events-rg-bundle-item-iccp-group")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("iccp_group") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(BundleInformation.EventsRg.EventsRgIccpGroups.EventsRgIccpGroup, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(BundleInformation.EventsRg.EventsRgIccpGroups.EventsRgIccpGroup, self).__setattr__(name, value)


                class EventsRgBundleItemIccpGroup(Entity):
                    """
                    Data for this item
                    
                    .. attribute:: item_name
                    
                    	Name for the current item to use
                    	**type**\:  str
                    
                    .. attribute:: items
                    
                    	Event items
                    	**type**\: list of    :py:class:`Items <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.EventsRg.EventsRgIccpGroups.EventsRgIccpGroup.EventsRgBundleItemIccpGroup.Items>`
                    
                    

                    """

                    _prefix = 'bundlemgr-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(BundleInformation.EventsRg.EventsRgIccpGroups.EventsRgIccpGroup.EventsRgBundleItemIccpGroup, self).__init__()

                        self.yang_name = "events-rg-bundle-item-iccp-group"
                        self.yang_parent_name = "events-rg-iccp-group"

                        self.item_name = YLeaf(YType.str, "item-name")

                        self.items = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("item_name") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(BundleInformation.EventsRg.EventsRgIccpGroups.EventsRgIccpGroup.EventsRgBundleItemIccpGroup, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(BundleInformation.EventsRg.EventsRgIccpGroups.EventsRgIccpGroup.EventsRgBundleItemIccpGroup, self).__setattr__(name, value)


                    class Items(Entity):
                        """
                        Event items
                        
                        .. attribute:: bundle_evt_info
                        
                        	Event information for a bundle
                        	**type**\:   :py:class:`BundleEvtInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.EventsRg.EventsRgIccpGroups.EventsRgIccpGroup.EventsRgBundleItemIccpGroup.Items.BundleEvtInfo>`
                        
                        .. attribute:: event_type
                        
                        	EventType
                        	**type**\:   :py:class:`BmdBagTarget <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmdBagTarget>`
                        
                        .. attribute:: member_evt_info
                        
                        	Event information for a member
                        	**type**\:   :py:class:`MemberEvtInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.EventsRg.EventsRgIccpGroups.EventsRgIccpGroup.EventsRgBundleItemIccpGroup.Items.MemberEvtInfo>`
                        
                        .. attribute:: rg_evt_info
                        
                        	Event information for an RG
                        	**type**\:   :py:class:`RgEvtInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.EventsRg.EventsRgIccpGroups.EventsRgIccpGroup.EventsRgBundleItemIccpGroup.Items.RgEvtInfo>`
                        
                        

                        """

                        _prefix = 'bundlemgr-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(BundleInformation.EventsRg.EventsRgIccpGroups.EventsRgIccpGroup.EventsRgBundleItemIccpGroup.Items, self).__init__()

                            self.yang_name = "items"
                            self.yang_parent_name = "events-rg-bundle-item-iccp-group"

                            self.event_type = YLeaf(YType.enumeration, "event-type")

                            self.bundle_evt_info = BundleInformation.EventsRg.EventsRgIccpGroups.EventsRgIccpGroup.EventsRgBundleItemIccpGroup.Items.BundleEvtInfo()
                            self.bundle_evt_info.parent = self
                            self._children_name_map["bundle_evt_info"] = "bundle-evt-info"
                            self._children_yang_names.add("bundle-evt-info")

                            self.member_evt_info = BundleInformation.EventsRg.EventsRgIccpGroups.EventsRgIccpGroup.EventsRgBundleItemIccpGroup.Items.MemberEvtInfo()
                            self.member_evt_info.parent = self
                            self._children_name_map["member_evt_info"] = "member-evt-info"
                            self._children_yang_names.add("member-evt-info")

                            self.rg_evt_info = BundleInformation.EventsRg.EventsRgIccpGroups.EventsRgIccpGroup.EventsRgBundleItemIccpGroup.Items.RgEvtInfo()
                            self.rg_evt_info.parent = self
                            self._children_name_map["rg_evt_info"] = "rg-evt-info"
                            self._children_yang_names.add("rg-evt-info")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("event_type") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(BundleInformation.EventsRg.EventsRgIccpGroups.EventsRgIccpGroup.EventsRgBundleItemIccpGroup.Items, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(BundleInformation.EventsRg.EventsRgIccpGroups.EventsRgIccpGroup.EventsRgBundleItemIccpGroup.Items, self).__setattr__(name, value)


                        class MemberEvtInfo(Entity):
                            """
                            Event information for a member
                            
                            .. attribute:: data
                            
                            	Additional data for the event
                            	**type**\:   :py:class:`Data <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.EventsRg.EventsRgIccpGroups.EventsRgIccpGroup.EventsRgBundleItemIccpGroup.Items.MemberEvtInfo.Data>`
                            
                            .. attribute:: member_event_type
                            
                            	Type of event for member
                            	**type**\:   :py:class:`BmdBagEventMbrItem <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmdBagEventMbrItem>`
                            
                            .. attribute:: time_stamp
                            
                            	Time stamp of the event
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            

                            """

                            _prefix = 'bundlemgr-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(BundleInformation.EventsRg.EventsRgIccpGroups.EventsRgIccpGroup.EventsRgBundleItemIccpGroup.Items.MemberEvtInfo, self).__init__()

                                self.yang_name = "member-evt-info"
                                self.yang_parent_name = "items"

                                self.member_event_type = YLeaf(YType.enumeration, "member-event-type")

                                self.time_stamp = YLeaf(YType.uint64, "time-stamp")

                                self.data = BundleInformation.EventsRg.EventsRgIccpGroups.EventsRgIccpGroup.EventsRgBundleItemIccpGroup.Items.MemberEvtInfo.Data()
                                self.data.parent = self
                                self._children_name_map["data"] = "data"
                                self._children_yang_names.add("data")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("member_event_type",
                                                "time_stamp") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(BundleInformation.EventsRg.EventsRgIccpGroups.EventsRgIccpGroup.EventsRgBundleItemIccpGroup.Items.MemberEvtInfo, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(BundleInformation.EventsRg.EventsRgIccpGroups.EventsRgIccpGroup.EventsRgBundleItemIccpGroup.Items.MemberEvtInfo, self).__setattr__(name, value)


                            class Data(Entity):
                                """
                                Additional data for the event
                                
                                .. attribute:: data_type
                                
                                	DataType
                                	**type**\:   :py:class:`BmdBagEventData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmdBagEventData>`
                                
                                .. attribute:: error
                                
                                	Error
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: no_data
                                
                                	NoData
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: string_data
                                
                                	StringData
                                	**type**\:  str
                                
                                

                                """

                                _prefix = 'bundlemgr-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(BundleInformation.EventsRg.EventsRgIccpGroups.EventsRgIccpGroup.EventsRgBundleItemIccpGroup.Items.MemberEvtInfo.Data, self).__init__()

                                    self.yang_name = "data"
                                    self.yang_parent_name = "member-evt-info"

                                    self.data_type = YLeaf(YType.enumeration, "data-type")

                                    self.error = YLeaf(YType.uint32, "error")

                                    self.no_data = YLeaf(YType.uint8, "no-data")

                                    self.string_data = YLeaf(YType.str, "string-data")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("data_type",
                                                    "error",
                                                    "no_data",
                                                    "string_data") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(BundleInformation.EventsRg.EventsRgIccpGroups.EventsRgIccpGroup.EventsRgBundleItemIccpGroup.Items.MemberEvtInfo.Data, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(BundleInformation.EventsRg.EventsRgIccpGroups.EventsRgIccpGroup.EventsRgBundleItemIccpGroup.Items.MemberEvtInfo.Data, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.data_type.is_set or
                                        self.error.is_set or
                                        self.no_data.is_set or
                                        self.string_data.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.data_type.yfilter != YFilter.not_set or
                                        self.error.yfilter != YFilter.not_set or
                                        self.no_data.yfilter != YFilter.not_set or
                                        self.string_data.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "data" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.data_type.is_set or self.data_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.data_type.get_name_leafdata())
                                    if (self.error.is_set or self.error.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.error.get_name_leafdata())
                                    if (self.no_data.is_set or self.no_data.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.no_data.get_name_leafdata())
                                    if (self.string_data.is_set or self.string_data.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.string_data.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "data-type" or name == "error" or name == "no-data" or name == "string-data"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "data-type"):
                                        self.data_type = value
                                        self.data_type.value_namespace = name_space
                                        self.data_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "error"):
                                        self.error = value
                                        self.error.value_namespace = name_space
                                        self.error.value_namespace_prefix = name_space_prefix
                                    if(value_path == "no-data"):
                                        self.no_data = value
                                        self.no_data.value_namespace = name_space
                                        self.no_data.value_namespace_prefix = name_space_prefix
                                    if(value_path == "string-data"):
                                        self.string_data = value
                                        self.string_data.value_namespace = name_space
                                        self.string_data.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.member_event_type.is_set or
                                    self.time_stamp.is_set or
                                    (self.data is not None and self.data.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.member_event_type.yfilter != YFilter.not_set or
                                    self.time_stamp.yfilter != YFilter.not_set or
                                    (self.data is not None and self.data.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "member-evt-info" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.member_event_type.is_set or self.member_event_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.member_event_type.get_name_leafdata())
                                if (self.time_stamp.is_set or self.time_stamp.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.time_stamp.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "data"):
                                    if (self.data is None):
                                        self.data = BundleInformation.EventsRg.EventsRgIccpGroups.EventsRgIccpGroup.EventsRgBundleItemIccpGroup.Items.MemberEvtInfo.Data()
                                        self.data.parent = self
                                        self._children_name_map["data"] = "data"
                                    return self.data

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "data" or name == "member-event-type" or name == "time-stamp"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "member-event-type"):
                                    self.member_event_type = value
                                    self.member_event_type.value_namespace = name_space
                                    self.member_event_type.value_namespace_prefix = name_space_prefix
                                if(value_path == "time-stamp"):
                                    self.time_stamp = value
                                    self.time_stamp.value_namespace = name_space
                                    self.time_stamp.value_namespace_prefix = name_space_prefix


                        class BundleEvtInfo(Entity):
                            """
                            Event information for a bundle
                            
                            .. attribute:: bundle_event_type
                            
                            	Type of event for bundle
                            	**type**\:   :py:class:`BmdBagEventBdlItem <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmdBagEventBdlItem>`
                            
                            .. attribute:: data
                            
                            	Additional data for the event
                            	**type**\:   :py:class:`Data <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.EventsRg.EventsRgIccpGroups.EventsRgIccpGroup.EventsRgBundleItemIccpGroup.Items.BundleEvtInfo.Data>`
                            
                            .. attribute:: time_stamp
                            
                            	Time stamp of the event
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            

                            """

                            _prefix = 'bundlemgr-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(BundleInformation.EventsRg.EventsRgIccpGroups.EventsRgIccpGroup.EventsRgBundleItemIccpGroup.Items.BundleEvtInfo, self).__init__()

                                self.yang_name = "bundle-evt-info"
                                self.yang_parent_name = "items"

                                self.bundle_event_type = YLeaf(YType.enumeration, "bundle-event-type")

                                self.time_stamp = YLeaf(YType.uint64, "time-stamp")

                                self.data = BundleInformation.EventsRg.EventsRgIccpGroups.EventsRgIccpGroup.EventsRgBundleItemIccpGroup.Items.BundleEvtInfo.Data()
                                self.data.parent = self
                                self._children_name_map["data"] = "data"
                                self._children_yang_names.add("data")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("bundle_event_type",
                                                "time_stamp") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(BundleInformation.EventsRg.EventsRgIccpGroups.EventsRgIccpGroup.EventsRgBundleItemIccpGroup.Items.BundleEvtInfo, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(BundleInformation.EventsRg.EventsRgIccpGroups.EventsRgIccpGroup.EventsRgBundleItemIccpGroup.Items.BundleEvtInfo, self).__setattr__(name, value)


                            class Data(Entity):
                                """
                                Additional data for the event
                                
                                .. attribute:: data_type
                                
                                	DataType
                                	**type**\:   :py:class:`BmdBagEventData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmdBagEventData>`
                                
                                .. attribute:: error
                                
                                	Error
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: no_data
                                
                                	NoData
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: string_data
                                
                                	StringData
                                	**type**\:  str
                                
                                

                                """

                                _prefix = 'bundlemgr-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(BundleInformation.EventsRg.EventsRgIccpGroups.EventsRgIccpGroup.EventsRgBundleItemIccpGroup.Items.BundleEvtInfo.Data, self).__init__()

                                    self.yang_name = "data"
                                    self.yang_parent_name = "bundle-evt-info"

                                    self.data_type = YLeaf(YType.enumeration, "data-type")

                                    self.error = YLeaf(YType.uint32, "error")

                                    self.no_data = YLeaf(YType.uint8, "no-data")

                                    self.string_data = YLeaf(YType.str, "string-data")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("data_type",
                                                    "error",
                                                    "no_data",
                                                    "string_data") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(BundleInformation.EventsRg.EventsRgIccpGroups.EventsRgIccpGroup.EventsRgBundleItemIccpGroup.Items.BundleEvtInfo.Data, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(BundleInformation.EventsRg.EventsRgIccpGroups.EventsRgIccpGroup.EventsRgBundleItemIccpGroup.Items.BundleEvtInfo.Data, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.data_type.is_set or
                                        self.error.is_set or
                                        self.no_data.is_set or
                                        self.string_data.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.data_type.yfilter != YFilter.not_set or
                                        self.error.yfilter != YFilter.not_set or
                                        self.no_data.yfilter != YFilter.not_set or
                                        self.string_data.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "data" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.data_type.is_set or self.data_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.data_type.get_name_leafdata())
                                    if (self.error.is_set or self.error.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.error.get_name_leafdata())
                                    if (self.no_data.is_set or self.no_data.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.no_data.get_name_leafdata())
                                    if (self.string_data.is_set or self.string_data.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.string_data.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "data-type" or name == "error" or name == "no-data" or name == "string-data"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "data-type"):
                                        self.data_type = value
                                        self.data_type.value_namespace = name_space
                                        self.data_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "error"):
                                        self.error = value
                                        self.error.value_namespace = name_space
                                        self.error.value_namespace_prefix = name_space_prefix
                                    if(value_path == "no-data"):
                                        self.no_data = value
                                        self.no_data.value_namespace = name_space
                                        self.no_data.value_namespace_prefix = name_space_prefix
                                    if(value_path == "string-data"):
                                        self.string_data = value
                                        self.string_data.value_namespace = name_space
                                        self.string_data.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.bundle_event_type.is_set or
                                    self.time_stamp.is_set or
                                    (self.data is not None and self.data.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.bundle_event_type.yfilter != YFilter.not_set or
                                    self.time_stamp.yfilter != YFilter.not_set or
                                    (self.data is not None and self.data.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "bundle-evt-info" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.bundle_event_type.is_set or self.bundle_event_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.bundle_event_type.get_name_leafdata())
                                if (self.time_stamp.is_set or self.time_stamp.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.time_stamp.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "data"):
                                    if (self.data is None):
                                        self.data = BundleInformation.EventsRg.EventsRgIccpGroups.EventsRgIccpGroup.EventsRgBundleItemIccpGroup.Items.BundleEvtInfo.Data()
                                        self.data.parent = self
                                        self._children_name_map["data"] = "data"
                                    return self.data

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "data" or name == "bundle-event-type" or name == "time-stamp"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "bundle-event-type"):
                                    self.bundle_event_type = value
                                    self.bundle_event_type.value_namespace = name_space
                                    self.bundle_event_type.value_namespace_prefix = name_space_prefix
                                if(value_path == "time-stamp"):
                                    self.time_stamp = value
                                    self.time_stamp.value_namespace = name_space
                                    self.time_stamp.value_namespace_prefix = name_space_prefix


                        class RgEvtInfo(Entity):
                            """
                            Event information for an RG
                            
                            .. attribute:: data
                            
                            	Additional data for the event
                            	**type**\:   :py:class:`Data <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.EventsRg.EventsRgIccpGroups.EventsRgIccpGroup.EventsRgBundleItemIccpGroup.Items.RgEvtInfo.Data>`
                            
                            .. attribute:: rg_event_type
                            
                            	Type of event for RG
                            	**type**\:   :py:class:`BmdBagEventRgItem <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmdBagEventRgItem>`
                            
                            .. attribute:: time_stamp
                            
                            	Time stamp of the event
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            

                            """

                            _prefix = 'bundlemgr-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(BundleInformation.EventsRg.EventsRgIccpGroups.EventsRgIccpGroup.EventsRgBundleItemIccpGroup.Items.RgEvtInfo, self).__init__()

                                self.yang_name = "rg-evt-info"
                                self.yang_parent_name = "items"

                                self.rg_event_type = YLeaf(YType.enumeration, "rg-event-type")

                                self.time_stamp = YLeaf(YType.uint64, "time-stamp")

                                self.data = BundleInformation.EventsRg.EventsRgIccpGroups.EventsRgIccpGroup.EventsRgBundleItemIccpGroup.Items.RgEvtInfo.Data()
                                self.data.parent = self
                                self._children_name_map["data"] = "data"
                                self._children_yang_names.add("data")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("rg_event_type",
                                                "time_stamp") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(BundleInformation.EventsRg.EventsRgIccpGroups.EventsRgIccpGroup.EventsRgBundleItemIccpGroup.Items.RgEvtInfo, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(BundleInformation.EventsRg.EventsRgIccpGroups.EventsRgIccpGroup.EventsRgBundleItemIccpGroup.Items.RgEvtInfo, self).__setattr__(name, value)


                            class Data(Entity):
                                """
                                Additional data for the event
                                
                                .. attribute:: data_type
                                
                                	DataType
                                	**type**\:   :py:class:`BmdBagEventData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmdBagEventData>`
                                
                                .. attribute:: error
                                
                                	Error
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: no_data
                                
                                	NoData
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: string_data
                                
                                	StringData
                                	**type**\:  str
                                
                                

                                """

                                _prefix = 'bundlemgr-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(BundleInformation.EventsRg.EventsRgIccpGroups.EventsRgIccpGroup.EventsRgBundleItemIccpGroup.Items.RgEvtInfo.Data, self).__init__()

                                    self.yang_name = "data"
                                    self.yang_parent_name = "rg-evt-info"

                                    self.data_type = YLeaf(YType.enumeration, "data-type")

                                    self.error = YLeaf(YType.uint32, "error")

                                    self.no_data = YLeaf(YType.uint8, "no-data")

                                    self.string_data = YLeaf(YType.str, "string-data")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("data_type",
                                                    "error",
                                                    "no_data",
                                                    "string_data") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(BundleInformation.EventsRg.EventsRgIccpGroups.EventsRgIccpGroup.EventsRgBundleItemIccpGroup.Items.RgEvtInfo.Data, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(BundleInformation.EventsRg.EventsRgIccpGroups.EventsRgIccpGroup.EventsRgBundleItemIccpGroup.Items.RgEvtInfo.Data, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.data_type.is_set or
                                        self.error.is_set or
                                        self.no_data.is_set or
                                        self.string_data.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.data_type.yfilter != YFilter.not_set or
                                        self.error.yfilter != YFilter.not_set or
                                        self.no_data.yfilter != YFilter.not_set or
                                        self.string_data.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "data" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.data_type.is_set or self.data_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.data_type.get_name_leafdata())
                                    if (self.error.is_set or self.error.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.error.get_name_leafdata())
                                    if (self.no_data.is_set or self.no_data.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.no_data.get_name_leafdata())
                                    if (self.string_data.is_set or self.string_data.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.string_data.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "data-type" or name == "error" or name == "no-data" or name == "string-data"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "data-type"):
                                        self.data_type = value
                                        self.data_type.value_namespace = name_space
                                        self.data_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "error"):
                                        self.error = value
                                        self.error.value_namespace = name_space
                                        self.error.value_namespace_prefix = name_space_prefix
                                    if(value_path == "no-data"):
                                        self.no_data = value
                                        self.no_data.value_namespace = name_space
                                        self.no_data.value_namespace_prefix = name_space_prefix
                                    if(value_path == "string-data"):
                                        self.string_data = value
                                        self.string_data.value_namespace = name_space
                                        self.string_data.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.rg_event_type.is_set or
                                    self.time_stamp.is_set or
                                    (self.data is not None and self.data.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.rg_event_type.yfilter != YFilter.not_set or
                                    self.time_stamp.yfilter != YFilter.not_set or
                                    (self.data is not None and self.data.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "rg-evt-info" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.rg_event_type.is_set or self.rg_event_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.rg_event_type.get_name_leafdata())
                                if (self.time_stamp.is_set or self.time_stamp.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.time_stamp.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "data"):
                                    if (self.data is None):
                                        self.data = BundleInformation.EventsRg.EventsRgIccpGroups.EventsRgIccpGroup.EventsRgBundleItemIccpGroup.Items.RgEvtInfo.Data()
                                        self.data.parent = self
                                        self._children_name_map["data"] = "data"
                                    return self.data

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "data" or name == "rg-event-type" or name == "time-stamp"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "rg-event-type"):
                                    self.rg_event_type = value
                                    self.rg_event_type.value_namespace = name_space
                                    self.rg_event_type.value_namespace_prefix = name_space_prefix
                                if(value_path == "time-stamp"):
                                    self.time_stamp = value
                                    self.time_stamp.value_namespace = name_space
                                    self.time_stamp.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.event_type.is_set or
                                (self.bundle_evt_info is not None and self.bundle_evt_info.has_data()) or
                                (self.member_evt_info is not None and self.member_evt_info.has_data()) or
                                (self.rg_evt_info is not None and self.rg_evt_info.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.event_type.yfilter != YFilter.not_set or
                                (self.bundle_evt_info is not None and self.bundle_evt_info.has_operation()) or
                                (self.member_evt_info is not None and self.member_evt_info.has_operation()) or
                                (self.rg_evt_info is not None and self.rg_evt_info.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "items" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.event_type.is_set or self.event_type.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.event_type.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "bundle-evt-info"):
                                if (self.bundle_evt_info is None):
                                    self.bundle_evt_info = BundleInformation.EventsRg.EventsRgIccpGroups.EventsRgIccpGroup.EventsRgBundleItemIccpGroup.Items.BundleEvtInfo()
                                    self.bundle_evt_info.parent = self
                                    self._children_name_map["bundle_evt_info"] = "bundle-evt-info"
                                return self.bundle_evt_info

                            if (child_yang_name == "member-evt-info"):
                                if (self.member_evt_info is None):
                                    self.member_evt_info = BundleInformation.EventsRg.EventsRgIccpGroups.EventsRgIccpGroup.EventsRgBundleItemIccpGroup.Items.MemberEvtInfo()
                                    self.member_evt_info.parent = self
                                    self._children_name_map["member_evt_info"] = "member-evt-info"
                                return self.member_evt_info

                            if (child_yang_name == "rg-evt-info"):
                                if (self.rg_evt_info is None):
                                    self.rg_evt_info = BundleInformation.EventsRg.EventsRgIccpGroups.EventsRgIccpGroup.EventsRgBundleItemIccpGroup.Items.RgEvtInfo()
                                    self.rg_evt_info.parent = self
                                    self._children_name_map["rg_evt_info"] = "rg-evt-info"
                                return self.rg_evt_info

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "bundle-evt-info" or name == "member-evt-info" or name == "rg-evt-info" or name == "event-type"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "event-type"):
                                self.event_type = value
                                self.event_type.value_namespace = name_space
                                self.event_type.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.items:
                            if (c.has_data()):
                                return True
                        return self.item_name.is_set

                    def has_operation(self):
                        for c in self.items:
                            if (c.has_operation()):
                                return True
                        return (
                            self.yfilter != YFilter.not_set or
                            self.item_name.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "events-rg-bundle-item-iccp-group" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.item_name.is_set or self.item_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.item_name.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "items"):
                            for c in self.items:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = BundleInformation.EventsRg.EventsRgIccpGroups.EventsRgIccpGroup.EventsRgBundleItemIccpGroup.Items()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.items.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "items" or name == "item-name"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "item-name"):
                            self.item_name = value
                            self.item_name.value_namespace = name_space
                            self.item_name.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    return (
                        self.iccp_group.is_set or
                        (self.events_rg_bundle_item_iccp_group is not None and self.events_rg_bundle_item_iccp_group.has_data()))

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.iccp_group.yfilter != YFilter.not_set or
                        (self.events_rg_bundle_item_iccp_group is not None and self.events_rg_bundle_item_iccp_group.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "events-rg-iccp-group" + "[iccp-group='" + self.iccp_group.get() + "']" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-bundlemgr-oper:bundle-information/events-rg/events-rg-iccp-groups/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.iccp_group.is_set or self.iccp_group.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.iccp_group.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "events-rg-bundle-item-iccp-group"):
                        if (self.events_rg_bundle_item_iccp_group is None):
                            self.events_rg_bundle_item_iccp_group = BundleInformation.EventsRg.EventsRgIccpGroups.EventsRgIccpGroup.EventsRgBundleItemIccpGroup()
                            self.events_rg_bundle_item_iccp_group.parent = self
                            self._children_name_map["events_rg_bundle_item_iccp_group"] = "events-rg-bundle-item-iccp-group"
                        return self.events_rg_bundle_item_iccp_group

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "events-rg-bundle-item-iccp-group" or name == "iccp-group"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "iccp-group"):
                        self.iccp_group = value
                        self.iccp_group.value_namespace = name_space
                        self.iccp_group.value_namespace_prefix = name_space_prefix

            def has_data(self):
                for c in self.events_rg_iccp_group:
                    if (c.has_data()):
                        return True
                return False

            def has_operation(self):
                for c in self.events_rg_iccp_group:
                    if (c.has_operation()):
                        return True
                return self.yfilter != YFilter.not_set

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "events-rg-iccp-groups" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-bundlemgr-oper:bundle-information/events-rg/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "events-rg-iccp-group"):
                    for c in self.events_rg_iccp_group:
                        segment = c.get_segment_path()
                        if (segment_path == segment):
                            return c
                    c = BundleInformation.EventsRg.EventsRgIccpGroups.EventsRgIccpGroup()
                    c.parent = self
                    local_reference_key = "ydk::seg::%s" % segment_path
                    self._local_refs[local_reference_key] = c
                    self.events_rg_iccp_group.append(c)
                    return c

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "events-rg-iccp-group"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                pass


        class EventsRgBundles(Entity):
            """
            Bundle interfaces with ICCP events information
            
            .. attribute:: events_rg_bundle
            
            	Bundle interface
            	**type**\: list of    :py:class:`EventsRgBundle <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.EventsRg.EventsRgBundles.EventsRgBundle>`
            
            

            """

            _prefix = 'bundlemgr-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(BundleInformation.EventsRg.EventsRgBundles, self).__init__()

                self.yang_name = "events-rg-bundles"
                self.yang_parent_name = "events-rg"

                self.events_rg_bundle = YList(self)

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in () and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(BundleInformation.EventsRg.EventsRgBundles, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(BundleInformation.EventsRg.EventsRgBundles, self).__setattr__(name, value)


            class EventsRgBundle(Entity):
                """
                Bundle interface
                
                .. attribute:: bundle_interface  <key>
                
                	Bundle interface
                	**type**\:  str
                
                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                
                .. attribute:: events_rg_bundle_ancestor
                
                	Data for this item and its parent bundle
                	**type**\:   :py:class:`EventsRgBundleAncestor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.EventsRg.EventsRgBundles.EventsRgBundle.EventsRgBundleAncestor>`
                
                

                """

                _prefix = 'bundlemgr-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(BundleInformation.EventsRg.EventsRgBundles.EventsRgBundle, self).__init__()

                    self.yang_name = "events-rg-bundle"
                    self.yang_parent_name = "events-rg-bundles"

                    self.bundle_interface = YLeaf(YType.str, "bundle-interface")

                    self.events_rg_bundle_ancestor = BundleInformation.EventsRg.EventsRgBundles.EventsRgBundle.EventsRgBundleAncestor()
                    self.events_rg_bundle_ancestor.parent = self
                    self._children_name_map["events_rg_bundle_ancestor"] = "events-rg-bundle-ancestor"
                    self._children_yang_names.add("events-rg-bundle-ancestor")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("bundle_interface") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(BundleInformation.EventsRg.EventsRgBundles.EventsRgBundle, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(BundleInformation.EventsRg.EventsRgBundles.EventsRgBundle, self).__setattr__(name, value)


                class EventsRgBundleAncestor(Entity):
                    """
                    Data for this item and its parent bundle
                    
                    .. attribute:: item_name
                    
                    	Name for the current item to use
                    	**type**\:  str
                    
                    .. attribute:: items
                    
                    	Event items
                    	**type**\: list of    :py:class:`Items <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.EventsRg.EventsRgBundles.EventsRgBundle.EventsRgBundleAncestor.Items>`
                    
                    

                    """

                    _prefix = 'bundlemgr-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(BundleInformation.EventsRg.EventsRgBundles.EventsRgBundle.EventsRgBundleAncestor, self).__init__()

                        self.yang_name = "events-rg-bundle-ancestor"
                        self.yang_parent_name = "events-rg-bundle"

                        self.item_name = YLeaf(YType.str, "item-name")

                        self.items = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("item_name") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(BundleInformation.EventsRg.EventsRgBundles.EventsRgBundle.EventsRgBundleAncestor, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(BundleInformation.EventsRg.EventsRgBundles.EventsRgBundle.EventsRgBundleAncestor, self).__setattr__(name, value)


                    class Items(Entity):
                        """
                        Event items
                        
                        .. attribute:: bundle_evt_info
                        
                        	Event information for a bundle
                        	**type**\:   :py:class:`BundleEvtInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.EventsRg.EventsRgBundles.EventsRgBundle.EventsRgBundleAncestor.Items.BundleEvtInfo>`
                        
                        .. attribute:: event_type
                        
                        	EventType
                        	**type**\:   :py:class:`BmdBagTarget <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmdBagTarget>`
                        
                        .. attribute:: member_evt_info
                        
                        	Event information for a member
                        	**type**\:   :py:class:`MemberEvtInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.EventsRg.EventsRgBundles.EventsRgBundle.EventsRgBundleAncestor.Items.MemberEvtInfo>`
                        
                        .. attribute:: rg_evt_info
                        
                        	Event information for an RG
                        	**type**\:   :py:class:`RgEvtInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.EventsRg.EventsRgBundles.EventsRgBundle.EventsRgBundleAncestor.Items.RgEvtInfo>`
                        
                        

                        """

                        _prefix = 'bundlemgr-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(BundleInformation.EventsRg.EventsRgBundles.EventsRgBundle.EventsRgBundleAncestor.Items, self).__init__()

                            self.yang_name = "items"
                            self.yang_parent_name = "events-rg-bundle-ancestor"

                            self.event_type = YLeaf(YType.enumeration, "event-type")

                            self.bundle_evt_info = BundleInformation.EventsRg.EventsRgBundles.EventsRgBundle.EventsRgBundleAncestor.Items.BundleEvtInfo()
                            self.bundle_evt_info.parent = self
                            self._children_name_map["bundle_evt_info"] = "bundle-evt-info"
                            self._children_yang_names.add("bundle-evt-info")

                            self.member_evt_info = BundleInformation.EventsRg.EventsRgBundles.EventsRgBundle.EventsRgBundleAncestor.Items.MemberEvtInfo()
                            self.member_evt_info.parent = self
                            self._children_name_map["member_evt_info"] = "member-evt-info"
                            self._children_yang_names.add("member-evt-info")

                            self.rg_evt_info = BundleInformation.EventsRg.EventsRgBundles.EventsRgBundle.EventsRgBundleAncestor.Items.RgEvtInfo()
                            self.rg_evt_info.parent = self
                            self._children_name_map["rg_evt_info"] = "rg-evt-info"
                            self._children_yang_names.add("rg-evt-info")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("event_type") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(BundleInformation.EventsRg.EventsRgBundles.EventsRgBundle.EventsRgBundleAncestor.Items, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(BundleInformation.EventsRg.EventsRgBundles.EventsRgBundle.EventsRgBundleAncestor.Items, self).__setattr__(name, value)


                        class MemberEvtInfo(Entity):
                            """
                            Event information for a member
                            
                            .. attribute:: data
                            
                            	Additional data for the event
                            	**type**\:   :py:class:`Data <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.EventsRg.EventsRgBundles.EventsRgBundle.EventsRgBundleAncestor.Items.MemberEvtInfo.Data>`
                            
                            .. attribute:: member_event_type
                            
                            	Type of event for member
                            	**type**\:   :py:class:`BmdBagEventMbrItem <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmdBagEventMbrItem>`
                            
                            .. attribute:: time_stamp
                            
                            	Time stamp of the event
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            

                            """

                            _prefix = 'bundlemgr-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(BundleInformation.EventsRg.EventsRgBundles.EventsRgBundle.EventsRgBundleAncestor.Items.MemberEvtInfo, self).__init__()

                                self.yang_name = "member-evt-info"
                                self.yang_parent_name = "items"

                                self.member_event_type = YLeaf(YType.enumeration, "member-event-type")

                                self.time_stamp = YLeaf(YType.uint64, "time-stamp")

                                self.data = BundleInformation.EventsRg.EventsRgBundles.EventsRgBundle.EventsRgBundleAncestor.Items.MemberEvtInfo.Data()
                                self.data.parent = self
                                self._children_name_map["data"] = "data"
                                self._children_yang_names.add("data")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("member_event_type",
                                                "time_stamp") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(BundleInformation.EventsRg.EventsRgBundles.EventsRgBundle.EventsRgBundleAncestor.Items.MemberEvtInfo, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(BundleInformation.EventsRg.EventsRgBundles.EventsRgBundle.EventsRgBundleAncestor.Items.MemberEvtInfo, self).__setattr__(name, value)


                            class Data(Entity):
                                """
                                Additional data for the event
                                
                                .. attribute:: data_type
                                
                                	DataType
                                	**type**\:   :py:class:`BmdBagEventData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmdBagEventData>`
                                
                                .. attribute:: error
                                
                                	Error
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: no_data
                                
                                	NoData
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: string_data
                                
                                	StringData
                                	**type**\:  str
                                
                                

                                """

                                _prefix = 'bundlemgr-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(BundleInformation.EventsRg.EventsRgBundles.EventsRgBundle.EventsRgBundleAncestor.Items.MemberEvtInfo.Data, self).__init__()

                                    self.yang_name = "data"
                                    self.yang_parent_name = "member-evt-info"

                                    self.data_type = YLeaf(YType.enumeration, "data-type")

                                    self.error = YLeaf(YType.uint32, "error")

                                    self.no_data = YLeaf(YType.uint8, "no-data")

                                    self.string_data = YLeaf(YType.str, "string-data")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("data_type",
                                                    "error",
                                                    "no_data",
                                                    "string_data") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(BundleInformation.EventsRg.EventsRgBundles.EventsRgBundle.EventsRgBundleAncestor.Items.MemberEvtInfo.Data, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(BundleInformation.EventsRg.EventsRgBundles.EventsRgBundle.EventsRgBundleAncestor.Items.MemberEvtInfo.Data, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.data_type.is_set or
                                        self.error.is_set or
                                        self.no_data.is_set or
                                        self.string_data.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.data_type.yfilter != YFilter.not_set or
                                        self.error.yfilter != YFilter.not_set or
                                        self.no_data.yfilter != YFilter.not_set or
                                        self.string_data.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "data" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.data_type.is_set or self.data_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.data_type.get_name_leafdata())
                                    if (self.error.is_set or self.error.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.error.get_name_leafdata())
                                    if (self.no_data.is_set or self.no_data.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.no_data.get_name_leafdata())
                                    if (self.string_data.is_set or self.string_data.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.string_data.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "data-type" or name == "error" or name == "no-data" or name == "string-data"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "data-type"):
                                        self.data_type = value
                                        self.data_type.value_namespace = name_space
                                        self.data_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "error"):
                                        self.error = value
                                        self.error.value_namespace = name_space
                                        self.error.value_namespace_prefix = name_space_prefix
                                    if(value_path == "no-data"):
                                        self.no_data = value
                                        self.no_data.value_namespace = name_space
                                        self.no_data.value_namespace_prefix = name_space_prefix
                                    if(value_path == "string-data"):
                                        self.string_data = value
                                        self.string_data.value_namespace = name_space
                                        self.string_data.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.member_event_type.is_set or
                                    self.time_stamp.is_set or
                                    (self.data is not None and self.data.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.member_event_type.yfilter != YFilter.not_set or
                                    self.time_stamp.yfilter != YFilter.not_set or
                                    (self.data is not None and self.data.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "member-evt-info" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.member_event_type.is_set or self.member_event_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.member_event_type.get_name_leafdata())
                                if (self.time_stamp.is_set or self.time_stamp.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.time_stamp.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "data"):
                                    if (self.data is None):
                                        self.data = BundleInformation.EventsRg.EventsRgBundles.EventsRgBundle.EventsRgBundleAncestor.Items.MemberEvtInfo.Data()
                                        self.data.parent = self
                                        self._children_name_map["data"] = "data"
                                    return self.data

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "data" or name == "member-event-type" or name == "time-stamp"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "member-event-type"):
                                    self.member_event_type = value
                                    self.member_event_type.value_namespace = name_space
                                    self.member_event_type.value_namespace_prefix = name_space_prefix
                                if(value_path == "time-stamp"):
                                    self.time_stamp = value
                                    self.time_stamp.value_namespace = name_space
                                    self.time_stamp.value_namespace_prefix = name_space_prefix


                        class BundleEvtInfo(Entity):
                            """
                            Event information for a bundle
                            
                            .. attribute:: bundle_event_type
                            
                            	Type of event for bundle
                            	**type**\:   :py:class:`BmdBagEventBdlItem <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmdBagEventBdlItem>`
                            
                            .. attribute:: data
                            
                            	Additional data for the event
                            	**type**\:   :py:class:`Data <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.EventsRg.EventsRgBundles.EventsRgBundle.EventsRgBundleAncestor.Items.BundleEvtInfo.Data>`
                            
                            .. attribute:: time_stamp
                            
                            	Time stamp of the event
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            

                            """

                            _prefix = 'bundlemgr-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(BundleInformation.EventsRg.EventsRgBundles.EventsRgBundle.EventsRgBundleAncestor.Items.BundleEvtInfo, self).__init__()

                                self.yang_name = "bundle-evt-info"
                                self.yang_parent_name = "items"

                                self.bundle_event_type = YLeaf(YType.enumeration, "bundle-event-type")

                                self.time_stamp = YLeaf(YType.uint64, "time-stamp")

                                self.data = BundleInformation.EventsRg.EventsRgBundles.EventsRgBundle.EventsRgBundleAncestor.Items.BundleEvtInfo.Data()
                                self.data.parent = self
                                self._children_name_map["data"] = "data"
                                self._children_yang_names.add("data")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("bundle_event_type",
                                                "time_stamp") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(BundleInformation.EventsRg.EventsRgBundles.EventsRgBundle.EventsRgBundleAncestor.Items.BundleEvtInfo, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(BundleInformation.EventsRg.EventsRgBundles.EventsRgBundle.EventsRgBundleAncestor.Items.BundleEvtInfo, self).__setattr__(name, value)


                            class Data(Entity):
                                """
                                Additional data for the event
                                
                                .. attribute:: data_type
                                
                                	DataType
                                	**type**\:   :py:class:`BmdBagEventData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmdBagEventData>`
                                
                                .. attribute:: error
                                
                                	Error
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: no_data
                                
                                	NoData
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: string_data
                                
                                	StringData
                                	**type**\:  str
                                
                                

                                """

                                _prefix = 'bundlemgr-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(BundleInformation.EventsRg.EventsRgBundles.EventsRgBundle.EventsRgBundleAncestor.Items.BundleEvtInfo.Data, self).__init__()

                                    self.yang_name = "data"
                                    self.yang_parent_name = "bundle-evt-info"

                                    self.data_type = YLeaf(YType.enumeration, "data-type")

                                    self.error = YLeaf(YType.uint32, "error")

                                    self.no_data = YLeaf(YType.uint8, "no-data")

                                    self.string_data = YLeaf(YType.str, "string-data")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("data_type",
                                                    "error",
                                                    "no_data",
                                                    "string_data") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(BundleInformation.EventsRg.EventsRgBundles.EventsRgBundle.EventsRgBundleAncestor.Items.BundleEvtInfo.Data, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(BundleInformation.EventsRg.EventsRgBundles.EventsRgBundle.EventsRgBundleAncestor.Items.BundleEvtInfo.Data, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.data_type.is_set or
                                        self.error.is_set or
                                        self.no_data.is_set or
                                        self.string_data.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.data_type.yfilter != YFilter.not_set or
                                        self.error.yfilter != YFilter.not_set or
                                        self.no_data.yfilter != YFilter.not_set or
                                        self.string_data.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "data" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.data_type.is_set or self.data_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.data_type.get_name_leafdata())
                                    if (self.error.is_set or self.error.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.error.get_name_leafdata())
                                    if (self.no_data.is_set or self.no_data.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.no_data.get_name_leafdata())
                                    if (self.string_data.is_set or self.string_data.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.string_data.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "data-type" or name == "error" or name == "no-data" or name == "string-data"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "data-type"):
                                        self.data_type = value
                                        self.data_type.value_namespace = name_space
                                        self.data_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "error"):
                                        self.error = value
                                        self.error.value_namespace = name_space
                                        self.error.value_namespace_prefix = name_space_prefix
                                    if(value_path == "no-data"):
                                        self.no_data = value
                                        self.no_data.value_namespace = name_space
                                        self.no_data.value_namespace_prefix = name_space_prefix
                                    if(value_path == "string-data"):
                                        self.string_data = value
                                        self.string_data.value_namespace = name_space
                                        self.string_data.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.bundle_event_type.is_set or
                                    self.time_stamp.is_set or
                                    (self.data is not None and self.data.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.bundle_event_type.yfilter != YFilter.not_set or
                                    self.time_stamp.yfilter != YFilter.not_set or
                                    (self.data is not None and self.data.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "bundle-evt-info" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.bundle_event_type.is_set or self.bundle_event_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.bundle_event_type.get_name_leafdata())
                                if (self.time_stamp.is_set or self.time_stamp.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.time_stamp.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "data"):
                                    if (self.data is None):
                                        self.data = BundleInformation.EventsRg.EventsRgBundles.EventsRgBundle.EventsRgBundleAncestor.Items.BundleEvtInfo.Data()
                                        self.data.parent = self
                                        self._children_name_map["data"] = "data"
                                    return self.data

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "data" or name == "bundle-event-type" or name == "time-stamp"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "bundle-event-type"):
                                    self.bundle_event_type = value
                                    self.bundle_event_type.value_namespace = name_space
                                    self.bundle_event_type.value_namespace_prefix = name_space_prefix
                                if(value_path == "time-stamp"):
                                    self.time_stamp = value
                                    self.time_stamp.value_namespace = name_space
                                    self.time_stamp.value_namespace_prefix = name_space_prefix


                        class RgEvtInfo(Entity):
                            """
                            Event information for an RG
                            
                            .. attribute:: data
                            
                            	Additional data for the event
                            	**type**\:   :py:class:`Data <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.EventsRg.EventsRgBundles.EventsRgBundle.EventsRgBundleAncestor.Items.RgEvtInfo.Data>`
                            
                            .. attribute:: rg_event_type
                            
                            	Type of event for RG
                            	**type**\:   :py:class:`BmdBagEventRgItem <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmdBagEventRgItem>`
                            
                            .. attribute:: time_stamp
                            
                            	Time stamp of the event
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            

                            """

                            _prefix = 'bundlemgr-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(BundleInformation.EventsRg.EventsRgBundles.EventsRgBundle.EventsRgBundleAncestor.Items.RgEvtInfo, self).__init__()

                                self.yang_name = "rg-evt-info"
                                self.yang_parent_name = "items"

                                self.rg_event_type = YLeaf(YType.enumeration, "rg-event-type")

                                self.time_stamp = YLeaf(YType.uint64, "time-stamp")

                                self.data = BundleInformation.EventsRg.EventsRgBundles.EventsRgBundle.EventsRgBundleAncestor.Items.RgEvtInfo.Data()
                                self.data.parent = self
                                self._children_name_map["data"] = "data"
                                self._children_yang_names.add("data")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("rg_event_type",
                                                "time_stamp") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(BundleInformation.EventsRg.EventsRgBundles.EventsRgBundle.EventsRgBundleAncestor.Items.RgEvtInfo, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(BundleInformation.EventsRg.EventsRgBundles.EventsRgBundle.EventsRgBundleAncestor.Items.RgEvtInfo, self).__setattr__(name, value)


                            class Data(Entity):
                                """
                                Additional data for the event
                                
                                .. attribute:: data_type
                                
                                	DataType
                                	**type**\:   :py:class:`BmdBagEventData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmdBagEventData>`
                                
                                .. attribute:: error
                                
                                	Error
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: no_data
                                
                                	NoData
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: string_data
                                
                                	StringData
                                	**type**\:  str
                                
                                

                                """

                                _prefix = 'bundlemgr-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(BundleInformation.EventsRg.EventsRgBundles.EventsRgBundle.EventsRgBundleAncestor.Items.RgEvtInfo.Data, self).__init__()

                                    self.yang_name = "data"
                                    self.yang_parent_name = "rg-evt-info"

                                    self.data_type = YLeaf(YType.enumeration, "data-type")

                                    self.error = YLeaf(YType.uint32, "error")

                                    self.no_data = YLeaf(YType.uint8, "no-data")

                                    self.string_data = YLeaf(YType.str, "string-data")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("data_type",
                                                    "error",
                                                    "no_data",
                                                    "string_data") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(BundleInformation.EventsRg.EventsRgBundles.EventsRgBundle.EventsRgBundleAncestor.Items.RgEvtInfo.Data, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(BundleInformation.EventsRg.EventsRgBundles.EventsRgBundle.EventsRgBundleAncestor.Items.RgEvtInfo.Data, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.data_type.is_set or
                                        self.error.is_set or
                                        self.no_data.is_set or
                                        self.string_data.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.data_type.yfilter != YFilter.not_set or
                                        self.error.yfilter != YFilter.not_set or
                                        self.no_data.yfilter != YFilter.not_set or
                                        self.string_data.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "data" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.data_type.is_set or self.data_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.data_type.get_name_leafdata())
                                    if (self.error.is_set or self.error.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.error.get_name_leafdata())
                                    if (self.no_data.is_set or self.no_data.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.no_data.get_name_leafdata())
                                    if (self.string_data.is_set or self.string_data.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.string_data.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "data-type" or name == "error" or name == "no-data" or name == "string-data"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "data-type"):
                                        self.data_type = value
                                        self.data_type.value_namespace = name_space
                                        self.data_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "error"):
                                        self.error = value
                                        self.error.value_namespace = name_space
                                        self.error.value_namespace_prefix = name_space_prefix
                                    if(value_path == "no-data"):
                                        self.no_data = value
                                        self.no_data.value_namespace = name_space
                                        self.no_data.value_namespace_prefix = name_space_prefix
                                    if(value_path == "string-data"):
                                        self.string_data = value
                                        self.string_data.value_namespace = name_space
                                        self.string_data.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.rg_event_type.is_set or
                                    self.time_stamp.is_set or
                                    (self.data is not None and self.data.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.rg_event_type.yfilter != YFilter.not_set or
                                    self.time_stamp.yfilter != YFilter.not_set or
                                    (self.data is not None and self.data.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "rg-evt-info" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.rg_event_type.is_set or self.rg_event_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.rg_event_type.get_name_leafdata())
                                if (self.time_stamp.is_set or self.time_stamp.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.time_stamp.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "data"):
                                    if (self.data is None):
                                        self.data = BundleInformation.EventsRg.EventsRgBundles.EventsRgBundle.EventsRgBundleAncestor.Items.RgEvtInfo.Data()
                                        self.data.parent = self
                                        self._children_name_map["data"] = "data"
                                    return self.data

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "data" or name == "rg-event-type" or name == "time-stamp"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "rg-event-type"):
                                    self.rg_event_type = value
                                    self.rg_event_type.value_namespace = name_space
                                    self.rg_event_type.value_namespace_prefix = name_space_prefix
                                if(value_path == "time-stamp"):
                                    self.time_stamp = value
                                    self.time_stamp.value_namespace = name_space
                                    self.time_stamp.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.event_type.is_set or
                                (self.bundle_evt_info is not None and self.bundle_evt_info.has_data()) or
                                (self.member_evt_info is not None and self.member_evt_info.has_data()) or
                                (self.rg_evt_info is not None and self.rg_evt_info.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.event_type.yfilter != YFilter.not_set or
                                (self.bundle_evt_info is not None and self.bundle_evt_info.has_operation()) or
                                (self.member_evt_info is not None and self.member_evt_info.has_operation()) or
                                (self.rg_evt_info is not None and self.rg_evt_info.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "items" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.event_type.is_set or self.event_type.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.event_type.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "bundle-evt-info"):
                                if (self.bundle_evt_info is None):
                                    self.bundle_evt_info = BundleInformation.EventsRg.EventsRgBundles.EventsRgBundle.EventsRgBundleAncestor.Items.BundleEvtInfo()
                                    self.bundle_evt_info.parent = self
                                    self._children_name_map["bundle_evt_info"] = "bundle-evt-info"
                                return self.bundle_evt_info

                            if (child_yang_name == "member-evt-info"):
                                if (self.member_evt_info is None):
                                    self.member_evt_info = BundleInformation.EventsRg.EventsRgBundles.EventsRgBundle.EventsRgBundleAncestor.Items.MemberEvtInfo()
                                    self.member_evt_info.parent = self
                                    self._children_name_map["member_evt_info"] = "member-evt-info"
                                return self.member_evt_info

                            if (child_yang_name == "rg-evt-info"):
                                if (self.rg_evt_info is None):
                                    self.rg_evt_info = BundleInformation.EventsRg.EventsRgBundles.EventsRgBundle.EventsRgBundleAncestor.Items.RgEvtInfo()
                                    self.rg_evt_info.parent = self
                                    self._children_name_map["rg_evt_info"] = "rg-evt-info"
                                return self.rg_evt_info

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "bundle-evt-info" or name == "member-evt-info" or name == "rg-evt-info" or name == "event-type"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "event-type"):
                                self.event_type = value
                                self.event_type.value_namespace = name_space
                                self.event_type.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.items:
                            if (c.has_data()):
                                return True
                        return self.item_name.is_set

                    def has_operation(self):
                        for c in self.items:
                            if (c.has_operation()):
                                return True
                        return (
                            self.yfilter != YFilter.not_set or
                            self.item_name.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "events-rg-bundle-ancestor" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.item_name.is_set or self.item_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.item_name.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "items"):
                            for c in self.items:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = BundleInformation.EventsRg.EventsRgBundles.EventsRgBundle.EventsRgBundleAncestor.Items()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.items.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "items" or name == "item-name"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "item-name"):
                            self.item_name = value
                            self.item_name.value_namespace = name_space
                            self.item_name.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    return (
                        self.bundle_interface.is_set or
                        (self.events_rg_bundle_ancestor is not None and self.events_rg_bundle_ancestor.has_data()))

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.bundle_interface.yfilter != YFilter.not_set or
                        (self.events_rg_bundle_ancestor is not None and self.events_rg_bundle_ancestor.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "events-rg-bundle" + "[bundle-interface='" + self.bundle_interface.get() + "']" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-bundlemgr-oper:bundle-information/events-rg/events-rg-bundles/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.bundle_interface.is_set or self.bundle_interface.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.bundle_interface.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "events-rg-bundle-ancestor"):
                        if (self.events_rg_bundle_ancestor is None):
                            self.events_rg_bundle_ancestor = BundleInformation.EventsRg.EventsRgBundles.EventsRgBundle.EventsRgBundleAncestor()
                            self.events_rg_bundle_ancestor.parent = self
                            self._children_name_map["events_rg_bundle_ancestor"] = "events-rg-bundle-ancestor"
                        return self.events_rg_bundle_ancestor

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "events-rg-bundle-ancestor" or name == "bundle-interface"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "bundle-interface"):
                        self.bundle_interface = value
                        self.bundle_interface.value_namespace = name_space
                        self.bundle_interface.value_namespace_prefix = name_space_prefix

            def has_data(self):
                for c in self.events_rg_bundle:
                    if (c.has_data()):
                        return True
                return False

            def has_operation(self):
                for c in self.events_rg_bundle:
                    if (c.has_operation()):
                        return True
                return self.yfilter != YFilter.not_set

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "events-rg-bundles" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-bundlemgr-oper:bundle-information/events-rg/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "events-rg-bundle"):
                    for c in self.events_rg_bundle:
                        segment = c.get_segment_path()
                        if (segment_path == segment):
                            return c
                    c = BundleInformation.EventsRg.EventsRgBundles.EventsRgBundle()
                    c.parent = self
                    local_reference_key = "ydk::seg::%s" % segment_path
                    self._local_refs[local_reference_key] = c
                    self.events_rg_bundle.append(c)
                    return c

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "events-rg-bundle"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                pass

        def has_data(self):
            return (
                (self.events_rg_bundles is not None and self.events_rg_bundles.has_data()) or
                (self.events_rg_iccp_groups is not None and self.events_rg_iccp_groups.has_data()) or
                (self.events_rg_members is not None and self.events_rg_members.has_data()))

        def has_operation(self):
            return (
                self.yfilter != YFilter.not_set or
                (self.events_rg_bundles is not None and self.events_rg_bundles.has_operation()) or
                (self.events_rg_iccp_groups is not None and self.events_rg_iccp_groups.has_operation()) or
                (self.events_rg_members is not None and self.events_rg_members.has_operation()))

        def get_segment_path(self):
            path_buffer = ""
            path_buffer = "events-rg" + path_buffer

            return path_buffer

        def get_entity_path(self, ancestor):
            path_buffer = ""
            if (ancestor is None):
                path_buffer = "Cisco-IOS-XR-bundlemgr-oper:bundle-information/%s" % self.get_segment_path()
            else:
                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

            leaf_name_data = LeafDataList()

            entity_path = EntityPath(path_buffer, leaf_name_data)
            return entity_path

        def get_child_by_name(self, child_yang_name, segment_path):
            child = self._get_child_by_seg_name([child_yang_name, segment_path])
            if child is not None:
                return child

            if (child_yang_name == "events-rg-bundles"):
                if (self.events_rg_bundles is None):
                    self.events_rg_bundles = BundleInformation.EventsRg.EventsRgBundles()
                    self.events_rg_bundles.parent = self
                    self._children_name_map["events_rg_bundles"] = "events-rg-bundles"
                return self.events_rg_bundles

            if (child_yang_name == "events-rg-iccp-groups"):
                if (self.events_rg_iccp_groups is None):
                    self.events_rg_iccp_groups = BundleInformation.EventsRg.EventsRgIccpGroups()
                    self.events_rg_iccp_groups.parent = self
                    self._children_name_map["events_rg_iccp_groups"] = "events-rg-iccp-groups"
                return self.events_rg_iccp_groups

            if (child_yang_name == "events-rg-members"):
                if (self.events_rg_members is None):
                    self.events_rg_members = BundleInformation.EventsRg.EventsRgMembers()
                    self.events_rg_members.parent = self
                    self._children_name_map["events_rg_members"] = "events-rg-members"
                return self.events_rg_members

            return None

        def has_leaf_or_child_of_name(self, name):
            if(name == "events-rg-bundles" or name == "events-rg-iccp-groups" or name == "events-rg-members"):
                return True
            return False

        def set_value(self, value_path, value, name_space, name_space_prefix):
            pass


    class Lacp(Entity):
        """
        LACP information for bundles and members
        
        .. attribute:: lacp_bundles
        
        	Bundle interfaces with LACP information
        	**type**\:   :py:class:`LacpBundles <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.Lacp.LacpBundles>`
        
        .. attribute:: lacp_members
        
        	Member interfaces with LACP information
        	**type**\:   :py:class:`LacpMembers <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.Lacp.LacpMembers>`
        
        

        """

        _prefix = 'bundlemgr-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(BundleInformation.Lacp, self).__init__()

            self.yang_name = "lacp"
            self.yang_parent_name = "bundle-information"

            self.lacp_bundles = BundleInformation.Lacp.LacpBundles()
            self.lacp_bundles.parent = self
            self._children_name_map["lacp_bundles"] = "lacp-bundles"
            self._children_yang_names.add("lacp-bundles")

            self.lacp_members = BundleInformation.Lacp.LacpMembers()
            self.lacp_members.parent = self
            self._children_name_map["lacp_members"] = "lacp-members"
            self._children_yang_names.add("lacp-members")


        class LacpBundles(Entity):
            """
            Bundle interfaces with LACP information
            
            .. attribute:: lacp_bundle
            
            	Bundle interface
            	**type**\: list of    :py:class:`LacpBundle <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.Lacp.LacpBundles.LacpBundle>`
            
            

            """

            _prefix = 'bundlemgr-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(BundleInformation.Lacp.LacpBundles, self).__init__()

                self.yang_name = "lacp-bundles"
                self.yang_parent_name = "lacp"

                self.lacp_bundle = YList(self)

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in () and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(BundleInformation.Lacp.LacpBundles, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(BundleInformation.Lacp.LacpBundles, self).__setattr__(name, value)


            class LacpBundle(Entity):
                """
                Bundle interface
                
                .. attribute:: bundle_interface  <key>
                
                	Bundle interface
                	**type**\:  str
                
                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                
                .. attribute:: lacp_bundle_children_members
                
                	Children of bundle with LACP information
                	**type**\:   :py:class:`LacpBundleChildrenMembers <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleChildrenMembers>`
                
                .. attribute:: lacp_bundle_descendant
                
                	Data for this item and all its members
                	**type**\:   :py:class:`LacpBundleDescendant <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleDescendant>`
                
                .. attribute:: lacp_bundle_item
                
                	Data for this item
                	**type**\:   :py:class:`LacpBundleItem <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleItem>`
                
                

                """

                _prefix = 'bundlemgr-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(BundleInformation.Lacp.LacpBundles.LacpBundle, self).__init__()

                    self.yang_name = "lacp-bundle"
                    self.yang_parent_name = "lacp-bundles"

                    self.bundle_interface = YLeaf(YType.str, "bundle-interface")

                    self.lacp_bundle_children_members = BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleChildrenMembers()
                    self.lacp_bundle_children_members.parent = self
                    self._children_name_map["lacp_bundle_children_members"] = "lacp-bundle-children-members"
                    self._children_yang_names.add("lacp-bundle-children-members")

                    self.lacp_bundle_descendant = BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleDescendant()
                    self.lacp_bundle_descendant.parent = self
                    self._children_name_map["lacp_bundle_descendant"] = "lacp-bundle-descendant"
                    self._children_yang_names.add("lacp-bundle-descendant")

                    self.lacp_bundle_item = BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleItem()
                    self.lacp_bundle_item.parent = self
                    self._children_name_map["lacp_bundle_item"] = "lacp-bundle-item"
                    self._children_yang_names.add("lacp-bundle-item")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("bundle_interface") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(BundleInformation.Lacp.LacpBundles.LacpBundle, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(BundleInformation.Lacp.LacpBundles.LacpBundle, self).__setattr__(name, value)


                class LacpBundleItem(Entity):
                    """
                    Data for this item
                    
                    .. attribute:: actor_bundle_data
                    
                    	Basic bundle information
                    	**type**\:   :py:class:`ActorBundleData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleItem.ActorBundleData>`
                    
                    .. attribute:: actor_operational_key
                    
                    	Operational key of the interface
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: bundle_system_id
                    
                    	System ID for the bundle
                    	**type**\:   :py:class:`BundleSystemId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleItem.BundleSystemId>`
                    
                    .. attribute:: partner_operational_key
                    
                    	Operational key of the partner
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: partner_system_mac_address
                    
                    	MAC Address used to identify the partner system
                    	**type**\:  str
                    
                    	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                    
                    .. attribute:: partner_system_priority
                    
                    	Priority of the partner system
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'bundlemgr-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleItem, self).__init__()

                        self.yang_name = "lacp-bundle-item"
                        self.yang_parent_name = "lacp-bundle"

                        self.actor_operational_key = YLeaf(YType.uint16, "actor-operational-key")

                        self.partner_operational_key = YLeaf(YType.uint16, "partner-operational-key")

                        self.partner_system_mac_address = YLeaf(YType.str, "partner-system-mac-address")

                        self.partner_system_priority = YLeaf(YType.uint16, "partner-system-priority")

                        self.actor_bundle_data = BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleItem.ActorBundleData()
                        self.actor_bundle_data.parent = self
                        self._children_name_map["actor_bundle_data"] = "actor-bundle-data"
                        self._children_yang_names.add("actor-bundle-data")

                        self.bundle_system_id = BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleItem.BundleSystemId()
                        self.bundle_system_id.parent = self
                        self._children_name_map["bundle_system_id"] = "bundle-system-id"
                        self._children_yang_names.add("bundle-system-id")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("actor_operational_key",
                                        "partner_operational_key",
                                        "partner_system_mac_address",
                                        "partner_system_priority") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleItem, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleItem, self).__setattr__(name, value)


                    class ActorBundleData(Entity):
                        """
                        Basic bundle information
                        
                        .. attribute:: active_foreign_member_count
                        
                        	The number of active foreign members on the bundle
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: active_member_count
                        
                        	The number of active local members on the bundle
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: available_bandwidth
                        
                        	Bandwidth available to the bundle interface (kbps)
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: kbit/s
                        
                        .. attribute:: bfd_config
                        
                        	Configuration values for BFD on bundle members
                        	**type**\: list of    :py:class:`BfdConfig <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleItem.ActorBundleData.BfdConfig>`
                        
                        .. attribute:: bundle_interface_name
                        
                        	Bundle interface name
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: bundle_status
                        
                        	The state of the bundle
                        	**type**\:   :py:class:`BmBdlState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmBdlState>`
                        
                        .. attribute:: cisco_extensions
                        
                        	The status of the Cisco Extensions feature (1 = enabled, 0 = not enabled)
                        	**type**\:  bool
                        
                        .. attribute:: collector_max_delay
                        
                        	Collector Max Delay
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: configured_bandwidth
                        
                        	Bandwidth configured on the bundle interface (kbps)
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: kbit/s
                        
                        .. attribute:: configured_foreign_member_count
                        
                        	The number of configured local members on the bundle
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: configured_member_count
                        
                        	The number of configured local members on the bundle
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: effective_bandwidth
                        
                        	Effective bandwidth on the bundle interface (kbps)
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: kbit/s
                        
                        .. attribute:: iccp_group_id
                        
                        	ICCP Group that the bundle is configured to
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: inter_chassis
                        
                        	Indicates if this bundle is operating as an inter\-chassis link (1 = I\-C link, 0 = normal)
                        	**type**\:  bool
                        
                        .. attribute:: ipv4bfd_status
                        
                        	The status of the BFD (IPv4) feature on the bundle
                        	**type**\:   :py:class:`BmFeatureStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmFeatureStatus>`
                        
                        .. attribute:: ipv6bfd_status
                        
                        	The status of the BFD (IPv6) feature on the bundle
                        	**type**\:   :py:class:`BmFeatureStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmFeatureStatus>`
                        
                        .. attribute:: is_active
                        
                        	Indicates the active/standby redundancy state of the device for the bundle
                        	**type**\:  bool
                        
                        .. attribute:: lacp_nonrevertive
                        
                        	The status of the LACP nonrevertive feature (1 = enable, 0 = not enabled)
                        	**type**\:  bool
                        
                        .. attribute:: lacp_status
                        
                        	The status of the LACP feature on the bundle
                        	**type**\:   :py:class:`BmFeatureStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmFeatureStatus>`
                        
                        .. attribute:: link_order_status
                        
                        	The status of the link order signaling feature on the bundle
                        	**type**\:   :py:class:`BmFeatureStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmFeatureStatus>`
                        
                        .. attribute:: load_balance_hash_type
                        
                        	The type of hash to use for load balancing
                        	**type**\:  str
                        
                        .. attribute:: load_balance_locality_threshold
                        
                        	The number of links required per rack for localized load balancing
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: mac_address
                        
                        	MAC address of this member
                        	**type**\:   :py:class:`MacAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleItem.ActorBundleData.MacAddress>`
                        
                        .. attribute:: mac_source
                        
                        	The source of the MAC Address
                        	**type**\:   :py:class:`BmBdlMacSource <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmBdlMacSource>`
                        
                        .. attribute:: mac_source_member
                        
                        	The name of the member that supplied the MAC address
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: maximize_threshold_value_band_width
                        
                        	Attempt to maximize the bundle if bandwidth is below this value
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: maximize_threshold_value_links
                        
                        	Attempt to maximize the bundle if links are below this value
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: maximum_active_links
                        
                        	Maximum number of active links in the bundle
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: maximum_active_links_source
                        
                        	Source of maximum active links value
                        	**type**\:   :py:class:`BmWhichSystem <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmWhichSystem>`
                        
                        .. attribute:: minimum_active_links
                        
                        	Minimum number of active links for bundle to go up
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: minimum_bandwidth
                        
                        	Minimum bundle bandwidth for bundle to go up (kbps)
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: kbit/s
                        
                        .. attribute:: mlacp_mode
                        
                        	Indicates the mode of the device for the bundle
                        	**type**\:   :py:class:`BundleMlacpMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleMlacpMode>`
                        
                        .. attribute:: mlacp_status
                        
                        	The status of the mLACP feature on the bundle
                        	**type**\:   :py:class:`BmFeatureStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmFeatureStatus>`
                        
                        .. attribute:: primary_member
                        
                        	Primary bundle member (no longer applicable)
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: recovery_delay
                        
                        	Number of seconds to wait before becoming active after recovering from a failure
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        	**units**\: second
                        
                        .. attribute:: singleton
                        
                        	Is the ICCP group of the bundle in singleton mode (1 = singleton; 0 = not singleton)
                        	**type**\:  bool
                        
                        .. attribute:: standby_member_count
                        
                        	The number of standby local members on the bundle
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: suppression_timer
                        
                        	Timer for suppressing bundle state flaps
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: switchover_type
                        
                        	How a switchover of the bundle from this device will occur
                        	**type**\:   :py:class:`BmdMlacpSwitchover <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmdMlacpSwitchover>`
                        
                        .. attribute:: wait_while_timer
                        
                        	The wait while time used for member ports
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'bundlemgr-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleItem.ActorBundleData, self).__init__()

                            self.yang_name = "actor-bundle-data"
                            self.yang_parent_name = "lacp-bundle-item"

                            self.active_foreign_member_count = YLeaf(YType.uint16, "active-foreign-member-count")

                            self.active_member_count = YLeaf(YType.uint16, "active-member-count")

                            self.available_bandwidth = YLeaf(YType.uint32, "available-bandwidth")

                            self.bundle_interface_name = YLeaf(YType.str, "bundle-interface-name")

                            self.bundle_status = YLeaf(YType.enumeration, "bundle-status")

                            self.cisco_extensions = YLeaf(YType.boolean, "cisco-extensions")

                            self.collector_max_delay = YLeaf(YType.uint16, "collector-max-delay")

                            self.configured_bandwidth = YLeaf(YType.uint32, "configured-bandwidth")

                            self.configured_foreign_member_count = YLeaf(YType.uint16, "configured-foreign-member-count")

                            self.configured_member_count = YLeaf(YType.uint16, "configured-member-count")

                            self.effective_bandwidth = YLeaf(YType.uint32, "effective-bandwidth")

                            self.iccp_group_id = YLeaf(YType.uint32, "iccp-group-id")

                            self.inter_chassis = YLeaf(YType.boolean, "inter-chassis")

                            self.ipv4bfd_status = YLeaf(YType.enumeration, "ipv4bfd-status")

                            self.ipv6bfd_status = YLeaf(YType.enumeration, "ipv6bfd-status")

                            self.is_active = YLeaf(YType.boolean, "is-active")

                            self.lacp_nonrevertive = YLeaf(YType.boolean, "lacp-nonrevertive")

                            self.lacp_status = YLeaf(YType.enumeration, "lacp-status")

                            self.link_order_status = YLeaf(YType.enumeration, "link-order-status")

                            self.load_balance_hash_type = YLeaf(YType.str, "load-balance-hash-type")

                            self.load_balance_locality_threshold = YLeaf(YType.uint16, "load-balance-locality-threshold")

                            self.mac_source = YLeaf(YType.enumeration, "mac-source")

                            self.mac_source_member = YLeaf(YType.str, "mac-source-member")

                            self.maximize_threshold_value_band_width = YLeaf(YType.uint32, "maximize-threshold-value-band-width")

                            self.maximize_threshold_value_links = YLeaf(YType.uint32, "maximize-threshold-value-links")

                            self.maximum_active_links = YLeaf(YType.uint8, "maximum-active-links")

                            self.maximum_active_links_source = YLeaf(YType.enumeration, "maximum-active-links-source")

                            self.minimum_active_links = YLeaf(YType.uint8, "minimum-active-links")

                            self.minimum_bandwidth = YLeaf(YType.uint32, "minimum-bandwidth")

                            self.mlacp_mode = YLeaf(YType.enumeration, "mlacp-mode")

                            self.mlacp_status = YLeaf(YType.enumeration, "mlacp-status")

                            self.primary_member = YLeaf(YType.str, "primary-member")

                            self.recovery_delay = YLeaf(YType.uint16, "recovery-delay")

                            self.singleton = YLeaf(YType.boolean, "singleton")

                            self.standby_member_count = YLeaf(YType.uint16, "standby-member-count")

                            self.suppression_timer = YLeaf(YType.uint16, "suppression-timer")

                            self.switchover_type = YLeaf(YType.enumeration, "switchover-type")

                            self.wait_while_timer = YLeaf(YType.uint16, "wait-while-timer")

                            self.mac_address = BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleItem.ActorBundleData.MacAddress()
                            self.mac_address.parent = self
                            self._children_name_map["mac_address"] = "mac-address"
                            self._children_yang_names.add("mac-address")

                            self.bfd_config = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("active_foreign_member_count",
                                            "active_member_count",
                                            "available_bandwidth",
                                            "bundle_interface_name",
                                            "bundle_status",
                                            "cisco_extensions",
                                            "collector_max_delay",
                                            "configured_bandwidth",
                                            "configured_foreign_member_count",
                                            "configured_member_count",
                                            "effective_bandwidth",
                                            "iccp_group_id",
                                            "inter_chassis",
                                            "ipv4bfd_status",
                                            "ipv6bfd_status",
                                            "is_active",
                                            "lacp_nonrevertive",
                                            "lacp_status",
                                            "link_order_status",
                                            "load_balance_hash_type",
                                            "load_balance_locality_threshold",
                                            "mac_source",
                                            "mac_source_member",
                                            "maximize_threshold_value_band_width",
                                            "maximize_threshold_value_links",
                                            "maximum_active_links",
                                            "maximum_active_links_source",
                                            "minimum_active_links",
                                            "minimum_bandwidth",
                                            "mlacp_mode",
                                            "mlacp_status",
                                            "primary_member",
                                            "recovery_delay",
                                            "singleton",
                                            "standby_member_count",
                                            "suppression_timer",
                                            "switchover_type",
                                            "wait_while_timer") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleItem.ActorBundleData, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleItem.ActorBundleData, self).__setattr__(name, value)


                        class MacAddress(Entity):
                            """
                            MAC address of this member
                            
                            .. attribute:: address
                            
                            	MAC address
                            	**type**\:  str
                            
                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                            
                            

                            """

                            _prefix = 'bundlemgr-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleItem.ActorBundleData.MacAddress, self).__init__()

                                self.yang_name = "mac-address"
                                self.yang_parent_name = "actor-bundle-data"

                                self.address = YLeaf(YType.str, "address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleItem.ActorBundleData.MacAddress, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleItem.ActorBundleData.MacAddress, self).__setattr__(name, value)

                            def has_data(self):
                                return self.address.is_set

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "mac-address" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.address.is_set or self.address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "address"):
                                    self.address = value
                                    self.address.value_namespace = name_space
                                    self.address.value_namespace_prefix = name_space_prefix


                        class BfdConfig(Entity):
                            """
                            Configuration values for BFD on bundle members
                            
                            .. attribute:: bundle_status
                            
                            	Status of BFD on the bundle
                            	**type**\:   :py:class:`BmdBfdBdlState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmdBfdBdlState>`
                            
                            .. attribute:: destination_address
                            
                            	Configured destination address for BFD session
                            	**type**\:   :py:class:`DestinationAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleItem.ActorBundleData.BfdConfig.DestinationAddress>`
                            
                            .. attribute:: fast_detect
                            
                            	Flag indicating if BFD is enabled (1 = enabled; 0 = not enabled)
                            	**type**\:  bool
                            
                            .. attribute:: mode_info
                            
                            	Standard used for per\-member BFD
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nbr_unconfig_timer
                            
                            	Time to wait on session NBR\_UNCONFIG before declaring DOWN
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: pref_echo_min_interval
                            
                            	Preferred echo minimum interval for the BFD session (ms)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: pref_min_interval
                            
                            	Preferred minimum interval for the BFD session (ms)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: pref_multiplier
                            
                            	Preferred multiplier for the BFD session
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: start_timer
                            
                            	Time to wait on session start before declaring DOWN
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'bundlemgr-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleItem.ActorBundleData.BfdConfig, self).__init__()

                                self.yang_name = "bfd-config"
                                self.yang_parent_name = "actor-bundle-data"

                                self.bundle_status = YLeaf(YType.enumeration, "bundle-status")

                                self.fast_detect = YLeaf(YType.boolean, "fast-detect")

                                self.mode_info = YLeaf(YType.uint32, "mode-info")

                                self.nbr_unconfig_timer = YLeaf(YType.uint32, "nbr-unconfig-timer")

                                self.pref_echo_min_interval = YLeaf(YType.uint32, "pref-echo-min-interval")

                                self.pref_min_interval = YLeaf(YType.uint32, "pref-min-interval")

                                self.pref_multiplier = YLeaf(YType.uint16, "pref-multiplier")

                                self.start_timer = YLeaf(YType.uint32, "start-timer")

                                self.destination_address = BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleItem.ActorBundleData.BfdConfig.DestinationAddress()
                                self.destination_address.parent = self
                                self._children_name_map["destination_address"] = "destination-address"
                                self._children_yang_names.add("destination-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("bundle_status",
                                                "fast_detect",
                                                "mode_info",
                                                "nbr_unconfig_timer",
                                                "pref_echo_min_interval",
                                                "pref_min_interval",
                                                "pref_multiplier",
                                                "start_timer") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleItem.ActorBundleData.BfdConfig, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleItem.ActorBundleData.BfdConfig, self).__setattr__(name, value)


                            class DestinationAddress(Entity):
                                """
                                Configured destination address for BFD session
                                
                                .. attribute:: af
                                
                                	AF
                                	**type**\:   :py:class:`BmAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmAfId>`
                                
                                .. attribute:: ipv4
                                
                                	IPv4 address type
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6
                                
                                	IPv6 address type
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'bundlemgr-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleItem.ActorBundleData.BfdConfig.DestinationAddress, self).__init__()

                                    self.yang_name = "destination-address"
                                    self.yang_parent_name = "bfd-config"

                                    self.af = YLeaf(YType.enumeration, "af")

                                    self.ipv4 = YLeaf(YType.str, "ipv4")

                                    self.ipv6 = YLeaf(YType.str, "ipv6")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("af",
                                                    "ipv4",
                                                    "ipv6") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleItem.ActorBundleData.BfdConfig.DestinationAddress, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleItem.ActorBundleData.BfdConfig.DestinationAddress, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.af.is_set or
                                        self.ipv4.is_set or
                                        self.ipv6.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.af.yfilter != YFilter.not_set or
                                        self.ipv4.yfilter != YFilter.not_set or
                                        self.ipv6.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "destination-address" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.af.is_set or self.af.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.af.get_name_leafdata())
                                    if (self.ipv4.is_set or self.ipv4.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv4.get_name_leafdata())
                                    if (self.ipv6.is_set or self.ipv6.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv6.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "af" or name == "ipv4" or name == "ipv6"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "af"):
                                        self.af = value
                                        self.af.value_namespace = name_space
                                        self.af.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv4"):
                                        self.ipv4 = value
                                        self.ipv4.value_namespace = name_space
                                        self.ipv4.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv6"):
                                        self.ipv6 = value
                                        self.ipv6.value_namespace = name_space
                                        self.ipv6.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.bundle_status.is_set or
                                    self.fast_detect.is_set or
                                    self.mode_info.is_set or
                                    self.nbr_unconfig_timer.is_set or
                                    self.pref_echo_min_interval.is_set or
                                    self.pref_min_interval.is_set or
                                    self.pref_multiplier.is_set or
                                    self.start_timer.is_set or
                                    (self.destination_address is not None and self.destination_address.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.bundle_status.yfilter != YFilter.not_set or
                                    self.fast_detect.yfilter != YFilter.not_set or
                                    self.mode_info.yfilter != YFilter.not_set or
                                    self.nbr_unconfig_timer.yfilter != YFilter.not_set or
                                    self.pref_echo_min_interval.yfilter != YFilter.not_set or
                                    self.pref_min_interval.yfilter != YFilter.not_set or
                                    self.pref_multiplier.yfilter != YFilter.not_set or
                                    self.start_timer.yfilter != YFilter.not_set or
                                    (self.destination_address is not None and self.destination_address.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "bfd-config" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.bundle_status.is_set or self.bundle_status.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.bundle_status.get_name_leafdata())
                                if (self.fast_detect.is_set or self.fast_detect.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.fast_detect.get_name_leafdata())
                                if (self.mode_info.is_set or self.mode_info.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mode_info.get_name_leafdata())
                                if (self.nbr_unconfig_timer.is_set or self.nbr_unconfig_timer.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.nbr_unconfig_timer.get_name_leafdata())
                                if (self.pref_echo_min_interval.is_set or self.pref_echo_min_interval.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pref_echo_min_interval.get_name_leafdata())
                                if (self.pref_min_interval.is_set or self.pref_min_interval.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pref_min_interval.get_name_leafdata())
                                if (self.pref_multiplier.is_set or self.pref_multiplier.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pref_multiplier.get_name_leafdata())
                                if (self.start_timer.is_set or self.start_timer.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.start_timer.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "destination-address"):
                                    if (self.destination_address is None):
                                        self.destination_address = BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleItem.ActorBundleData.BfdConfig.DestinationAddress()
                                        self.destination_address.parent = self
                                        self._children_name_map["destination_address"] = "destination-address"
                                    return self.destination_address

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "destination-address" or name == "bundle-status" or name == "fast-detect" or name == "mode-info" or name == "nbr-unconfig-timer" or name == "pref-echo-min-interval" or name == "pref-min-interval" or name == "pref-multiplier" or name == "start-timer"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "bundle-status"):
                                    self.bundle_status = value
                                    self.bundle_status.value_namespace = name_space
                                    self.bundle_status.value_namespace_prefix = name_space_prefix
                                if(value_path == "fast-detect"):
                                    self.fast_detect = value
                                    self.fast_detect.value_namespace = name_space
                                    self.fast_detect.value_namespace_prefix = name_space_prefix
                                if(value_path == "mode-info"):
                                    self.mode_info = value
                                    self.mode_info.value_namespace = name_space
                                    self.mode_info.value_namespace_prefix = name_space_prefix
                                if(value_path == "nbr-unconfig-timer"):
                                    self.nbr_unconfig_timer = value
                                    self.nbr_unconfig_timer.value_namespace = name_space
                                    self.nbr_unconfig_timer.value_namespace_prefix = name_space_prefix
                                if(value_path == "pref-echo-min-interval"):
                                    self.pref_echo_min_interval = value
                                    self.pref_echo_min_interval.value_namespace = name_space
                                    self.pref_echo_min_interval.value_namespace_prefix = name_space_prefix
                                if(value_path == "pref-min-interval"):
                                    self.pref_min_interval = value
                                    self.pref_min_interval.value_namespace = name_space
                                    self.pref_min_interval.value_namespace_prefix = name_space_prefix
                                if(value_path == "pref-multiplier"):
                                    self.pref_multiplier = value
                                    self.pref_multiplier.value_namespace = name_space
                                    self.pref_multiplier.value_namespace_prefix = name_space_prefix
                                if(value_path == "start-timer"):
                                    self.start_timer = value
                                    self.start_timer.value_namespace = name_space
                                    self.start_timer.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.bfd_config:
                                if (c.has_data()):
                                    return True
                            return (
                                self.active_foreign_member_count.is_set or
                                self.active_member_count.is_set or
                                self.available_bandwidth.is_set or
                                self.bundle_interface_name.is_set or
                                self.bundle_status.is_set or
                                self.cisco_extensions.is_set or
                                self.collector_max_delay.is_set or
                                self.configured_bandwidth.is_set or
                                self.configured_foreign_member_count.is_set or
                                self.configured_member_count.is_set or
                                self.effective_bandwidth.is_set or
                                self.iccp_group_id.is_set or
                                self.inter_chassis.is_set or
                                self.ipv4bfd_status.is_set or
                                self.ipv6bfd_status.is_set or
                                self.is_active.is_set or
                                self.lacp_nonrevertive.is_set or
                                self.lacp_status.is_set or
                                self.link_order_status.is_set or
                                self.load_balance_hash_type.is_set or
                                self.load_balance_locality_threshold.is_set or
                                self.mac_source.is_set or
                                self.mac_source_member.is_set or
                                self.maximize_threshold_value_band_width.is_set or
                                self.maximize_threshold_value_links.is_set or
                                self.maximum_active_links.is_set or
                                self.maximum_active_links_source.is_set or
                                self.minimum_active_links.is_set or
                                self.minimum_bandwidth.is_set or
                                self.mlacp_mode.is_set or
                                self.mlacp_status.is_set or
                                self.primary_member.is_set or
                                self.recovery_delay.is_set or
                                self.singleton.is_set or
                                self.standby_member_count.is_set or
                                self.suppression_timer.is_set or
                                self.switchover_type.is_set or
                                self.wait_while_timer.is_set or
                                (self.mac_address is not None and self.mac_address.has_data()))

                        def has_operation(self):
                            for c in self.bfd_config:
                                if (c.has_operation()):
                                    return True
                            return (
                                self.yfilter != YFilter.not_set or
                                self.active_foreign_member_count.yfilter != YFilter.not_set or
                                self.active_member_count.yfilter != YFilter.not_set or
                                self.available_bandwidth.yfilter != YFilter.not_set or
                                self.bundle_interface_name.yfilter != YFilter.not_set or
                                self.bundle_status.yfilter != YFilter.not_set or
                                self.cisco_extensions.yfilter != YFilter.not_set or
                                self.collector_max_delay.yfilter != YFilter.not_set or
                                self.configured_bandwidth.yfilter != YFilter.not_set or
                                self.configured_foreign_member_count.yfilter != YFilter.not_set or
                                self.configured_member_count.yfilter != YFilter.not_set or
                                self.effective_bandwidth.yfilter != YFilter.not_set or
                                self.iccp_group_id.yfilter != YFilter.not_set or
                                self.inter_chassis.yfilter != YFilter.not_set or
                                self.ipv4bfd_status.yfilter != YFilter.not_set or
                                self.ipv6bfd_status.yfilter != YFilter.not_set or
                                self.is_active.yfilter != YFilter.not_set or
                                self.lacp_nonrevertive.yfilter != YFilter.not_set or
                                self.lacp_status.yfilter != YFilter.not_set or
                                self.link_order_status.yfilter != YFilter.not_set or
                                self.load_balance_hash_type.yfilter != YFilter.not_set or
                                self.load_balance_locality_threshold.yfilter != YFilter.not_set or
                                self.mac_source.yfilter != YFilter.not_set or
                                self.mac_source_member.yfilter != YFilter.not_set or
                                self.maximize_threshold_value_band_width.yfilter != YFilter.not_set or
                                self.maximize_threshold_value_links.yfilter != YFilter.not_set or
                                self.maximum_active_links.yfilter != YFilter.not_set or
                                self.maximum_active_links_source.yfilter != YFilter.not_set or
                                self.minimum_active_links.yfilter != YFilter.not_set or
                                self.minimum_bandwidth.yfilter != YFilter.not_set or
                                self.mlacp_mode.yfilter != YFilter.not_set or
                                self.mlacp_status.yfilter != YFilter.not_set or
                                self.primary_member.yfilter != YFilter.not_set or
                                self.recovery_delay.yfilter != YFilter.not_set or
                                self.singleton.yfilter != YFilter.not_set or
                                self.standby_member_count.yfilter != YFilter.not_set or
                                self.suppression_timer.yfilter != YFilter.not_set or
                                self.switchover_type.yfilter != YFilter.not_set or
                                self.wait_while_timer.yfilter != YFilter.not_set or
                                (self.mac_address is not None and self.mac_address.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "actor-bundle-data" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.active_foreign_member_count.is_set or self.active_foreign_member_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.active_foreign_member_count.get_name_leafdata())
                            if (self.active_member_count.is_set or self.active_member_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.active_member_count.get_name_leafdata())
                            if (self.available_bandwidth.is_set or self.available_bandwidth.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.available_bandwidth.get_name_leafdata())
                            if (self.bundle_interface_name.is_set or self.bundle_interface_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.bundle_interface_name.get_name_leafdata())
                            if (self.bundle_status.is_set or self.bundle_status.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.bundle_status.get_name_leafdata())
                            if (self.cisco_extensions.is_set or self.cisco_extensions.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.cisco_extensions.get_name_leafdata())
                            if (self.collector_max_delay.is_set or self.collector_max_delay.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.collector_max_delay.get_name_leafdata())
                            if (self.configured_bandwidth.is_set or self.configured_bandwidth.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.configured_bandwidth.get_name_leafdata())
                            if (self.configured_foreign_member_count.is_set or self.configured_foreign_member_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.configured_foreign_member_count.get_name_leafdata())
                            if (self.configured_member_count.is_set or self.configured_member_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.configured_member_count.get_name_leafdata())
                            if (self.effective_bandwidth.is_set or self.effective_bandwidth.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.effective_bandwidth.get_name_leafdata())
                            if (self.iccp_group_id.is_set or self.iccp_group_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.iccp_group_id.get_name_leafdata())
                            if (self.inter_chassis.is_set or self.inter_chassis.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.inter_chassis.get_name_leafdata())
                            if (self.ipv4bfd_status.is_set or self.ipv4bfd_status.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4bfd_status.get_name_leafdata())
                            if (self.ipv6bfd_status.is_set or self.ipv6bfd_status.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6bfd_status.get_name_leafdata())
                            if (self.is_active.is_set or self.is_active.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_active.get_name_leafdata())
                            if (self.lacp_nonrevertive.is_set or self.lacp_nonrevertive.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.lacp_nonrevertive.get_name_leafdata())
                            if (self.lacp_status.is_set or self.lacp_status.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.lacp_status.get_name_leafdata())
                            if (self.link_order_status.is_set or self.link_order_status.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.link_order_status.get_name_leafdata())
                            if (self.load_balance_hash_type.is_set or self.load_balance_hash_type.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.load_balance_hash_type.get_name_leafdata())
                            if (self.load_balance_locality_threshold.is_set or self.load_balance_locality_threshold.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.load_balance_locality_threshold.get_name_leafdata())
                            if (self.mac_source.is_set or self.mac_source.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mac_source.get_name_leafdata())
                            if (self.mac_source_member.is_set or self.mac_source_member.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mac_source_member.get_name_leafdata())
                            if (self.maximize_threshold_value_band_width.is_set or self.maximize_threshold_value_band_width.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.maximize_threshold_value_band_width.get_name_leafdata())
                            if (self.maximize_threshold_value_links.is_set or self.maximize_threshold_value_links.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.maximize_threshold_value_links.get_name_leafdata())
                            if (self.maximum_active_links.is_set or self.maximum_active_links.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.maximum_active_links.get_name_leafdata())
                            if (self.maximum_active_links_source.is_set or self.maximum_active_links_source.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.maximum_active_links_source.get_name_leafdata())
                            if (self.minimum_active_links.is_set or self.minimum_active_links.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.minimum_active_links.get_name_leafdata())
                            if (self.minimum_bandwidth.is_set or self.minimum_bandwidth.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.minimum_bandwidth.get_name_leafdata())
                            if (self.mlacp_mode.is_set or self.mlacp_mode.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mlacp_mode.get_name_leafdata())
                            if (self.mlacp_status.is_set or self.mlacp_status.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mlacp_status.get_name_leafdata())
                            if (self.primary_member.is_set or self.primary_member.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.primary_member.get_name_leafdata())
                            if (self.recovery_delay.is_set or self.recovery_delay.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.recovery_delay.get_name_leafdata())
                            if (self.singleton.is_set or self.singleton.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.singleton.get_name_leafdata())
                            if (self.standby_member_count.is_set or self.standby_member_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.standby_member_count.get_name_leafdata())
                            if (self.suppression_timer.is_set or self.suppression_timer.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.suppression_timer.get_name_leafdata())
                            if (self.switchover_type.is_set or self.switchover_type.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.switchover_type.get_name_leafdata())
                            if (self.wait_while_timer.is_set or self.wait_while_timer.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.wait_while_timer.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "bfd-config"):
                                for c in self.bfd_config:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleItem.ActorBundleData.BfdConfig()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.bfd_config.append(c)
                                return c

                            if (child_yang_name == "mac-address"):
                                if (self.mac_address is None):
                                    self.mac_address = BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleItem.ActorBundleData.MacAddress()
                                    self.mac_address.parent = self
                                    self._children_name_map["mac_address"] = "mac-address"
                                return self.mac_address

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "bfd-config" or name == "mac-address" or name == "active-foreign-member-count" or name == "active-member-count" or name == "available-bandwidth" or name == "bundle-interface-name" or name == "bundle-status" or name == "cisco-extensions" or name == "collector-max-delay" or name == "configured-bandwidth" or name == "configured-foreign-member-count" or name == "configured-member-count" or name == "effective-bandwidth" or name == "iccp-group-id" or name == "inter-chassis" or name == "ipv4bfd-status" or name == "ipv6bfd-status" or name == "is-active" or name == "lacp-nonrevertive" or name == "lacp-status" or name == "link-order-status" or name == "load-balance-hash-type" or name == "load-balance-locality-threshold" or name == "mac-source" or name == "mac-source-member" or name == "maximize-threshold-value-band-width" or name == "maximize-threshold-value-links" or name == "maximum-active-links" or name == "maximum-active-links-source" or name == "minimum-active-links" or name == "minimum-bandwidth" or name == "mlacp-mode" or name == "mlacp-status" or name == "primary-member" or name == "recovery-delay" or name == "singleton" or name == "standby-member-count" or name == "suppression-timer" or name == "switchover-type" or name == "wait-while-timer"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "active-foreign-member-count"):
                                self.active_foreign_member_count = value
                                self.active_foreign_member_count.value_namespace = name_space
                                self.active_foreign_member_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "active-member-count"):
                                self.active_member_count = value
                                self.active_member_count.value_namespace = name_space
                                self.active_member_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "available-bandwidth"):
                                self.available_bandwidth = value
                                self.available_bandwidth.value_namespace = name_space
                                self.available_bandwidth.value_namespace_prefix = name_space_prefix
                            if(value_path == "bundle-interface-name"):
                                self.bundle_interface_name = value
                                self.bundle_interface_name.value_namespace = name_space
                                self.bundle_interface_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "bundle-status"):
                                self.bundle_status = value
                                self.bundle_status.value_namespace = name_space
                                self.bundle_status.value_namespace_prefix = name_space_prefix
                            if(value_path == "cisco-extensions"):
                                self.cisco_extensions = value
                                self.cisco_extensions.value_namespace = name_space
                                self.cisco_extensions.value_namespace_prefix = name_space_prefix
                            if(value_path == "collector-max-delay"):
                                self.collector_max_delay = value
                                self.collector_max_delay.value_namespace = name_space
                                self.collector_max_delay.value_namespace_prefix = name_space_prefix
                            if(value_path == "configured-bandwidth"):
                                self.configured_bandwidth = value
                                self.configured_bandwidth.value_namespace = name_space
                                self.configured_bandwidth.value_namespace_prefix = name_space_prefix
                            if(value_path == "configured-foreign-member-count"):
                                self.configured_foreign_member_count = value
                                self.configured_foreign_member_count.value_namespace = name_space
                                self.configured_foreign_member_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "configured-member-count"):
                                self.configured_member_count = value
                                self.configured_member_count.value_namespace = name_space
                                self.configured_member_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "effective-bandwidth"):
                                self.effective_bandwidth = value
                                self.effective_bandwidth.value_namespace = name_space
                                self.effective_bandwidth.value_namespace_prefix = name_space_prefix
                            if(value_path == "iccp-group-id"):
                                self.iccp_group_id = value
                                self.iccp_group_id.value_namespace = name_space
                                self.iccp_group_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "inter-chassis"):
                                self.inter_chassis = value
                                self.inter_chassis.value_namespace = name_space
                                self.inter_chassis.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4bfd-status"):
                                self.ipv4bfd_status = value
                                self.ipv4bfd_status.value_namespace = name_space
                                self.ipv4bfd_status.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6bfd-status"):
                                self.ipv6bfd_status = value
                                self.ipv6bfd_status.value_namespace = name_space
                                self.ipv6bfd_status.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-active"):
                                self.is_active = value
                                self.is_active.value_namespace = name_space
                                self.is_active.value_namespace_prefix = name_space_prefix
                            if(value_path == "lacp-nonrevertive"):
                                self.lacp_nonrevertive = value
                                self.lacp_nonrevertive.value_namespace = name_space
                                self.lacp_nonrevertive.value_namespace_prefix = name_space_prefix
                            if(value_path == "lacp-status"):
                                self.lacp_status = value
                                self.lacp_status.value_namespace = name_space
                                self.lacp_status.value_namespace_prefix = name_space_prefix
                            if(value_path == "link-order-status"):
                                self.link_order_status = value
                                self.link_order_status.value_namespace = name_space
                                self.link_order_status.value_namespace_prefix = name_space_prefix
                            if(value_path == "load-balance-hash-type"):
                                self.load_balance_hash_type = value
                                self.load_balance_hash_type.value_namespace = name_space
                                self.load_balance_hash_type.value_namespace_prefix = name_space_prefix
                            if(value_path == "load-balance-locality-threshold"):
                                self.load_balance_locality_threshold = value
                                self.load_balance_locality_threshold.value_namespace = name_space
                                self.load_balance_locality_threshold.value_namespace_prefix = name_space_prefix
                            if(value_path == "mac-source"):
                                self.mac_source = value
                                self.mac_source.value_namespace = name_space
                                self.mac_source.value_namespace_prefix = name_space_prefix
                            if(value_path == "mac-source-member"):
                                self.mac_source_member = value
                                self.mac_source_member.value_namespace = name_space
                                self.mac_source_member.value_namespace_prefix = name_space_prefix
                            if(value_path == "maximize-threshold-value-band-width"):
                                self.maximize_threshold_value_band_width = value
                                self.maximize_threshold_value_band_width.value_namespace = name_space
                                self.maximize_threshold_value_band_width.value_namespace_prefix = name_space_prefix
                            if(value_path == "maximize-threshold-value-links"):
                                self.maximize_threshold_value_links = value
                                self.maximize_threshold_value_links.value_namespace = name_space
                                self.maximize_threshold_value_links.value_namespace_prefix = name_space_prefix
                            if(value_path == "maximum-active-links"):
                                self.maximum_active_links = value
                                self.maximum_active_links.value_namespace = name_space
                                self.maximum_active_links.value_namespace_prefix = name_space_prefix
                            if(value_path == "maximum-active-links-source"):
                                self.maximum_active_links_source = value
                                self.maximum_active_links_source.value_namespace = name_space
                                self.maximum_active_links_source.value_namespace_prefix = name_space_prefix
                            if(value_path == "minimum-active-links"):
                                self.minimum_active_links = value
                                self.minimum_active_links.value_namespace = name_space
                                self.minimum_active_links.value_namespace_prefix = name_space_prefix
                            if(value_path == "minimum-bandwidth"):
                                self.minimum_bandwidth = value
                                self.minimum_bandwidth.value_namespace = name_space
                                self.minimum_bandwidth.value_namespace_prefix = name_space_prefix
                            if(value_path == "mlacp-mode"):
                                self.mlacp_mode = value
                                self.mlacp_mode.value_namespace = name_space
                                self.mlacp_mode.value_namespace_prefix = name_space_prefix
                            if(value_path == "mlacp-status"):
                                self.mlacp_status = value
                                self.mlacp_status.value_namespace = name_space
                                self.mlacp_status.value_namespace_prefix = name_space_prefix
                            if(value_path == "primary-member"):
                                self.primary_member = value
                                self.primary_member.value_namespace = name_space
                                self.primary_member.value_namespace_prefix = name_space_prefix
                            if(value_path == "recovery-delay"):
                                self.recovery_delay = value
                                self.recovery_delay.value_namespace = name_space
                                self.recovery_delay.value_namespace_prefix = name_space_prefix
                            if(value_path == "singleton"):
                                self.singleton = value
                                self.singleton.value_namespace = name_space
                                self.singleton.value_namespace_prefix = name_space_prefix
                            if(value_path == "standby-member-count"):
                                self.standby_member_count = value
                                self.standby_member_count.value_namespace = name_space
                                self.standby_member_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "suppression-timer"):
                                self.suppression_timer = value
                                self.suppression_timer.value_namespace = name_space
                                self.suppression_timer.value_namespace_prefix = name_space_prefix
                            if(value_path == "switchover-type"):
                                self.switchover_type = value
                                self.switchover_type.value_namespace = name_space
                                self.switchover_type.value_namespace_prefix = name_space_prefix
                            if(value_path == "wait-while-timer"):
                                self.wait_while_timer = value
                                self.wait_while_timer.value_namespace = name_space
                                self.wait_while_timer.value_namespace_prefix = name_space_prefix


                    class BundleSystemId(Entity):
                        """
                        System ID for the bundle
                        
                        .. attribute:: system_mac_addr
                        
                        	MAC Address used to identify the system
                        	**type**\:   :py:class:`SystemMacAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleItem.BundleSystemId.SystemMacAddr>`
                        
                        .. attribute:: system_prio
                        
                        	Priority of the system
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'bundlemgr-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleItem.BundleSystemId, self).__init__()

                            self.yang_name = "bundle-system-id"
                            self.yang_parent_name = "lacp-bundle-item"

                            self.system_prio = YLeaf(YType.uint16, "system-prio")

                            self.system_mac_addr = BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleItem.BundleSystemId.SystemMacAddr()
                            self.system_mac_addr.parent = self
                            self._children_name_map["system_mac_addr"] = "system-mac-addr"
                            self._children_yang_names.add("system-mac-addr")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("system_prio") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleItem.BundleSystemId, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleItem.BundleSystemId, self).__setattr__(name, value)


                        class SystemMacAddr(Entity):
                            """
                            MAC Address used to identify the system
                            
                            .. attribute:: macaddr
                            
                            	macaddr
                            	**type**\:  str
                            
                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                            
                            

                            """

                            _prefix = 'bundlemgr-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleItem.BundleSystemId.SystemMacAddr, self).__init__()

                                self.yang_name = "system-mac-addr"
                                self.yang_parent_name = "bundle-system-id"

                                self.macaddr = YLeaf(YType.str, "macaddr")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("macaddr") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleItem.BundleSystemId.SystemMacAddr, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleItem.BundleSystemId.SystemMacAddr, self).__setattr__(name, value)

                            def has_data(self):
                                return self.macaddr.is_set

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.macaddr.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "system-mac-addr" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.macaddr.is_set or self.macaddr.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.macaddr.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "macaddr"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "macaddr"):
                                    self.macaddr = value
                                    self.macaddr.value_namespace = name_space
                                    self.macaddr.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.system_prio.is_set or
                                (self.system_mac_addr is not None and self.system_mac_addr.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.system_prio.yfilter != YFilter.not_set or
                                (self.system_mac_addr is not None and self.system_mac_addr.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "bundle-system-id" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.system_prio.is_set or self.system_prio.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.system_prio.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "system-mac-addr"):
                                if (self.system_mac_addr is None):
                                    self.system_mac_addr = BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleItem.BundleSystemId.SystemMacAddr()
                                    self.system_mac_addr.parent = self
                                    self._children_name_map["system_mac_addr"] = "system-mac-addr"
                                return self.system_mac_addr

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "system-mac-addr" or name == "system-prio"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "system-prio"):
                                self.system_prio = value
                                self.system_prio.value_namespace = name_space
                                self.system_prio.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.actor_operational_key.is_set or
                            self.partner_operational_key.is_set or
                            self.partner_system_mac_address.is_set or
                            self.partner_system_priority.is_set or
                            (self.actor_bundle_data is not None and self.actor_bundle_data.has_data()) or
                            (self.bundle_system_id is not None and self.bundle_system_id.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.actor_operational_key.yfilter != YFilter.not_set or
                            self.partner_operational_key.yfilter != YFilter.not_set or
                            self.partner_system_mac_address.yfilter != YFilter.not_set or
                            self.partner_system_priority.yfilter != YFilter.not_set or
                            (self.actor_bundle_data is not None and self.actor_bundle_data.has_operation()) or
                            (self.bundle_system_id is not None and self.bundle_system_id.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "lacp-bundle-item" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.actor_operational_key.is_set or self.actor_operational_key.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.actor_operational_key.get_name_leafdata())
                        if (self.partner_operational_key.is_set or self.partner_operational_key.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.partner_operational_key.get_name_leafdata())
                        if (self.partner_system_mac_address.is_set or self.partner_system_mac_address.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.partner_system_mac_address.get_name_leafdata())
                        if (self.partner_system_priority.is_set or self.partner_system_priority.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.partner_system_priority.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "actor-bundle-data"):
                            if (self.actor_bundle_data is None):
                                self.actor_bundle_data = BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleItem.ActorBundleData()
                                self.actor_bundle_data.parent = self
                                self._children_name_map["actor_bundle_data"] = "actor-bundle-data"
                            return self.actor_bundle_data

                        if (child_yang_name == "bundle-system-id"):
                            if (self.bundle_system_id is None):
                                self.bundle_system_id = BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleItem.BundleSystemId()
                                self.bundle_system_id.parent = self
                                self._children_name_map["bundle_system_id"] = "bundle-system-id"
                            return self.bundle_system_id

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "actor-bundle-data" or name == "bundle-system-id" or name == "actor-operational-key" or name == "partner-operational-key" or name == "partner-system-mac-address" or name == "partner-system-priority"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "actor-operational-key"):
                            self.actor_operational_key = value
                            self.actor_operational_key.value_namespace = name_space
                            self.actor_operational_key.value_namespace_prefix = name_space_prefix
                        if(value_path == "partner-operational-key"):
                            self.partner_operational_key = value
                            self.partner_operational_key.value_namespace = name_space
                            self.partner_operational_key.value_namespace_prefix = name_space_prefix
                        if(value_path == "partner-system-mac-address"):
                            self.partner_system_mac_address = value
                            self.partner_system_mac_address.value_namespace = name_space
                            self.partner_system_mac_address.value_namespace_prefix = name_space_prefix
                        if(value_path == "partner-system-priority"):
                            self.partner_system_priority = value
                            self.partner_system_priority.value_namespace = name_space
                            self.partner_system_priority.value_namespace_prefix = name_space_prefix


                class LacpBundleDescendant(Entity):
                    """
                    Data for this item and all its members
                    
                    .. attribute:: bundle_data
                    
                    	Bundle information
                    	**type**\:   :py:class:`BundleData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleDescendant.BundleData>`
                    
                    .. attribute:: member_data
                    
                    	Member information
                    	**type**\: list of    :py:class:`MemberData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleDescendant.MemberData>`
                    
                    

                    """

                    _prefix = 'bundlemgr-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleDescendant, self).__init__()

                        self.yang_name = "lacp-bundle-descendant"
                        self.yang_parent_name = "lacp-bundle"

                        self.bundle_data = BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleDescendant.BundleData()
                        self.bundle_data.parent = self
                        self._children_name_map["bundle_data"] = "bundle-data"
                        self._children_yang_names.add("bundle-data")

                        self.member_data = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleDescendant, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleDescendant, self).__setattr__(name, value)


                    class BundleData(Entity):
                        """
                        Bundle information
                        
                        .. attribute:: actor_bundle_data
                        
                        	Basic bundle information
                        	**type**\:   :py:class:`ActorBundleData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleDescendant.BundleData.ActorBundleData>`
                        
                        .. attribute:: actor_operational_key
                        
                        	Operational key of the interface
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: bundle_system_id
                        
                        	System ID for the bundle
                        	**type**\:   :py:class:`BundleSystemId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleDescendant.BundleData.BundleSystemId>`
                        
                        .. attribute:: partner_operational_key
                        
                        	Operational key of the partner
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: partner_system_mac_address
                        
                        	MAC Address used to identify the partner system
                        	**type**\:  str
                        
                        	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                        
                        .. attribute:: partner_system_priority
                        
                        	Priority of the partner system
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'bundlemgr-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleDescendant.BundleData, self).__init__()

                            self.yang_name = "bundle-data"
                            self.yang_parent_name = "lacp-bundle-descendant"

                            self.actor_operational_key = YLeaf(YType.uint16, "actor-operational-key")

                            self.partner_operational_key = YLeaf(YType.uint16, "partner-operational-key")

                            self.partner_system_mac_address = YLeaf(YType.str, "partner-system-mac-address")

                            self.partner_system_priority = YLeaf(YType.uint16, "partner-system-priority")

                            self.actor_bundle_data = BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleDescendant.BundleData.ActorBundleData()
                            self.actor_bundle_data.parent = self
                            self._children_name_map["actor_bundle_data"] = "actor-bundle-data"
                            self._children_yang_names.add("actor-bundle-data")

                            self.bundle_system_id = BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleDescendant.BundleData.BundleSystemId()
                            self.bundle_system_id.parent = self
                            self._children_name_map["bundle_system_id"] = "bundle-system-id"
                            self._children_yang_names.add("bundle-system-id")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("actor_operational_key",
                                            "partner_operational_key",
                                            "partner_system_mac_address",
                                            "partner_system_priority") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleDescendant.BundleData, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleDescendant.BundleData, self).__setattr__(name, value)


                        class ActorBundleData(Entity):
                            """
                            Basic bundle information
                            
                            .. attribute:: active_foreign_member_count
                            
                            	The number of active foreign members on the bundle
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: active_member_count
                            
                            	The number of active local members on the bundle
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: available_bandwidth
                            
                            	Bandwidth available to the bundle interface (kbps)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: bfd_config
                            
                            	Configuration values for BFD on bundle members
                            	**type**\: list of    :py:class:`BfdConfig <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleDescendant.BundleData.ActorBundleData.BfdConfig>`
                            
                            .. attribute:: bundle_interface_name
                            
                            	Bundle interface name
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: bundle_status
                            
                            	The state of the bundle
                            	**type**\:   :py:class:`BmBdlState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmBdlState>`
                            
                            .. attribute:: cisco_extensions
                            
                            	The status of the Cisco Extensions feature (1 = enabled, 0 = not enabled)
                            	**type**\:  bool
                            
                            .. attribute:: collector_max_delay
                            
                            	Collector Max Delay
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: configured_bandwidth
                            
                            	Bandwidth configured on the bundle interface (kbps)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: configured_foreign_member_count
                            
                            	The number of configured local members on the bundle
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: configured_member_count
                            
                            	The number of configured local members on the bundle
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: effective_bandwidth
                            
                            	Effective bandwidth on the bundle interface (kbps)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: iccp_group_id
                            
                            	ICCP Group that the bundle is configured to
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: inter_chassis
                            
                            	Indicates if this bundle is operating as an inter\-chassis link (1 = I\-C link, 0 = normal)
                            	**type**\:  bool
                            
                            .. attribute:: ipv4bfd_status
                            
                            	The status of the BFD (IPv4) feature on the bundle
                            	**type**\:   :py:class:`BmFeatureStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmFeatureStatus>`
                            
                            .. attribute:: ipv6bfd_status
                            
                            	The status of the BFD (IPv6) feature on the bundle
                            	**type**\:   :py:class:`BmFeatureStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmFeatureStatus>`
                            
                            .. attribute:: is_active
                            
                            	Indicates the active/standby redundancy state of the device for the bundle
                            	**type**\:  bool
                            
                            .. attribute:: lacp_nonrevertive
                            
                            	The status of the LACP nonrevertive feature (1 = enable, 0 = not enabled)
                            	**type**\:  bool
                            
                            .. attribute:: lacp_status
                            
                            	The status of the LACP feature on the bundle
                            	**type**\:   :py:class:`BmFeatureStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmFeatureStatus>`
                            
                            .. attribute:: link_order_status
                            
                            	The status of the link order signaling feature on the bundle
                            	**type**\:   :py:class:`BmFeatureStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmFeatureStatus>`
                            
                            .. attribute:: load_balance_hash_type
                            
                            	The type of hash to use for load balancing
                            	**type**\:  str
                            
                            .. attribute:: load_balance_locality_threshold
                            
                            	The number of links required per rack for localized load balancing
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: mac_address
                            
                            	MAC address of this member
                            	**type**\:   :py:class:`MacAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleDescendant.BundleData.ActorBundleData.MacAddress>`
                            
                            .. attribute:: mac_source
                            
                            	The source of the MAC Address
                            	**type**\:   :py:class:`BmBdlMacSource <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmBdlMacSource>`
                            
                            .. attribute:: mac_source_member
                            
                            	The name of the member that supplied the MAC address
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: maximize_threshold_value_band_width
                            
                            	Attempt to maximize the bundle if bandwidth is below this value
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: maximize_threshold_value_links
                            
                            	Attempt to maximize the bundle if links are below this value
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: maximum_active_links
                            
                            	Maximum number of active links in the bundle
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: maximum_active_links_source
                            
                            	Source of maximum active links value
                            	**type**\:   :py:class:`BmWhichSystem <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmWhichSystem>`
                            
                            .. attribute:: minimum_active_links
                            
                            	Minimum number of active links for bundle to go up
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: minimum_bandwidth
                            
                            	Minimum bundle bandwidth for bundle to go up (kbps)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: mlacp_mode
                            
                            	Indicates the mode of the device for the bundle
                            	**type**\:   :py:class:`BundleMlacpMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleMlacpMode>`
                            
                            .. attribute:: mlacp_status
                            
                            	The status of the mLACP feature on the bundle
                            	**type**\:   :py:class:`BmFeatureStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmFeatureStatus>`
                            
                            .. attribute:: primary_member
                            
                            	Primary bundle member (no longer applicable)
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: recovery_delay
                            
                            	Number of seconds to wait before becoming active after recovering from a failure
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            	**units**\: second
                            
                            .. attribute:: singleton
                            
                            	Is the ICCP group of the bundle in singleton mode (1 = singleton; 0 = not singleton)
                            	**type**\:  bool
                            
                            .. attribute:: standby_member_count
                            
                            	The number of standby local members on the bundle
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: suppression_timer
                            
                            	Timer for suppressing bundle state flaps
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: switchover_type
                            
                            	How a switchover of the bundle from this device will occur
                            	**type**\:   :py:class:`BmdMlacpSwitchover <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmdMlacpSwitchover>`
                            
                            .. attribute:: wait_while_timer
                            
                            	The wait while time used for member ports
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'bundlemgr-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleDescendant.BundleData.ActorBundleData, self).__init__()

                                self.yang_name = "actor-bundle-data"
                                self.yang_parent_name = "bundle-data"

                                self.active_foreign_member_count = YLeaf(YType.uint16, "active-foreign-member-count")

                                self.active_member_count = YLeaf(YType.uint16, "active-member-count")

                                self.available_bandwidth = YLeaf(YType.uint32, "available-bandwidth")

                                self.bundle_interface_name = YLeaf(YType.str, "bundle-interface-name")

                                self.bundle_status = YLeaf(YType.enumeration, "bundle-status")

                                self.cisco_extensions = YLeaf(YType.boolean, "cisco-extensions")

                                self.collector_max_delay = YLeaf(YType.uint16, "collector-max-delay")

                                self.configured_bandwidth = YLeaf(YType.uint32, "configured-bandwidth")

                                self.configured_foreign_member_count = YLeaf(YType.uint16, "configured-foreign-member-count")

                                self.configured_member_count = YLeaf(YType.uint16, "configured-member-count")

                                self.effective_bandwidth = YLeaf(YType.uint32, "effective-bandwidth")

                                self.iccp_group_id = YLeaf(YType.uint32, "iccp-group-id")

                                self.inter_chassis = YLeaf(YType.boolean, "inter-chassis")

                                self.ipv4bfd_status = YLeaf(YType.enumeration, "ipv4bfd-status")

                                self.ipv6bfd_status = YLeaf(YType.enumeration, "ipv6bfd-status")

                                self.is_active = YLeaf(YType.boolean, "is-active")

                                self.lacp_nonrevertive = YLeaf(YType.boolean, "lacp-nonrevertive")

                                self.lacp_status = YLeaf(YType.enumeration, "lacp-status")

                                self.link_order_status = YLeaf(YType.enumeration, "link-order-status")

                                self.load_balance_hash_type = YLeaf(YType.str, "load-balance-hash-type")

                                self.load_balance_locality_threshold = YLeaf(YType.uint16, "load-balance-locality-threshold")

                                self.mac_source = YLeaf(YType.enumeration, "mac-source")

                                self.mac_source_member = YLeaf(YType.str, "mac-source-member")

                                self.maximize_threshold_value_band_width = YLeaf(YType.uint32, "maximize-threshold-value-band-width")

                                self.maximize_threshold_value_links = YLeaf(YType.uint32, "maximize-threshold-value-links")

                                self.maximum_active_links = YLeaf(YType.uint8, "maximum-active-links")

                                self.maximum_active_links_source = YLeaf(YType.enumeration, "maximum-active-links-source")

                                self.minimum_active_links = YLeaf(YType.uint8, "minimum-active-links")

                                self.minimum_bandwidth = YLeaf(YType.uint32, "minimum-bandwidth")

                                self.mlacp_mode = YLeaf(YType.enumeration, "mlacp-mode")

                                self.mlacp_status = YLeaf(YType.enumeration, "mlacp-status")

                                self.primary_member = YLeaf(YType.str, "primary-member")

                                self.recovery_delay = YLeaf(YType.uint16, "recovery-delay")

                                self.singleton = YLeaf(YType.boolean, "singleton")

                                self.standby_member_count = YLeaf(YType.uint16, "standby-member-count")

                                self.suppression_timer = YLeaf(YType.uint16, "suppression-timer")

                                self.switchover_type = YLeaf(YType.enumeration, "switchover-type")

                                self.wait_while_timer = YLeaf(YType.uint16, "wait-while-timer")

                                self.mac_address = BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleDescendant.BundleData.ActorBundleData.MacAddress()
                                self.mac_address.parent = self
                                self._children_name_map["mac_address"] = "mac-address"
                                self._children_yang_names.add("mac-address")

                                self.bfd_config = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("active_foreign_member_count",
                                                "active_member_count",
                                                "available_bandwidth",
                                                "bundle_interface_name",
                                                "bundle_status",
                                                "cisco_extensions",
                                                "collector_max_delay",
                                                "configured_bandwidth",
                                                "configured_foreign_member_count",
                                                "configured_member_count",
                                                "effective_bandwidth",
                                                "iccp_group_id",
                                                "inter_chassis",
                                                "ipv4bfd_status",
                                                "ipv6bfd_status",
                                                "is_active",
                                                "lacp_nonrevertive",
                                                "lacp_status",
                                                "link_order_status",
                                                "load_balance_hash_type",
                                                "load_balance_locality_threshold",
                                                "mac_source",
                                                "mac_source_member",
                                                "maximize_threshold_value_band_width",
                                                "maximize_threshold_value_links",
                                                "maximum_active_links",
                                                "maximum_active_links_source",
                                                "minimum_active_links",
                                                "minimum_bandwidth",
                                                "mlacp_mode",
                                                "mlacp_status",
                                                "primary_member",
                                                "recovery_delay",
                                                "singleton",
                                                "standby_member_count",
                                                "suppression_timer",
                                                "switchover_type",
                                                "wait_while_timer") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleDescendant.BundleData.ActorBundleData, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleDescendant.BundleData.ActorBundleData, self).__setattr__(name, value)


                            class MacAddress(Entity):
                                """
                                MAC address of this member
                                
                                .. attribute:: address
                                
                                	MAC address
                                	**type**\:  str
                                
                                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                
                                

                                """

                                _prefix = 'bundlemgr-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleDescendant.BundleData.ActorBundleData.MacAddress, self).__init__()

                                    self.yang_name = "mac-address"
                                    self.yang_parent_name = "actor-bundle-data"

                                    self.address = YLeaf(YType.str, "address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleDescendant.BundleData.ActorBundleData.MacAddress, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleDescendant.BundleData.ActorBundleData.MacAddress, self).__setattr__(name, value)

                                def has_data(self):
                                    return self.address.is_set

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "mac-address" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.address.is_set or self.address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "address"):
                                        self.address = value
                                        self.address.value_namespace = name_space
                                        self.address.value_namespace_prefix = name_space_prefix


                            class BfdConfig(Entity):
                                """
                                Configuration values for BFD on bundle members
                                
                                .. attribute:: bundle_status
                                
                                	Status of BFD on the bundle
                                	**type**\:   :py:class:`BmdBfdBdlState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmdBfdBdlState>`
                                
                                .. attribute:: destination_address
                                
                                	Configured destination address for BFD session
                                	**type**\:   :py:class:`DestinationAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleDescendant.BundleData.ActorBundleData.BfdConfig.DestinationAddress>`
                                
                                .. attribute:: fast_detect
                                
                                	Flag indicating if BFD is enabled (1 = enabled; 0 = not enabled)
                                	**type**\:  bool
                                
                                .. attribute:: mode_info
                                
                                	Standard used for per\-member BFD
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: nbr_unconfig_timer
                                
                                	Time to wait on session NBR\_UNCONFIG before declaring DOWN
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: pref_echo_min_interval
                                
                                	Preferred echo minimum interval for the BFD session (ms)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: pref_min_interval
                                
                                	Preferred minimum interval for the BFD session (ms)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: pref_multiplier
                                
                                	Preferred multiplier for the BFD session
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: start_timer
                                
                                	Time to wait on session start before declaring DOWN
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'bundlemgr-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleDescendant.BundleData.ActorBundleData.BfdConfig, self).__init__()

                                    self.yang_name = "bfd-config"
                                    self.yang_parent_name = "actor-bundle-data"

                                    self.bundle_status = YLeaf(YType.enumeration, "bundle-status")

                                    self.fast_detect = YLeaf(YType.boolean, "fast-detect")

                                    self.mode_info = YLeaf(YType.uint32, "mode-info")

                                    self.nbr_unconfig_timer = YLeaf(YType.uint32, "nbr-unconfig-timer")

                                    self.pref_echo_min_interval = YLeaf(YType.uint32, "pref-echo-min-interval")

                                    self.pref_min_interval = YLeaf(YType.uint32, "pref-min-interval")

                                    self.pref_multiplier = YLeaf(YType.uint16, "pref-multiplier")

                                    self.start_timer = YLeaf(YType.uint32, "start-timer")

                                    self.destination_address = BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleDescendant.BundleData.ActorBundleData.BfdConfig.DestinationAddress()
                                    self.destination_address.parent = self
                                    self._children_name_map["destination_address"] = "destination-address"
                                    self._children_yang_names.add("destination-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("bundle_status",
                                                    "fast_detect",
                                                    "mode_info",
                                                    "nbr_unconfig_timer",
                                                    "pref_echo_min_interval",
                                                    "pref_min_interval",
                                                    "pref_multiplier",
                                                    "start_timer") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleDescendant.BundleData.ActorBundleData.BfdConfig, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleDescendant.BundleData.ActorBundleData.BfdConfig, self).__setattr__(name, value)


                                class DestinationAddress(Entity):
                                    """
                                    Configured destination address for BFD session
                                    
                                    .. attribute:: af
                                    
                                    	AF
                                    	**type**\:   :py:class:`BmAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmAfId>`
                                    
                                    .. attribute:: ipv4
                                    
                                    	IPv4 address type
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6
                                    
                                    	IPv6 address type
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'bundlemgr-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleDescendant.BundleData.ActorBundleData.BfdConfig.DestinationAddress, self).__init__()

                                        self.yang_name = "destination-address"
                                        self.yang_parent_name = "bfd-config"

                                        self.af = YLeaf(YType.enumeration, "af")

                                        self.ipv4 = YLeaf(YType.str, "ipv4")

                                        self.ipv6 = YLeaf(YType.str, "ipv6")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("af",
                                                        "ipv4",
                                                        "ipv6") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleDescendant.BundleData.ActorBundleData.BfdConfig.DestinationAddress, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleDescendant.BundleData.ActorBundleData.BfdConfig.DestinationAddress, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.af.is_set or
                                            self.ipv4.is_set or
                                            self.ipv6.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.af.yfilter != YFilter.not_set or
                                            self.ipv4.yfilter != YFilter.not_set or
                                            self.ipv6.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "destination-address" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.af.is_set or self.af.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.af.get_name_leafdata())
                                        if (self.ipv4.is_set or self.ipv4.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ipv4.get_name_leafdata())
                                        if (self.ipv6.is_set or self.ipv6.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ipv6.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "af" or name == "ipv4" or name == "ipv6"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "af"):
                                            self.af = value
                                            self.af.value_namespace = name_space
                                            self.af.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ipv4"):
                                            self.ipv4 = value
                                            self.ipv4.value_namespace = name_space
                                            self.ipv4.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ipv6"):
                                            self.ipv6 = value
                                            self.ipv6.value_namespace = name_space
                                            self.ipv6.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.bundle_status.is_set or
                                        self.fast_detect.is_set or
                                        self.mode_info.is_set or
                                        self.nbr_unconfig_timer.is_set or
                                        self.pref_echo_min_interval.is_set or
                                        self.pref_min_interval.is_set or
                                        self.pref_multiplier.is_set or
                                        self.start_timer.is_set or
                                        (self.destination_address is not None and self.destination_address.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.bundle_status.yfilter != YFilter.not_set or
                                        self.fast_detect.yfilter != YFilter.not_set or
                                        self.mode_info.yfilter != YFilter.not_set or
                                        self.nbr_unconfig_timer.yfilter != YFilter.not_set or
                                        self.pref_echo_min_interval.yfilter != YFilter.not_set or
                                        self.pref_min_interval.yfilter != YFilter.not_set or
                                        self.pref_multiplier.yfilter != YFilter.not_set or
                                        self.start_timer.yfilter != YFilter.not_set or
                                        (self.destination_address is not None and self.destination_address.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "bfd-config" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.bundle_status.is_set or self.bundle_status.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.bundle_status.get_name_leafdata())
                                    if (self.fast_detect.is_set or self.fast_detect.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.fast_detect.get_name_leafdata())
                                    if (self.mode_info.is_set or self.mode_info.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.mode_info.get_name_leafdata())
                                    if (self.nbr_unconfig_timer.is_set or self.nbr_unconfig_timer.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.nbr_unconfig_timer.get_name_leafdata())
                                    if (self.pref_echo_min_interval.is_set or self.pref_echo_min_interval.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.pref_echo_min_interval.get_name_leafdata())
                                    if (self.pref_min_interval.is_set or self.pref_min_interval.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.pref_min_interval.get_name_leafdata())
                                    if (self.pref_multiplier.is_set or self.pref_multiplier.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.pref_multiplier.get_name_leafdata())
                                    if (self.start_timer.is_set or self.start_timer.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.start_timer.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "destination-address"):
                                        if (self.destination_address is None):
                                            self.destination_address = BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleDescendant.BundleData.ActorBundleData.BfdConfig.DestinationAddress()
                                            self.destination_address.parent = self
                                            self._children_name_map["destination_address"] = "destination-address"
                                        return self.destination_address

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "destination-address" or name == "bundle-status" or name == "fast-detect" or name == "mode-info" or name == "nbr-unconfig-timer" or name == "pref-echo-min-interval" or name == "pref-min-interval" or name == "pref-multiplier" or name == "start-timer"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "bundle-status"):
                                        self.bundle_status = value
                                        self.bundle_status.value_namespace = name_space
                                        self.bundle_status.value_namespace_prefix = name_space_prefix
                                    if(value_path == "fast-detect"):
                                        self.fast_detect = value
                                        self.fast_detect.value_namespace = name_space
                                        self.fast_detect.value_namespace_prefix = name_space_prefix
                                    if(value_path == "mode-info"):
                                        self.mode_info = value
                                        self.mode_info.value_namespace = name_space
                                        self.mode_info.value_namespace_prefix = name_space_prefix
                                    if(value_path == "nbr-unconfig-timer"):
                                        self.nbr_unconfig_timer = value
                                        self.nbr_unconfig_timer.value_namespace = name_space
                                        self.nbr_unconfig_timer.value_namespace_prefix = name_space_prefix
                                    if(value_path == "pref-echo-min-interval"):
                                        self.pref_echo_min_interval = value
                                        self.pref_echo_min_interval.value_namespace = name_space
                                        self.pref_echo_min_interval.value_namespace_prefix = name_space_prefix
                                    if(value_path == "pref-min-interval"):
                                        self.pref_min_interval = value
                                        self.pref_min_interval.value_namespace = name_space
                                        self.pref_min_interval.value_namespace_prefix = name_space_prefix
                                    if(value_path == "pref-multiplier"):
                                        self.pref_multiplier = value
                                        self.pref_multiplier.value_namespace = name_space
                                        self.pref_multiplier.value_namespace_prefix = name_space_prefix
                                    if(value_path == "start-timer"):
                                        self.start_timer = value
                                        self.start_timer.value_namespace = name_space
                                        self.start_timer.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.bfd_config:
                                    if (c.has_data()):
                                        return True
                                return (
                                    self.active_foreign_member_count.is_set or
                                    self.active_member_count.is_set or
                                    self.available_bandwidth.is_set or
                                    self.bundle_interface_name.is_set or
                                    self.bundle_status.is_set or
                                    self.cisco_extensions.is_set or
                                    self.collector_max_delay.is_set or
                                    self.configured_bandwidth.is_set or
                                    self.configured_foreign_member_count.is_set or
                                    self.configured_member_count.is_set or
                                    self.effective_bandwidth.is_set or
                                    self.iccp_group_id.is_set or
                                    self.inter_chassis.is_set or
                                    self.ipv4bfd_status.is_set or
                                    self.ipv6bfd_status.is_set or
                                    self.is_active.is_set or
                                    self.lacp_nonrevertive.is_set or
                                    self.lacp_status.is_set or
                                    self.link_order_status.is_set or
                                    self.load_balance_hash_type.is_set or
                                    self.load_balance_locality_threshold.is_set or
                                    self.mac_source.is_set or
                                    self.mac_source_member.is_set or
                                    self.maximize_threshold_value_band_width.is_set or
                                    self.maximize_threshold_value_links.is_set or
                                    self.maximum_active_links.is_set or
                                    self.maximum_active_links_source.is_set or
                                    self.minimum_active_links.is_set or
                                    self.minimum_bandwidth.is_set or
                                    self.mlacp_mode.is_set or
                                    self.mlacp_status.is_set or
                                    self.primary_member.is_set or
                                    self.recovery_delay.is_set or
                                    self.singleton.is_set or
                                    self.standby_member_count.is_set or
                                    self.suppression_timer.is_set or
                                    self.switchover_type.is_set or
                                    self.wait_while_timer.is_set or
                                    (self.mac_address is not None and self.mac_address.has_data()))

                            def has_operation(self):
                                for c in self.bfd_config:
                                    if (c.has_operation()):
                                        return True
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.active_foreign_member_count.yfilter != YFilter.not_set or
                                    self.active_member_count.yfilter != YFilter.not_set or
                                    self.available_bandwidth.yfilter != YFilter.not_set or
                                    self.bundle_interface_name.yfilter != YFilter.not_set or
                                    self.bundle_status.yfilter != YFilter.not_set or
                                    self.cisco_extensions.yfilter != YFilter.not_set or
                                    self.collector_max_delay.yfilter != YFilter.not_set or
                                    self.configured_bandwidth.yfilter != YFilter.not_set or
                                    self.configured_foreign_member_count.yfilter != YFilter.not_set or
                                    self.configured_member_count.yfilter != YFilter.not_set or
                                    self.effective_bandwidth.yfilter != YFilter.not_set or
                                    self.iccp_group_id.yfilter != YFilter.not_set or
                                    self.inter_chassis.yfilter != YFilter.not_set or
                                    self.ipv4bfd_status.yfilter != YFilter.not_set or
                                    self.ipv6bfd_status.yfilter != YFilter.not_set or
                                    self.is_active.yfilter != YFilter.not_set or
                                    self.lacp_nonrevertive.yfilter != YFilter.not_set or
                                    self.lacp_status.yfilter != YFilter.not_set or
                                    self.link_order_status.yfilter != YFilter.not_set or
                                    self.load_balance_hash_type.yfilter != YFilter.not_set or
                                    self.load_balance_locality_threshold.yfilter != YFilter.not_set or
                                    self.mac_source.yfilter != YFilter.not_set or
                                    self.mac_source_member.yfilter != YFilter.not_set or
                                    self.maximize_threshold_value_band_width.yfilter != YFilter.not_set or
                                    self.maximize_threshold_value_links.yfilter != YFilter.not_set or
                                    self.maximum_active_links.yfilter != YFilter.not_set or
                                    self.maximum_active_links_source.yfilter != YFilter.not_set or
                                    self.minimum_active_links.yfilter != YFilter.not_set or
                                    self.minimum_bandwidth.yfilter != YFilter.not_set or
                                    self.mlacp_mode.yfilter != YFilter.not_set or
                                    self.mlacp_status.yfilter != YFilter.not_set or
                                    self.primary_member.yfilter != YFilter.not_set or
                                    self.recovery_delay.yfilter != YFilter.not_set or
                                    self.singleton.yfilter != YFilter.not_set or
                                    self.standby_member_count.yfilter != YFilter.not_set or
                                    self.suppression_timer.yfilter != YFilter.not_set or
                                    self.switchover_type.yfilter != YFilter.not_set or
                                    self.wait_while_timer.yfilter != YFilter.not_set or
                                    (self.mac_address is not None and self.mac_address.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "actor-bundle-data" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.active_foreign_member_count.is_set or self.active_foreign_member_count.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.active_foreign_member_count.get_name_leafdata())
                                if (self.active_member_count.is_set or self.active_member_count.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.active_member_count.get_name_leafdata())
                                if (self.available_bandwidth.is_set or self.available_bandwidth.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.available_bandwidth.get_name_leafdata())
                                if (self.bundle_interface_name.is_set or self.bundle_interface_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.bundle_interface_name.get_name_leafdata())
                                if (self.bundle_status.is_set or self.bundle_status.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.bundle_status.get_name_leafdata())
                                if (self.cisco_extensions.is_set or self.cisco_extensions.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.cisco_extensions.get_name_leafdata())
                                if (self.collector_max_delay.is_set or self.collector_max_delay.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.collector_max_delay.get_name_leafdata())
                                if (self.configured_bandwidth.is_set or self.configured_bandwidth.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.configured_bandwidth.get_name_leafdata())
                                if (self.configured_foreign_member_count.is_set or self.configured_foreign_member_count.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.configured_foreign_member_count.get_name_leafdata())
                                if (self.configured_member_count.is_set or self.configured_member_count.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.configured_member_count.get_name_leafdata())
                                if (self.effective_bandwidth.is_set or self.effective_bandwidth.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.effective_bandwidth.get_name_leafdata())
                                if (self.iccp_group_id.is_set or self.iccp_group_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.iccp_group_id.get_name_leafdata())
                                if (self.inter_chassis.is_set or self.inter_chassis.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.inter_chassis.get_name_leafdata())
                                if (self.ipv4bfd_status.is_set or self.ipv4bfd_status.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4bfd_status.get_name_leafdata())
                                if (self.ipv6bfd_status.is_set or self.ipv6bfd_status.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6bfd_status.get_name_leafdata())
                                if (self.is_active.is_set or self.is_active.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_active.get_name_leafdata())
                                if (self.lacp_nonrevertive.is_set or self.lacp_nonrevertive.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.lacp_nonrevertive.get_name_leafdata())
                                if (self.lacp_status.is_set or self.lacp_status.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.lacp_status.get_name_leafdata())
                                if (self.link_order_status.is_set or self.link_order_status.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.link_order_status.get_name_leafdata())
                                if (self.load_balance_hash_type.is_set or self.load_balance_hash_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.load_balance_hash_type.get_name_leafdata())
                                if (self.load_balance_locality_threshold.is_set or self.load_balance_locality_threshold.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.load_balance_locality_threshold.get_name_leafdata())
                                if (self.mac_source.is_set or self.mac_source.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mac_source.get_name_leafdata())
                                if (self.mac_source_member.is_set or self.mac_source_member.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mac_source_member.get_name_leafdata())
                                if (self.maximize_threshold_value_band_width.is_set or self.maximize_threshold_value_band_width.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.maximize_threshold_value_band_width.get_name_leafdata())
                                if (self.maximize_threshold_value_links.is_set or self.maximize_threshold_value_links.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.maximize_threshold_value_links.get_name_leafdata())
                                if (self.maximum_active_links.is_set or self.maximum_active_links.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.maximum_active_links.get_name_leafdata())
                                if (self.maximum_active_links_source.is_set or self.maximum_active_links_source.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.maximum_active_links_source.get_name_leafdata())
                                if (self.minimum_active_links.is_set or self.minimum_active_links.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.minimum_active_links.get_name_leafdata())
                                if (self.minimum_bandwidth.is_set or self.minimum_bandwidth.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.minimum_bandwidth.get_name_leafdata())
                                if (self.mlacp_mode.is_set or self.mlacp_mode.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mlacp_mode.get_name_leafdata())
                                if (self.mlacp_status.is_set or self.mlacp_status.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mlacp_status.get_name_leafdata())
                                if (self.primary_member.is_set or self.primary_member.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.primary_member.get_name_leafdata())
                                if (self.recovery_delay.is_set or self.recovery_delay.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.recovery_delay.get_name_leafdata())
                                if (self.singleton.is_set or self.singleton.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.singleton.get_name_leafdata())
                                if (self.standby_member_count.is_set or self.standby_member_count.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.standby_member_count.get_name_leafdata())
                                if (self.suppression_timer.is_set or self.suppression_timer.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.suppression_timer.get_name_leafdata())
                                if (self.switchover_type.is_set or self.switchover_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.switchover_type.get_name_leafdata())
                                if (self.wait_while_timer.is_set or self.wait_while_timer.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.wait_while_timer.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "bfd-config"):
                                    for c in self.bfd_config:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleDescendant.BundleData.ActorBundleData.BfdConfig()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.bfd_config.append(c)
                                    return c

                                if (child_yang_name == "mac-address"):
                                    if (self.mac_address is None):
                                        self.mac_address = BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleDescendant.BundleData.ActorBundleData.MacAddress()
                                        self.mac_address.parent = self
                                        self._children_name_map["mac_address"] = "mac-address"
                                    return self.mac_address

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "bfd-config" or name == "mac-address" or name == "active-foreign-member-count" or name == "active-member-count" or name == "available-bandwidth" or name == "bundle-interface-name" or name == "bundle-status" or name == "cisco-extensions" or name == "collector-max-delay" or name == "configured-bandwidth" or name == "configured-foreign-member-count" or name == "configured-member-count" or name == "effective-bandwidth" or name == "iccp-group-id" or name == "inter-chassis" or name == "ipv4bfd-status" or name == "ipv6bfd-status" or name == "is-active" or name == "lacp-nonrevertive" or name == "lacp-status" or name == "link-order-status" or name == "load-balance-hash-type" or name == "load-balance-locality-threshold" or name == "mac-source" or name == "mac-source-member" or name == "maximize-threshold-value-band-width" or name == "maximize-threshold-value-links" or name == "maximum-active-links" or name == "maximum-active-links-source" or name == "minimum-active-links" or name == "minimum-bandwidth" or name == "mlacp-mode" or name == "mlacp-status" or name == "primary-member" or name == "recovery-delay" or name == "singleton" or name == "standby-member-count" or name == "suppression-timer" or name == "switchover-type" or name == "wait-while-timer"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "active-foreign-member-count"):
                                    self.active_foreign_member_count = value
                                    self.active_foreign_member_count.value_namespace = name_space
                                    self.active_foreign_member_count.value_namespace_prefix = name_space_prefix
                                if(value_path == "active-member-count"):
                                    self.active_member_count = value
                                    self.active_member_count.value_namespace = name_space
                                    self.active_member_count.value_namespace_prefix = name_space_prefix
                                if(value_path == "available-bandwidth"):
                                    self.available_bandwidth = value
                                    self.available_bandwidth.value_namespace = name_space
                                    self.available_bandwidth.value_namespace_prefix = name_space_prefix
                                if(value_path == "bundle-interface-name"):
                                    self.bundle_interface_name = value
                                    self.bundle_interface_name.value_namespace = name_space
                                    self.bundle_interface_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "bundle-status"):
                                    self.bundle_status = value
                                    self.bundle_status.value_namespace = name_space
                                    self.bundle_status.value_namespace_prefix = name_space_prefix
                                if(value_path == "cisco-extensions"):
                                    self.cisco_extensions = value
                                    self.cisco_extensions.value_namespace = name_space
                                    self.cisco_extensions.value_namespace_prefix = name_space_prefix
                                if(value_path == "collector-max-delay"):
                                    self.collector_max_delay = value
                                    self.collector_max_delay.value_namespace = name_space
                                    self.collector_max_delay.value_namespace_prefix = name_space_prefix
                                if(value_path == "configured-bandwidth"):
                                    self.configured_bandwidth = value
                                    self.configured_bandwidth.value_namespace = name_space
                                    self.configured_bandwidth.value_namespace_prefix = name_space_prefix
                                if(value_path == "configured-foreign-member-count"):
                                    self.configured_foreign_member_count = value
                                    self.configured_foreign_member_count.value_namespace = name_space
                                    self.configured_foreign_member_count.value_namespace_prefix = name_space_prefix
                                if(value_path == "configured-member-count"):
                                    self.configured_member_count = value
                                    self.configured_member_count.value_namespace = name_space
                                    self.configured_member_count.value_namespace_prefix = name_space_prefix
                                if(value_path == "effective-bandwidth"):
                                    self.effective_bandwidth = value
                                    self.effective_bandwidth.value_namespace = name_space
                                    self.effective_bandwidth.value_namespace_prefix = name_space_prefix
                                if(value_path == "iccp-group-id"):
                                    self.iccp_group_id = value
                                    self.iccp_group_id.value_namespace = name_space
                                    self.iccp_group_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "inter-chassis"):
                                    self.inter_chassis = value
                                    self.inter_chassis.value_namespace = name_space
                                    self.inter_chassis.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4bfd-status"):
                                    self.ipv4bfd_status = value
                                    self.ipv4bfd_status.value_namespace = name_space
                                    self.ipv4bfd_status.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6bfd-status"):
                                    self.ipv6bfd_status = value
                                    self.ipv6bfd_status.value_namespace = name_space
                                    self.ipv6bfd_status.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-active"):
                                    self.is_active = value
                                    self.is_active.value_namespace = name_space
                                    self.is_active.value_namespace_prefix = name_space_prefix
                                if(value_path == "lacp-nonrevertive"):
                                    self.lacp_nonrevertive = value
                                    self.lacp_nonrevertive.value_namespace = name_space
                                    self.lacp_nonrevertive.value_namespace_prefix = name_space_prefix
                                if(value_path == "lacp-status"):
                                    self.lacp_status = value
                                    self.lacp_status.value_namespace = name_space
                                    self.lacp_status.value_namespace_prefix = name_space_prefix
                                if(value_path == "link-order-status"):
                                    self.link_order_status = value
                                    self.link_order_status.value_namespace = name_space
                                    self.link_order_status.value_namespace_prefix = name_space_prefix
                                if(value_path == "load-balance-hash-type"):
                                    self.load_balance_hash_type = value
                                    self.load_balance_hash_type.value_namespace = name_space
                                    self.load_balance_hash_type.value_namespace_prefix = name_space_prefix
                                if(value_path == "load-balance-locality-threshold"):
                                    self.load_balance_locality_threshold = value
                                    self.load_balance_locality_threshold.value_namespace = name_space
                                    self.load_balance_locality_threshold.value_namespace_prefix = name_space_prefix
                                if(value_path == "mac-source"):
                                    self.mac_source = value
                                    self.mac_source.value_namespace = name_space
                                    self.mac_source.value_namespace_prefix = name_space_prefix
                                if(value_path == "mac-source-member"):
                                    self.mac_source_member = value
                                    self.mac_source_member.value_namespace = name_space
                                    self.mac_source_member.value_namespace_prefix = name_space_prefix
                                if(value_path == "maximize-threshold-value-band-width"):
                                    self.maximize_threshold_value_band_width = value
                                    self.maximize_threshold_value_band_width.value_namespace = name_space
                                    self.maximize_threshold_value_band_width.value_namespace_prefix = name_space_prefix
                                if(value_path == "maximize-threshold-value-links"):
                                    self.maximize_threshold_value_links = value
                                    self.maximize_threshold_value_links.value_namespace = name_space
                                    self.maximize_threshold_value_links.value_namespace_prefix = name_space_prefix
                                if(value_path == "maximum-active-links"):
                                    self.maximum_active_links = value
                                    self.maximum_active_links.value_namespace = name_space
                                    self.maximum_active_links.value_namespace_prefix = name_space_prefix
                                if(value_path == "maximum-active-links-source"):
                                    self.maximum_active_links_source = value
                                    self.maximum_active_links_source.value_namespace = name_space
                                    self.maximum_active_links_source.value_namespace_prefix = name_space_prefix
                                if(value_path == "minimum-active-links"):
                                    self.minimum_active_links = value
                                    self.minimum_active_links.value_namespace = name_space
                                    self.minimum_active_links.value_namespace_prefix = name_space_prefix
                                if(value_path == "minimum-bandwidth"):
                                    self.minimum_bandwidth = value
                                    self.minimum_bandwidth.value_namespace = name_space
                                    self.minimum_bandwidth.value_namespace_prefix = name_space_prefix
                                if(value_path == "mlacp-mode"):
                                    self.mlacp_mode = value
                                    self.mlacp_mode.value_namespace = name_space
                                    self.mlacp_mode.value_namespace_prefix = name_space_prefix
                                if(value_path == "mlacp-status"):
                                    self.mlacp_status = value
                                    self.mlacp_status.value_namespace = name_space
                                    self.mlacp_status.value_namespace_prefix = name_space_prefix
                                if(value_path == "primary-member"):
                                    self.primary_member = value
                                    self.primary_member.value_namespace = name_space
                                    self.primary_member.value_namespace_prefix = name_space_prefix
                                if(value_path == "recovery-delay"):
                                    self.recovery_delay = value
                                    self.recovery_delay.value_namespace = name_space
                                    self.recovery_delay.value_namespace_prefix = name_space_prefix
                                if(value_path == "singleton"):
                                    self.singleton = value
                                    self.singleton.value_namespace = name_space
                                    self.singleton.value_namespace_prefix = name_space_prefix
                                if(value_path == "standby-member-count"):
                                    self.standby_member_count = value
                                    self.standby_member_count.value_namespace = name_space
                                    self.standby_member_count.value_namespace_prefix = name_space_prefix
                                if(value_path == "suppression-timer"):
                                    self.suppression_timer = value
                                    self.suppression_timer.value_namespace = name_space
                                    self.suppression_timer.value_namespace_prefix = name_space_prefix
                                if(value_path == "switchover-type"):
                                    self.switchover_type = value
                                    self.switchover_type.value_namespace = name_space
                                    self.switchover_type.value_namespace_prefix = name_space_prefix
                                if(value_path == "wait-while-timer"):
                                    self.wait_while_timer = value
                                    self.wait_while_timer.value_namespace = name_space
                                    self.wait_while_timer.value_namespace_prefix = name_space_prefix


                        class BundleSystemId(Entity):
                            """
                            System ID for the bundle
                            
                            .. attribute:: system_mac_addr
                            
                            	MAC Address used to identify the system
                            	**type**\:   :py:class:`SystemMacAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleDescendant.BundleData.BundleSystemId.SystemMacAddr>`
                            
                            .. attribute:: system_prio
                            
                            	Priority of the system
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'bundlemgr-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleDescendant.BundleData.BundleSystemId, self).__init__()

                                self.yang_name = "bundle-system-id"
                                self.yang_parent_name = "bundle-data"

                                self.system_prio = YLeaf(YType.uint16, "system-prio")

                                self.system_mac_addr = BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleDescendant.BundleData.BundleSystemId.SystemMacAddr()
                                self.system_mac_addr.parent = self
                                self._children_name_map["system_mac_addr"] = "system-mac-addr"
                                self._children_yang_names.add("system-mac-addr")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("system_prio") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleDescendant.BundleData.BundleSystemId, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleDescendant.BundleData.BundleSystemId, self).__setattr__(name, value)


                            class SystemMacAddr(Entity):
                                """
                                MAC Address used to identify the system
                                
                                .. attribute:: macaddr
                                
                                	macaddr
                                	**type**\:  str
                                
                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                
                                

                                """

                                _prefix = 'bundlemgr-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleDescendant.BundleData.BundleSystemId.SystemMacAddr, self).__init__()

                                    self.yang_name = "system-mac-addr"
                                    self.yang_parent_name = "bundle-system-id"

                                    self.macaddr = YLeaf(YType.str, "macaddr")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("macaddr") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleDescendant.BundleData.BundleSystemId.SystemMacAddr, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleDescendant.BundleData.BundleSystemId.SystemMacAddr, self).__setattr__(name, value)

                                def has_data(self):
                                    return self.macaddr.is_set

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.macaddr.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "system-mac-addr" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.macaddr.is_set or self.macaddr.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.macaddr.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "macaddr"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "macaddr"):
                                        self.macaddr = value
                                        self.macaddr.value_namespace = name_space
                                        self.macaddr.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.system_prio.is_set or
                                    (self.system_mac_addr is not None and self.system_mac_addr.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.system_prio.yfilter != YFilter.not_set or
                                    (self.system_mac_addr is not None and self.system_mac_addr.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "bundle-system-id" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.system_prio.is_set or self.system_prio.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.system_prio.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "system-mac-addr"):
                                    if (self.system_mac_addr is None):
                                        self.system_mac_addr = BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleDescendant.BundleData.BundleSystemId.SystemMacAddr()
                                        self.system_mac_addr.parent = self
                                        self._children_name_map["system_mac_addr"] = "system-mac-addr"
                                    return self.system_mac_addr

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "system-mac-addr" or name == "system-prio"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "system-prio"):
                                    self.system_prio = value
                                    self.system_prio.value_namespace = name_space
                                    self.system_prio.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.actor_operational_key.is_set or
                                self.partner_operational_key.is_set or
                                self.partner_system_mac_address.is_set or
                                self.partner_system_priority.is_set or
                                (self.actor_bundle_data is not None and self.actor_bundle_data.has_data()) or
                                (self.bundle_system_id is not None and self.bundle_system_id.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.actor_operational_key.yfilter != YFilter.not_set or
                                self.partner_operational_key.yfilter != YFilter.not_set or
                                self.partner_system_mac_address.yfilter != YFilter.not_set or
                                self.partner_system_priority.yfilter != YFilter.not_set or
                                (self.actor_bundle_data is not None and self.actor_bundle_data.has_operation()) or
                                (self.bundle_system_id is not None and self.bundle_system_id.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "bundle-data" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.actor_operational_key.is_set or self.actor_operational_key.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.actor_operational_key.get_name_leafdata())
                            if (self.partner_operational_key.is_set or self.partner_operational_key.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.partner_operational_key.get_name_leafdata())
                            if (self.partner_system_mac_address.is_set or self.partner_system_mac_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.partner_system_mac_address.get_name_leafdata())
                            if (self.partner_system_priority.is_set or self.partner_system_priority.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.partner_system_priority.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "actor-bundle-data"):
                                if (self.actor_bundle_data is None):
                                    self.actor_bundle_data = BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleDescendant.BundleData.ActorBundleData()
                                    self.actor_bundle_data.parent = self
                                    self._children_name_map["actor_bundle_data"] = "actor-bundle-data"
                                return self.actor_bundle_data

                            if (child_yang_name == "bundle-system-id"):
                                if (self.bundle_system_id is None):
                                    self.bundle_system_id = BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleDescendant.BundleData.BundleSystemId()
                                    self.bundle_system_id.parent = self
                                    self._children_name_map["bundle_system_id"] = "bundle-system-id"
                                return self.bundle_system_id

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "actor-bundle-data" or name == "bundle-system-id" or name == "actor-operational-key" or name == "partner-operational-key" or name == "partner-system-mac-address" or name == "partner-system-priority"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "actor-operational-key"):
                                self.actor_operational_key = value
                                self.actor_operational_key.value_namespace = name_space
                                self.actor_operational_key.value_namespace_prefix = name_space_prefix
                            if(value_path == "partner-operational-key"):
                                self.partner_operational_key = value
                                self.partner_operational_key.value_namespace = name_space
                                self.partner_operational_key.value_namespace_prefix = name_space_prefix
                            if(value_path == "partner-system-mac-address"):
                                self.partner_system_mac_address = value
                                self.partner_system_mac_address.value_namespace = name_space
                                self.partner_system_mac_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "partner-system-priority"):
                                self.partner_system_priority = value
                                self.partner_system_priority.value_namespace = name_space
                                self.partner_system_priority.value_namespace_prefix = name_space_prefix


                    class MemberData(Entity):
                        """
                        Member information
                        
                        .. attribute:: actor_churn_state
                        
                        	State of the Churn state machine for the Actor
                        	**type**\:   :py:class:`LacpChurnstates <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.LacpChurnstates>`
                        
                        .. attribute:: actor_info
                        
                        	LACP information for the port from the actor
                        	**type**\:   :py:class:`ActorInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleDescendant.MemberData.ActorInfo>`
                        
                        .. attribute:: additional_info
                        
                        	Additional information for the link
                        	**type**\:   :py:class:`AdditionalInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleDescendant.MemberData.AdditionalInfo>`
                        
                        .. attribute:: attached_aggregator_id
                        
                        	MIB ifindex of attached bundle
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: iccp_group_id
                        
                        	The ID of the ICCP group that the link is configured on
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: mux_state
                        
                        	State of the Mux state machine
                        	**type**\:   :py:class:`BmMuxstate <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmMuxstate>`
                        
                        .. attribute:: partner_churn_state
                        
                        	State of the Churn state machine for the Partner
                        	**type**\:   :py:class:`LacpChurnstates <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.LacpChurnstates>`
                        
                        .. attribute:: partner_info
                        
                        	LACP information for the port from the partner
                        	**type**\:   :py:class:`PartnerInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleDescendant.MemberData.PartnerInfo>`
                        
                        .. attribute:: period_state
                        
                        	State of the Period state machine
                        	**type**\:   :py:class:`LacpPeriodState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.LacpPeriodState>`
                        
                        .. attribute:: receive_machine_state
                        
                        	State of the RX state machine
                        	**type**\:   :py:class:`Rxstates <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.Rxstates>`
                        
                        .. attribute:: selected_aggregator_id
                        
                        	MIB ifindex of selected bundle
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: selection_state
                        
                        	State of the Selection Logic state machine
                        	**type**\:   :py:class:`LacpSelState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.LacpSelState>`
                        
                        

                        """

                        _prefix = 'bundlemgr-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleDescendant.MemberData, self).__init__()

                            self.yang_name = "member-data"
                            self.yang_parent_name = "lacp-bundle-descendant"

                            self.actor_churn_state = YLeaf(YType.enumeration, "actor-churn-state")

                            self.attached_aggregator_id = YLeaf(YType.uint32, "attached-aggregator-id")

                            self.iccp_group_id = YLeaf(YType.uint32, "iccp-group-id")

                            self.mux_state = YLeaf(YType.enumeration, "mux-state")

                            self.partner_churn_state = YLeaf(YType.enumeration, "partner-churn-state")

                            self.period_state = YLeaf(YType.enumeration, "period-state")

                            self.receive_machine_state = YLeaf(YType.enumeration, "receive-machine-state")

                            self.selected_aggregator_id = YLeaf(YType.uint32, "selected-aggregator-id")

                            self.selection_state = YLeaf(YType.enumeration, "selection-state")

                            self.actor_info = BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleDescendant.MemberData.ActorInfo()
                            self.actor_info.parent = self
                            self._children_name_map["actor_info"] = "actor-info"
                            self._children_yang_names.add("actor-info")

                            self.additional_info = BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleDescendant.MemberData.AdditionalInfo()
                            self.additional_info.parent = self
                            self._children_name_map["additional_info"] = "additional-info"
                            self._children_yang_names.add("additional-info")

                            self.partner_info = BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleDescendant.MemberData.PartnerInfo()
                            self.partner_info.parent = self
                            self._children_name_map["partner_info"] = "partner-info"
                            self._children_yang_names.add("partner-info")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("actor_churn_state",
                                            "attached_aggregator_id",
                                            "iccp_group_id",
                                            "mux_state",
                                            "partner_churn_state",
                                            "period_state",
                                            "receive_machine_state",
                                            "selected_aggregator_id",
                                            "selection_state") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleDescendant.MemberData, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleDescendant.MemberData, self).__setattr__(name, value)


                        class ActorInfo(Entity):
                            """
                            LACP information for the port from the actor
                            
                            .. attribute:: port_info
                            
                            	LACP parameters for this device
                            	**type**\:   :py:class:`PortInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleDescendant.MemberData.ActorInfo.PortInfo>`
                            
                            .. attribute:: tx_period
                            
                            	Time (in ms) between transmitting LACPDUs
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'bundlemgr-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleDescendant.MemberData.ActorInfo, self).__init__()

                                self.yang_name = "actor-info"
                                self.yang_parent_name = "member-data"

                                self.tx_period = YLeaf(YType.uint32, "tx-period")

                                self.port_info = BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleDescendant.MemberData.ActorInfo.PortInfo()
                                self.port_info.parent = self
                                self._children_name_map["port_info"] = "port-info"
                                self._children_yang_names.add("port-info")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("tx_period") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleDescendant.MemberData.ActorInfo, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleDescendant.MemberData.ActorInfo, self).__setattr__(name, value)


                            class PortInfo(Entity):
                                """
                                LACP parameters for this device
                                
                                .. attribute:: key
                                
                                	key
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: port
                                
                                	port
                                	**type**\:   :py:class:`Port <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleDescendant.MemberData.ActorInfo.PortInfo.Port>`
                                
                                .. attribute:: state
                                
                                	state
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: system
                                
                                	system
                                	**type**\:   :py:class:`System <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleDescendant.MemberData.ActorInfo.PortInfo.System>`
                                
                                

                                """

                                _prefix = 'bundlemgr-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleDescendant.MemberData.ActorInfo.PortInfo, self).__init__()

                                    self.yang_name = "port-info"
                                    self.yang_parent_name = "actor-info"

                                    self.key = YLeaf(YType.uint16, "key")

                                    self.state = YLeaf(YType.uint8, "state")

                                    self.port = BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleDescendant.MemberData.ActorInfo.PortInfo.Port()
                                    self.port.parent = self
                                    self._children_name_map["port"] = "port"
                                    self._children_yang_names.add("port")

                                    self.system = BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleDescendant.MemberData.ActorInfo.PortInfo.System()
                                    self.system.parent = self
                                    self._children_name_map["system"] = "system"
                                    self._children_yang_names.add("system")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("key",
                                                    "state") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleDescendant.MemberData.ActorInfo.PortInfo, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleDescendant.MemberData.ActorInfo.PortInfo, self).__setattr__(name, value)


                                class System(Entity):
                                    """
                                    system
                                    
                                    .. attribute:: system_mac_addr
                                    
                                    	MAC Address used to identify the system
                                    	**type**\:   :py:class:`SystemMacAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleDescendant.MemberData.ActorInfo.PortInfo.System.SystemMacAddr>`
                                    
                                    .. attribute:: system_prio
                                    
                                    	Priority of the system
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'bundlemgr-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleDescendant.MemberData.ActorInfo.PortInfo.System, self).__init__()

                                        self.yang_name = "system"
                                        self.yang_parent_name = "port-info"

                                        self.system_prio = YLeaf(YType.uint16, "system-prio")

                                        self.system_mac_addr = BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleDescendant.MemberData.ActorInfo.PortInfo.System.SystemMacAddr()
                                        self.system_mac_addr.parent = self
                                        self._children_name_map["system_mac_addr"] = "system-mac-addr"
                                        self._children_yang_names.add("system-mac-addr")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("system_prio") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleDescendant.MemberData.ActorInfo.PortInfo.System, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleDescendant.MemberData.ActorInfo.PortInfo.System, self).__setattr__(name, value)


                                    class SystemMacAddr(Entity):
                                        """
                                        MAC Address used to identify the system
                                        
                                        .. attribute:: macaddr
                                        
                                        	macaddr
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'bundlemgr-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleDescendant.MemberData.ActorInfo.PortInfo.System.SystemMacAddr, self).__init__()

                                            self.yang_name = "system-mac-addr"
                                            self.yang_parent_name = "system"

                                            self.macaddr = YLeaf(YType.str, "macaddr")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("macaddr") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleDescendant.MemberData.ActorInfo.PortInfo.System.SystemMacAddr, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleDescendant.MemberData.ActorInfo.PortInfo.System.SystemMacAddr, self).__setattr__(name, value)

                                        def has_data(self):
                                            return self.macaddr.is_set

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.macaddr.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "system-mac-addr" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.macaddr.is_set or self.macaddr.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.macaddr.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "macaddr"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "macaddr"):
                                                self.macaddr = value
                                                self.macaddr.value_namespace = name_space
                                                self.macaddr.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.system_prio.is_set or
                                            (self.system_mac_addr is not None and self.system_mac_addr.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.system_prio.yfilter != YFilter.not_set or
                                            (self.system_mac_addr is not None and self.system_mac_addr.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "system" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.system_prio.is_set or self.system_prio.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.system_prio.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "system-mac-addr"):
                                            if (self.system_mac_addr is None):
                                                self.system_mac_addr = BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleDescendant.MemberData.ActorInfo.PortInfo.System.SystemMacAddr()
                                                self.system_mac_addr.parent = self
                                                self._children_name_map["system_mac_addr"] = "system-mac-addr"
                                            return self.system_mac_addr

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "system-mac-addr" or name == "system-prio"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "system-prio"):
                                            self.system_prio = value
                                            self.system_prio.value_namespace = name_space
                                            self.system_prio.value_namespace_prefix = name_space_prefix


                                class Port(Entity):
                                    """
                                    port
                                    
                                    .. attribute:: link_number
                                    
                                    	link number
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: link_priority
                                    
                                    	link priority
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'bundlemgr-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleDescendant.MemberData.ActorInfo.PortInfo.Port, self).__init__()

                                        self.yang_name = "port"
                                        self.yang_parent_name = "port-info"

                                        self.link_number = YLeaf(YType.uint16, "link-number")

                                        self.link_priority = YLeaf(YType.uint16, "link-priority")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("link_number",
                                                        "link_priority") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleDescendant.MemberData.ActorInfo.PortInfo.Port, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleDescendant.MemberData.ActorInfo.PortInfo.Port, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.link_number.is_set or
                                            self.link_priority.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.link_number.yfilter != YFilter.not_set or
                                            self.link_priority.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "port" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.link_number.is_set or self.link_number.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.link_number.get_name_leafdata())
                                        if (self.link_priority.is_set or self.link_priority.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.link_priority.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "link-number" or name == "link-priority"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "link-number"):
                                            self.link_number = value
                                            self.link_number.value_namespace = name_space
                                            self.link_number.value_namespace_prefix = name_space_prefix
                                        if(value_path == "link-priority"):
                                            self.link_priority = value
                                            self.link_priority.value_namespace = name_space
                                            self.link_priority.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.key.is_set or
                                        self.state.is_set or
                                        (self.port is not None and self.port.has_data()) or
                                        (self.system is not None and self.system.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.key.yfilter != YFilter.not_set or
                                        self.state.yfilter != YFilter.not_set or
                                        (self.port is not None and self.port.has_operation()) or
                                        (self.system is not None and self.system.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "port-info" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.key.is_set or self.key.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.key.get_name_leafdata())
                                    if (self.state.is_set or self.state.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.state.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "port"):
                                        if (self.port is None):
                                            self.port = BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleDescendant.MemberData.ActorInfo.PortInfo.Port()
                                            self.port.parent = self
                                            self._children_name_map["port"] = "port"
                                        return self.port

                                    if (child_yang_name == "system"):
                                        if (self.system is None):
                                            self.system = BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleDescendant.MemberData.ActorInfo.PortInfo.System()
                                            self.system.parent = self
                                            self._children_name_map["system"] = "system"
                                        return self.system

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "port" or name == "system" or name == "key" or name == "state"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "key"):
                                        self.key = value
                                        self.key.value_namespace = name_space
                                        self.key.value_namespace_prefix = name_space_prefix
                                    if(value_path == "state"):
                                        self.state = value
                                        self.state.value_namespace = name_space
                                        self.state.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.tx_period.is_set or
                                    (self.port_info is not None and self.port_info.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.tx_period.yfilter != YFilter.not_set or
                                    (self.port_info is not None and self.port_info.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "actor-info" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.tx_period.is_set or self.tx_period.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.tx_period.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "port-info"):
                                    if (self.port_info is None):
                                        self.port_info = BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleDescendant.MemberData.ActorInfo.PortInfo()
                                        self.port_info.parent = self
                                        self._children_name_map["port_info"] = "port-info"
                                    return self.port_info

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "port-info" or name == "tx-period"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "tx-period"):
                                    self.tx_period = value
                                    self.tx_period.value_namespace = name_space
                                    self.tx_period.value_namespace_prefix = name_space_prefix


                        class PartnerInfo(Entity):
                            """
                            LACP information for the port from the partner
                            
                            .. attribute:: port_info
                            
                            	LACP parameters for this device
                            	**type**\:   :py:class:`PortInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleDescendant.MemberData.PartnerInfo.PortInfo>`
                            
                            .. attribute:: tx_period
                            
                            	Time (in ms) between transmitting LACPDUs
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'bundlemgr-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleDescendant.MemberData.PartnerInfo, self).__init__()

                                self.yang_name = "partner-info"
                                self.yang_parent_name = "member-data"

                                self.tx_period = YLeaf(YType.uint32, "tx-period")

                                self.port_info = BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleDescendant.MemberData.PartnerInfo.PortInfo()
                                self.port_info.parent = self
                                self._children_name_map["port_info"] = "port-info"
                                self._children_yang_names.add("port-info")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("tx_period") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleDescendant.MemberData.PartnerInfo, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleDescendant.MemberData.PartnerInfo, self).__setattr__(name, value)


                            class PortInfo(Entity):
                                """
                                LACP parameters for this device
                                
                                .. attribute:: key
                                
                                	key
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: port
                                
                                	port
                                	**type**\:   :py:class:`Port <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleDescendant.MemberData.PartnerInfo.PortInfo.Port>`
                                
                                .. attribute:: state
                                
                                	state
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: system
                                
                                	system
                                	**type**\:   :py:class:`System <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleDescendant.MemberData.PartnerInfo.PortInfo.System>`
                                
                                

                                """

                                _prefix = 'bundlemgr-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleDescendant.MemberData.PartnerInfo.PortInfo, self).__init__()

                                    self.yang_name = "port-info"
                                    self.yang_parent_name = "partner-info"

                                    self.key = YLeaf(YType.uint16, "key")

                                    self.state = YLeaf(YType.uint8, "state")

                                    self.port = BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleDescendant.MemberData.PartnerInfo.PortInfo.Port()
                                    self.port.parent = self
                                    self._children_name_map["port"] = "port"
                                    self._children_yang_names.add("port")

                                    self.system = BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleDescendant.MemberData.PartnerInfo.PortInfo.System()
                                    self.system.parent = self
                                    self._children_name_map["system"] = "system"
                                    self._children_yang_names.add("system")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("key",
                                                    "state") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleDescendant.MemberData.PartnerInfo.PortInfo, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleDescendant.MemberData.PartnerInfo.PortInfo, self).__setattr__(name, value)


                                class System(Entity):
                                    """
                                    system
                                    
                                    .. attribute:: system_mac_addr
                                    
                                    	MAC Address used to identify the system
                                    	**type**\:   :py:class:`SystemMacAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleDescendant.MemberData.PartnerInfo.PortInfo.System.SystemMacAddr>`
                                    
                                    .. attribute:: system_prio
                                    
                                    	Priority of the system
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'bundlemgr-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleDescendant.MemberData.PartnerInfo.PortInfo.System, self).__init__()

                                        self.yang_name = "system"
                                        self.yang_parent_name = "port-info"

                                        self.system_prio = YLeaf(YType.uint16, "system-prio")

                                        self.system_mac_addr = BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleDescendant.MemberData.PartnerInfo.PortInfo.System.SystemMacAddr()
                                        self.system_mac_addr.parent = self
                                        self._children_name_map["system_mac_addr"] = "system-mac-addr"
                                        self._children_yang_names.add("system-mac-addr")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("system_prio") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleDescendant.MemberData.PartnerInfo.PortInfo.System, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleDescendant.MemberData.PartnerInfo.PortInfo.System, self).__setattr__(name, value)


                                    class SystemMacAddr(Entity):
                                        """
                                        MAC Address used to identify the system
                                        
                                        .. attribute:: macaddr
                                        
                                        	macaddr
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'bundlemgr-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleDescendant.MemberData.PartnerInfo.PortInfo.System.SystemMacAddr, self).__init__()

                                            self.yang_name = "system-mac-addr"
                                            self.yang_parent_name = "system"

                                            self.macaddr = YLeaf(YType.str, "macaddr")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("macaddr") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleDescendant.MemberData.PartnerInfo.PortInfo.System.SystemMacAddr, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleDescendant.MemberData.PartnerInfo.PortInfo.System.SystemMacAddr, self).__setattr__(name, value)

                                        def has_data(self):
                                            return self.macaddr.is_set

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.macaddr.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "system-mac-addr" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.macaddr.is_set or self.macaddr.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.macaddr.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "macaddr"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "macaddr"):
                                                self.macaddr = value
                                                self.macaddr.value_namespace = name_space
                                                self.macaddr.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.system_prio.is_set or
                                            (self.system_mac_addr is not None and self.system_mac_addr.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.system_prio.yfilter != YFilter.not_set or
                                            (self.system_mac_addr is not None and self.system_mac_addr.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "system" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.system_prio.is_set or self.system_prio.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.system_prio.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "system-mac-addr"):
                                            if (self.system_mac_addr is None):
                                                self.system_mac_addr = BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleDescendant.MemberData.PartnerInfo.PortInfo.System.SystemMacAddr()
                                                self.system_mac_addr.parent = self
                                                self._children_name_map["system_mac_addr"] = "system-mac-addr"
                                            return self.system_mac_addr

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "system-mac-addr" or name == "system-prio"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "system-prio"):
                                            self.system_prio = value
                                            self.system_prio.value_namespace = name_space
                                            self.system_prio.value_namespace_prefix = name_space_prefix


                                class Port(Entity):
                                    """
                                    port
                                    
                                    .. attribute:: link_number
                                    
                                    	link number
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: link_priority
                                    
                                    	link priority
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'bundlemgr-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleDescendant.MemberData.PartnerInfo.PortInfo.Port, self).__init__()

                                        self.yang_name = "port"
                                        self.yang_parent_name = "port-info"

                                        self.link_number = YLeaf(YType.uint16, "link-number")

                                        self.link_priority = YLeaf(YType.uint16, "link-priority")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("link_number",
                                                        "link_priority") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleDescendant.MemberData.PartnerInfo.PortInfo.Port, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleDescendant.MemberData.PartnerInfo.PortInfo.Port, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.link_number.is_set or
                                            self.link_priority.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.link_number.yfilter != YFilter.not_set or
                                            self.link_priority.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "port" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.link_number.is_set or self.link_number.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.link_number.get_name_leafdata())
                                        if (self.link_priority.is_set or self.link_priority.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.link_priority.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "link-number" or name == "link-priority"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "link-number"):
                                            self.link_number = value
                                            self.link_number.value_namespace = name_space
                                            self.link_number.value_namespace_prefix = name_space_prefix
                                        if(value_path == "link-priority"):
                                            self.link_priority = value
                                            self.link_priority.value_namespace = name_space
                                            self.link_priority.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.key.is_set or
                                        self.state.is_set or
                                        (self.port is not None and self.port.has_data()) or
                                        (self.system is not None and self.system.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.key.yfilter != YFilter.not_set or
                                        self.state.yfilter != YFilter.not_set or
                                        (self.port is not None and self.port.has_operation()) or
                                        (self.system is not None and self.system.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "port-info" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.key.is_set or self.key.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.key.get_name_leafdata())
                                    if (self.state.is_set or self.state.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.state.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "port"):
                                        if (self.port is None):
                                            self.port = BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleDescendant.MemberData.PartnerInfo.PortInfo.Port()
                                            self.port.parent = self
                                            self._children_name_map["port"] = "port"
                                        return self.port

                                    if (child_yang_name == "system"):
                                        if (self.system is None):
                                            self.system = BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleDescendant.MemberData.PartnerInfo.PortInfo.System()
                                            self.system.parent = self
                                            self._children_name_map["system"] = "system"
                                        return self.system

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "port" or name == "system" or name == "key" or name == "state"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "key"):
                                        self.key = value
                                        self.key.value_namespace = name_space
                                        self.key.value_namespace_prefix = name_space_prefix
                                    if(value_path == "state"):
                                        self.state = value
                                        self.state.value_namespace = name_space
                                        self.state.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.tx_period.is_set or
                                    (self.port_info is not None and self.port_info.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.tx_period.yfilter != YFilter.not_set or
                                    (self.port_info is not None and self.port_info.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "partner-info" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.tx_period.is_set or self.tx_period.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.tx_period.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "port-info"):
                                    if (self.port_info is None):
                                        self.port_info = BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleDescendant.MemberData.PartnerInfo.PortInfo()
                                        self.port_info.parent = self
                                        self._children_name_map["port_info"] = "port-info"
                                    return self.port_info

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "port-info" or name == "tx-period"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "tx-period"):
                                    self.tx_period = value
                                    self.tx_period.value_namespace = name_space
                                    self.tx_period.value_namespace_prefix = name_space_prefix


                        class AdditionalInfo(Entity):
                            """
                            Additional information for the link
                            
                            .. attribute:: foreign
                            
                            	Information for a foreign port
                            	**type**\:   :py:class:`Foreign <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleDescendant.MemberData.AdditionalInfo.Foreign>`
                            
                            .. attribute:: local
                            
                            	Information for a local port
                            	**type**\:   :py:class:`Local <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleDescendant.MemberData.AdditionalInfo.Local>`
                            
                            .. attribute:: mbr_type
                            
                            	MbrType
                            	**type**\:   :py:class:`BmdMemberTypeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmdMemberTypeEnum>`
                            
                            

                            """

                            _prefix = 'bundlemgr-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleDescendant.MemberData.AdditionalInfo, self).__init__()

                                self.yang_name = "additional-info"
                                self.yang_parent_name = "member-data"

                                self.mbr_type = YLeaf(YType.enumeration, "mbr-type")

                                self.foreign = BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleDescendant.MemberData.AdditionalInfo.Foreign()
                                self.foreign.parent = self
                                self._children_name_map["foreign"] = "foreign"
                                self._children_yang_names.add("foreign")

                                self.local = BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleDescendant.MemberData.AdditionalInfo.Local()
                                self.local.parent = self
                                self._children_name_map["local"] = "local"
                                self._children_yang_names.add("local")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("mbr_type") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleDescendant.MemberData.AdditionalInfo, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleDescendant.MemberData.AdditionalInfo, self).__setattr__(name, value)


                            class Local(Entity):
                                """
                                Information for a local port
                                
                                .. attribute:: interface_handle
                                
                                	Member's interface handle
                                	**type**\:  str
                                
                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                
                                

                                """

                                _prefix = 'bundlemgr-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleDescendant.MemberData.AdditionalInfo.Local, self).__init__()

                                    self.yang_name = "local"
                                    self.yang_parent_name = "additional-info"

                                    self.interface_handle = YLeaf(YType.str, "interface-handle")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("interface_handle") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleDescendant.MemberData.AdditionalInfo.Local, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleDescendant.MemberData.AdditionalInfo.Local, self).__setattr__(name, value)

                                def has_data(self):
                                    return self.interface_handle.is_set

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.interface_handle.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "local" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.interface_handle.is_set or self.interface_handle.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.interface_handle.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "interface-handle"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "interface-handle"):
                                        self.interface_handle = value
                                        self.interface_handle.value_namespace = name_space
                                        self.interface_handle.value_namespace_prefix = name_space_prefix


                            class Foreign(Entity):
                                """
                                Information for a foreign port
                                
                                .. attribute:: member_name
                                
                                	Member's (short form) name
                                	**type**\:  str
                                
                                .. attribute:: peer_address
                                
                                	The LDP address of the device that the link is configured on
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'bundlemgr-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleDescendant.MemberData.AdditionalInfo.Foreign, self).__init__()

                                    self.yang_name = "foreign"
                                    self.yang_parent_name = "additional-info"

                                    self.member_name = YLeaf(YType.str, "member-name")

                                    self.peer_address = YLeaf(YType.str, "peer-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("member_name",
                                                    "peer_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleDescendant.MemberData.AdditionalInfo.Foreign, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleDescendant.MemberData.AdditionalInfo.Foreign, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.member_name.is_set or
                                        self.peer_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.member_name.yfilter != YFilter.not_set or
                                        self.peer_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "foreign" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.member_name.is_set or self.member_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.member_name.get_name_leafdata())
                                    if (self.peer_address.is_set or self.peer_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.peer_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "member-name" or name == "peer-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "member-name"):
                                        self.member_name = value
                                        self.member_name.value_namespace = name_space
                                        self.member_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "peer-address"):
                                        self.peer_address = value
                                        self.peer_address.value_namespace = name_space
                                        self.peer_address.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.mbr_type.is_set or
                                    (self.foreign is not None and self.foreign.has_data()) or
                                    (self.local is not None and self.local.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.mbr_type.yfilter != YFilter.not_set or
                                    (self.foreign is not None and self.foreign.has_operation()) or
                                    (self.local is not None and self.local.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "additional-info" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.mbr_type.is_set or self.mbr_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mbr_type.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "foreign"):
                                    if (self.foreign is None):
                                        self.foreign = BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleDescendant.MemberData.AdditionalInfo.Foreign()
                                        self.foreign.parent = self
                                        self._children_name_map["foreign"] = "foreign"
                                    return self.foreign

                                if (child_yang_name == "local"):
                                    if (self.local is None):
                                        self.local = BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleDescendant.MemberData.AdditionalInfo.Local()
                                        self.local.parent = self
                                        self._children_name_map["local"] = "local"
                                    return self.local

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "foreign" or name == "local" or name == "mbr-type"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "mbr-type"):
                                    self.mbr_type = value
                                    self.mbr_type.value_namespace = name_space
                                    self.mbr_type.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.actor_churn_state.is_set or
                                self.attached_aggregator_id.is_set or
                                self.iccp_group_id.is_set or
                                self.mux_state.is_set or
                                self.partner_churn_state.is_set or
                                self.period_state.is_set or
                                self.receive_machine_state.is_set or
                                self.selected_aggregator_id.is_set or
                                self.selection_state.is_set or
                                (self.actor_info is not None and self.actor_info.has_data()) or
                                (self.additional_info is not None and self.additional_info.has_data()) or
                                (self.partner_info is not None and self.partner_info.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.actor_churn_state.yfilter != YFilter.not_set or
                                self.attached_aggregator_id.yfilter != YFilter.not_set or
                                self.iccp_group_id.yfilter != YFilter.not_set or
                                self.mux_state.yfilter != YFilter.not_set or
                                self.partner_churn_state.yfilter != YFilter.not_set or
                                self.period_state.yfilter != YFilter.not_set or
                                self.receive_machine_state.yfilter != YFilter.not_set or
                                self.selected_aggregator_id.yfilter != YFilter.not_set or
                                self.selection_state.yfilter != YFilter.not_set or
                                (self.actor_info is not None and self.actor_info.has_operation()) or
                                (self.additional_info is not None and self.additional_info.has_operation()) or
                                (self.partner_info is not None and self.partner_info.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "member-data" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.actor_churn_state.is_set or self.actor_churn_state.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.actor_churn_state.get_name_leafdata())
                            if (self.attached_aggregator_id.is_set or self.attached_aggregator_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.attached_aggregator_id.get_name_leafdata())
                            if (self.iccp_group_id.is_set or self.iccp_group_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.iccp_group_id.get_name_leafdata())
                            if (self.mux_state.is_set or self.mux_state.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mux_state.get_name_leafdata())
                            if (self.partner_churn_state.is_set or self.partner_churn_state.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.partner_churn_state.get_name_leafdata())
                            if (self.period_state.is_set or self.period_state.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.period_state.get_name_leafdata())
                            if (self.receive_machine_state.is_set or self.receive_machine_state.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.receive_machine_state.get_name_leafdata())
                            if (self.selected_aggregator_id.is_set or self.selected_aggregator_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.selected_aggregator_id.get_name_leafdata())
                            if (self.selection_state.is_set or self.selection_state.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.selection_state.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "actor-info"):
                                if (self.actor_info is None):
                                    self.actor_info = BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleDescendant.MemberData.ActorInfo()
                                    self.actor_info.parent = self
                                    self._children_name_map["actor_info"] = "actor-info"
                                return self.actor_info

                            if (child_yang_name == "additional-info"):
                                if (self.additional_info is None):
                                    self.additional_info = BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleDescendant.MemberData.AdditionalInfo()
                                    self.additional_info.parent = self
                                    self._children_name_map["additional_info"] = "additional-info"
                                return self.additional_info

                            if (child_yang_name == "partner-info"):
                                if (self.partner_info is None):
                                    self.partner_info = BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleDescendant.MemberData.PartnerInfo()
                                    self.partner_info.parent = self
                                    self._children_name_map["partner_info"] = "partner-info"
                                return self.partner_info

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "actor-info" or name == "additional-info" or name == "partner-info" or name == "actor-churn-state" or name == "attached-aggregator-id" or name == "iccp-group-id" or name == "mux-state" or name == "partner-churn-state" or name == "period-state" or name == "receive-machine-state" or name == "selected-aggregator-id" or name == "selection-state"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "actor-churn-state"):
                                self.actor_churn_state = value
                                self.actor_churn_state.value_namespace = name_space
                                self.actor_churn_state.value_namespace_prefix = name_space_prefix
                            if(value_path == "attached-aggregator-id"):
                                self.attached_aggregator_id = value
                                self.attached_aggregator_id.value_namespace = name_space
                                self.attached_aggregator_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "iccp-group-id"):
                                self.iccp_group_id = value
                                self.iccp_group_id.value_namespace = name_space
                                self.iccp_group_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "mux-state"):
                                self.mux_state = value
                                self.mux_state.value_namespace = name_space
                                self.mux_state.value_namespace_prefix = name_space_prefix
                            if(value_path == "partner-churn-state"):
                                self.partner_churn_state = value
                                self.partner_churn_state.value_namespace = name_space
                                self.partner_churn_state.value_namespace_prefix = name_space_prefix
                            if(value_path == "period-state"):
                                self.period_state = value
                                self.period_state.value_namespace = name_space
                                self.period_state.value_namespace_prefix = name_space_prefix
                            if(value_path == "receive-machine-state"):
                                self.receive_machine_state = value
                                self.receive_machine_state.value_namespace = name_space
                                self.receive_machine_state.value_namespace_prefix = name_space_prefix
                            if(value_path == "selected-aggregator-id"):
                                self.selected_aggregator_id = value
                                self.selected_aggregator_id.value_namespace = name_space
                                self.selected_aggregator_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "selection-state"):
                                self.selection_state = value
                                self.selection_state.value_namespace = name_space
                                self.selection_state.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.member_data:
                            if (c.has_data()):
                                return True
                        return (self.bundle_data is not None and self.bundle_data.has_data())

                    def has_operation(self):
                        for c in self.member_data:
                            if (c.has_operation()):
                                return True
                        return (
                            self.yfilter != YFilter.not_set or
                            (self.bundle_data is not None and self.bundle_data.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "lacp-bundle-descendant" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "bundle-data"):
                            if (self.bundle_data is None):
                                self.bundle_data = BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleDescendant.BundleData()
                                self.bundle_data.parent = self
                                self._children_name_map["bundle_data"] = "bundle-data"
                            return self.bundle_data

                        if (child_yang_name == "member-data"):
                            for c in self.member_data:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleDescendant.MemberData()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.member_data.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "bundle-data" or name == "member-data"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class LacpBundleChildrenMembers(Entity):
                    """
                    Children of bundle with LACP information
                    
                    .. attribute:: lacp_bundle_children_member
                    
                    	Bundle member item with LACP information
                    	**type**\: list of    :py:class:`LacpBundleChildrenMember <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleChildrenMembers.LacpBundleChildrenMember>`
                    
                    

                    """

                    _prefix = 'bundlemgr-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleChildrenMembers, self).__init__()

                        self.yang_name = "lacp-bundle-children-members"
                        self.yang_parent_name = "lacp-bundle"

                        self.lacp_bundle_children_member = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleChildrenMembers, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleChildrenMembers, self).__setattr__(name, value)


                    class LacpBundleChildrenMember(Entity):
                        """
                        Bundle member item with LACP information
                        
                        .. attribute:: member_interface  <key>
                        
                        	Member interface
                        	**type**\:  str
                        
                        .. attribute:: actor_churn_state
                        
                        	State of the Churn state machine for the Actor
                        	**type**\:   :py:class:`LacpChurnstates <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.LacpChurnstates>`
                        
                        .. attribute:: actor_info
                        
                        	LACP information for the port from the actor
                        	**type**\:   :py:class:`ActorInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleChildrenMembers.LacpBundleChildrenMember.ActorInfo>`
                        
                        .. attribute:: additional_info
                        
                        	Additional information for the link
                        	**type**\:   :py:class:`AdditionalInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleChildrenMembers.LacpBundleChildrenMember.AdditionalInfo>`
                        
                        .. attribute:: attached_aggregator_id
                        
                        	MIB ifindex of attached bundle
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: iccp_group_id
                        
                        	The ID of the ICCP group that the link is configured on
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: mux_state
                        
                        	State of the Mux state machine
                        	**type**\:   :py:class:`BmMuxstate <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmMuxstate>`
                        
                        .. attribute:: partner_churn_state
                        
                        	State of the Churn state machine for the Partner
                        	**type**\:   :py:class:`LacpChurnstates <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.LacpChurnstates>`
                        
                        .. attribute:: partner_info
                        
                        	LACP information for the port from the partner
                        	**type**\:   :py:class:`PartnerInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleChildrenMembers.LacpBundleChildrenMember.PartnerInfo>`
                        
                        .. attribute:: period_state
                        
                        	State of the Period state machine
                        	**type**\:   :py:class:`LacpPeriodState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.LacpPeriodState>`
                        
                        .. attribute:: receive_machine_state
                        
                        	State of the RX state machine
                        	**type**\:   :py:class:`Rxstates <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.Rxstates>`
                        
                        .. attribute:: selected_aggregator_id
                        
                        	MIB ifindex of selected bundle
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: selection_state
                        
                        	State of the Selection Logic state machine
                        	**type**\:   :py:class:`LacpSelState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.LacpSelState>`
                        
                        

                        """

                        _prefix = 'bundlemgr-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleChildrenMembers.LacpBundleChildrenMember, self).__init__()

                            self.yang_name = "lacp-bundle-children-member"
                            self.yang_parent_name = "lacp-bundle-children-members"

                            self.member_interface = YLeaf(YType.str, "member-interface")

                            self.actor_churn_state = YLeaf(YType.enumeration, "actor-churn-state")

                            self.attached_aggregator_id = YLeaf(YType.uint32, "attached-aggregator-id")

                            self.iccp_group_id = YLeaf(YType.uint32, "iccp-group-id")

                            self.mux_state = YLeaf(YType.enumeration, "mux-state")

                            self.partner_churn_state = YLeaf(YType.enumeration, "partner-churn-state")

                            self.period_state = YLeaf(YType.enumeration, "period-state")

                            self.receive_machine_state = YLeaf(YType.enumeration, "receive-machine-state")

                            self.selected_aggregator_id = YLeaf(YType.uint32, "selected-aggregator-id")

                            self.selection_state = YLeaf(YType.enumeration, "selection-state")

                            self.actor_info = BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleChildrenMembers.LacpBundleChildrenMember.ActorInfo()
                            self.actor_info.parent = self
                            self._children_name_map["actor_info"] = "actor-info"
                            self._children_yang_names.add("actor-info")

                            self.additional_info = BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleChildrenMembers.LacpBundleChildrenMember.AdditionalInfo()
                            self.additional_info.parent = self
                            self._children_name_map["additional_info"] = "additional-info"
                            self._children_yang_names.add("additional-info")

                            self.partner_info = BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleChildrenMembers.LacpBundleChildrenMember.PartnerInfo()
                            self.partner_info.parent = self
                            self._children_name_map["partner_info"] = "partner-info"
                            self._children_yang_names.add("partner-info")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("member_interface",
                                            "actor_churn_state",
                                            "attached_aggregator_id",
                                            "iccp_group_id",
                                            "mux_state",
                                            "partner_churn_state",
                                            "period_state",
                                            "receive_machine_state",
                                            "selected_aggregator_id",
                                            "selection_state") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleChildrenMembers.LacpBundleChildrenMember, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleChildrenMembers.LacpBundleChildrenMember, self).__setattr__(name, value)


                        class ActorInfo(Entity):
                            """
                            LACP information for the port from the actor
                            
                            .. attribute:: port_info
                            
                            	LACP parameters for this device
                            	**type**\:   :py:class:`PortInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleChildrenMembers.LacpBundleChildrenMember.ActorInfo.PortInfo>`
                            
                            .. attribute:: tx_period
                            
                            	Time (in ms) between transmitting LACPDUs
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'bundlemgr-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleChildrenMembers.LacpBundleChildrenMember.ActorInfo, self).__init__()

                                self.yang_name = "actor-info"
                                self.yang_parent_name = "lacp-bundle-children-member"

                                self.tx_period = YLeaf(YType.uint32, "tx-period")

                                self.port_info = BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleChildrenMembers.LacpBundleChildrenMember.ActorInfo.PortInfo()
                                self.port_info.parent = self
                                self._children_name_map["port_info"] = "port-info"
                                self._children_yang_names.add("port-info")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("tx_period") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleChildrenMembers.LacpBundleChildrenMember.ActorInfo, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleChildrenMembers.LacpBundleChildrenMember.ActorInfo, self).__setattr__(name, value)


                            class PortInfo(Entity):
                                """
                                LACP parameters for this device
                                
                                .. attribute:: key
                                
                                	key
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: port
                                
                                	port
                                	**type**\:   :py:class:`Port <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleChildrenMembers.LacpBundleChildrenMember.ActorInfo.PortInfo.Port>`
                                
                                .. attribute:: state
                                
                                	state
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: system
                                
                                	system
                                	**type**\:   :py:class:`System <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleChildrenMembers.LacpBundleChildrenMember.ActorInfo.PortInfo.System>`
                                
                                

                                """

                                _prefix = 'bundlemgr-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleChildrenMembers.LacpBundleChildrenMember.ActorInfo.PortInfo, self).__init__()

                                    self.yang_name = "port-info"
                                    self.yang_parent_name = "actor-info"

                                    self.key = YLeaf(YType.uint16, "key")

                                    self.state = YLeaf(YType.uint8, "state")

                                    self.port = BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleChildrenMembers.LacpBundleChildrenMember.ActorInfo.PortInfo.Port()
                                    self.port.parent = self
                                    self._children_name_map["port"] = "port"
                                    self._children_yang_names.add("port")

                                    self.system = BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleChildrenMembers.LacpBundleChildrenMember.ActorInfo.PortInfo.System()
                                    self.system.parent = self
                                    self._children_name_map["system"] = "system"
                                    self._children_yang_names.add("system")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("key",
                                                    "state") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleChildrenMembers.LacpBundleChildrenMember.ActorInfo.PortInfo, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleChildrenMembers.LacpBundleChildrenMember.ActorInfo.PortInfo, self).__setattr__(name, value)


                                class System(Entity):
                                    """
                                    system
                                    
                                    .. attribute:: system_mac_addr
                                    
                                    	MAC Address used to identify the system
                                    	**type**\:   :py:class:`SystemMacAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleChildrenMembers.LacpBundleChildrenMember.ActorInfo.PortInfo.System.SystemMacAddr>`
                                    
                                    .. attribute:: system_prio
                                    
                                    	Priority of the system
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'bundlemgr-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleChildrenMembers.LacpBundleChildrenMember.ActorInfo.PortInfo.System, self).__init__()

                                        self.yang_name = "system"
                                        self.yang_parent_name = "port-info"

                                        self.system_prio = YLeaf(YType.uint16, "system-prio")

                                        self.system_mac_addr = BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleChildrenMembers.LacpBundleChildrenMember.ActorInfo.PortInfo.System.SystemMacAddr()
                                        self.system_mac_addr.parent = self
                                        self._children_name_map["system_mac_addr"] = "system-mac-addr"
                                        self._children_yang_names.add("system-mac-addr")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("system_prio") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleChildrenMembers.LacpBundleChildrenMember.ActorInfo.PortInfo.System, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleChildrenMembers.LacpBundleChildrenMember.ActorInfo.PortInfo.System, self).__setattr__(name, value)


                                    class SystemMacAddr(Entity):
                                        """
                                        MAC Address used to identify the system
                                        
                                        .. attribute:: macaddr
                                        
                                        	macaddr
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'bundlemgr-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleChildrenMembers.LacpBundleChildrenMember.ActorInfo.PortInfo.System.SystemMacAddr, self).__init__()

                                            self.yang_name = "system-mac-addr"
                                            self.yang_parent_name = "system"

                                            self.macaddr = YLeaf(YType.str, "macaddr")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("macaddr") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleChildrenMembers.LacpBundleChildrenMember.ActorInfo.PortInfo.System.SystemMacAddr, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleChildrenMembers.LacpBundleChildrenMember.ActorInfo.PortInfo.System.SystemMacAddr, self).__setattr__(name, value)

                                        def has_data(self):
                                            return self.macaddr.is_set

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.macaddr.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "system-mac-addr" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.macaddr.is_set or self.macaddr.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.macaddr.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "macaddr"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "macaddr"):
                                                self.macaddr = value
                                                self.macaddr.value_namespace = name_space
                                                self.macaddr.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.system_prio.is_set or
                                            (self.system_mac_addr is not None and self.system_mac_addr.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.system_prio.yfilter != YFilter.not_set or
                                            (self.system_mac_addr is not None and self.system_mac_addr.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "system" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.system_prio.is_set or self.system_prio.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.system_prio.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "system-mac-addr"):
                                            if (self.system_mac_addr is None):
                                                self.system_mac_addr = BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleChildrenMembers.LacpBundleChildrenMember.ActorInfo.PortInfo.System.SystemMacAddr()
                                                self.system_mac_addr.parent = self
                                                self._children_name_map["system_mac_addr"] = "system-mac-addr"
                                            return self.system_mac_addr

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "system-mac-addr" or name == "system-prio"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "system-prio"):
                                            self.system_prio = value
                                            self.system_prio.value_namespace = name_space
                                            self.system_prio.value_namespace_prefix = name_space_prefix


                                class Port(Entity):
                                    """
                                    port
                                    
                                    .. attribute:: link_number
                                    
                                    	link number
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: link_priority
                                    
                                    	link priority
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'bundlemgr-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleChildrenMembers.LacpBundleChildrenMember.ActorInfo.PortInfo.Port, self).__init__()

                                        self.yang_name = "port"
                                        self.yang_parent_name = "port-info"

                                        self.link_number = YLeaf(YType.uint16, "link-number")

                                        self.link_priority = YLeaf(YType.uint16, "link-priority")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("link_number",
                                                        "link_priority") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleChildrenMembers.LacpBundleChildrenMember.ActorInfo.PortInfo.Port, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleChildrenMembers.LacpBundleChildrenMember.ActorInfo.PortInfo.Port, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.link_number.is_set or
                                            self.link_priority.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.link_number.yfilter != YFilter.not_set or
                                            self.link_priority.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "port" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.link_number.is_set or self.link_number.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.link_number.get_name_leafdata())
                                        if (self.link_priority.is_set or self.link_priority.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.link_priority.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "link-number" or name == "link-priority"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "link-number"):
                                            self.link_number = value
                                            self.link_number.value_namespace = name_space
                                            self.link_number.value_namespace_prefix = name_space_prefix
                                        if(value_path == "link-priority"):
                                            self.link_priority = value
                                            self.link_priority.value_namespace = name_space
                                            self.link_priority.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.key.is_set or
                                        self.state.is_set or
                                        (self.port is not None and self.port.has_data()) or
                                        (self.system is not None and self.system.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.key.yfilter != YFilter.not_set or
                                        self.state.yfilter != YFilter.not_set or
                                        (self.port is not None and self.port.has_operation()) or
                                        (self.system is not None and self.system.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "port-info" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.key.is_set or self.key.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.key.get_name_leafdata())
                                    if (self.state.is_set or self.state.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.state.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "port"):
                                        if (self.port is None):
                                            self.port = BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleChildrenMembers.LacpBundleChildrenMember.ActorInfo.PortInfo.Port()
                                            self.port.parent = self
                                            self._children_name_map["port"] = "port"
                                        return self.port

                                    if (child_yang_name == "system"):
                                        if (self.system is None):
                                            self.system = BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleChildrenMembers.LacpBundleChildrenMember.ActorInfo.PortInfo.System()
                                            self.system.parent = self
                                            self._children_name_map["system"] = "system"
                                        return self.system

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "port" or name == "system" or name == "key" or name == "state"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "key"):
                                        self.key = value
                                        self.key.value_namespace = name_space
                                        self.key.value_namespace_prefix = name_space_prefix
                                    if(value_path == "state"):
                                        self.state = value
                                        self.state.value_namespace = name_space
                                        self.state.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.tx_period.is_set or
                                    (self.port_info is not None and self.port_info.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.tx_period.yfilter != YFilter.not_set or
                                    (self.port_info is not None and self.port_info.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "actor-info" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.tx_period.is_set or self.tx_period.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.tx_period.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "port-info"):
                                    if (self.port_info is None):
                                        self.port_info = BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleChildrenMembers.LacpBundleChildrenMember.ActorInfo.PortInfo()
                                        self.port_info.parent = self
                                        self._children_name_map["port_info"] = "port-info"
                                    return self.port_info

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "port-info" or name == "tx-period"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "tx-period"):
                                    self.tx_period = value
                                    self.tx_period.value_namespace = name_space
                                    self.tx_period.value_namespace_prefix = name_space_prefix


                        class PartnerInfo(Entity):
                            """
                            LACP information for the port from the partner
                            
                            .. attribute:: port_info
                            
                            	LACP parameters for this device
                            	**type**\:   :py:class:`PortInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleChildrenMembers.LacpBundleChildrenMember.PartnerInfo.PortInfo>`
                            
                            .. attribute:: tx_period
                            
                            	Time (in ms) between transmitting LACPDUs
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'bundlemgr-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleChildrenMembers.LacpBundleChildrenMember.PartnerInfo, self).__init__()

                                self.yang_name = "partner-info"
                                self.yang_parent_name = "lacp-bundle-children-member"

                                self.tx_period = YLeaf(YType.uint32, "tx-period")

                                self.port_info = BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleChildrenMembers.LacpBundleChildrenMember.PartnerInfo.PortInfo()
                                self.port_info.parent = self
                                self._children_name_map["port_info"] = "port-info"
                                self._children_yang_names.add("port-info")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("tx_period") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleChildrenMembers.LacpBundleChildrenMember.PartnerInfo, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleChildrenMembers.LacpBundleChildrenMember.PartnerInfo, self).__setattr__(name, value)


                            class PortInfo(Entity):
                                """
                                LACP parameters for this device
                                
                                .. attribute:: key
                                
                                	key
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: port
                                
                                	port
                                	**type**\:   :py:class:`Port <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleChildrenMembers.LacpBundleChildrenMember.PartnerInfo.PortInfo.Port>`
                                
                                .. attribute:: state
                                
                                	state
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: system
                                
                                	system
                                	**type**\:   :py:class:`System <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleChildrenMembers.LacpBundleChildrenMember.PartnerInfo.PortInfo.System>`
                                
                                

                                """

                                _prefix = 'bundlemgr-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleChildrenMembers.LacpBundleChildrenMember.PartnerInfo.PortInfo, self).__init__()

                                    self.yang_name = "port-info"
                                    self.yang_parent_name = "partner-info"

                                    self.key = YLeaf(YType.uint16, "key")

                                    self.state = YLeaf(YType.uint8, "state")

                                    self.port = BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleChildrenMembers.LacpBundleChildrenMember.PartnerInfo.PortInfo.Port()
                                    self.port.parent = self
                                    self._children_name_map["port"] = "port"
                                    self._children_yang_names.add("port")

                                    self.system = BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleChildrenMembers.LacpBundleChildrenMember.PartnerInfo.PortInfo.System()
                                    self.system.parent = self
                                    self._children_name_map["system"] = "system"
                                    self._children_yang_names.add("system")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("key",
                                                    "state") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleChildrenMembers.LacpBundleChildrenMember.PartnerInfo.PortInfo, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleChildrenMembers.LacpBundleChildrenMember.PartnerInfo.PortInfo, self).__setattr__(name, value)


                                class System(Entity):
                                    """
                                    system
                                    
                                    .. attribute:: system_mac_addr
                                    
                                    	MAC Address used to identify the system
                                    	**type**\:   :py:class:`SystemMacAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleChildrenMembers.LacpBundleChildrenMember.PartnerInfo.PortInfo.System.SystemMacAddr>`
                                    
                                    .. attribute:: system_prio
                                    
                                    	Priority of the system
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'bundlemgr-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleChildrenMembers.LacpBundleChildrenMember.PartnerInfo.PortInfo.System, self).__init__()

                                        self.yang_name = "system"
                                        self.yang_parent_name = "port-info"

                                        self.system_prio = YLeaf(YType.uint16, "system-prio")

                                        self.system_mac_addr = BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleChildrenMembers.LacpBundleChildrenMember.PartnerInfo.PortInfo.System.SystemMacAddr()
                                        self.system_mac_addr.parent = self
                                        self._children_name_map["system_mac_addr"] = "system-mac-addr"
                                        self._children_yang_names.add("system-mac-addr")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("system_prio") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleChildrenMembers.LacpBundleChildrenMember.PartnerInfo.PortInfo.System, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleChildrenMembers.LacpBundleChildrenMember.PartnerInfo.PortInfo.System, self).__setattr__(name, value)


                                    class SystemMacAddr(Entity):
                                        """
                                        MAC Address used to identify the system
                                        
                                        .. attribute:: macaddr
                                        
                                        	macaddr
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'bundlemgr-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleChildrenMembers.LacpBundleChildrenMember.PartnerInfo.PortInfo.System.SystemMacAddr, self).__init__()

                                            self.yang_name = "system-mac-addr"
                                            self.yang_parent_name = "system"

                                            self.macaddr = YLeaf(YType.str, "macaddr")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("macaddr") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleChildrenMembers.LacpBundleChildrenMember.PartnerInfo.PortInfo.System.SystemMacAddr, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleChildrenMembers.LacpBundleChildrenMember.PartnerInfo.PortInfo.System.SystemMacAddr, self).__setattr__(name, value)

                                        def has_data(self):
                                            return self.macaddr.is_set

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.macaddr.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "system-mac-addr" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.macaddr.is_set or self.macaddr.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.macaddr.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "macaddr"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "macaddr"):
                                                self.macaddr = value
                                                self.macaddr.value_namespace = name_space
                                                self.macaddr.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.system_prio.is_set or
                                            (self.system_mac_addr is not None and self.system_mac_addr.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.system_prio.yfilter != YFilter.not_set or
                                            (self.system_mac_addr is not None and self.system_mac_addr.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "system" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.system_prio.is_set or self.system_prio.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.system_prio.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "system-mac-addr"):
                                            if (self.system_mac_addr is None):
                                                self.system_mac_addr = BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleChildrenMembers.LacpBundleChildrenMember.PartnerInfo.PortInfo.System.SystemMacAddr()
                                                self.system_mac_addr.parent = self
                                                self._children_name_map["system_mac_addr"] = "system-mac-addr"
                                            return self.system_mac_addr

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "system-mac-addr" or name == "system-prio"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "system-prio"):
                                            self.system_prio = value
                                            self.system_prio.value_namespace = name_space
                                            self.system_prio.value_namespace_prefix = name_space_prefix


                                class Port(Entity):
                                    """
                                    port
                                    
                                    .. attribute:: link_number
                                    
                                    	link number
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: link_priority
                                    
                                    	link priority
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'bundlemgr-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleChildrenMembers.LacpBundleChildrenMember.PartnerInfo.PortInfo.Port, self).__init__()

                                        self.yang_name = "port"
                                        self.yang_parent_name = "port-info"

                                        self.link_number = YLeaf(YType.uint16, "link-number")

                                        self.link_priority = YLeaf(YType.uint16, "link-priority")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("link_number",
                                                        "link_priority") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleChildrenMembers.LacpBundleChildrenMember.PartnerInfo.PortInfo.Port, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleChildrenMembers.LacpBundleChildrenMember.PartnerInfo.PortInfo.Port, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.link_number.is_set or
                                            self.link_priority.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.link_number.yfilter != YFilter.not_set or
                                            self.link_priority.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "port" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.link_number.is_set or self.link_number.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.link_number.get_name_leafdata())
                                        if (self.link_priority.is_set or self.link_priority.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.link_priority.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "link-number" or name == "link-priority"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "link-number"):
                                            self.link_number = value
                                            self.link_number.value_namespace = name_space
                                            self.link_number.value_namespace_prefix = name_space_prefix
                                        if(value_path == "link-priority"):
                                            self.link_priority = value
                                            self.link_priority.value_namespace = name_space
                                            self.link_priority.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.key.is_set or
                                        self.state.is_set or
                                        (self.port is not None and self.port.has_data()) or
                                        (self.system is not None and self.system.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.key.yfilter != YFilter.not_set or
                                        self.state.yfilter != YFilter.not_set or
                                        (self.port is not None and self.port.has_operation()) or
                                        (self.system is not None and self.system.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "port-info" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.key.is_set or self.key.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.key.get_name_leafdata())
                                    if (self.state.is_set or self.state.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.state.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "port"):
                                        if (self.port is None):
                                            self.port = BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleChildrenMembers.LacpBundleChildrenMember.PartnerInfo.PortInfo.Port()
                                            self.port.parent = self
                                            self._children_name_map["port"] = "port"
                                        return self.port

                                    if (child_yang_name == "system"):
                                        if (self.system is None):
                                            self.system = BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleChildrenMembers.LacpBundleChildrenMember.PartnerInfo.PortInfo.System()
                                            self.system.parent = self
                                            self._children_name_map["system"] = "system"
                                        return self.system

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "port" or name == "system" or name == "key" or name == "state"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "key"):
                                        self.key = value
                                        self.key.value_namespace = name_space
                                        self.key.value_namespace_prefix = name_space_prefix
                                    if(value_path == "state"):
                                        self.state = value
                                        self.state.value_namespace = name_space
                                        self.state.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.tx_period.is_set or
                                    (self.port_info is not None and self.port_info.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.tx_period.yfilter != YFilter.not_set or
                                    (self.port_info is not None and self.port_info.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "partner-info" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.tx_period.is_set or self.tx_period.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.tx_period.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "port-info"):
                                    if (self.port_info is None):
                                        self.port_info = BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleChildrenMembers.LacpBundleChildrenMember.PartnerInfo.PortInfo()
                                        self.port_info.parent = self
                                        self._children_name_map["port_info"] = "port-info"
                                    return self.port_info

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "port-info" or name == "tx-period"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "tx-period"):
                                    self.tx_period = value
                                    self.tx_period.value_namespace = name_space
                                    self.tx_period.value_namespace_prefix = name_space_prefix


                        class AdditionalInfo(Entity):
                            """
                            Additional information for the link
                            
                            .. attribute:: foreign
                            
                            	Information for a foreign port
                            	**type**\:   :py:class:`Foreign <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleChildrenMembers.LacpBundleChildrenMember.AdditionalInfo.Foreign>`
                            
                            .. attribute:: local
                            
                            	Information for a local port
                            	**type**\:   :py:class:`Local <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleChildrenMembers.LacpBundleChildrenMember.AdditionalInfo.Local>`
                            
                            .. attribute:: mbr_type
                            
                            	MbrType
                            	**type**\:   :py:class:`BmdMemberTypeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmdMemberTypeEnum>`
                            
                            

                            """

                            _prefix = 'bundlemgr-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleChildrenMembers.LacpBundleChildrenMember.AdditionalInfo, self).__init__()

                                self.yang_name = "additional-info"
                                self.yang_parent_name = "lacp-bundle-children-member"

                                self.mbr_type = YLeaf(YType.enumeration, "mbr-type")

                                self.foreign = BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleChildrenMembers.LacpBundleChildrenMember.AdditionalInfo.Foreign()
                                self.foreign.parent = self
                                self._children_name_map["foreign"] = "foreign"
                                self._children_yang_names.add("foreign")

                                self.local = BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleChildrenMembers.LacpBundleChildrenMember.AdditionalInfo.Local()
                                self.local.parent = self
                                self._children_name_map["local"] = "local"
                                self._children_yang_names.add("local")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("mbr_type") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleChildrenMembers.LacpBundleChildrenMember.AdditionalInfo, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleChildrenMembers.LacpBundleChildrenMember.AdditionalInfo, self).__setattr__(name, value)


                            class Local(Entity):
                                """
                                Information for a local port
                                
                                .. attribute:: interface_handle
                                
                                	Member's interface handle
                                	**type**\:  str
                                
                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                
                                

                                """

                                _prefix = 'bundlemgr-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleChildrenMembers.LacpBundleChildrenMember.AdditionalInfo.Local, self).__init__()

                                    self.yang_name = "local"
                                    self.yang_parent_name = "additional-info"

                                    self.interface_handle = YLeaf(YType.str, "interface-handle")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("interface_handle") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleChildrenMembers.LacpBundleChildrenMember.AdditionalInfo.Local, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleChildrenMembers.LacpBundleChildrenMember.AdditionalInfo.Local, self).__setattr__(name, value)

                                def has_data(self):
                                    return self.interface_handle.is_set

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.interface_handle.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "local" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.interface_handle.is_set or self.interface_handle.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.interface_handle.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "interface-handle"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "interface-handle"):
                                        self.interface_handle = value
                                        self.interface_handle.value_namespace = name_space
                                        self.interface_handle.value_namespace_prefix = name_space_prefix


                            class Foreign(Entity):
                                """
                                Information for a foreign port
                                
                                .. attribute:: member_name
                                
                                	Member's (short form) name
                                	**type**\:  str
                                
                                .. attribute:: peer_address
                                
                                	The LDP address of the device that the link is configured on
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'bundlemgr-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleChildrenMembers.LacpBundleChildrenMember.AdditionalInfo.Foreign, self).__init__()

                                    self.yang_name = "foreign"
                                    self.yang_parent_name = "additional-info"

                                    self.member_name = YLeaf(YType.str, "member-name")

                                    self.peer_address = YLeaf(YType.str, "peer-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("member_name",
                                                    "peer_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleChildrenMembers.LacpBundleChildrenMember.AdditionalInfo.Foreign, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleChildrenMembers.LacpBundleChildrenMember.AdditionalInfo.Foreign, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.member_name.is_set or
                                        self.peer_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.member_name.yfilter != YFilter.not_set or
                                        self.peer_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "foreign" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.member_name.is_set or self.member_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.member_name.get_name_leafdata())
                                    if (self.peer_address.is_set or self.peer_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.peer_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "member-name" or name == "peer-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "member-name"):
                                        self.member_name = value
                                        self.member_name.value_namespace = name_space
                                        self.member_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "peer-address"):
                                        self.peer_address = value
                                        self.peer_address.value_namespace = name_space
                                        self.peer_address.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.mbr_type.is_set or
                                    (self.foreign is not None and self.foreign.has_data()) or
                                    (self.local is not None and self.local.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.mbr_type.yfilter != YFilter.not_set or
                                    (self.foreign is not None and self.foreign.has_operation()) or
                                    (self.local is not None and self.local.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "additional-info" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.mbr_type.is_set or self.mbr_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mbr_type.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "foreign"):
                                    if (self.foreign is None):
                                        self.foreign = BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleChildrenMembers.LacpBundleChildrenMember.AdditionalInfo.Foreign()
                                        self.foreign.parent = self
                                        self._children_name_map["foreign"] = "foreign"
                                    return self.foreign

                                if (child_yang_name == "local"):
                                    if (self.local is None):
                                        self.local = BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleChildrenMembers.LacpBundleChildrenMember.AdditionalInfo.Local()
                                        self.local.parent = self
                                        self._children_name_map["local"] = "local"
                                    return self.local

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "foreign" or name == "local" or name == "mbr-type"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "mbr-type"):
                                    self.mbr_type = value
                                    self.mbr_type.value_namespace = name_space
                                    self.mbr_type.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.member_interface.is_set or
                                self.actor_churn_state.is_set or
                                self.attached_aggregator_id.is_set or
                                self.iccp_group_id.is_set or
                                self.mux_state.is_set or
                                self.partner_churn_state.is_set or
                                self.period_state.is_set or
                                self.receive_machine_state.is_set or
                                self.selected_aggregator_id.is_set or
                                self.selection_state.is_set or
                                (self.actor_info is not None and self.actor_info.has_data()) or
                                (self.additional_info is not None and self.additional_info.has_data()) or
                                (self.partner_info is not None and self.partner_info.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.member_interface.yfilter != YFilter.not_set or
                                self.actor_churn_state.yfilter != YFilter.not_set or
                                self.attached_aggregator_id.yfilter != YFilter.not_set or
                                self.iccp_group_id.yfilter != YFilter.not_set or
                                self.mux_state.yfilter != YFilter.not_set or
                                self.partner_churn_state.yfilter != YFilter.not_set or
                                self.period_state.yfilter != YFilter.not_set or
                                self.receive_machine_state.yfilter != YFilter.not_set or
                                self.selected_aggregator_id.yfilter != YFilter.not_set or
                                self.selection_state.yfilter != YFilter.not_set or
                                (self.actor_info is not None and self.actor_info.has_operation()) or
                                (self.additional_info is not None and self.additional_info.has_operation()) or
                                (self.partner_info is not None and self.partner_info.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "lacp-bundle-children-member" + "[member-interface='" + self.member_interface.get() + "']" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.member_interface.is_set or self.member_interface.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.member_interface.get_name_leafdata())
                            if (self.actor_churn_state.is_set or self.actor_churn_state.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.actor_churn_state.get_name_leafdata())
                            if (self.attached_aggregator_id.is_set or self.attached_aggregator_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.attached_aggregator_id.get_name_leafdata())
                            if (self.iccp_group_id.is_set or self.iccp_group_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.iccp_group_id.get_name_leafdata())
                            if (self.mux_state.is_set or self.mux_state.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mux_state.get_name_leafdata())
                            if (self.partner_churn_state.is_set or self.partner_churn_state.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.partner_churn_state.get_name_leafdata())
                            if (self.period_state.is_set or self.period_state.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.period_state.get_name_leafdata())
                            if (self.receive_machine_state.is_set or self.receive_machine_state.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.receive_machine_state.get_name_leafdata())
                            if (self.selected_aggregator_id.is_set or self.selected_aggregator_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.selected_aggregator_id.get_name_leafdata())
                            if (self.selection_state.is_set or self.selection_state.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.selection_state.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "actor-info"):
                                if (self.actor_info is None):
                                    self.actor_info = BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleChildrenMembers.LacpBundleChildrenMember.ActorInfo()
                                    self.actor_info.parent = self
                                    self._children_name_map["actor_info"] = "actor-info"
                                return self.actor_info

                            if (child_yang_name == "additional-info"):
                                if (self.additional_info is None):
                                    self.additional_info = BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleChildrenMembers.LacpBundleChildrenMember.AdditionalInfo()
                                    self.additional_info.parent = self
                                    self._children_name_map["additional_info"] = "additional-info"
                                return self.additional_info

                            if (child_yang_name == "partner-info"):
                                if (self.partner_info is None):
                                    self.partner_info = BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleChildrenMembers.LacpBundleChildrenMember.PartnerInfo()
                                    self.partner_info.parent = self
                                    self._children_name_map["partner_info"] = "partner-info"
                                return self.partner_info

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "actor-info" or name == "additional-info" or name == "partner-info" or name == "member-interface" or name == "actor-churn-state" or name == "attached-aggregator-id" or name == "iccp-group-id" or name == "mux-state" or name == "partner-churn-state" or name == "period-state" or name == "receive-machine-state" or name == "selected-aggregator-id" or name == "selection-state"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "member-interface"):
                                self.member_interface = value
                                self.member_interface.value_namespace = name_space
                                self.member_interface.value_namespace_prefix = name_space_prefix
                            if(value_path == "actor-churn-state"):
                                self.actor_churn_state = value
                                self.actor_churn_state.value_namespace = name_space
                                self.actor_churn_state.value_namespace_prefix = name_space_prefix
                            if(value_path == "attached-aggregator-id"):
                                self.attached_aggregator_id = value
                                self.attached_aggregator_id.value_namespace = name_space
                                self.attached_aggregator_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "iccp-group-id"):
                                self.iccp_group_id = value
                                self.iccp_group_id.value_namespace = name_space
                                self.iccp_group_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "mux-state"):
                                self.mux_state = value
                                self.mux_state.value_namespace = name_space
                                self.mux_state.value_namespace_prefix = name_space_prefix
                            if(value_path == "partner-churn-state"):
                                self.partner_churn_state = value
                                self.partner_churn_state.value_namespace = name_space
                                self.partner_churn_state.value_namespace_prefix = name_space_prefix
                            if(value_path == "period-state"):
                                self.period_state = value
                                self.period_state.value_namespace = name_space
                                self.period_state.value_namespace_prefix = name_space_prefix
                            if(value_path == "receive-machine-state"):
                                self.receive_machine_state = value
                                self.receive_machine_state.value_namespace = name_space
                                self.receive_machine_state.value_namespace_prefix = name_space_prefix
                            if(value_path == "selected-aggregator-id"):
                                self.selected_aggregator_id = value
                                self.selected_aggregator_id.value_namespace = name_space
                                self.selected_aggregator_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "selection-state"):
                                self.selection_state = value
                                self.selection_state.value_namespace = name_space
                                self.selection_state.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.lacp_bundle_children_member:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.lacp_bundle_children_member:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "lacp-bundle-children-members" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "lacp-bundle-children-member"):
                            for c in self.lacp_bundle_children_member:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleChildrenMembers.LacpBundleChildrenMember()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.lacp_bundle_children_member.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "lacp-bundle-children-member"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass

                def has_data(self):
                    return (
                        self.bundle_interface.is_set or
                        (self.lacp_bundle_children_members is not None and self.lacp_bundle_children_members.has_data()) or
                        (self.lacp_bundle_descendant is not None and self.lacp_bundle_descendant.has_data()) or
                        (self.lacp_bundle_item is not None and self.lacp_bundle_item.has_data()))

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.bundle_interface.yfilter != YFilter.not_set or
                        (self.lacp_bundle_children_members is not None and self.lacp_bundle_children_members.has_operation()) or
                        (self.lacp_bundle_descendant is not None and self.lacp_bundle_descendant.has_operation()) or
                        (self.lacp_bundle_item is not None and self.lacp_bundle_item.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "lacp-bundle" + "[bundle-interface='" + self.bundle_interface.get() + "']" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-bundlemgr-oper:bundle-information/lacp/lacp-bundles/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.bundle_interface.is_set or self.bundle_interface.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.bundle_interface.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "lacp-bundle-children-members"):
                        if (self.lacp_bundle_children_members is None):
                            self.lacp_bundle_children_members = BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleChildrenMembers()
                            self.lacp_bundle_children_members.parent = self
                            self._children_name_map["lacp_bundle_children_members"] = "lacp-bundle-children-members"
                        return self.lacp_bundle_children_members

                    if (child_yang_name == "lacp-bundle-descendant"):
                        if (self.lacp_bundle_descendant is None):
                            self.lacp_bundle_descendant = BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleDescendant()
                            self.lacp_bundle_descendant.parent = self
                            self._children_name_map["lacp_bundle_descendant"] = "lacp-bundle-descendant"
                        return self.lacp_bundle_descendant

                    if (child_yang_name == "lacp-bundle-item"):
                        if (self.lacp_bundle_item is None):
                            self.lacp_bundle_item = BundleInformation.Lacp.LacpBundles.LacpBundle.LacpBundleItem()
                            self.lacp_bundle_item.parent = self
                            self._children_name_map["lacp_bundle_item"] = "lacp-bundle-item"
                        return self.lacp_bundle_item

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "lacp-bundle-children-members" or name == "lacp-bundle-descendant" or name == "lacp-bundle-item" or name == "bundle-interface"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "bundle-interface"):
                        self.bundle_interface = value
                        self.bundle_interface.value_namespace = name_space
                        self.bundle_interface.value_namespace_prefix = name_space_prefix

            def has_data(self):
                for c in self.lacp_bundle:
                    if (c.has_data()):
                        return True
                return False

            def has_operation(self):
                for c in self.lacp_bundle:
                    if (c.has_operation()):
                        return True
                return self.yfilter != YFilter.not_set

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "lacp-bundles" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-bundlemgr-oper:bundle-information/lacp/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "lacp-bundle"):
                    for c in self.lacp_bundle:
                        segment = c.get_segment_path()
                        if (segment_path == segment):
                            return c
                    c = BundleInformation.Lacp.LacpBundles.LacpBundle()
                    c.parent = self
                    local_reference_key = "ydk::seg::%s" % segment_path
                    self._local_refs[local_reference_key] = c
                    self.lacp_bundle.append(c)
                    return c

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "lacp-bundle"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                pass


        class LacpMembers(Entity):
            """
            Member interfaces with LACP information
            
            .. attribute:: lacp_member
            
            	Member interface
            	**type**\: list of    :py:class:`LacpMember <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.Lacp.LacpMembers.LacpMember>`
            
            

            """

            _prefix = 'bundlemgr-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(BundleInformation.Lacp.LacpMembers, self).__init__()

                self.yang_name = "lacp-members"
                self.yang_parent_name = "lacp"

                self.lacp_member = YList(self)

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in () and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(BundleInformation.Lacp.LacpMembers, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(BundleInformation.Lacp.LacpMembers, self).__setattr__(name, value)


            class LacpMember(Entity):
                """
                Member interface
                
                .. attribute:: member_interface  <key>
                
                	Member interface
                	**type**\:  str
                
                .. attribute:: lacp_member_ancestor
                
                	Data for this item and its parent bundle
                	**type**\:   :py:class:`LacpMemberAncestor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.Lacp.LacpMembers.LacpMember.LacpMemberAncestor>`
                
                .. attribute:: lacp_member_item
                
                	Data for this item
                	**type**\:   :py:class:`LacpMemberItem <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.Lacp.LacpMembers.LacpMember.LacpMemberItem>`
                
                

                """

                _prefix = 'bundlemgr-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(BundleInformation.Lacp.LacpMembers.LacpMember, self).__init__()

                    self.yang_name = "lacp-member"
                    self.yang_parent_name = "lacp-members"

                    self.member_interface = YLeaf(YType.str, "member-interface")

                    self.lacp_member_ancestor = BundleInformation.Lacp.LacpMembers.LacpMember.LacpMemberAncestor()
                    self.lacp_member_ancestor.parent = self
                    self._children_name_map["lacp_member_ancestor"] = "lacp-member-ancestor"
                    self._children_yang_names.add("lacp-member-ancestor")

                    self.lacp_member_item = BundleInformation.Lacp.LacpMembers.LacpMember.LacpMemberItem()
                    self.lacp_member_item.parent = self
                    self._children_name_map["lacp_member_item"] = "lacp-member-item"
                    self._children_yang_names.add("lacp-member-item")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("member_interface") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(BundleInformation.Lacp.LacpMembers.LacpMember, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(BundleInformation.Lacp.LacpMembers.LacpMember, self).__setattr__(name, value)


                class LacpMemberAncestor(Entity):
                    """
                    Data for this item and its parent bundle
                    
                    .. attribute:: bundle_data
                    
                    	Bundle information
                    	**type**\:   :py:class:`BundleData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.Lacp.LacpMembers.LacpMember.LacpMemberAncestor.BundleData>`
                    
                    .. attribute:: member_data
                    
                    	Member information
                    	**type**\: list of    :py:class:`MemberData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.Lacp.LacpMembers.LacpMember.LacpMemberAncestor.MemberData>`
                    
                    

                    """

                    _prefix = 'bundlemgr-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(BundleInformation.Lacp.LacpMembers.LacpMember.LacpMemberAncestor, self).__init__()

                        self.yang_name = "lacp-member-ancestor"
                        self.yang_parent_name = "lacp-member"

                        self.bundle_data = BundleInformation.Lacp.LacpMembers.LacpMember.LacpMemberAncestor.BundleData()
                        self.bundle_data.parent = self
                        self._children_name_map["bundle_data"] = "bundle-data"
                        self._children_yang_names.add("bundle-data")

                        self.member_data = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(BundleInformation.Lacp.LacpMembers.LacpMember.LacpMemberAncestor, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(BundleInformation.Lacp.LacpMembers.LacpMember.LacpMemberAncestor, self).__setattr__(name, value)


                    class BundleData(Entity):
                        """
                        Bundle information
                        
                        .. attribute:: actor_bundle_data
                        
                        	Basic bundle information
                        	**type**\:   :py:class:`ActorBundleData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.Lacp.LacpMembers.LacpMember.LacpMemberAncestor.BundleData.ActorBundleData>`
                        
                        .. attribute:: actor_operational_key
                        
                        	Operational key of the interface
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: bundle_system_id
                        
                        	System ID for the bundle
                        	**type**\:   :py:class:`BundleSystemId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.Lacp.LacpMembers.LacpMember.LacpMemberAncestor.BundleData.BundleSystemId>`
                        
                        .. attribute:: partner_operational_key
                        
                        	Operational key of the partner
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: partner_system_mac_address
                        
                        	MAC Address used to identify the partner system
                        	**type**\:  str
                        
                        	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                        
                        .. attribute:: partner_system_priority
                        
                        	Priority of the partner system
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'bundlemgr-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(BundleInformation.Lacp.LacpMembers.LacpMember.LacpMemberAncestor.BundleData, self).__init__()

                            self.yang_name = "bundle-data"
                            self.yang_parent_name = "lacp-member-ancestor"

                            self.actor_operational_key = YLeaf(YType.uint16, "actor-operational-key")

                            self.partner_operational_key = YLeaf(YType.uint16, "partner-operational-key")

                            self.partner_system_mac_address = YLeaf(YType.str, "partner-system-mac-address")

                            self.partner_system_priority = YLeaf(YType.uint16, "partner-system-priority")

                            self.actor_bundle_data = BundleInformation.Lacp.LacpMembers.LacpMember.LacpMemberAncestor.BundleData.ActorBundleData()
                            self.actor_bundle_data.parent = self
                            self._children_name_map["actor_bundle_data"] = "actor-bundle-data"
                            self._children_yang_names.add("actor-bundle-data")

                            self.bundle_system_id = BundleInformation.Lacp.LacpMembers.LacpMember.LacpMemberAncestor.BundleData.BundleSystemId()
                            self.bundle_system_id.parent = self
                            self._children_name_map["bundle_system_id"] = "bundle-system-id"
                            self._children_yang_names.add("bundle-system-id")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("actor_operational_key",
                                            "partner_operational_key",
                                            "partner_system_mac_address",
                                            "partner_system_priority") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(BundleInformation.Lacp.LacpMembers.LacpMember.LacpMemberAncestor.BundleData, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(BundleInformation.Lacp.LacpMembers.LacpMember.LacpMemberAncestor.BundleData, self).__setattr__(name, value)


                        class ActorBundleData(Entity):
                            """
                            Basic bundle information
                            
                            .. attribute:: active_foreign_member_count
                            
                            	The number of active foreign members on the bundle
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: active_member_count
                            
                            	The number of active local members on the bundle
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: available_bandwidth
                            
                            	Bandwidth available to the bundle interface (kbps)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: bfd_config
                            
                            	Configuration values for BFD on bundle members
                            	**type**\: list of    :py:class:`BfdConfig <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.Lacp.LacpMembers.LacpMember.LacpMemberAncestor.BundleData.ActorBundleData.BfdConfig>`
                            
                            .. attribute:: bundle_interface_name
                            
                            	Bundle interface name
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: bundle_status
                            
                            	The state of the bundle
                            	**type**\:   :py:class:`BmBdlState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmBdlState>`
                            
                            .. attribute:: cisco_extensions
                            
                            	The status of the Cisco Extensions feature (1 = enabled, 0 = not enabled)
                            	**type**\:  bool
                            
                            .. attribute:: collector_max_delay
                            
                            	Collector Max Delay
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: configured_bandwidth
                            
                            	Bandwidth configured on the bundle interface (kbps)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: configured_foreign_member_count
                            
                            	The number of configured local members on the bundle
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: configured_member_count
                            
                            	The number of configured local members on the bundle
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: effective_bandwidth
                            
                            	Effective bandwidth on the bundle interface (kbps)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: iccp_group_id
                            
                            	ICCP Group that the bundle is configured to
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: inter_chassis
                            
                            	Indicates if this bundle is operating as an inter\-chassis link (1 = I\-C link, 0 = normal)
                            	**type**\:  bool
                            
                            .. attribute:: ipv4bfd_status
                            
                            	The status of the BFD (IPv4) feature on the bundle
                            	**type**\:   :py:class:`BmFeatureStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmFeatureStatus>`
                            
                            .. attribute:: ipv6bfd_status
                            
                            	The status of the BFD (IPv6) feature on the bundle
                            	**type**\:   :py:class:`BmFeatureStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmFeatureStatus>`
                            
                            .. attribute:: is_active
                            
                            	Indicates the active/standby redundancy state of the device for the bundle
                            	**type**\:  bool
                            
                            .. attribute:: lacp_nonrevertive
                            
                            	The status of the LACP nonrevertive feature (1 = enable, 0 = not enabled)
                            	**type**\:  bool
                            
                            .. attribute:: lacp_status
                            
                            	The status of the LACP feature on the bundle
                            	**type**\:   :py:class:`BmFeatureStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmFeatureStatus>`
                            
                            .. attribute:: link_order_status
                            
                            	The status of the link order signaling feature on the bundle
                            	**type**\:   :py:class:`BmFeatureStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmFeatureStatus>`
                            
                            .. attribute:: load_balance_hash_type
                            
                            	The type of hash to use for load balancing
                            	**type**\:  str
                            
                            .. attribute:: load_balance_locality_threshold
                            
                            	The number of links required per rack for localized load balancing
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: mac_address
                            
                            	MAC address of this member
                            	**type**\:   :py:class:`MacAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.Lacp.LacpMembers.LacpMember.LacpMemberAncestor.BundleData.ActorBundleData.MacAddress>`
                            
                            .. attribute:: mac_source
                            
                            	The source of the MAC Address
                            	**type**\:   :py:class:`BmBdlMacSource <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmBdlMacSource>`
                            
                            .. attribute:: mac_source_member
                            
                            	The name of the member that supplied the MAC address
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: maximize_threshold_value_band_width
                            
                            	Attempt to maximize the bundle if bandwidth is below this value
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: maximize_threshold_value_links
                            
                            	Attempt to maximize the bundle if links are below this value
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: maximum_active_links
                            
                            	Maximum number of active links in the bundle
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: maximum_active_links_source
                            
                            	Source of maximum active links value
                            	**type**\:   :py:class:`BmWhichSystem <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmWhichSystem>`
                            
                            .. attribute:: minimum_active_links
                            
                            	Minimum number of active links for bundle to go up
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: minimum_bandwidth
                            
                            	Minimum bundle bandwidth for bundle to go up (kbps)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: mlacp_mode
                            
                            	Indicates the mode of the device for the bundle
                            	**type**\:   :py:class:`BundleMlacpMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleMlacpMode>`
                            
                            .. attribute:: mlacp_status
                            
                            	The status of the mLACP feature on the bundle
                            	**type**\:   :py:class:`BmFeatureStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmFeatureStatus>`
                            
                            .. attribute:: primary_member
                            
                            	Primary bundle member (no longer applicable)
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: recovery_delay
                            
                            	Number of seconds to wait before becoming active after recovering from a failure
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            	**units**\: second
                            
                            .. attribute:: singleton
                            
                            	Is the ICCP group of the bundle in singleton mode (1 = singleton; 0 = not singleton)
                            	**type**\:  bool
                            
                            .. attribute:: standby_member_count
                            
                            	The number of standby local members on the bundle
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: suppression_timer
                            
                            	Timer for suppressing bundle state flaps
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: switchover_type
                            
                            	How a switchover of the bundle from this device will occur
                            	**type**\:   :py:class:`BmdMlacpSwitchover <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmdMlacpSwitchover>`
                            
                            .. attribute:: wait_while_timer
                            
                            	The wait while time used for member ports
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'bundlemgr-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(BundleInformation.Lacp.LacpMembers.LacpMember.LacpMemberAncestor.BundleData.ActorBundleData, self).__init__()

                                self.yang_name = "actor-bundle-data"
                                self.yang_parent_name = "bundle-data"

                                self.active_foreign_member_count = YLeaf(YType.uint16, "active-foreign-member-count")

                                self.active_member_count = YLeaf(YType.uint16, "active-member-count")

                                self.available_bandwidth = YLeaf(YType.uint32, "available-bandwidth")

                                self.bundle_interface_name = YLeaf(YType.str, "bundle-interface-name")

                                self.bundle_status = YLeaf(YType.enumeration, "bundle-status")

                                self.cisco_extensions = YLeaf(YType.boolean, "cisco-extensions")

                                self.collector_max_delay = YLeaf(YType.uint16, "collector-max-delay")

                                self.configured_bandwidth = YLeaf(YType.uint32, "configured-bandwidth")

                                self.configured_foreign_member_count = YLeaf(YType.uint16, "configured-foreign-member-count")

                                self.configured_member_count = YLeaf(YType.uint16, "configured-member-count")

                                self.effective_bandwidth = YLeaf(YType.uint32, "effective-bandwidth")

                                self.iccp_group_id = YLeaf(YType.uint32, "iccp-group-id")

                                self.inter_chassis = YLeaf(YType.boolean, "inter-chassis")

                                self.ipv4bfd_status = YLeaf(YType.enumeration, "ipv4bfd-status")

                                self.ipv6bfd_status = YLeaf(YType.enumeration, "ipv6bfd-status")

                                self.is_active = YLeaf(YType.boolean, "is-active")

                                self.lacp_nonrevertive = YLeaf(YType.boolean, "lacp-nonrevertive")

                                self.lacp_status = YLeaf(YType.enumeration, "lacp-status")

                                self.link_order_status = YLeaf(YType.enumeration, "link-order-status")

                                self.load_balance_hash_type = YLeaf(YType.str, "load-balance-hash-type")

                                self.load_balance_locality_threshold = YLeaf(YType.uint16, "load-balance-locality-threshold")

                                self.mac_source = YLeaf(YType.enumeration, "mac-source")

                                self.mac_source_member = YLeaf(YType.str, "mac-source-member")

                                self.maximize_threshold_value_band_width = YLeaf(YType.uint32, "maximize-threshold-value-band-width")

                                self.maximize_threshold_value_links = YLeaf(YType.uint32, "maximize-threshold-value-links")

                                self.maximum_active_links = YLeaf(YType.uint8, "maximum-active-links")

                                self.maximum_active_links_source = YLeaf(YType.enumeration, "maximum-active-links-source")

                                self.minimum_active_links = YLeaf(YType.uint8, "minimum-active-links")

                                self.minimum_bandwidth = YLeaf(YType.uint32, "minimum-bandwidth")

                                self.mlacp_mode = YLeaf(YType.enumeration, "mlacp-mode")

                                self.mlacp_status = YLeaf(YType.enumeration, "mlacp-status")

                                self.primary_member = YLeaf(YType.str, "primary-member")

                                self.recovery_delay = YLeaf(YType.uint16, "recovery-delay")

                                self.singleton = YLeaf(YType.boolean, "singleton")

                                self.standby_member_count = YLeaf(YType.uint16, "standby-member-count")

                                self.suppression_timer = YLeaf(YType.uint16, "suppression-timer")

                                self.switchover_type = YLeaf(YType.enumeration, "switchover-type")

                                self.wait_while_timer = YLeaf(YType.uint16, "wait-while-timer")

                                self.mac_address = BundleInformation.Lacp.LacpMembers.LacpMember.LacpMemberAncestor.BundleData.ActorBundleData.MacAddress()
                                self.mac_address.parent = self
                                self._children_name_map["mac_address"] = "mac-address"
                                self._children_yang_names.add("mac-address")

                                self.bfd_config = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("active_foreign_member_count",
                                                "active_member_count",
                                                "available_bandwidth",
                                                "bundle_interface_name",
                                                "bundle_status",
                                                "cisco_extensions",
                                                "collector_max_delay",
                                                "configured_bandwidth",
                                                "configured_foreign_member_count",
                                                "configured_member_count",
                                                "effective_bandwidth",
                                                "iccp_group_id",
                                                "inter_chassis",
                                                "ipv4bfd_status",
                                                "ipv6bfd_status",
                                                "is_active",
                                                "lacp_nonrevertive",
                                                "lacp_status",
                                                "link_order_status",
                                                "load_balance_hash_type",
                                                "load_balance_locality_threshold",
                                                "mac_source",
                                                "mac_source_member",
                                                "maximize_threshold_value_band_width",
                                                "maximize_threshold_value_links",
                                                "maximum_active_links",
                                                "maximum_active_links_source",
                                                "minimum_active_links",
                                                "minimum_bandwidth",
                                                "mlacp_mode",
                                                "mlacp_status",
                                                "primary_member",
                                                "recovery_delay",
                                                "singleton",
                                                "standby_member_count",
                                                "suppression_timer",
                                                "switchover_type",
                                                "wait_while_timer") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(BundleInformation.Lacp.LacpMembers.LacpMember.LacpMemberAncestor.BundleData.ActorBundleData, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(BundleInformation.Lacp.LacpMembers.LacpMember.LacpMemberAncestor.BundleData.ActorBundleData, self).__setattr__(name, value)


                            class MacAddress(Entity):
                                """
                                MAC address of this member
                                
                                .. attribute:: address
                                
                                	MAC address
                                	**type**\:  str
                                
                                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                
                                

                                """

                                _prefix = 'bundlemgr-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(BundleInformation.Lacp.LacpMembers.LacpMember.LacpMemberAncestor.BundleData.ActorBundleData.MacAddress, self).__init__()

                                    self.yang_name = "mac-address"
                                    self.yang_parent_name = "actor-bundle-data"

                                    self.address = YLeaf(YType.str, "address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(BundleInformation.Lacp.LacpMembers.LacpMember.LacpMemberAncestor.BundleData.ActorBundleData.MacAddress, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(BundleInformation.Lacp.LacpMembers.LacpMember.LacpMemberAncestor.BundleData.ActorBundleData.MacAddress, self).__setattr__(name, value)

                                def has_data(self):
                                    return self.address.is_set

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "mac-address" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.address.is_set or self.address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "address"):
                                        self.address = value
                                        self.address.value_namespace = name_space
                                        self.address.value_namespace_prefix = name_space_prefix


                            class BfdConfig(Entity):
                                """
                                Configuration values for BFD on bundle members
                                
                                .. attribute:: bundle_status
                                
                                	Status of BFD on the bundle
                                	**type**\:   :py:class:`BmdBfdBdlState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmdBfdBdlState>`
                                
                                .. attribute:: destination_address
                                
                                	Configured destination address for BFD session
                                	**type**\:   :py:class:`DestinationAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.Lacp.LacpMembers.LacpMember.LacpMemberAncestor.BundleData.ActorBundleData.BfdConfig.DestinationAddress>`
                                
                                .. attribute:: fast_detect
                                
                                	Flag indicating if BFD is enabled (1 = enabled; 0 = not enabled)
                                	**type**\:  bool
                                
                                .. attribute:: mode_info
                                
                                	Standard used for per\-member BFD
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: nbr_unconfig_timer
                                
                                	Time to wait on session NBR\_UNCONFIG before declaring DOWN
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: pref_echo_min_interval
                                
                                	Preferred echo minimum interval for the BFD session (ms)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: pref_min_interval
                                
                                	Preferred minimum interval for the BFD session (ms)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: pref_multiplier
                                
                                	Preferred multiplier for the BFD session
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: start_timer
                                
                                	Time to wait on session start before declaring DOWN
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'bundlemgr-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(BundleInformation.Lacp.LacpMembers.LacpMember.LacpMemberAncestor.BundleData.ActorBundleData.BfdConfig, self).__init__()

                                    self.yang_name = "bfd-config"
                                    self.yang_parent_name = "actor-bundle-data"

                                    self.bundle_status = YLeaf(YType.enumeration, "bundle-status")

                                    self.fast_detect = YLeaf(YType.boolean, "fast-detect")

                                    self.mode_info = YLeaf(YType.uint32, "mode-info")

                                    self.nbr_unconfig_timer = YLeaf(YType.uint32, "nbr-unconfig-timer")

                                    self.pref_echo_min_interval = YLeaf(YType.uint32, "pref-echo-min-interval")

                                    self.pref_min_interval = YLeaf(YType.uint32, "pref-min-interval")

                                    self.pref_multiplier = YLeaf(YType.uint16, "pref-multiplier")

                                    self.start_timer = YLeaf(YType.uint32, "start-timer")

                                    self.destination_address = BundleInformation.Lacp.LacpMembers.LacpMember.LacpMemberAncestor.BundleData.ActorBundleData.BfdConfig.DestinationAddress()
                                    self.destination_address.parent = self
                                    self._children_name_map["destination_address"] = "destination-address"
                                    self._children_yang_names.add("destination-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("bundle_status",
                                                    "fast_detect",
                                                    "mode_info",
                                                    "nbr_unconfig_timer",
                                                    "pref_echo_min_interval",
                                                    "pref_min_interval",
                                                    "pref_multiplier",
                                                    "start_timer") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(BundleInformation.Lacp.LacpMembers.LacpMember.LacpMemberAncestor.BundleData.ActorBundleData.BfdConfig, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(BundleInformation.Lacp.LacpMembers.LacpMember.LacpMemberAncestor.BundleData.ActorBundleData.BfdConfig, self).__setattr__(name, value)


                                class DestinationAddress(Entity):
                                    """
                                    Configured destination address for BFD session
                                    
                                    .. attribute:: af
                                    
                                    	AF
                                    	**type**\:   :py:class:`BmAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmAfId>`
                                    
                                    .. attribute:: ipv4
                                    
                                    	IPv4 address type
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6
                                    
                                    	IPv6 address type
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'bundlemgr-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(BundleInformation.Lacp.LacpMembers.LacpMember.LacpMemberAncestor.BundleData.ActorBundleData.BfdConfig.DestinationAddress, self).__init__()

                                        self.yang_name = "destination-address"
                                        self.yang_parent_name = "bfd-config"

                                        self.af = YLeaf(YType.enumeration, "af")

                                        self.ipv4 = YLeaf(YType.str, "ipv4")

                                        self.ipv6 = YLeaf(YType.str, "ipv6")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("af",
                                                        "ipv4",
                                                        "ipv6") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(BundleInformation.Lacp.LacpMembers.LacpMember.LacpMemberAncestor.BundleData.ActorBundleData.BfdConfig.DestinationAddress, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(BundleInformation.Lacp.LacpMembers.LacpMember.LacpMemberAncestor.BundleData.ActorBundleData.BfdConfig.DestinationAddress, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.af.is_set or
                                            self.ipv4.is_set or
                                            self.ipv6.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.af.yfilter != YFilter.not_set or
                                            self.ipv4.yfilter != YFilter.not_set or
                                            self.ipv6.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "destination-address" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.af.is_set or self.af.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.af.get_name_leafdata())
                                        if (self.ipv4.is_set or self.ipv4.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ipv4.get_name_leafdata())
                                        if (self.ipv6.is_set or self.ipv6.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ipv6.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "af" or name == "ipv4" or name == "ipv6"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "af"):
                                            self.af = value
                                            self.af.value_namespace = name_space
                                            self.af.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ipv4"):
                                            self.ipv4 = value
                                            self.ipv4.value_namespace = name_space
                                            self.ipv4.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ipv6"):
                                            self.ipv6 = value
                                            self.ipv6.value_namespace = name_space
                                            self.ipv6.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.bundle_status.is_set or
                                        self.fast_detect.is_set or
                                        self.mode_info.is_set or
                                        self.nbr_unconfig_timer.is_set or
                                        self.pref_echo_min_interval.is_set or
                                        self.pref_min_interval.is_set or
                                        self.pref_multiplier.is_set or
                                        self.start_timer.is_set or
                                        (self.destination_address is not None and self.destination_address.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.bundle_status.yfilter != YFilter.not_set or
                                        self.fast_detect.yfilter != YFilter.not_set or
                                        self.mode_info.yfilter != YFilter.not_set or
                                        self.nbr_unconfig_timer.yfilter != YFilter.not_set or
                                        self.pref_echo_min_interval.yfilter != YFilter.not_set or
                                        self.pref_min_interval.yfilter != YFilter.not_set or
                                        self.pref_multiplier.yfilter != YFilter.not_set or
                                        self.start_timer.yfilter != YFilter.not_set or
                                        (self.destination_address is not None and self.destination_address.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "bfd-config" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.bundle_status.is_set or self.bundle_status.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.bundle_status.get_name_leafdata())
                                    if (self.fast_detect.is_set or self.fast_detect.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.fast_detect.get_name_leafdata())
                                    if (self.mode_info.is_set or self.mode_info.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.mode_info.get_name_leafdata())
                                    if (self.nbr_unconfig_timer.is_set or self.nbr_unconfig_timer.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.nbr_unconfig_timer.get_name_leafdata())
                                    if (self.pref_echo_min_interval.is_set or self.pref_echo_min_interval.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.pref_echo_min_interval.get_name_leafdata())
                                    if (self.pref_min_interval.is_set or self.pref_min_interval.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.pref_min_interval.get_name_leafdata())
                                    if (self.pref_multiplier.is_set or self.pref_multiplier.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.pref_multiplier.get_name_leafdata())
                                    if (self.start_timer.is_set or self.start_timer.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.start_timer.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "destination-address"):
                                        if (self.destination_address is None):
                                            self.destination_address = BundleInformation.Lacp.LacpMembers.LacpMember.LacpMemberAncestor.BundleData.ActorBundleData.BfdConfig.DestinationAddress()
                                            self.destination_address.parent = self
                                            self._children_name_map["destination_address"] = "destination-address"
                                        return self.destination_address

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "destination-address" or name == "bundle-status" or name == "fast-detect" or name == "mode-info" or name == "nbr-unconfig-timer" or name == "pref-echo-min-interval" or name == "pref-min-interval" or name == "pref-multiplier" or name == "start-timer"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "bundle-status"):
                                        self.bundle_status = value
                                        self.bundle_status.value_namespace = name_space
                                        self.bundle_status.value_namespace_prefix = name_space_prefix
                                    if(value_path == "fast-detect"):
                                        self.fast_detect = value
                                        self.fast_detect.value_namespace = name_space
                                        self.fast_detect.value_namespace_prefix = name_space_prefix
                                    if(value_path == "mode-info"):
                                        self.mode_info = value
                                        self.mode_info.value_namespace = name_space
                                        self.mode_info.value_namespace_prefix = name_space_prefix
                                    if(value_path == "nbr-unconfig-timer"):
                                        self.nbr_unconfig_timer = value
                                        self.nbr_unconfig_timer.value_namespace = name_space
                                        self.nbr_unconfig_timer.value_namespace_prefix = name_space_prefix
                                    if(value_path == "pref-echo-min-interval"):
                                        self.pref_echo_min_interval = value
                                        self.pref_echo_min_interval.value_namespace = name_space
                                        self.pref_echo_min_interval.value_namespace_prefix = name_space_prefix
                                    if(value_path == "pref-min-interval"):
                                        self.pref_min_interval = value
                                        self.pref_min_interval.value_namespace = name_space
                                        self.pref_min_interval.value_namespace_prefix = name_space_prefix
                                    if(value_path == "pref-multiplier"):
                                        self.pref_multiplier = value
                                        self.pref_multiplier.value_namespace = name_space
                                        self.pref_multiplier.value_namespace_prefix = name_space_prefix
                                    if(value_path == "start-timer"):
                                        self.start_timer = value
                                        self.start_timer.value_namespace = name_space
                                        self.start_timer.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.bfd_config:
                                    if (c.has_data()):
                                        return True
                                return (
                                    self.active_foreign_member_count.is_set or
                                    self.active_member_count.is_set or
                                    self.available_bandwidth.is_set or
                                    self.bundle_interface_name.is_set or
                                    self.bundle_status.is_set or
                                    self.cisco_extensions.is_set or
                                    self.collector_max_delay.is_set or
                                    self.configured_bandwidth.is_set or
                                    self.configured_foreign_member_count.is_set or
                                    self.configured_member_count.is_set or
                                    self.effective_bandwidth.is_set or
                                    self.iccp_group_id.is_set or
                                    self.inter_chassis.is_set or
                                    self.ipv4bfd_status.is_set or
                                    self.ipv6bfd_status.is_set or
                                    self.is_active.is_set or
                                    self.lacp_nonrevertive.is_set or
                                    self.lacp_status.is_set or
                                    self.link_order_status.is_set or
                                    self.load_balance_hash_type.is_set or
                                    self.load_balance_locality_threshold.is_set or
                                    self.mac_source.is_set or
                                    self.mac_source_member.is_set or
                                    self.maximize_threshold_value_band_width.is_set or
                                    self.maximize_threshold_value_links.is_set or
                                    self.maximum_active_links.is_set or
                                    self.maximum_active_links_source.is_set or
                                    self.minimum_active_links.is_set or
                                    self.minimum_bandwidth.is_set or
                                    self.mlacp_mode.is_set or
                                    self.mlacp_status.is_set or
                                    self.primary_member.is_set or
                                    self.recovery_delay.is_set or
                                    self.singleton.is_set or
                                    self.standby_member_count.is_set or
                                    self.suppression_timer.is_set or
                                    self.switchover_type.is_set or
                                    self.wait_while_timer.is_set or
                                    (self.mac_address is not None and self.mac_address.has_data()))

                            def has_operation(self):
                                for c in self.bfd_config:
                                    if (c.has_operation()):
                                        return True
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.active_foreign_member_count.yfilter != YFilter.not_set or
                                    self.active_member_count.yfilter != YFilter.not_set or
                                    self.available_bandwidth.yfilter != YFilter.not_set or
                                    self.bundle_interface_name.yfilter != YFilter.not_set or
                                    self.bundle_status.yfilter != YFilter.not_set or
                                    self.cisco_extensions.yfilter != YFilter.not_set or
                                    self.collector_max_delay.yfilter != YFilter.not_set or
                                    self.configured_bandwidth.yfilter != YFilter.not_set or
                                    self.configured_foreign_member_count.yfilter != YFilter.not_set or
                                    self.configured_member_count.yfilter != YFilter.not_set or
                                    self.effective_bandwidth.yfilter != YFilter.not_set or
                                    self.iccp_group_id.yfilter != YFilter.not_set or
                                    self.inter_chassis.yfilter != YFilter.not_set or
                                    self.ipv4bfd_status.yfilter != YFilter.not_set or
                                    self.ipv6bfd_status.yfilter != YFilter.not_set or
                                    self.is_active.yfilter != YFilter.not_set or
                                    self.lacp_nonrevertive.yfilter != YFilter.not_set or
                                    self.lacp_status.yfilter != YFilter.not_set or
                                    self.link_order_status.yfilter != YFilter.not_set or
                                    self.load_balance_hash_type.yfilter != YFilter.not_set or
                                    self.load_balance_locality_threshold.yfilter != YFilter.not_set or
                                    self.mac_source.yfilter != YFilter.not_set or
                                    self.mac_source_member.yfilter != YFilter.not_set or
                                    self.maximize_threshold_value_band_width.yfilter != YFilter.not_set or
                                    self.maximize_threshold_value_links.yfilter != YFilter.not_set or
                                    self.maximum_active_links.yfilter != YFilter.not_set or
                                    self.maximum_active_links_source.yfilter != YFilter.not_set or
                                    self.minimum_active_links.yfilter != YFilter.not_set or
                                    self.minimum_bandwidth.yfilter != YFilter.not_set or
                                    self.mlacp_mode.yfilter != YFilter.not_set or
                                    self.mlacp_status.yfilter != YFilter.not_set or
                                    self.primary_member.yfilter != YFilter.not_set or
                                    self.recovery_delay.yfilter != YFilter.not_set or
                                    self.singleton.yfilter != YFilter.not_set or
                                    self.standby_member_count.yfilter != YFilter.not_set or
                                    self.suppression_timer.yfilter != YFilter.not_set or
                                    self.switchover_type.yfilter != YFilter.not_set or
                                    self.wait_while_timer.yfilter != YFilter.not_set or
                                    (self.mac_address is not None and self.mac_address.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "actor-bundle-data" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.active_foreign_member_count.is_set or self.active_foreign_member_count.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.active_foreign_member_count.get_name_leafdata())
                                if (self.active_member_count.is_set or self.active_member_count.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.active_member_count.get_name_leafdata())
                                if (self.available_bandwidth.is_set or self.available_bandwidth.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.available_bandwidth.get_name_leafdata())
                                if (self.bundle_interface_name.is_set or self.bundle_interface_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.bundle_interface_name.get_name_leafdata())
                                if (self.bundle_status.is_set or self.bundle_status.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.bundle_status.get_name_leafdata())
                                if (self.cisco_extensions.is_set or self.cisco_extensions.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.cisco_extensions.get_name_leafdata())
                                if (self.collector_max_delay.is_set or self.collector_max_delay.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.collector_max_delay.get_name_leafdata())
                                if (self.configured_bandwidth.is_set or self.configured_bandwidth.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.configured_bandwidth.get_name_leafdata())
                                if (self.configured_foreign_member_count.is_set or self.configured_foreign_member_count.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.configured_foreign_member_count.get_name_leafdata())
                                if (self.configured_member_count.is_set or self.configured_member_count.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.configured_member_count.get_name_leafdata())
                                if (self.effective_bandwidth.is_set or self.effective_bandwidth.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.effective_bandwidth.get_name_leafdata())
                                if (self.iccp_group_id.is_set or self.iccp_group_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.iccp_group_id.get_name_leafdata())
                                if (self.inter_chassis.is_set or self.inter_chassis.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.inter_chassis.get_name_leafdata())
                                if (self.ipv4bfd_status.is_set or self.ipv4bfd_status.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4bfd_status.get_name_leafdata())
                                if (self.ipv6bfd_status.is_set or self.ipv6bfd_status.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6bfd_status.get_name_leafdata())
                                if (self.is_active.is_set or self.is_active.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_active.get_name_leafdata())
                                if (self.lacp_nonrevertive.is_set or self.lacp_nonrevertive.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.lacp_nonrevertive.get_name_leafdata())
                                if (self.lacp_status.is_set or self.lacp_status.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.lacp_status.get_name_leafdata())
                                if (self.link_order_status.is_set or self.link_order_status.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.link_order_status.get_name_leafdata())
                                if (self.load_balance_hash_type.is_set or self.load_balance_hash_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.load_balance_hash_type.get_name_leafdata())
                                if (self.load_balance_locality_threshold.is_set or self.load_balance_locality_threshold.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.load_balance_locality_threshold.get_name_leafdata())
                                if (self.mac_source.is_set or self.mac_source.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mac_source.get_name_leafdata())
                                if (self.mac_source_member.is_set or self.mac_source_member.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mac_source_member.get_name_leafdata())
                                if (self.maximize_threshold_value_band_width.is_set or self.maximize_threshold_value_band_width.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.maximize_threshold_value_band_width.get_name_leafdata())
                                if (self.maximize_threshold_value_links.is_set or self.maximize_threshold_value_links.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.maximize_threshold_value_links.get_name_leafdata())
                                if (self.maximum_active_links.is_set or self.maximum_active_links.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.maximum_active_links.get_name_leafdata())
                                if (self.maximum_active_links_source.is_set or self.maximum_active_links_source.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.maximum_active_links_source.get_name_leafdata())
                                if (self.minimum_active_links.is_set or self.minimum_active_links.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.minimum_active_links.get_name_leafdata())
                                if (self.minimum_bandwidth.is_set or self.minimum_bandwidth.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.minimum_bandwidth.get_name_leafdata())
                                if (self.mlacp_mode.is_set or self.mlacp_mode.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mlacp_mode.get_name_leafdata())
                                if (self.mlacp_status.is_set or self.mlacp_status.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mlacp_status.get_name_leafdata())
                                if (self.primary_member.is_set or self.primary_member.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.primary_member.get_name_leafdata())
                                if (self.recovery_delay.is_set or self.recovery_delay.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.recovery_delay.get_name_leafdata())
                                if (self.singleton.is_set or self.singleton.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.singleton.get_name_leafdata())
                                if (self.standby_member_count.is_set or self.standby_member_count.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.standby_member_count.get_name_leafdata())
                                if (self.suppression_timer.is_set or self.suppression_timer.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.suppression_timer.get_name_leafdata())
                                if (self.switchover_type.is_set or self.switchover_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.switchover_type.get_name_leafdata())
                                if (self.wait_while_timer.is_set or self.wait_while_timer.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.wait_while_timer.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "bfd-config"):
                                    for c in self.bfd_config:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = BundleInformation.Lacp.LacpMembers.LacpMember.LacpMemberAncestor.BundleData.ActorBundleData.BfdConfig()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.bfd_config.append(c)
                                    return c

                                if (child_yang_name == "mac-address"):
                                    if (self.mac_address is None):
                                        self.mac_address = BundleInformation.Lacp.LacpMembers.LacpMember.LacpMemberAncestor.BundleData.ActorBundleData.MacAddress()
                                        self.mac_address.parent = self
                                        self._children_name_map["mac_address"] = "mac-address"
                                    return self.mac_address

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "bfd-config" or name == "mac-address" or name == "active-foreign-member-count" or name == "active-member-count" or name == "available-bandwidth" or name == "bundle-interface-name" or name == "bundle-status" or name == "cisco-extensions" or name == "collector-max-delay" or name == "configured-bandwidth" or name == "configured-foreign-member-count" or name == "configured-member-count" or name == "effective-bandwidth" or name == "iccp-group-id" or name == "inter-chassis" or name == "ipv4bfd-status" or name == "ipv6bfd-status" or name == "is-active" or name == "lacp-nonrevertive" or name == "lacp-status" or name == "link-order-status" or name == "load-balance-hash-type" or name == "load-balance-locality-threshold" or name == "mac-source" or name == "mac-source-member" or name == "maximize-threshold-value-band-width" or name == "maximize-threshold-value-links" or name == "maximum-active-links" or name == "maximum-active-links-source" or name == "minimum-active-links" or name == "minimum-bandwidth" or name == "mlacp-mode" or name == "mlacp-status" or name == "primary-member" or name == "recovery-delay" or name == "singleton" or name == "standby-member-count" or name == "suppression-timer" or name == "switchover-type" or name == "wait-while-timer"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "active-foreign-member-count"):
                                    self.active_foreign_member_count = value
                                    self.active_foreign_member_count.value_namespace = name_space
                                    self.active_foreign_member_count.value_namespace_prefix = name_space_prefix
                                if(value_path == "active-member-count"):
                                    self.active_member_count = value
                                    self.active_member_count.value_namespace = name_space
                                    self.active_member_count.value_namespace_prefix = name_space_prefix
                                if(value_path == "available-bandwidth"):
                                    self.available_bandwidth = value
                                    self.available_bandwidth.value_namespace = name_space
                                    self.available_bandwidth.value_namespace_prefix = name_space_prefix
                                if(value_path == "bundle-interface-name"):
                                    self.bundle_interface_name = value
                                    self.bundle_interface_name.value_namespace = name_space
                                    self.bundle_interface_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "bundle-status"):
                                    self.bundle_status = value
                                    self.bundle_status.value_namespace = name_space
                                    self.bundle_status.value_namespace_prefix = name_space_prefix
                                if(value_path == "cisco-extensions"):
                                    self.cisco_extensions = value
                                    self.cisco_extensions.value_namespace = name_space
                                    self.cisco_extensions.value_namespace_prefix = name_space_prefix
                                if(value_path == "collector-max-delay"):
                                    self.collector_max_delay = value
                                    self.collector_max_delay.value_namespace = name_space
                                    self.collector_max_delay.value_namespace_prefix = name_space_prefix
                                if(value_path == "configured-bandwidth"):
                                    self.configured_bandwidth = value
                                    self.configured_bandwidth.value_namespace = name_space
                                    self.configured_bandwidth.value_namespace_prefix = name_space_prefix
                                if(value_path == "configured-foreign-member-count"):
                                    self.configured_foreign_member_count = value
                                    self.configured_foreign_member_count.value_namespace = name_space
                                    self.configured_foreign_member_count.value_namespace_prefix = name_space_prefix
                                if(value_path == "configured-member-count"):
                                    self.configured_member_count = value
                                    self.configured_member_count.value_namespace = name_space
                                    self.configured_member_count.value_namespace_prefix = name_space_prefix
                                if(value_path == "effective-bandwidth"):
                                    self.effective_bandwidth = value
                                    self.effective_bandwidth.value_namespace = name_space
                                    self.effective_bandwidth.value_namespace_prefix = name_space_prefix
                                if(value_path == "iccp-group-id"):
                                    self.iccp_group_id = value
                                    self.iccp_group_id.value_namespace = name_space
                                    self.iccp_group_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "inter-chassis"):
                                    self.inter_chassis = value
                                    self.inter_chassis.value_namespace = name_space
                                    self.inter_chassis.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4bfd-status"):
                                    self.ipv4bfd_status = value
                                    self.ipv4bfd_status.value_namespace = name_space
                                    self.ipv4bfd_status.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6bfd-status"):
                                    self.ipv6bfd_status = value
                                    self.ipv6bfd_status.value_namespace = name_space
                                    self.ipv6bfd_status.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-active"):
                                    self.is_active = value
                                    self.is_active.value_namespace = name_space
                                    self.is_active.value_namespace_prefix = name_space_prefix
                                if(value_path == "lacp-nonrevertive"):
                                    self.lacp_nonrevertive = value
                                    self.lacp_nonrevertive.value_namespace = name_space
                                    self.lacp_nonrevertive.value_namespace_prefix = name_space_prefix
                                if(value_path == "lacp-status"):
                                    self.lacp_status = value
                                    self.lacp_status.value_namespace = name_space
                                    self.lacp_status.value_namespace_prefix = name_space_prefix
                                if(value_path == "link-order-status"):
                                    self.link_order_status = value
                                    self.link_order_status.value_namespace = name_space
                                    self.link_order_status.value_namespace_prefix = name_space_prefix
                                if(value_path == "load-balance-hash-type"):
                                    self.load_balance_hash_type = value
                                    self.load_balance_hash_type.value_namespace = name_space
                                    self.load_balance_hash_type.value_namespace_prefix = name_space_prefix
                                if(value_path == "load-balance-locality-threshold"):
                                    self.load_balance_locality_threshold = value
                                    self.load_balance_locality_threshold.value_namespace = name_space
                                    self.load_balance_locality_threshold.value_namespace_prefix = name_space_prefix
                                if(value_path == "mac-source"):
                                    self.mac_source = value
                                    self.mac_source.value_namespace = name_space
                                    self.mac_source.value_namespace_prefix = name_space_prefix
                                if(value_path == "mac-source-member"):
                                    self.mac_source_member = value
                                    self.mac_source_member.value_namespace = name_space
                                    self.mac_source_member.value_namespace_prefix = name_space_prefix
                                if(value_path == "maximize-threshold-value-band-width"):
                                    self.maximize_threshold_value_band_width = value
                                    self.maximize_threshold_value_band_width.value_namespace = name_space
                                    self.maximize_threshold_value_band_width.value_namespace_prefix = name_space_prefix
                                if(value_path == "maximize-threshold-value-links"):
                                    self.maximize_threshold_value_links = value
                                    self.maximize_threshold_value_links.value_namespace = name_space
                                    self.maximize_threshold_value_links.value_namespace_prefix = name_space_prefix
                                if(value_path == "maximum-active-links"):
                                    self.maximum_active_links = value
                                    self.maximum_active_links.value_namespace = name_space
                                    self.maximum_active_links.value_namespace_prefix = name_space_prefix
                                if(value_path == "maximum-active-links-source"):
                                    self.maximum_active_links_source = value
                                    self.maximum_active_links_source.value_namespace = name_space
                                    self.maximum_active_links_source.value_namespace_prefix = name_space_prefix
                                if(value_path == "minimum-active-links"):
                                    self.minimum_active_links = value
                                    self.minimum_active_links.value_namespace = name_space
                                    self.minimum_active_links.value_namespace_prefix = name_space_prefix
                                if(value_path == "minimum-bandwidth"):
                                    self.minimum_bandwidth = value
                                    self.minimum_bandwidth.value_namespace = name_space
                                    self.minimum_bandwidth.value_namespace_prefix = name_space_prefix
                                if(value_path == "mlacp-mode"):
                                    self.mlacp_mode = value
                                    self.mlacp_mode.value_namespace = name_space
                                    self.mlacp_mode.value_namespace_prefix = name_space_prefix
                                if(value_path == "mlacp-status"):
                                    self.mlacp_status = value
                                    self.mlacp_status.value_namespace = name_space
                                    self.mlacp_status.value_namespace_prefix = name_space_prefix
                                if(value_path == "primary-member"):
                                    self.primary_member = value
                                    self.primary_member.value_namespace = name_space
                                    self.primary_member.value_namespace_prefix = name_space_prefix
                                if(value_path == "recovery-delay"):
                                    self.recovery_delay = value
                                    self.recovery_delay.value_namespace = name_space
                                    self.recovery_delay.value_namespace_prefix = name_space_prefix
                                if(value_path == "singleton"):
                                    self.singleton = value
                                    self.singleton.value_namespace = name_space
                                    self.singleton.value_namespace_prefix = name_space_prefix
                                if(value_path == "standby-member-count"):
                                    self.standby_member_count = value
                                    self.standby_member_count.value_namespace = name_space
                                    self.standby_member_count.value_namespace_prefix = name_space_prefix
                                if(value_path == "suppression-timer"):
                                    self.suppression_timer = value
                                    self.suppression_timer.value_namespace = name_space
                                    self.suppression_timer.value_namespace_prefix = name_space_prefix
                                if(value_path == "switchover-type"):
                                    self.switchover_type = value
                                    self.switchover_type.value_namespace = name_space
                                    self.switchover_type.value_namespace_prefix = name_space_prefix
                                if(value_path == "wait-while-timer"):
                                    self.wait_while_timer = value
                                    self.wait_while_timer.value_namespace = name_space
                                    self.wait_while_timer.value_namespace_prefix = name_space_prefix


                        class BundleSystemId(Entity):
                            """
                            System ID for the bundle
                            
                            .. attribute:: system_mac_addr
                            
                            	MAC Address used to identify the system
                            	**type**\:   :py:class:`SystemMacAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.Lacp.LacpMembers.LacpMember.LacpMemberAncestor.BundleData.BundleSystemId.SystemMacAddr>`
                            
                            .. attribute:: system_prio
                            
                            	Priority of the system
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'bundlemgr-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(BundleInformation.Lacp.LacpMembers.LacpMember.LacpMemberAncestor.BundleData.BundleSystemId, self).__init__()

                                self.yang_name = "bundle-system-id"
                                self.yang_parent_name = "bundle-data"

                                self.system_prio = YLeaf(YType.uint16, "system-prio")

                                self.system_mac_addr = BundleInformation.Lacp.LacpMembers.LacpMember.LacpMemberAncestor.BundleData.BundleSystemId.SystemMacAddr()
                                self.system_mac_addr.parent = self
                                self._children_name_map["system_mac_addr"] = "system-mac-addr"
                                self._children_yang_names.add("system-mac-addr")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("system_prio") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(BundleInformation.Lacp.LacpMembers.LacpMember.LacpMemberAncestor.BundleData.BundleSystemId, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(BundleInformation.Lacp.LacpMembers.LacpMember.LacpMemberAncestor.BundleData.BundleSystemId, self).__setattr__(name, value)


                            class SystemMacAddr(Entity):
                                """
                                MAC Address used to identify the system
                                
                                .. attribute:: macaddr
                                
                                	macaddr
                                	**type**\:  str
                                
                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                
                                

                                """

                                _prefix = 'bundlemgr-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(BundleInformation.Lacp.LacpMembers.LacpMember.LacpMemberAncestor.BundleData.BundleSystemId.SystemMacAddr, self).__init__()

                                    self.yang_name = "system-mac-addr"
                                    self.yang_parent_name = "bundle-system-id"

                                    self.macaddr = YLeaf(YType.str, "macaddr")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("macaddr") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(BundleInformation.Lacp.LacpMembers.LacpMember.LacpMemberAncestor.BundleData.BundleSystemId.SystemMacAddr, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(BundleInformation.Lacp.LacpMembers.LacpMember.LacpMemberAncestor.BundleData.BundleSystemId.SystemMacAddr, self).__setattr__(name, value)

                                def has_data(self):
                                    return self.macaddr.is_set

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.macaddr.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "system-mac-addr" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.macaddr.is_set or self.macaddr.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.macaddr.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "macaddr"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "macaddr"):
                                        self.macaddr = value
                                        self.macaddr.value_namespace = name_space
                                        self.macaddr.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.system_prio.is_set or
                                    (self.system_mac_addr is not None and self.system_mac_addr.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.system_prio.yfilter != YFilter.not_set or
                                    (self.system_mac_addr is not None and self.system_mac_addr.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "bundle-system-id" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.system_prio.is_set or self.system_prio.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.system_prio.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "system-mac-addr"):
                                    if (self.system_mac_addr is None):
                                        self.system_mac_addr = BundleInformation.Lacp.LacpMembers.LacpMember.LacpMemberAncestor.BundleData.BundleSystemId.SystemMacAddr()
                                        self.system_mac_addr.parent = self
                                        self._children_name_map["system_mac_addr"] = "system-mac-addr"
                                    return self.system_mac_addr

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "system-mac-addr" or name == "system-prio"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "system-prio"):
                                    self.system_prio = value
                                    self.system_prio.value_namespace = name_space
                                    self.system_prio.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.actor_operational_key.is_set or
                                self.partner_operational_key.is_set or
                                self.partner_system_mac_address.is_set or
                                self.partner_system_priority.is_set or
                                (self.actor_bundle_data is not None and self.actor_bundle_data.has_data()) or
                                (self.bundle_system_id is not None and self.bundle_system_id.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.actor_operational_key.yfilter != YFilter.not_set or
                                self.partner_operational_key.yfilter != YFilter.not_set or
                                self.partner_system_mac_address.yfilter != YFilter.not_set or
                                self.partner_system_priority.yfilter != YFilter.not_set or
                                (self.actor_bundle_data is not None and self.actor_bundle_data.has_operation()) or
                                (self.bundle_system_id is not None and self.bundle_system_id.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "bundle-data" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.actor_operational_key.is_set or self.actor_operational_key.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.actor_operational_key.get_name_leafdata())
                            if (self.partner_operational_key.is_set or self.partner_operational_key.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.partner_operational_key.get_name_leafdata())
                            if (self.partner_system_mac_address.is_set or self.partner_system_mac_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.partner_system_mac_address.get_name_leafdata())
                            if (self.partner_system_priority.is_set or self.partner_system_priority.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.partner_system_priority.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "actor-bundle-data"):
                                if (self.actor_bundle_data is None):
                                    self.actor_bundle_data = BundleInformation.Lacp.LacpMembers.LacpMember.LacpMemberAncestor.BundleData.ActorBundleData()
                                    self.actor_bundle_data.parent = self
                                    self._children_name_map["actor_bundle_data"] = "actor-bundle-data"
                                return self.actor_bundle_data

                            if (child_yang_name == "bundle-system-id"):
                                if (self.bundle_system_id is None):
                                    self.bundle_system_id = BundleInformation.Lacp.LacpMembers.LacpMember.LacpMemberAncestor.BundleData.BundleSystemId()
                                    self.bundle_system_id.parent = self
                                    self._children_name_map["bundle_system_id"] = "bundle-system-id"
                                return self.bundle_system_id

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "actor-bundle-data" or name == "bundle-system-id" or name == "actor-operational-key" or name == "partner-operational-key" or name == "partner-system-mac-address" or name == "partner-system-priority"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "actor-operational-key"):
                                self.actor_operational_key = value
                                self.actor_operational_key.value_namespace = name_space
                                self.actor_operational_key.value_namespace_prefix = name_space_prefix
                            if(value_path == "partner-operational-key"):
                                self.partner_operational_key = value
                                self.partner_operational_key.value_namespace = name_space
                                self.partner_operational_key.value_namespace_prefix = name_space_prefix
                            if(value_path == "partner-system-mac-address"):
                                self.partner_system_mac_address = value
                                self.partner_system_mac_address.value_namespace = name_space
                                self.partner_system_mac_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "partner-system-priority"):
                                self.partner_system_priority = value
                                self.partner_system_priority.value_namespace = name_space
                                self.partner_system_priority.value_namespace_prefix = name_space_prefix


                    class MemberData(Entity):
                        """
                        Member information
                        
                        .. attribute:: actor_churn_state
                        
                        	State of the Churn state machine for the Actor
                        	**type**\:   :py:class:`LacpChurnstates <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.LacpChurnstates>`
                        
                        .. attribute:: actor_info
                        
                        	LACP information for the port from the actor
                        	**type**\:   :py:class:`ActorInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.Lacp.LacpMembers.LacpMember.LacpMemberAncestor.MemberData.ActorInfo>`
                        
                        .. attribute:: additional_info
                        
                        	Additional information for the link
                        	**type**\:   :py:class:`AdditionalInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.Lacp.LacpMembers.LacpMember.LacpMemberAncestor.MemberData.AdditionalInfo>`
                        
                        .. attribute:: attached_aggregator_id
                        
                        	MIB ifindex of attached bundle
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: iccp_group_id
                        
                        	The ID of the ICCP group that the link is configured on
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: mux_state
                        
                        	State of the Mux state machine
                        	**type**\:   :py:class:`BmMuxstate <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmMuxstate>`
                        
                        .. attribute:: partner_churn_state
                        
                        	State of the Churn state machine for the Partner
                        	**type**\:   :py:class:`LacpChurnstates <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.LacpChurnstates>`
                        
                        .. attribute:: partner_info
                        
                        	LACP information for the port from the partner
                        	**type**\:   :py:class:`PartnerInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.Lacp.LacpMembers.LacpMember.LacpMemberAncestor.MemberData.PartnerInfo>`
                        
                        .. attribute:: period_state
                        
                        	State of the Period state machine
                        	**type**\:   :py:class:`LacpPeriodState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.LacpPeriodState>`
                        
                        .. attribute:: receive_machine_state
                        
                        	State of the RX state machine
                        	**type**\:   :py:class:`Rxstates <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.Rxstates>`
                        
                        .. attribute:: selected_aggregator_id
                        
                        	MIB ifindex of selected bundle
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: selection_state
                        
                        	State of the Selection Logic state machine
                        	**type**\:   :py:class:`LacpSelState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.LacpSelState>`
                        
                        

                        """

                        _prefix = 'bundlemgr-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(BundleInformation.Lacp.LacpMembers.LacpMember.LacpMemberAncestor.MemberData, self).__init__()

                            self.yang_name = "member-data"
                            self.yang_parent_name = "lacp-member-ancestor"

                            self.actor_churn_state = YLeaf(YType.enumeration, "actor-churn-state")

                            self.attached_aggregator_id = YLeaf(YType.uint32, "attached-aggregator-id")

                            self.iccp_group_id = YLeaf(YType.uint32, "iccp-group-id")

                            self.mux_state = YLeaf(YType.enumeration, "mux-state")

                            self.partner_churn_state = YLeaf(YType.enumeration, "partner-churn-state")

                            self.period_state = YLeaf(YType.enumeration, "period-state")

                            self.receive_machine_state = YLeaf(YType.enumeration, "receive-machine-state")

                            self.selected_aggregator_id = YLeaf(YType.uint32, "selected-aggregator-id")

                            self.selection_state = YLeaf(YType.enumeration, "selection-state")

                            self.actor_info = BundleInformation.Lacp.LacpMembers.LacpMember.LacpMemberAncestor.MemberData.ActorInfo()
                            self.actor_info.parent = self
                            self._children_name_map["actor_info"] = "actor-info"
                            self._children_yang_names.add("actor-info")

                            self.additional_info = BundleInformation.Lacp.LacpMembers.LacpMember.LacpMemberAncestor.MemberData.AdditionalInfo()
                            self.additional_info.parent = self
                            self._children_name_map["additional_info"] = "additional-info"
                            self._children_yang_names.add("additional-info")

                            self.partner_info = BundleInformation.Lacp.LacpMembers.LacpMember.LacpMemberAncestor.MemberData.PartnerInfo()
                            self.partner_info.parent = self
                            self._children_name_map["partner_info"] = "partner-info"
                            self._children_yang_names.add("partner-info")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("actor_churn_state",
                                            "attached_aggregator_id",
                                            "iccp_group_id",
                                            "mux_state",
                                            "partner_churn_state",
                                            "period_state",
                                            "receive_machine_state",
                                            "selected_aggregator_id",
                                            "selection_state") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(BundleInformation.Lacp.LacpMembers.LacpMember.LacpMemberAncestor.MemberData, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(BundleInformation.Lacp.LacpMembers.LacpMember.LacpMemberAncestor.MemberData, self).__setattr__(name, value)


                        class ActorInfo(Entity):
                            """
                            LACP information for the port from the actor
                            
                            .. attribute:: port_info
                            
                            	LACP parameters for this device
                            	**type**\:   :py:class:`PortInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.Lacp.LacpMembers.LacpMember.LacpMemberAncestor.MemberData.ActorInfo.PortInfo>`
                            
                            .. attribute:: tx_period
                            
                            	Time (in ms) between transmitting LACPDUs
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'bundlemgr-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(BundleInformation.Lacp.LacpMembers.LacpMember.LacpMemberAncestor.MemberData.ActorInfo, self).__init__()

                                self.yang_name = "actor-info"
                                self.yang_parent_name = "member-data"

                                self.tx_period = YLeaf(YType.uint32, "tx-period")

                                self.port_info = BundleInformation.Lacp.LacpMembers.LacpMember.LacpMemberAncestor.MemberData.ActorInfo.PortInfo()
                                self.port_info.parent = self
                                self._children_name_map["port_info"] = "port-info"
                                self._children_yang_names.add("port-info")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("tx_period") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(BundleInformation.Lacp.LacpMembers.LacpMember.LacpMemberAncestor.MemberData.ActorInfo, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(BundleInformation.Lacp.LacpMembers.LacpMember.LacpMemberAncestor.MemberData.ActorInfo, self).__setattr__(name, value)


                            class PortInfo(Entity):
                                """
                                LACP parameters for this device
                                
                                .. attribute:: key
                                
                                	key
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: port
                                
                                	port
                                	**type**\:   :py:class:`Port <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.Lacp.LacpMembers.LacpMember.LacpMemberAncestor.MemberData.ActorInfo.PortInfo.Port>`
                                
                                .. attribute:: state
                                
                                	state
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: system
                                
                                	system
                                	**type**\:   :py:class:`System <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.Lacp.LacpMembers.LacpMember.LacpMemberAncestor.MemberData.ActorInfo.PortInfo.System>`
                                
                                

                                """

                                _prefix = 'bundlemgr-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(BundleInformation.Lacp.LacpMembers.LacpMember.LacpMemberAncestor.MemberData.ActorInfo.PortInfo, self).__init__()

                                    self.yang_name = "port-info"
                                    self.yang_parent_name = "actor-info"

                                    self.key = YLeaf(YType.uint16, "key")

                                    self.state = YLeaf(YType.uint8, "state")

                                    self.port = BundleInformation.Lacp.LacpMembers.LacpMember.LacpMemberAncestor.MemberData.ActorInfo.PortInfo.Port()
                                    self.port.parent = self
                                    self._children_name_map["port"] = "port"
                                    self._children_yang_names.add("port")

                                    self.system = BundleInformation.Lacp.LacpMembers.LacpMember.LacpMemberAncestor.MemberData.ActorInfo.PortInfo.System()
                                    self.system.parent = self
                                    self._children_name_map["system"] = "system"
                                    self._children_yang_names.add("system")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("key",
                                                    "state") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(BundleInformation.Lacp.LacpMembers.LacpMember.LacpMemberAncestor.MemberData.ActorInfo.PortInfo, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(BundleInformation.Lacp.LacpMembers.LacpMember.LacpMemberAncestor.MemberData.ActorInfo.PortInfo, self).__setattr__(name, value)


                                class System(Entity):
                                    """
                                    system
                                    
                                    .. attribute:: system_mac_addr
                                    
                                    	MAC Address used to identify the system
                                    	**type**\:   :py:class:`SystemMacAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.Lacp.LacpMembers.LacpMember.LacpMemberAncestor.MemberData.ActorInfo.PortInfo.System.SystemMacAddr>`
                                    
                                    .. attribute:: system_prio
                                    
                                    	Priority of the system
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'bundlemgr-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(BundleInformation.Lacp.LacpMembers.LacpMember.LacpMemberAncestor.MemberData.ActorInfo.PortInfo.System, self).__init__()

                                        self.yang_name = "system"
                                        self.yang_parent_name = "port-info"

                                        self.system_prio = YLeaf(YType.uint16, "system-prio")

                                        self.system_mac_addr = BundleInformation.Lacp.LacpMembers.LacpMember.LacpMemberAncestor.MemberData.ActorInfo.PortInfo.System.SystemMacAddr()
                                        self.system_mac_addr.parent = self
                                        self._children_name_map["system_mac_addr"] = "system-mac-addr"
                                        self._children_yang_names.add("system-mac-addr")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("system_prio") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(BundleInformation.Lacp.LacpMembers.LacpMember.LacpMemberAncestor.MemberData.ActorInfo.PortInfo.System, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(BundleInformation.Lacp.LacpMembers.LacpMember.LacpMemberAncestor.MemberData.ActorInfo.PortInfo.System, self).__setattr__(name, value)


                                    class SystemMacAddr(Entity):
                                        """
                                        MAC Address used to identify the system
                                        
                                        .. attribute:: macaddr
                                        
                                        	macaddr
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'bundlemgr-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(BundleInformation.Lacp.LacpMembers.LacpMember.LacpMemberAncestor.MemberData.ActorInfo.PortInfo.System.SystemMacAddr, self).__init__()

                                            self.yang_name = "system-mac-addr"
                                            self.yang_parent_name = "system"

                                            self.macaddr = YLeaf(YType.str, "macaddr")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("macaddr") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(BundleInformation.Lacp.LacpMembers.LacpMember.LacpMemberAncestor.MemberData.ActorInfo.PortInfo.System.SystemMacAddr, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(BundleInformation.Lacp.LacpMembers.LacpMember.LacpMemberAncestor.MemberData.ActorInfo.PortInfo.System.SystemMacAddr, self).__setattr__(name, value)

                                        def has_data(self):
                                            return self.macaddr.is_set

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.macaddr.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "system-mac-addr" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.macaddr.is_set or self.macaddr.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.macaddr.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "macaddr"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "macaddr"):
                                                self.macaddr = value
                                                self.macaddr.value_namespace = name_space
                                                self.macaddr.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.system_prio.is_set or
                                            (self.system_mac_addr is not None and self.system_mac_addr.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.system_prio.yfilter != YFilter.not_set or
                                            (self.system_mac_addr is not None and self.system_mac_addr.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "system" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.system_prio.is_set or self.system_prio.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.system_prio.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "system-mac-addr"):
                                            if (self.system_mac_addr is None):
                                                self.system_mac_addr = BundleInformation.Lacp.LacpMembers.LacpMember.LacpMemberAncestor.MemberData.ActorInfo.PortInfo.System.SystemMacAddr()
                                                self.system_mac_addr.parent = self
                                                self._children_name_map["system_mac_addr"] = "system-mac-addr"
                                            return self.system_mac_addr

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "system-mac-addr" or name == "system-prio"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "system-prio"):
                                            self.system_prio = value
                                            self.system_prio.value_namespace = name_space
                                            self.system_prio.value_namespace_prefix = name_space_prefix


                                class Port(Entity):
                                    """
                                    port
                                    
                                    .. attribute:: link_number
                                    
                                    	link number
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: link_priority
                                    
                                    	link priority
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'bundlemgr-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(BundleInformation.Lacp.LacpMembers.LacpMember.LacpMemberAncestor.MemberData.ActorInfo.PortInfo.Port, self).__init__()

                                        self.yang_name = "port"
                                        self.yang_parent_name = "port-info"

                                        self.link_number = YLeaf(YType.uint16, "link-number")

                                        self.link_priority = YLeaf(YType.uint16, "link-priority")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("link_number",
                                                        "link_priority") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(BundleInformation.Lacp.LacpMembers.LacpMember.LacpMemberAncestor.MemberData.ActorInfo.PortInfo.Port, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(BundleInformation.Lacp.LacpMembers.LacpMember.LacpMemberAncestor.MemberData.ActorInfo.PortInfo.Port, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.link_number.is_set or
                                            self.link_priority.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.link_number.yfilter != YFilter.not_set or
                                            self.link_priority.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "port" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.link_number.is_set or self.link_number.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.link_number.get_name_leafdata())
                                        if (self.link_priority.is_set or self.link_priority.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.link_priority.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "link-number" or name == "link-priority"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "link-number"):
                                            self.link_number = value
                                            self.link_number.value_namespace = name_space
                                            self.link_number.value_namespace_prefix = name_space_prefix
                                        if(value_path == "link-priority"):
                                            self.link_priority = value
                                            self.link_priority.value_namespace = name_space
                                            self.link_priority.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.key.is_set or
                                        self.state.is_set or
                                        (self.port is not None and self.port.has_data()) or
                                        (self.system is not None and self.system.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.key.yfilter != YFilter.not_set or
                                        self.state.yfilter != YFilter.not_set or
                                        (self.port is not None and self.port.has_operation()) or
                                        (self.system is not None and self.system.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "port-info" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.key.is_set or self.key.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.key.get_name_leafdata())
                                    if (self.state.is_set or self.state.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.state.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "port"):
                                        if (self.port is None):
                                            self.port = BundleInformation.Lacp.LacpMembers.LacpMember.LacpMemberAncestor.MemberData.ActorInfo.PortInfo.Port()
                                            self.port.parent = self
                                            self._children_name_map["port"] = "port"
                                        return self.port

                                    if (child_yang_name == "system"):
                                        if (self.system is None):
                                            self.system = BundleInformation.Lacp.LacpMembers.LacpMember.LacpMemberAncestor.MemberData.ActorInfo.PortInfo.System()
                                            self.system.parent = self
                                            self._children_name_map["system"] = "system"
                                        return self.system

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "port" or name == "system" or name == "key" or name == "state"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "key"):
                                        self.key = value
                                        self.key.value_namespace = name_space
                                        self.key.value_namespace_prefix = name_space_prefix
                                    if(value_path == "state"):
                                        self.state = value
                                        self.state.value_namespace = name_space
                                        self.state.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.tx_period.is_set or
                                    (self.port_info is not None and self.port_info.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.tx_period.yfilter != YFilter.not_set or
                                    (self.port_info is not None and self.port_info.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "actor-info" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.tx_period.is_set or self.tx_period.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.tx_period.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "port-info"):
                                    if (self.port_info is None):
                                        self.port_info = BundleInformation.Lacp.LacpMembers.LacpMember.LacpMemberAncestor.MemberData.ActorInfo.PortInfo()
                                        self.port_info.parent = self
                                        self._children_name_map["port_info"] = "port-info"
                                    return self.port_info

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "port-info" or name == "tx-period"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "tx-period"):
                                    self.tx_period = value
                                    self.tx_period.value_namespace = name_space
                                    self.tx_period.value_namespace_prefix = name_space_prefix


                        class PartnerInfo(Entity):
                            """
                            LACP information for the port from the partner
                            
                            .. attribute:: port_info
                            
                            	LACP parameters for this device
                            	**type**\:   :py:class:`PortInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.Lacp.LacpMembers.LacpMember.LacpMemberAncestor.MemberData.PartnerInfo.PortInfo>`
                            
                            .. attribute:: tx_period
                            
                            	Time (in ms) between transmitting LACPDUs
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'bundlemgr-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(BundleInformation.Lacp.LacpMembers.LacpMember.LacpMemberAncestor.MemberData.PartnerInfo, self).__init__()

                                self.yang_name = "partner-info"
                                self.yang_parent_name = "member-data"

                                self.tx_period = YLeaf(YType.uint32, "tx-period")

                                self.port_info = BundleInformation.Lacp.LacpMembers.LacpMember.LacpMemberAncestor.MemberData.PartnerInfo.PortInfo()
                                self.port_info.parent = self
                                self._children_name_map["port_info"] = "port-info"
                                self._children_yang_names.add("port-info")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("tx_period") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(BundleInformation.Lacp.LacpMembers.LacpMember.LacpMemberAncestor.MemberData.PartnerInfo, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(BundleInformation.Lacp.LacpMembers.LacpMember.LacpMemberAncestor.MemberData.PartnerInfo, self).__setattr__(name, value)


                            class PortInfo(Entity):
                                """
                                LACP parameters for this device
                                
                                .. attribute:: key
                                
                                	key
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: port
                                
                                	port
                                	**type**\:   :py:class:`Port <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.Lacp.LacpMembers.LacpMember.LacpMemberAncestor.MemberData.PartnerInfo.PortInfo.Port>`
                                
                                .. attribute:: state
                                
                                	state
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: system
                                
                                	system
                                	**type**\:   :py:class:`System <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.Lacp.LacpMembers.LacpMember.LacpMemberAncestor.MemberData.PartnerInfo.PortInfo.System>`
                                
                                

                                """

                                _prefix = 'bundlemgr-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(BundleInformation.Lacp.LacpMembers.LacpMember.LacpMemberAncestor.MemberData.PartnerInfo.PortInfo, self).__init__()

                                    self.yang_name = "port-info"
                                    self.yang_parent_name = "partner-info"

                                    self.key = YLeaf(YType.uint16, "key")

                                    self.state = YLeaf(YType.uint8, "state")

                                    self.port = BundleInformation.Lacp.LacpMembers.LacpMember.LacpMemberAncestor.MemberData.PartnerInfo.PortInfo.Port()
                                    self.port.parent = self
                                    self._children_name_map["port"] = "port"
                                    self._children_yang_names.add("port")

                                    self.system = BundleInformation.Lacp.LacpMembers.LacpMember.LacpMemberAncestor.MemberData.PartnerInfo.PortInfo.System()
                                    self.system.parent = self
                                    self._children_name_map["system"] = "system"
                                    self._children_yang_names.add("system")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("key",
                                                    "state") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(BundleInformation.Lacp.LacpMembers.LacpMember.LacpMemberAncestor.MemberData.PartnerInfo.PortInfo, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(BundleInformation.Lacp.LacpMembers.LacpMember.LacpMemberAncestor.MemberData.PartnerInfo.PortInfo, self).__setattr__(name, value)


                                class System(Entity):
                                    """
                                    system
                                    
                                    .. attribute:: system_mac_addr
                                    
                                    	MAC Address used to identify the system
                                    	**type**\:   :py:class:`SystemMacAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.Lacp.LacpMembers.LacpMember.LacpMemberAncestor.MemberData.PartnerInfo.PortInfo.System.SystemMacAddr>`
                                    
                                    .. attribute:: system_prio
                                    
                                    	Priority of the system
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'bundlemgr-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(BundleInformation.Lacp.LacpMembers.LacpMember.LacpMemberAncestor.MemberData.PartnerInfo.PortInfo.System, self).__init__()

                                        self.yang_name = "system"
                                        self.yang_parent_name = "port-info"

                                        self.system_prio = YLeaf(YType.uint16, "system-prio")

                                        self.system_mac_addr = BundleInformation.Lacp.LacpMembers.LacpMember.LacpMemberAncestor.MemberData.PartnerInfo.PortInfo.System.SystemMacAddr()
                                        self.system_mac_addr.parent = self
                                        self._children_name_map["system_mac_addr"] = "system-mac-addr"
                                        self._children_yang_names.add("system-mac-addr")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("system_prio") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(BundleInformation.Lacp.LacpMembers.LacpMember.LacpMemberAncestor.MemberData.PartnerInfo.PortInfo.System, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(BundleInformation.Lacp.LacpMembers.LacpMember.LacpMemberAncestor.MemberData.PartnerInfo.PortInfo.System, self).__setattr__(name, value)


                                    class SystemMacAddr(Entity):
                                        """
                                        MAC Address used to identify the system
                                        
                                        .. attribute:: macaddr
                                        
                                        	macaddr
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'bundlemgr-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(BundleInformation.Lacp.LacpMembers.LacpMember.LacpMemberAncestor.MemberData.PartnerInfo.PortInfo.System.SystemMacAddr, self).__init__()

                                            self.yang_name = "system-mac-addr"
                                            self.yang_parent_name = "system"

                                            self.macaddr = YLeaf(YType.str, "macaddr")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("macaddr") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(BundleInformation.Lacp.LacpMembers.LacpMember.LacpMemberAncestor.MemberData.PartnerInfo.PortInfo.System.SystemMacAddr, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(BundleInformation.Lacp.LacpMembers.LacpMember.LacpMemberAncestor.MemberData.PartnerInfo.PortInfo.System.SystemMacAddr, self).__setattr__(name, value)

                                        def has_data(self):
                                            return self.macaddr.is_set

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.macaddr.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "system-mac-addr" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.macaddr.is_set or self.macaddr.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.macaddr.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "macaddr"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "macaddr"):
                                                self.macaddr = value
                                                self.macaddr.value_namespace = name_space
                                                self.macaddr.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.system_prio.is_set or
                                            (self.system_mac_addr is not None and self.system_mac_addr.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.system_prio.yfilter != YFilter.not_set or
                                            (self.system_mac_addr is not None and self.system_mac_addr.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "system" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.system_prio.is_set or self.system_prio.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.system_prio.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "system-mac-addr"):
                                            if (self.system_mac_addr is None):
                                                self.system_mac_addr = BundleInformation.Lacp.LacpMembers.LacpMember.LacpMemberAncestor.MemberData.PartnerInfo.PortInfo.System.SystemMacAddr()
                                                self.system_mac_addr.parent = self
                                                self._children_name_map["system_mac_addr"] = "system-mac-addr"
                                            return self.system_mac_addr

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "system-mac-addr" or name == "system-prio"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "system-prio"):
                                            self.system_prio = value
                                            self.system_prio.value_namespace = name_space
                                            self.system_prio.value_namespace_prefix = name_space_prefix


                                class Port(Entity):
                                    """
                                    port
                                    
                                    .. attribute:: link_number
                                    
                                    	link number
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: link_priority
                                    
                                    	link priority
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'bundlemgr-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(BundleInformation.Lacp.LacpMembers.LacpMember.LacpMemberAncestor.MemberData.PartnerInfo.PortInfo.Port, self).__init__()

                                        self.yang_name = "port"
                                        self.yang_parent_name = "port-info"

                                        self.link_number = YLeaf(YType.uint16, "link-number")

                                        self.link_priority = YLeaf(YType.uint16, "link-priority")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("link_number",
                                                        "link_priority") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(BundleInformation.Lacp.LacpMembers.LacpMember.LacpMemberAncestor.MemberData.PartnerInfo.PortInfo.Port, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(BundleInformation.Lacp.LacpMembers.LacpMember.LacpMemberAncestor.MemberData.PartnerInfo.PortInfo.Port, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.link_number.is_set or
                                            self.link_priority.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.link_number.yfilter != YFilter.not_set or
                                            self.link_priority.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "port" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.link_number.is_set or self.link_number.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.link_number.get_name_leafdata())
                                        if (self.link_priority.is_set or self.link_priority.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.link_priority.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "link-number" or name == "link-priority"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "link-number"):
                                            self.link_number = value
                                            self.link_number.value_namespace = name_space
                                            self.link_number.value_namespace_prefix = name_space_prefix
                                        if(value_path == "link-priority"):
                                            self.link_priority = value
                                            self.link_priority.value_namespace = name_space
                                            self.link_priority.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.key.is_set or
                                        self.state.is_set or
                                        (self.port is not None and self.port.has_data()) or
                                        (self.system is not None and self.system.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.key.yfilter != YFilter.not_set or
                                        self.state.yfilter != YFilter.not_set or
                                        (self.port is not None and self.port.has_operation()) or
                                        (self.system is not None and self.system.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "port-info" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.key.is_set or self.key.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.key.get_name_leafdata())
                                    if (self.state.is_set or self.state.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.state.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "port"):
                                        if (self.port is None):
                                            self.port = BundleInformation.Lacp.LacpMembers.LacpMember.LacpMemberAncestor.MemberData.PartnerInfo.PortInfo.Port()
                                            self.port.parent = self
                                            self._children_name_map["port"] = "port"
                                        return self.port

                                    if (child_yang_name == "system"):
                                        if (self.system is None):
                                            self.system = BundleInformation.Lacp.LacpMembers.LacpMember.LacpMemberAncestor.MemberData.PartnerInfo.PortInfo.System()
                                            self.system.parent = self
                                            self._children_name_map["system"] = "system"
                                        return self.system

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "port" or name == "system" or name == "key" or name == "state"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "key"):
                                        self.key = value
                                        self.key.value_namespace = name_space
                                        self.key.value_namespace_prefix = name_space_prefix
                                    if(value_path == "state"):
                                        self.state = value
                                        self.state.value_namespace = name_space
                                        self.state.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.tx_period.is_set or
                                    (self.port_info is not None and self.port_info.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.tx_period.yfilter != YFilter.not_set or
                                    (self.port_info is not None and self.port_info.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "partner-info" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.tx_period.is_set or self.tx_period.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.tx_period.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "port-info"):
                                    if (self.port_info is None):
                                        self.port_info = BundleInformation.Lacp.LacpMembers.LacpMember.LacpMemberAncestor.MemberData.PartnerInfo.PortInfo()
                                        self.port_info.parent = self
                                        self._children_name_map["port_info"] = "port-info"
                                    return self.port_info

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "port-info" or name == "tx-period"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "tx-period"):
                                    self.tx_period = value
                                    self.tx_period.value_namespace = name_space
                                    self.tx_period.value_namespace_prefix = name_space_prefix


                        class AdditionalInfo(Entity):
                            """
                            Additional information for the link
                            
                            .. attribute:: foreign
                            
                            	Information for a foreign port
                            	**type**\:   :py:class:`Foreign <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.Lacp.LacpMembers.LacpMember.LacpMemberAncestor.MemberData.AdditionalInfo.Foreign>`
                            
                            .. attribute:: local
                            
                            	Information for a local port
                            	**type**\:   :py:class:`Local <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.Lacp.LacpMembers.LacpMember.LacpMemberAncestor.MemberData.AdditionalInfo.Local>`
                            
                            .. attribute:: mbr_type
                            
                            	MbrType
                            	**type**\:   :py:class:`BmdMemberTypeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmdMemberTypeEnum>`
                            
                            

                            """

                            _prefix = 'bundlemgr-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(BundleInformation.Lacp.LacpMembers.LacpMember.LacpMemberAncestor.MemberData.AdditionalInfo, self).__init__()

                                self.yang_name = "additional-info"
                                self.yang_parent_name = "member-data"

                                self.mbr_type = YLeaf(YType.enumeration, "mbr-type")

                                self.foreign = BundleInformation.Lacp.LacpMembers.LacpMember.LacpMemberAncestor.MemberData.AdditionalInfo.Foreign()
                                self.foreign.parent = self
                                self._children_name_map["foreign"] = "foreign"
                                self._children_yang_names.add("foreign")

                                self.local = BundleInformation.Lacp.LacpMembers.LacpMember.LacpMemberAncestor.MemberData.AdditionalInfo.Local()
                                self.local.parent = self
                                self._children_name_map["local"] = "local"
                                self._children_yang_names.add("local")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("mbr_type") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(BundleInformation.Lacp.LacpMembers.LacpMember.LacpMemberAncestor.MemberData.AdditionalInfo, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(BundleInformation.Lacp.LacpMembers.LacpMember.LacpMemberAncestor.MemberData.AdditionalInfo, self).__setattr__(name, value)


                            class Local(Entity):
                                """
                                Information for a local port
                                
                                .. attribute:: interface_handle
                                
                                	Member's interface handle
                                	**type**\:  str
                                
                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                
                                

                                """

                                _prefix = 'bundlemgr-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(BundleInformation.Lacp.LacpMembers.LacpMember.LacpMemberAncestor.MemberData.AdditionalInfo.Local, self).__init__()

                                    self.yang_name = "local"
                                    self.yang_parent_name = "additional-info"

                                    self.interface_handle = YLeaf(YType.str, "interface-handle")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("interface_handle") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(BundleInformation.Lacp.LacpMembers.LacpMember.LacpMemberAncestor.MemberData.AdditionalInfo.Local, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(BundleInformation.Lacp.LacpMembers.LacpMember.LacpMemberAncestor.MemberData.AdditionalInfo.Local, self).__setattr__(name, value)

                                def has_data(self):
                                    return self.interface_handle.is_set

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.interface_handle.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "local" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.interface_handle.is_set or self.interface_handle.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.interface_handle.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "interface-handle"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "interface-handle"):
                                        self.interface_handle = value
                                        self.interface_handle.value_namespace = name_space
                                        self.interface_handle.value_namespace_prefix = name_space_prefix


                            class Foreign(Entity):
                                """
                                Information for a foreign port
                                
                                .. attribute:: member_name
                                
                                	Member's (short form) name
                                	**type**\:  str
                                
                                .. attribute:: peer_address
                                
                                	The LDP address of the device that the link is configured on
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'bundlemgr-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(BundleInformation.Lacp.LacpMembers.LacpMember.LacpMemberAncestor.MemberData.AdditionalInfo.Foreign, self).__init__()

                                    self.yang_name = "foreign"
                                    self.yang_parent_name = "additional-info"

                                    self.member_name = YLeaf(YType.str, "member-name")

                                    self.peer_address = YLeaf(YType.str, "peer-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("member_name",
                                                    "peer_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(BundleInformation.Lacp.LacpMembers.LacpMember.LacpMemberAncestor.MemberData.AdditionalInfo.Foreign, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(BundleInformation.Lacp.LacpMembers.LacpMember.LacpMemberAncestor.MemberData.AdditionalInfo.Foreign, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.member_name.is_set or
                                        self.peer_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.member_name.yfilter != YFilter.not_set or
                                        self.peer_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "foreign" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.member_name.is_set or self.member_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.member_name.get_name_leafdata())
                                    if (self.peer_address.is_set or self.peer_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.peer_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "member-name" or name == "peer-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "member-name"):
                                        self.member_name = value
                                        self.member_name.value_namespace = name_space
                                        self.member_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "peer-address"):
                                        self.peer_address = value
                                        self.peer_address.value_namespace = name_space
                                        self.peer_address.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.mbr_type.is_set or
                                    (self.foreign is not None and self.foreign.has_data()) or
                                    (self.local is not None and self.local.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.mbr_type.yfilter != YFilter.not_set or
                                    (self.foreign is not None and self.foreign.has_operation()) or
                                    (self.local is not None and self.local.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "additional-info" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.mbr_type.is_set or self.mbr_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mbr_type.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "foreign"):
                                    if (self.foreign is None):
                                        self.foreign = BundleInformation.Lacp.LacpMembers.LacpMember.LacpMemberAncestor.MemberData.AdditionalInfo.Foreign()
                                        self.foreign.parent = self
                                        self._children_name_map["foreign"] = "foreign"
                                    return self.foreign

                                if (child_yang_name == "local"):
                                    if (self.local is None):
                                        self.local = BundleInformation.Lacp.LacpMembers.LacpMember.LacpMemberAncestor.MemberData.AdditionalInfo.Local()
                                        self.local.parent = self
                                        self._children_name_map["local"] = "local"
                                    return self.local

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "foreign" or name == "local" or name == "mbr-type"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "mbr-type"):
                                    self.mbr_type = value
                                    self.mbr_type.value_namespace = name_space
                                    self.mbr_type.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.actor_churn_state.is_set or
                                self.attached_aggregator_id.is_set or
                                self.iccp_group_id.is_set or
                                self.mux_state.is_set or
                                self.partner_churn_state.is_set or
                                self.period_state.is_set or
                                self.receive_machine_state.is_set or
                                self.selected_aggregator_id.is_set or
                                self.selection_state.is_set or
                                (self.actor_info is not None and self.actor_info.has_data()) or
                                (self.additional_info is not None and self.additional_info.has_data()) or
                                (self.partner_info is not None and self.partner_info.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.actor_churn_state.yfilter != YFilter.not_set or
                                self.attached_aggregator_id.yfilter != YFilter.not_set or
                                self.iccp_group_id.yfilter != YFilter.not_set or
                                self.mux_state.yfilter != YFilter.not_set or
                                self.partner_churn_state.yfilter != YFilter.not_set or
                                self.period_state.yfilter != YFilter.not_set or
                                self.receive_machine_state.yfilter != YFilter.not_set or
                                self.selected_aggregator_id.yfilter != YFilter.not_set or
                                self.selection_state.yfilter != YFilter.not_set or
                                (self.actor_info is not None and self.actor_info.has_operation()) or
                                (self.additional_info is not None and self.additional_info.has_operation()) or
                                (self.partner_info is not None and self.partner_info.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "member-data" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.actor_churn_state.is_set or self.actor_churn_state.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.actor_churn_state.get_name_leafdata())
                            if (self.attached_aggregator_id.is_set or self.attached_aggregator_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.attached_aggregator_id.get_name_leafdata())
                            if (self.iccp_group_id.is_set or self.iccp_group_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.iccp_group_id.get_name_leafdata())
                            if (self.mux_state.is_set or self.mux_state.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mux_state.get_name_leafdata())
                            if (self.partner_churn_state.is_set or self.partner_churn_state.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.partner_churn_state.get_name_leafdata())
                            if (self.period_state.is_set or self.period_state.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.period_state.get_name_leafdata())
                            if (self.receive_machine_state.is_set or self.receive_machine_state.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.receive_machine_state.get_name_leafdata())
                            if (self.selected_aggregator_id.is_set or self.selected_aggregator_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.selected_aggregator_id.get_name_leafdata())
                            if (self.selection_state.is_set or self.selection_state.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.selection_state.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "actor-info"):
                                if (self.actor_info is None):
                                    self.actor_info = BundleInformation.Lacp.LacpMembers.LacpMember.LacpMemberAncestor.MemberData.ActorInfo()
                                    self.actor_info.parent = self
                                    self._children_name_map["actor_info"] = "actor-info"
                                return self.actor_info

                            if (child_yang_name == "additional-info"):
                                if (self.additional_info is None):
                                    self.additional_info = BundleInformation.Lacp.LacpMembers.LacpMember.LacpMemberAncestor.MemberData.AdditionalInfo()
                                    self.additional_info.parent = self
                                    self._children_name_map["additional_info"] = "additional-info"
                                return self.additional_info

                            if (child_yang_name == "partner-info"):
                                if (self.partner_info is None):
                                    self.partner_info = BundleInformation.Lacp.LacpMembers.LacpMember.LacpMemberAncestor.MemberData.PartnerInfo()
                                    self.partner_info.parent = self
                                    self._children_name_map["partner_info"] = "partner-info"
                                return self.partner_info

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "actor-info" or name == "additional-info" or name == "partner-info" or name == "actor-churn-state" or name == "attached-aggregator-id" or name == "iccp-group-id" or name == "mux-state" or name == "partner-churn-state" or name == "period-state" or name == "receive-machine-state" or name == "selected-aggregator-id" or name == "selection-state"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "actor-churn-state"):
                                self.actor_churn_state = value
                                self.actor_churn_state.value_namespace = name_space
                                self.actor_churn_state.value_namespace_prefix = name_space_prefix
                            if(value_path == "attached-aggregator-id"):
                                self.attached_aggregator_id = value
                                self.attached_aggregator_id.value_namespace = name_space
                                self.attached_aggregator_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "iccp-group-id"):
                                self.iccp_group_id = value
                                self.iccp_group_id.value_namespace = name_space
                                self.iccp_group_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "mux-state"):
                                self.mux_state = value
                                self.mux_state.value_namespace = name_space
                                self.mux_state.value_namespace_prefix = name_space_prefix
                            if(value_path == "partner-churn-state"):
                                self.partner_churn_state = value
                                self.partner_churn_state.value_namespace = name_space
                                self.partner_churn_state.value_namespace_prefix = name_space_prefix
                            if(value_path == "period-state"):
                                self.period_state = value
                                self.period_state.value_namespace = name_space
                                self.period_state.value_namespace_prefix = name_space_prefix
                            if(value_path == "receive-machine-state"):
                                self.receive_machine_state = value
                                self.receive_machine_state.value_namespace = name_space
                                self.receive_machine_state.value_namespace_prefix = name_space_prefix
                            if(value_path == "selected-aggregator-id"):
                                self.selected_aggregator_id = value
                                self.selected_aggregator_id.value_namespace = name_space
                                self.selected_aggregator_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "selection-state"):
                                self.selection_state = value
                                self.selection_state.value_namespace = name_space
                                self.selection_state.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.member_data:
                            if (c.has_data()):
                                return True
                        return (self.bundle_data is not None and self.bundle_data.has_data())

                    def has_operation(self):
                        for c in self.member_data:
                            if (c.has_operation()):
                                return True
                        return (
                            self.yfilter != YFilter.not_set or
                            (self.bundle_data is not None and self.bundle_data.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "lacp-member-ancestor" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "bundle-data"):
                            if (self.bundle_data is None):
                                self.bundle_data = BundleInformation.Lacp.LacpMembers.LacpMember.LacpMemberAncestor.BundleData()
                                self.bundle_data.parent = self
                                self._children_name_map["bundle_data"] = "bundle-data"
                            return self.bundle_data

                        if (child_yang_name == "member-data"):
                            for c in self.member_data:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = BundleInformation.Lacp.LacpMembers.LacpMember.LacpMemberAncestor.MemberData()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.member_data.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "bundle-data" or name == "member-data"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class LacpMemberItem(Entity):
                    """
                    Data for this item
                    
                    .. attribute:: actor_churn_state
                    
                    	State of the Churn state machine for the Actor
                    	**type**\:   :py:class:`LacpChurnstates <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.LacpChurnstates>`
                    
                    .. attribute:: actor_info
                    
                    	LACP information for the port from the actor
                    	**type**\:   :py:class:`ActorInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.Lacp.LacpMembers.LacpMember.LacpMemberItem.ActorInfo>`
                    
                    .. attribute:: additional_info
                    
                    	Additional information for the link
                    	**type**\:   :py:class:`AdditionalInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.Lacp.LacpMembers.LacpMember.LacpMemberItem.AdditionalInfo>`
                    
                    .. attribute:: attached_aggregator_id
                    
                    	MIB ifindex of attached bundle
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: iccp_group_id
                    
                    	The ID of the ICCP group that the link is configured on
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mux_state
                    
                    	State of the Mux state machine
                    	**type**\:   :py:class:`BmMuxstate <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmMuxstate>`
                    
                    .. attribute:: partner_churn_state
                    
                    	State of the Churn state machine for the Partner
                    	**type**\:   :py:class:`LacpChurnstates <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.LacpChurnstates>`
                    
                    .. attribute:: partner_info
                    
                    	LACP information for the port from the partner
                    	**type**\:   :py:class:`PartnerInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.Lacp.LacpMembers.LacpMember.LacpMemberItem.PartnerInfo>`
                    
                    .. attribute:: period_state
                    
                    	State of the Period state machine
                    	**type**\:   :py:class:`LacpPeriodState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.LacpPeriodState>`
                    
                    .. attribute:: receive_machine_state
                    
                    	State of the RX state machine
                    	**type**\:   :py:class:`Rxstates <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.Rxstates>`
                    
                    .. attribute:: selected_aggregator_id
                    
                    	MIB ifindex of selected bundle
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: selection_state
                    
                    	State of the Selection Logic state machine
                    	**type**\:   :py:class:`LacpSelState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.LacpSelState>`
                    
                    

                    """

                    _prefix = 'bundlemgr-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(BundleInformation.Lacp.LacpMembers.LacpMember.LacpMemberItem, self).__init__()

                        self.yang_name = "lacp-member-item"
                        self.yang_parent_name = "lacp-member"

                        self.actor_churn_state = YLeaf(YType.enumeration, "actor-churn-state")

                        self.attached_aggregator_id = YLeaf(YType.uint32, "attached-aggregator-id")

                        self.iccp_group_id = YLeaf(YType.uint32, "iccp-group-id")

                        self.mux_state = YLeaf(YType.enumeration, "mux-state")

                        self.partner_churn_state = YLeaf(YType.enumeration, "partner-churn-state")

                        self.period_state = YLeaf(YType.enumeration, "period-state")

                        self.receive_machine_state = YLeaf(YType.enumeration, "receive-machine-state")

                        self.selected_aggregator_id = YLeaf(YType.uint32, "selected-aggregator-id")

                        self.selection_state = YLeaf(YType.enumeration, "selection-state")

                        self.actor_info = BundleInformation.Lacp.LacpMembers.LacpMember.LacpMemberItem.ActorInfo()
                        self.actor_info.parent = self
                        self._children_name_map["actor_info"] = "actor-info"
                        self._children_yang_names.add("actor-info")

                        self.additional_info = BundleInformation.Lacp.LacpMembers.LacpMember.LacpMemberItem.AdditionalInfo()
                        self.additional_info.parent = self
                        self._children_name_map["additional_info"] = "additional-info"
                        self._children_yang_names.add("additional-info")

                        self.partner_info = BundleInformation.Lacp.LacpMembers.LacpMember.LacpMemberItem.PartnerInfo()
                        self.partner_info.parent = self
                        self._children_name_map["partner_info"] = "partner-info"
                        self._children_yang_names.add("partner-info")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("actor_churn_state",
                                        "attached_aggregator_id",
                                        "iccp_group_id",
                                        "mux_state",
                                        "partner_churn_state",
                                        "period_state",
                                        "receive_machine_state",
                                        "selected_aggregator_id",
                                        "selection_state") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(BundleInformation.Lacp.LacpMembers.LacpMember.LacpMemberItem, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(BundleInformation.Lacp.LacpMembers.LacpMember.LacpMemberItem, self).__setattr__(name, value)


                    class ActorInfo(Entity):
                        """
                        LACP information for the port from the actor
                        
                        .. attribute:: port_info
                        
                        	LACP parameters for this device
                        	**type**\:   :py:class:`PortInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.Lacp.LacpMembers.LacpMember.LacpMemberItem.ActorInfo.PortInfo>`
                        
                        .. attribute:: tx_period
                        
                        	Time (in ms) between transmitting LACPDUs
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'bundlemgr-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(BundleInformation.Lacp.LacpMembers.LacpMember.LacpMemberItem.ActorInfo, self).__init__()

                            self.yang_name = "actor-info"
                            self.yang_parent_name = "lacp-member-item"

                            self.tx_period = YLeaf(YType.uint32, "tx-period")

                            self.port_info = BundleInformation.Lacp.LacpMembers.LacpMember.LacpMemberItem.ActorInfo.PortInfo()
                            self.port_info.parent = self
                            self._children_name_map["port_info"] = "port-info"
                            self._children_yang_names.add("port-info")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("tx_period") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(BundleInformation.Lacp.LacpMembers.LacpMember.LacpMemberItem.ActorInfo, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(BundleInformation.Lacp.LacpMembers.LacpMember.LacpMemberItem.ActorInfo, self).__setattr__(name, value)


                        class PortInfo(Entity):
                            """
                            LACP parameters for this device
                            
                            .. attribute:: key
                            
                            	key
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: port
                            
                            	port
                            	**type**\:   :py:class:`Port <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.Lacp.LacpMembers.LacpMember.LacpMemberItem.ActorInfo.PortInfo.Port>`
                            
                            .. attribute:: state
                            
                            	state
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: system
                            
                            	system
                            	**type**\:   :py:class:`System <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.Lacp.LacpMembers.LacpMember.LacpMemberItem.ActorInfo.PortInfo.System>`
                            
                            

                            """

                            _prefix = 'bundlemgr-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(BundleInformation.Lacp.LacpMembers.LacpMember.LacpMemberItem.ActorInfo.PortInfo, self).__init__()

                                self.yang_name = "port-info"
                                self.yang_parent_name = "actor-info"

                                self.key = YLeaf(YType.uint16, "key")

                                self.state = YLeaf(YType.uint8, "state")

                                self.port = BundleInformation.Lacp.LacpMembers.LacpMember.LacpMemberItem.ActorInfo.PortInfo.Port()
                                self.port.parent = self
                                self._children_name_map["port"] = "port"
                                self._children_yang_names.add("port")

                                self.system = BundleInformation.Lacp.LacpMembers.LacpMember.LacpMemberItem.ActorInfo.PortInfo.System()
                                self.system.parent = self
                                self._children_name_map["system"] = "system"
                                self._children_yang_names.add("system")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("key",
                                                "state") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(BundleInformation.Lacp.LacpMembers.LacpMember.LacpMemberItem.ActorInfo.PortInfo, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(BundleInformation.Lacp.LacpMembers.LacpMember.LacpMemberItem.ActorInfo.PortInfo, self).__setattr__(name, value)


                            class System(Entity):
                                """
                                system
                                
                                .. attribute:: system_mac_addr
                                
                                	MAC Address used to identify the system
                                	**type**\:   :py:class:`SystemMacAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.Lacp.LacpMembers.LacpMember.LacpMemberItem.ActorInfo.PortInfo.System.SystemMacAddr>`
                                
                                .. attribute:: system_prio
                                
                                	Priority of the system
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'bundlemgr-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(BundleInformation.Lacp.LacpMembers.LacpMember.LacpMemberItem.ActorInfo.PortInfo.System, self).__init__()

                                    self.yang_name = "system"
                                    self.yang_parent_name = "port-info"

                                    self.system_prio = YLeaf(YType.uint16, "system-prio")

                                    self.system_mac_addr = BundleInformation.Lacp.LacpMembers.LacpMember.LacpMemberItem.ActorInfo.PortInfo.System.SystemMacAddr()
                                    self.system_mac_addr.parent = self
                                    self._children_name_map["system_mac_addr"] = "system-mac-addr"
                                    self._children_yang_names.add("system-mac-addr")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("system_prio") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(BundleInformation.Lacp.LacpMembers.LacpMember.LacpMemberItem.ActorInfo.PortInfo.System, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(BundleInformation.Lacp.LacpMembers.LacpMember.LacpMemberItem.ActorInfo.PortInfo.System, self).__setattr__(name, value)


                                class SystemMacAddr(Entity):
                                    """
                                    MAC Address used to identify the system
                                    
                                    .. attribute:: macaddr
                                    
                                    	macaddr
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'bundlemgr-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(BundleInformation.Lacp.LacpMembers.LacpMember.LacpMemberItem.ActorInfo.PortInfo.System.SystemMacAddr, self).__init__()

                                        self.yang_name = "system-mac-addr"
                                        self.yang_parent_name = "system"

                                        self.macaddr = YLeaf(YType.str, "macaddr")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("macaddr") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(BundleInformation.Lacp.LacpMembers.LacpMember.LacpMemberItem.ActorInfo.PortInfo.System.SystemMacAddr, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(BundleInformation.Lacp.LacpMembers.LacpMember.LacpMemberItem.ActorInfo.PortInfo.System.SystemMacAddr, self).__setattr__(name, value)

                                    def has_data(self):
                                        return self.macaddr.is_set

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.macaddr.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "system-mac-addr" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.macaddr.is_set or self.macaddr.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.macaddr.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "macaddr"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "macaddr"):
                                            self.macaddr = value
                                            self.macaddr.value_namespace = name_space
                                            self.macaddr.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.system_prio.is_set or
                                        (self.system_mac_addr is not None and self.system_mac_addr.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.system_prio.yfilter != YFilter.not_set or
                                        (self.system_mac_addr is not None and self.system_mac_addr.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "system" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.system_prio.is_set or self.system_prio.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.system_prio.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "system-mac-addr"):
                                        if (self.system_mac_addr is None):
                                            self.system_mac_addr = BundleInformation.Lacp.LacpMembers.LacpMember.LacpMemberItem.ActorInfo.PortInfo.System.SystemMacAddr()
                                            self.system_mac_addr.parent = self
                                            self._children_name_map["system_mac_addr"] = "system-mac-addr"
                                        return self.system_mac_addr

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "system-mac-addr" or name == "system-prio"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "system-prio"):
                                        self.system_prio = value
                                        self.system_prio.value_namespace = name_space
                                        self.system_prio.value_namespace_prefix = name_space_prefix


                            class Port(Entity):
                                """
                                port
                                
                                .. attribute:: link_number
                                
                                	link number
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: link_priority
                                
                                	link priority
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'bundlemgr-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(BundleInformation.Lacp.LacpMembers.LacpMember.LacpMemberItem.ActorInfo.PortInfo.Port, self).__init__()

                                    self.yang_name = "port"
                                    self.yang_parent_name = "port-info"

                                    self.link_number = YLeaf(YType.uint16, "link-number")

                                    self.link_priority = YLeaf(YType.uint16, "link-priority")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("link_number",
                                                    "link_priority") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(BundleInformation.Lacp.LacpMembers.LacpMember.LacpMemberItem.ActorInfo.PortInfo.Port, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(BundleInformation.Lacp.LacpMembers.LacpMember.LacpMemberItem.ActorInfo.PortInfo.Port, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.link_number.is_set or
                                        self.link_priority.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.link_number.yfilter != YFilter.not_set or
                                        self.link_priority.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "port" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.link_number.is_set or self.link_number.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.link_number.get_name_leafdata())
                                    if (self.link_priority.is_set or self.link_priority.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.link_priority.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "link-number" or name == "link-priority"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "link-number"):
                                        self.link_number = value
                                        self.link_number.value_namespace = name_space
                                        self.link_number.value_namespace_prefix = name_space_prefix
                                    if(value_path == "link-priority"):
                                        self.link_priority = value
                                        self.link_priority.value_namespace = name_space
                                        self.link_priority.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.key.is_set or
                                    self.state.is_set or
                                    (self.port is not None and self.port.has_data()) or
                                    (self.system is not None and self.system.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.key.yfilter != YFilter.not_set or
                                    self.state.yfilter != YFilter.not_set or
                                    (self.port is not None and self.port.has_operation()) or
                                    (self.system is not None and self.system.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "port-info" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.key.is_set or self.key.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.key.get_name_leafdata())
                                if (self.state.is_set or self.state.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.state.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "port"):
                                    if (self.port is None):
                                        self.port = BundleInformation.Lacp.LacpMembers.LacpMember.LacpMemberItem.ActorInfo.PortInfo.Port()
                                        self.port.parent = self
                                        self._children_name_map["port"] = "port"
                                    return self.port

                                if (child_yang_name == "system"):
                                    if (self.system is None):
                                        self.system = BundleInformation.Lacp.LacpMembers.LacpMember.LacpMemberItem.ActorInfo.PortInfo.System()
                                        self.system.parent = self
                                        self._children_name_map["system"] = "system"
                                    return self.system

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "port" or name == "system" or name == "key" or name == "state"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "key"):
                                    self.key = value
                                    self.key.value_namespace = name_space
                                    self.key.value_namespace_prefix = name_space_prefix
                                if(value_path == "state"):
                                    self.state = value
                                    self.state.value_namespace = name_space
                                    self.state.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.tx_period.is_set or
                                (self.port_info is not None and self.port_info.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.tx_period.yfilter != YFilter.not_set or
                                (self.port_info is not None and self.port_info.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "actor-info" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.tx_period.is_set or self.tx_period.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.tx_period.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "port-info"):
                                if (self.port_info is None):
                                    self.port_info = BundleInformation.Lacp.LacpMembers.LacpMember.LacpMemberItem.ActorInfo.PortInfo()
                                    self.port_info.parent = self
                                    self._children_name_map["port_info"] = "port-info"
                                return self.port_info

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "port-info" or name == "tx-period"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "tx-period"):
                                self.tx_period = value
                                self.tx_period.value_namespace = name_space
                                self.tx_period.value_namespace_prefix = name_space_prefix


                    class PartnerInfo(Entity):
                        """
                        LACP information for the port from the partner
                        
                        .. attribute:: port_info
                        
                        	LACP parameters for this device
                        	**type**\:   :py:class:`PortInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.Lacp.LacpMembers.LacpMember.LacpMemberItem.PartnerInfo.PortInfo>`
                        
                        .. attribute:: tx_period
                        
                        	Time (in ms) between transmitting LACPDUs
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'bundlemgr-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(BundleInformation.Lacp.LacpMembers.LacpMember.LacpMemberItem.PartnerInfo, self).__init__()

                            self.yang_name = "partner-info"
                            self.yang_parent_name = "lacp-member-item"

                            self.tx_period = YLeaf(YType.uint32, "tx-period")

                            self.port_info = BundleInformation.Lacp.LacpMembers.LacpMember.LacpMemberItem.PartnerInfo.PortInfo()
                            self.port_info.parent = self
                            self._children_name_map["port_info"] = "port-info"
                            self._children_yang_names.add("port-info")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("tx_period") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(BundleInformation.Lacp.LacpMembers.LacpMember.LacpMemberItem.PartnerInfo, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(BundleInformation.Lacp.LacpMembers.LacpMember.LacpMemberItem.PartnerInfo, self).__setattr__(name, value)


                        class PortInfo(Entity):
                            """
                            LACP parameters for this device
                            
                            .. attribute:: key
                            
                            	key
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: port
                            
                            	port
                            	**type**\:   :py:class:`Port <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.Lacp.LacpMembers.LacpMember.LacpMemberItem.PartnerInfo.PortInfo.Port>`
                            
                            .. attribute:: state
                            
                            	state
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: system
                            
                            	system
                            	**type**\:   :py:class:`System <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.Lacp.LacpMembers.LacpMember.LacpMemberItem.PartnerInfo.PortInfo.System>`
                            
                            

                            """

                            _prefix = 'bundlemgr-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(BundleInformation.Lacp.LacpMembers.LacpMember.LacpMemberItem.PartnerInfo.PortInfo, self).__init__()

                                self.yang_name = "port-info"
                                self.yang_parent_name = "partner-info"

                                self.key = YLeaf(YType.uint16, "key")

                                self.state = YLeaf(YType.uint8, "state")

                                self.port = BundleInformation.Lacp.LacpMembers.LacpMember.LacpMemberItem.PartnerInfo.PortInfo.Port()
                                self.port.parent = self
                                self._children_name_map["port"] = "port"
                                self._children_yang_names.add("port")

                                self.system = BundleInformation.Lacp.LacpMembers.LacpMember.LacpMemberItem.PartnerInfo.PortInfo.System()
                                self.system.parent = self
                                self._children_name_map["system"] = "system"
                                self._children_yang_names.add("system")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("key",
                                                "state") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(BundleInformation.Lacp.LacpMembers.LacpMember.LacpMemberItem.PartnerInfo.PortInfo, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(BundleInformation.Lacp.LacpMembers.LacpMember.LacpMemberItem.PartnerInfo.PortInfo, self).__setattr__(name, value)


                            class System(Entity):
                                """
                                system
                                
                                .. attribute:: system_mac_addr
                                
                                	MAC Address used to identify the system
                                	**type**\:   :py:class:`SystemMacAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.Lacp.LacpMembers.LacpMember.LacpMemberItem.PartnerInfo.PortInfo.System.SystemMacAddr>`
                                
                                .. attribute:: system_prio
                                
                                	Priority of the system
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'bundlemgr-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(BundleInformation.Lacp.LacpMembers.LacpMember.LacpMemberItem.PartnerInfo.PortInfo.System, self).__init__()

                                    self.yang_name = "system"
                                    self.yang_parent_name = "port-info"

                                    self.system_prio = YLeaf(YType.uint16, "system-prio")

                                    self.system_mac_addr = BundleInformation.Lacp.LacpMembers.LacpMember.LacpMemberItem.PartnerInfo.PortInfo.System.SystemMacAddr()
                                    self.system_mac_addr.parent = self
                                    self._children_name_map["system_mac_addr"] = "system-mac-addr"
                                    self._children_yang_names.add("system-mac-addr")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("system_prio") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(BundleInformation.Lacp.LacpMembers.LacpMember.LacpMemberItem.PartnerInfo.PortInfo.System, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(BundleInformation.Lacp.LacpMembers.LacpMember.LacpMemberItem.PartnerInfo.PortInfo.System, self).__setattr__(name, value)


                                class SystemMacAddr(Entity):
                                    """
                                    MAC Address used to identify the system
                                    
                                    .. attribute:: macaddr
                                    
                                    	macaddr
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'bundlemgr-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(BundleInformation.Lacp.LacpMembers.LacpMember.LacpMemberItem.PartnerInfo.PortInfo.System.SystemMacAddr, self).__init__()

                                        self.yang_name = "system-mac-addr"
                                        self.yang_parent_name = "system"

                                        self.macaddr = YLeaf(YType.str, "macaddr")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("macaddr") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(BundleInformation.Lacp.LacpMembers.LacpMember.LacpMemberItem.PartnerInfo.PortInfo.System.SystemMacAddr, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(BundleInformation.Lacp.LacpMembers.LacpMember.LacpMemberItem.PartnerInfo.PortInfo.System.SystemMacAddr, self).__setattr__(name, value)

                                    def has_data(self):
                                        return self.macaddr.is_set

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.macaddr.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "system-mac-addr" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.macaddr.is_set or self.macaddr.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.macaddr.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "macaddr"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "macaddr"):
                                            self.macaddr = value
                                            self.macaddr.value_namespace = name_space
                                            self.macaddr.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.system_prio.is_set or
                                        (self.system_mac_addr is not None and self.system_mac_addr.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.system_prio.yfilter != YFilter.not_set or
                                        (self.system_mac_addr is not None and self.system_mac_addr.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "system" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.system_prio.is_set or self.system_prio.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.system_prio.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "system-mac-addr"):
                                        if (self.system_mac_addr is None):
                                            self.system_mac_addr = BundleInformation.Lacp.LacpMembers.LacpMember.LacpMemberItem.PartnerInfo.PortInfo.System.SystemMacAddr()
                                            self.system_mac_addr.parent = self
                                            self._children_name_map["system_mac_addr"] = "system-mac-addr"
                                        return self.system_mac_addr

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "system-mac-addr" or name == "system-prio"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "system-prio"):
                                        self.system_prio = value
                                        self.system_prio.value_namespace = name_space
                                        self.system_prio.value_namespace_prefix = name_space_prefix


                            class Port(Entity):
                                """
                                port
                                
                                .. attribute:: link_number
                                
                                	link number
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: link_priority
                                
                                	link priority
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'bundlemgr-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(BundleInformation.Lacp.LacpMembers.LacpMember.LacpMemberItem.PartnerInfo.PortInfo.Port, self).__init__()

                                    self.yang_name = "port"
                                    self.yang_parent_name = "port-info"

                                    self.link_number = YLeaf(YType.uint16, "link-number")

                                    self.link_priority = YLeaf(YType.uint16, "link-priority")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("link_number",
                                                    "link_priority") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(BundleInformation.Lacp.LacpMembers.LacpMember.LacpMemberItem.PartnerInfo.PortInfo.Port, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(BundleInformation.Lacp.LacpMembers.LacpMember.LacpMemberItem.PartnerInfo.PortInfo.Port, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.link_number.is_set or
                                        self.link_priority.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.link_number.yfilter != YFilter.not_set or
                                        self.link_priority.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "port" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.link_number.is_set or self.link_number.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.link_number.get_name_leafdata())
                                    if (self.link_priority.is_set or self.link_priority.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.link_priority.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "link-number" or name == "link-priority"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "link-number"):
                                        self.link_number = value
                                        self.link_number.value_namespace = name_space
                                        self.link_number.value_namespace_prefix = name_space_prefix
                                    if(value_path == "link-priority"):
                                        self.link_priority = value
                                        self.link_priority.value_namespace = name_space
                                        self.link_priority.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.key.is_set or
                                    self.state.is_set or
                                    (self.port is not None and self.port.has_data()) or
                                    (self.system is not None and self.system.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.key.yfilter != YFilter.not_set or
                                    self.state.yfilter != YFilter.not_set or
                                    (self.port is not None and self.port.has_operation()) or
                                    (self.system is not None and self.system.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "port-info" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.key.is_set or self.key.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.key.get_name_leafdata())
                                if (self.state.is_set or self.state.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.state.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "port"):
                                    if (self.port is None):
                                        self.port = BundleInformation.Lacp.LacpMembers.LacpMember.LacpMemberItem.PartnerInfo.PortInfo.Port()
                                        self.port.parent = self
                                        self._children_name_map["port"] = "port"
                                    return self.port

                                if (child_yang_name == "system"):
                                    if (self.system is None):
                                        self.system = BundleInformation.Lacp.LacpMembers.LacpMember.LacpMemberItem.PartnerInfo.PortInfo.System()
                                        self.system.parent = self
                                        self._children_name_map["system"] = "system"
                                    return self.system

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "port" or name == "system" or name == "key" or name == "state"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "key"):
                                    self.key = value
                                    self.key.value_namespace = name_space
                                    self.key.value_namespace_prefix = name_space_prefix
                                if(value_path == "state"):
                                    self.state = value
                                    self.state.value_namespace = name_space
                                    self.state.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.tx_period.is_set or
                                (self.port_info is not None and self.port_info.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.tx_period.yfilter != YFilter.not_set or
                                (self.port_info is not None and self.port_info.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "partner-info" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.tx_period.is_set or self.tx_period.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.tx_period.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "port-info"):
                                if (self.port_info is None):
                                    self.port_info = BundleInformation.Lacp.LacpMembers.LacpMember.LacpMemberItem.PartnerInfo.PortInfo()
                                    self.port_info.parent = self
                                    self._children_name_map["port_info"] = "port-info"
                                return self.port_info

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "port-info" or name == "tx-period"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "tx-period"):
                                self.tx_period = value
                                self.tx_period.value_namespace = name_space
                                self.tx_period.value_namespace_prefix = name_space_prefix


                    class AdditionalInfo(Entity):
                        """
                        Additional information for the link
                        
                        .. attribute:: foreign
                        
                        	Information for a foreign port
                        	**type**\:   :py:class:`Foreign <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.Lacp.LacpMembers.LacpMember.LacpMemberItem.AdditionalInfo.Foreign>`
                        
                        .. attribute:: local
                        
                        	Information for a local port
                        	**type**\:   :py:class:`Local <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.Lacp.LacpMembers.LacpMember.LacpMemberItem.AdditionalInfo.Local>`
                        
                        .. attribute:: mbr_type
                        
                        	MbrType
                        	**type**\:   :py:class:`BmdMemberTypeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmdMemberTypeEnum>`
                        
                        

                        """

                        _prefix = 'bundlemgr-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(BundleInformation.Lacp.LacpMembers.LacpMember.LacpMemberItem.AdditionalInfo, self).__init__()

                            self.yang_name = "additional-info"
                            self.yang_parent_name = "lacp-member-item"

                            self.mbr_type = YLeaf(YType.enumeration, "mbr-type")

                            self.foreign = BundleInformation.Lacp.LacpMembers.LacpMember.LacpMemberItem.AdditionalInfo.Foreign()
                            self.foreign.parent = self
                            self._children_name_map["foreign"] = "foreign"
                            self._children_yang_names.add("foreign")

                            self.local = BundleInformation.Lacp.LacpMembers.LacpMember.LacpMemberItem.AdditionalInfo.Local()
                            self.local.parent = self
                            self._children_name_map["local"] = "local"
                            self._children_yang_names.add("local")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("mbr_type") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(BundleInformation.Lacp.LacpMembers.LacpMember.LacpMemberItem.AdditionalInfo, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(BundleInformation.Lacp.LacpMembers.LacpMember.LacpMemberItem.AdditionalInfo, self).__setattr__(name, value)


                        class Local(Entity):
                            """
                            Information for a local port
                            
                            .. attribute:: interface_handle
                            
                            	Member's interface handle
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            

                            """

                            _prefix = 'bundlemgr-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(BundleInformation.Lacp.LacpMembers.LacpMember.LacpMemberItem.AdditionalInfo.Local, self).__init__()

                                self.yang_name = "local"
                                self.yang_parent_name = "additional-info"

                                self.interface_handle = YLeaf(YType.str, "interface-handle")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("interface_handle") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(BundleInformation.Lacp.LacpMembers.LacpMember.LacpMemberItem.AdditionalInfo.Local, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(BundleInformation.Lacp.LacpMembers.LacpMember.LacpMemberItem.AdditionalInfo.Local, self).__setattr__(name, value)

                            def has_data(self):
                                return self.interface_handle.is_set

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.interface_handle.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "local" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.interface_handle.is_set or self.interface_handle.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.interface_handle.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "interface-handle"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "interface-handle"):
                                    self.interface_handle = value
                                    self.interface_handle.value_namespace = name_space
                                    self.interface_handle.value_namespace_prefix = name_space_prefix


                        class Foreign(Entity):
                            """
                            Information for a foreign port
                            
                            .. attribute:: member_name
                            
                            	Member's (short form) name
                            	**type**\:  str
                            
                            .. attribute:: peer_address
                            
                            	The LDP address of the device that the link is configured on
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'bundlemgr-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(BundleInformation.Lacp.LacpMembers.LacpMember.LacpMemberItem.AdditionalInfo.Foreign, self).__init__()

                                self.yang_name = "foreign"
                                self.yang_parent_name = "additional-info"

                                self.member_name = YLeaf(YType.str, "member-name")

                                self.peer_address = YLeaf(YType.str, "peer-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("member_name",
                                                "peer_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(BundleInformation.Lacp.LacpMembers.LacpMember.LacpMemberItem.AdditionalInfo.Foreign, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(BundleInformation.Lacp.LacpMembers.LacpMember.LacpMemberItem.AdditionalInfo.Foreign, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.member_name.is_set or
                                    self.peer_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.member_name.yfilter != YFilter.not_set or
                                    self.peer_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "foreign" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.member_name.is_set or self.member_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.member_name.get_name_leafdata())
                                if (self.peer_address.is_set or self.peer_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.peer_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "member-name" or name == "peer-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "member-name"):
                                    self.member_name = value
                                    self.member_name.value_namespace = name_space
                                    self.member_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "peer-address"):
                                    self.peer_address = value
                                    self.peer_address.value_namespace = name_space
                                    self.peer_address.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.mbr_type.is_set or
                                (self.foreign is not None and self.foreign.has_data()) or
                                (self.local is not None and self.local.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.mbr_type.yfilter != YFilter.not_set or
                                (self.foreign is not None and self.foreign.has_operation()) or
                                (self.local is not None and self.local.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "additional-info" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.mbr_type.is_set or self.mbr_type.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mbr_type.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "foreign"):
                                if (self.foreign is None):
                                    self.foreign = BundleInformation.Lacp.LacpMembers.LacpMember.LacpMemberItem.AdditionalInfo.Foreign()
                                    self.foreign.parent = self
                                    self._children_name_map["foreign"] = "foreign"
                                return self.foreign

                            if (child_yang_name == "local"):
                                if (self.local is None):
                                    self.local = BundleInformation.Lacp.LacpMembers.LacpMember.LacpMemberItem.AdditionalInfo.Local()
                                    self.local.parent = self
                                    self._children_name_map["local"] = "local"
                                return self.local

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "foreign" or name == "local" or name == "mbr-type"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "mbr-type"):
                                self.mbr_type = value
                                self.mbr_type.value_namespace = name_space
                                self.mbr_type.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.actor_churn_state.is_set or
                            self.attached_aggregator_id.is_set or
                            self.iccp_group_id.is_set or
                            self.mux_state.is_set or
                            self.partner_churn_state.is_set or
                            self.period_state.is_set or
                            self.receive_machine_state.is_set or
                            self.selected_aggregator_id.is_set or
                            self.selection_state.is_set or
                            (self.actor_info is not None and self.actor_info.has_data()) or
                            (self.additional_info is not None and self.additional_info.has_data()) or
                            (self.partner_info is not None and self.partner_info.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.actor_churn_state.yfilter != YFilter.not_set or
                            self.attached_aggregator_id.yfilter != YFilter.not_set or
                            self.iccp_group_id.yfilter != YFilter.not_set or
                            self.mux_state.yfilter != YFilter.not_set or
                            self.partner_churn_state.yfilter != YFilter.not_set or
                            self.period_state.yfilter != YFilter.not_set or
                            self.receive_machine_state.yfilter != YFilter.not_set or
                            self.selected_aggregator_id.yfilter != YFilter.not_set or
                            self.selection_state.yfilter != YFilter.not_set or
                            (self.actor_info is not None and self.actor_info.has_operation()) or
                            (self.additional_info is not None and self.additional_info.has_operation()) or
                            (self.partner_info is not None and self.partner_info.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "lacp-member-item" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.actor_churn_state.is_set or self.actor_churn_state.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.actor_churn_state.get_name_leafdata())
                        if (self.attached_aggregator_id.is_set or self.attached_aggregator_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.attached_aggregator_id.get_name_leafdata())
                        if (self.iccp_group_id.is_set or self.iccp_group_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.iccp_group_id.get_name_leafdata())
                        if (self.mux_state.is_set or self.mux_state.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mux_state.get_name_leafdata())
                        if (self.partner_churn_state.is_set or self.partner_churn_state.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.partner_churn_state.get_name_leafdata())
                        if (self.period_state.is_set or self.period_state.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.period_state.get_name_leafdata())
                        if (self.receive_machine_state.is_set or self.receive_machine_state.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.receive_machine_state.get_name_leafdata())
                        if (self.selected_aggregator_id.is_set or self.selected_aggregator_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.selected_aggregator_id.get_name_leafdata())
                        if (self.selection_state.is_set or self.selection_state.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.selection_state.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "actor-info"):
                            if (self.actor_info is None):
                                self.actor_info = BundleInformation.Lacp.LacpMembers.LacpMember.LacpMemberItem.ActorInfo()
                                self.actor_info.parent = self
                                self._children_name_map["actor_info"] = "actor-info"
                            return self.actor_info

                        if (child_yang_name == "additional-info"):
                            if (self.additional_info is None):
                                self.additional_info = BundleInformation.Lacp.LacpMembers.LacpMember.LacpMemberItem.AdditionalInfo()
                                self.additional_info.parent = self
                                self._children_name_map["additional_info"] = "additional-info"
                            return self.additional_info

                        if (child_yang_name == "partner-info"):
                            if (self.partner_info is None):
                                self.partner_info = BundleInformation.Lacp.LacpMembers.LacpMember.LacpMemberItem.PartnerInfo()
                                self.partner_info.parent = self
                                self._children_name_map["partner_info"] = "partner-info"
                            return self.partner_info

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "actor-info" or name == "additional-info" or name == "partner-info" or name == "actor-churn-state" or name == "attached-aggregator-id" or name == "iccp-group-id" or name == "mux-state" or name == "partner-churn-state" or name == "period-state" or name == "receive-machine-state" or name == "selected-aggregator-id" or name == "selection-state"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "actor-churn-state"):
                            self.actor_churn_state = value
                            self.actor_churn_state.value_namespace = name_space
                            self.actor_churn_state.value_namespace_prefix = name_space_prefix
                        if(value_path == "attached-aggregator-id"):
                            self.attached_aggregator_id = value
                            self.attached_aggregator_id.value_namespace = name_space
                            self.attached_aggregator_id.value_namespace_prefix = name_space_prefix
                        if(value_path == "iccp-group-id"):
                            self.iccp_group_id = value
                            self.iccp_group_id.value_namespace = name_space
                            self.iccp_group_id.value_namespace_prefix = name_space_prefix
                        if(value_path == "mux-state"):
                            self.mux_state = value
                            self.mux_state.value_namespace = name_space
                            self.mux_state.value_namespace_prefix = name_space_prefix
                        if(value_path == "partner-churn-state"):
                            self.partner_churn_state = value
                            self.partner_churn_state.value_namespace = name_space
                            self.partner_churn_state.value_namespace_prefix = name_space_prefix
                        if(value_path == "period-state"):
                            self.period_state = value
                            self.period_state.value_namespace = name_space
                            self.period_state.value_namespace_prefix = name_space_prefix
                        if(value_path == "receive-machine-state"):
                            self.receive_machine_state = value
                            self.receive_machine_state.value_namespace = name_space
                            self.receive_machine_state.value_namespace_prefix = name_space_prefix
                        if(value_path == "selected-aggregator-id"):
                            self.selected_aggregator_id = value
                            self.selected_aggregator_id.value_namespace = name_space
                            self.selected_aggregator_id.value_namespace_prefix = name_space_prefix
                        if(value_path == "selection-state"):
                            self.selection_state = value
                            self.selection_state.value_namespace = name_space
                            self.selection_state.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    return (
                        self.member_interface.is_set or
                        (self.lacp_member_ancestor is not None and self.lacp_member_ancestor.has_data()) or
                        (self.lacp_member_item is not None and self.lacp_member_item.has_data()))

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.member_interface.yfilter != YFilter.not_set or
                        (self.lacp_member_ancestor is not None and self.lacp_member_ancestor.has_operation()) or
                        (self.lacp_member_item is not None and self.lacp_member_item.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "lacp-member" + "[member-interface='" + self.member_interface.get() + "']" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-bundlemgr-oper:bundle-information/lacp/lacp-members/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.member_interface.is_set or self.member_interface.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.member_interface.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "lacp-member-ancestor"):
                        if (self.lacp_member_ancestor is None):
                            self.lacp_member_ancestor = BundleInformation.Lacp.LacpMembers.LacpMember.LacpMemberAncestor()
                            self.lacp_member_ancestor.parent = self
                            self._children_name_map["lacp_member_ancestor"] = "lacp-member-ancestor"
                        return self.lacp_member_ancestor

                    if (child_yang_name == "lacp-member-item"):
                        if (self.lacp_member_item is None):
                            self.lacp_member_item = BundleInformation.Lacp.LacpMembers.LacpMember.LacpMemberItem()
                            self.lacp_member_item.parent = self
                            self._children_name_map["lacp_member_item"] = "lacp-member-item"
                        return self.lacp_member_item

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "lacp-member-ancestor" or name == "lacp-member-item" or name == "member-interface"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "member-interface"):
                        self.member_interface = value
                        self.member_interface.value_namespace = name_space
                        self.member_interface.value_namespace_prefix = name_space_prefix

            def has_data(self):
                for c in self.lacp_member:
                    if (c.has_data()):
                        return True
                return False

            def has_operation(self):
                for c in self.lacp_member:
                    if (c.has_operation()):
                        return True
                return self.yfilter != YFilter.not_set

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "lacp-members" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-bundlemgr-oper:bundle-information/lacp/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "lacp-member"):
                    for c in self.lacp_member:
                        segment = c.get_segment_path()
                        if (segment_path == segment):
                            return c
                    c = BundleInformation.Lacp.LacpMembers.LacpMember()
                    c.parent = self
                    local_reference_key = "ydk::seg::%s" % segment_path
                    self._local_refs[local_reference_key] = c
                    self.lacp_member.append(c)
                    return c

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "lacp-member"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                pass

        def has_data(self):
            return (
                (self.lacp_bundles is not None and self.lacp_bundles.has_data()) or
                (self.lacp_members is not None and self.lacp_members.has_data()))

        def has_operation(self):
            return (
                self.yfilter != YFilter.not_set or
                (self.lacp_bundles is not None and self.lacp_bundles.has_operation()) or
                (self.lacp_members is not None and self.lacp_members.has_operation()))

        def get_segment_path(self):
            path_buffer = ""
            path_buffer = "lacp" + path_buffer

            return path_buffer

        def get_entity_path(self, ancestor):
            path_buffer = ""
            if (ancestor is None):
                path_buffer = "Cisco-IOS-XR-bundlemgr-oper:bundle-information/%s" % self.get_segment_path()
            else:
                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

            leaf_name_data = LeafDataList()

            entity_path = EntityPath(path_buffer, leaf_name_data)
            return entity_path

        def get_child_by_name(self, child_yang_name, segment_path):
            child = self._get_child_by_seg_name([child_yang_name, segment_path])
            if child is not None:
                return child

            if (child_yang_name == "lacp-bundles"):
                if (self.lacp_bundles is None):
                    self.lacp_bundles = BundleInformation.Lacp.LacpBundles()
                    self.lacp_bundles.parent = self
                    self._children_name_map["lacp_bundles"] = "lacp-bundles"
                return self.lacp_bundles

            if (child_yang_name == "lacp-members"):
                if (self.lacp_members is None):
                    self.lacp_members = BundleInformation.Lacp.LacpMembers()
                    self.lacp_members.parent = self
                    self._children_name_map["lacp_members"] = "lacp-members"
                return self.lacp_members

            return None

        def has_leaf_or_child_of_name(self, name):
            if(name == "lacp-bundles" or name == "lacp-members"):
                return True
            return False

        def set_value(self, value_path, value, name_space, name_space_prefix):
            pass


    class MlacpBundleCounters(Entity):
        """
        Bundle specific counters of mLACP events
        
        .. attribute:: bundles
        
        	Bundle interfaces with counters of mLACP events
        	**type**\:   :py:class:`Bundles <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.MlacpBundleCounters.Bundles>`
        
        .. attribute:: iccp_groups
        
        	ICCP Groups with counters of their bundle's mLACP events
        	**type**\:   :py:class:`IccpGroups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.MlacpBundleCounters.IccpGroups>`
        
        .. attribute:: nodes
        
        	Devices with counters of their bundle's mLACP events
        	**type**\:   :py:class:`Nodes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.MlacpBundleCounters.Nodes>`
        
        

        """

        _prefix = 'bundlemgr-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(BundleInformation.MlacpBundleCounters, self).__init__()

            self.yang_name = "mlacp-bundle-counters"
            self.yang_parent_name = "bundle-information"

            self.bundles = BundleInformation.MlacpBundleCounters.Bundles()
            self.bundles.parent = self
            self._children_name_map["bundles"] = "bundles"
            self._children_yang_names.add("bundles")

            self.iccp_groups = BundleInformation.MlacpBundleCounters.IccpGroups()
            self.iccp_groups.parent = self
            self._children_name_map["iccp_groups"] = "iccp-groups"
            self._children_yang_names.add("iccp-groups")

            self.nodes = BundleInformation.MlacpBundleCounters.Nodes()
            self.nodes.parent = self
            self._children_name_map["nodes"] = "nodes"
            self._children_yang_names.add("nodes")


        class IccpGroups(Entity):
            """
            ICCP Groups with counters of their bundle's
            mLACP events
            
            .. attribute:: iccp_group
            
            	ICCP Group ID
            	**type**\: list of    :py:class:`IccpGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.MlacpBundleCounters.IccpGroups.IccpGroup>`
            
            

            """

            _prefix = 'bundlemgr-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(BundleInformation.MlacpBundleCounters.IccpGroups, self).__init__()

                self.yang_name = "iccp-groups"
                self.yang_parent_name = "mlacp-bundle-counters"

                self.iccp_group = YList(self)

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in () and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(BundleInformation.MlacpBundleCounters.IccpGroups, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(BundleInformation.MlacpBundleCounters.IccpGroups, self).__setattr__(name, value)


            class IccpGroup(Entity):
                """
                ICCP Group ID
                
                .. attribute:: iccp_group  <key>
                
                	ICCP Group ID
                	**type**\:  int
                
                	**range:** 1..4294967295
                
                .. attribute:: iccp_group_item
                
                	Data for this item
                	**type**\:   :py:class:`IccpGroupItem <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.MlacpBundleCounters.IccpGroups.IccpGroup.IccpGroupItem>`
                
                

                """

                _prefix = 'bundlemgr-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(BundleInformation.MlacpBundleCounters.IccpGroups.IccpGroup, self).__init__()

                    self.yang_name = "iccp-group"
                    self.yang_parent_name = "iccp-groups"

                    self.iccp_group = YLeaf(YType.uint32, "iccp-group")

                    self.iccp_group_item = BundleInformation.MlacpBundleCounters.IccpGroups.IccpGroup.IccpGroupItem()
                    self.iccp_group_item.parent = self
                    self._children_name_map["iccp_group_item"] = "iccp-group-item"
                    self._children_yang_names.add("iccp-group-item")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("iccp_group") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(BundleInformation.MlacpBundleCounters.IccpGroups.IccpGroup, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(BundleInformation.MlacpBundleCounters.IccpGroups.IccpGroup, self).__setattr__(name, value)


                class IccpGroupItem(Entity):
                    """
                    Data for this item
                    
                    .. attribute:: iccp_group_data
                    
                    	ICCP Group mLACP TLV counter information
                    	**type**\:   :py:class:`IccpGroupData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.MlacpBundleCounters.IccpGroups.IccpGroup.IccpGroupItem.IccpGroupData>`
                    
                    .. attribute:: node_data
                    
                    	Peer device bundle mLACP counter information
                    	**type**\: list of    :py:class:`NodeData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.MlacpBundleCounters.IccpGroups.IccpGroup.IccpGroupItem.NodeData>`
                    
                    

                    """

                    _prefix = 'bundlemgr-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(BundleInformation.MlacpBundleCounters.IccpGroups.IccpGroup.IccpGroupItem, self).__init__()

                        self.yang_name = "iccp-group-item"
                        self.yang_parent_name = "iccp-group"

                        self.iccp_group_data = BundleInformation.MlacpBundleCounters.IccpGroups.IccpGroup.IccpGroupItem.IccpGroupData()
                        self.iccp_group_data.parent = self
                        self._children_name_map["iccp_group_data"] = "iccp-group-data"
                        self._children_yang_names.add("iccp-group-data")

                        self.node_data = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(BundleInformation.MlacpBundleCounters.IccpGroups.IccpGroup.IccpGroupItem, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(BundleInformation.MlacpBundleCounters.IccpGroups.IccpGroup.IccpGroupItem, self).__setattr__(name, value)


                    class IccpGroupData(Entity):
                        """
                        ICCP Group mLACP TLV counter information
                        
                        .. attribute:: bundle_data
                        
                        	Local device bundle mLACP counter information
                        	**type**\: list of    :py:class:`BundleData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.MlacpBundleCounters.IccpGroups.IccpGroup.IccpGroupItem.IccpGroupData.BundleData>`
                        
                        .. attribute:: iccp_group_id
                        
                        	ICCP Group ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: mlacp_sync_requests_on_all_local_bundles
                        
                        	Counts of mLACP sync request TLVs on all bundles
                        	**type**\:   :py:class:`MlacpSyncRequestsOnAllLocalBundles <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.MlacpBundleCounters.IccpGroups.IccpGroup.IccpGroupItem.IccpGroupData.MlacpSyncRequestsOnAllLocalBundles>`
                        
                        .. attribute:: mlacp_sync_requests_on_all_local_ports
                        
                        	Counts of mLACP sync request TLVs on all ports
                        	**type**\:   :py:class:`MlacpSyncRequestsOnAllLocalPorts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.MlacpBundleCounters.IccpGroups.IccpGroup.IccpGroupItem.IccpGroupData.MlacpSyncRequestsOnAllLocalPorts>`
                        
                        

                        """

                        _prefix = 'bundlemgr-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(BundleInformation.MlacpBundleCounters.IccpGroups.IccpGroup.IccpGroupItem.IccpGroupData, self).__init__()

                            self.yang_name = "iccp-group-data"
                            self.yang_parent_name = "iccp-group-item"

                            self.iccp_group_id = YLeaf(YType.uint32, "iccp-group-id")

                            self.mlacp_sync_requests_on_all_local_bundles = BundleInformation.MlacpBundleCounters.IccpGroups.IccpGroup.IccpGroupItem.IccpGroupData.MlacpSyncRequestsOnAllLocalBundles()
                            self.mlacp_sync_requests_on_all_local_bundles.parent = self
                            self._children_name_map["mlacp_sync_requests_on_all_local_bundles"] = "mlacp-sync-requests-on-all-local-bundles"
                            self._children_yang_names.add("mlacp-sync-requests-on-all-local-bundles")

                            self.mlacp_sync_requests_on_all_local_ports = BundleInformation.MlacpBundleCounters.IccpGroups.IccpGroup.IccpGroupItem.IccpGroupData.MlacpSyncRequestsOnAllLocalPorts()
                            self.mlacp_sync_requests_on_all_local_ports.parent = self
                            self._children_name_map["mlacp_sync_requests_on_all_local_ports"] = "mlacp-sync-requests-on-all-local-ports"
                            self._children_yang_names.add("mlacp-sync-requests-on-all-local-ports")

                            self.bundle_data = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("iccp_group_id") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(BundleInformation.MlacpBundleCounters.IccpGroups.IccpGroup.IccpGroupItem.IccpGroupData, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(BundleInformation.MlacpBundleCounters.IccpGroups.IccpGroup.IccpGroupItem.IccpGroupData, self).__setattr__(name, value)


                        class MlacpSyncRequestsOnAllLocalPorts(Entity):
                            """
                            Counts of mLACP sync request TLVs on all ports
                            
                            .. attribute:: last_time_cleared
                            
                            	Time in nsecs from boot when counters were last cleared (deprecated)
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: nanosecond
                            
                            .. attribute:: received_sync_requests
                            
                            	Number of mLACP sync request TLVs received
                            	**type**\:   :py:class:`ReceivedSyncRequests <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.MlacpBundleCounters.IccpGroups.IccpGroup.IccpGroupItem.IccpGroupData.MlacpSyncRequestsOnAllLocalPorts.ReceivedSyncRequests>`
                            
                            .. attribute:: time_since_cleared
                            
                            	Elapsed time in nsecs since counters were last cleared
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: nanosecond
                            
                            

                            """

                            _prefix = 'bundlemgr-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(BundleInformation.MlacpBundleCounters.IccpGroups.IccpGroup.IccpGroupItem.IccpGroupData.MlacpSyncRequestsOnAllLocalPorts, self).__init__()

                                self.yang_name = "mlacp-sync-requests-on-all-local-ports"
                                self.yang_parent_name = "iccp-group-data"

                                self.last_time_cleared = YLeaf(YType.uint64, "last-time-cleared")

                                self.time_since_cleared = YLeaf(YType.uint64, "time-since-cleared")

                                self.received_sync_requests = BundleInformation.MlacpBundleCounters.IccpGroups.IccpGroup.IccpGroupItem.IccpGroupData.MlacpSyncRequestsOnAllLocalPorts.ReceivedSyncRequests()
                                self.received_sync_requests.parent = self
                                self._children_name_map["received_sync_requests"] = "received-sync-requests"
                                self._children_yang_names.add("received-sync-requests")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("last_time_cleared",
                                                "time_since_cleared") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(BundleInformation.MlacpBundleCounters.IccpGroups.IccpGroup.IccpGroupItem.IccpGroupData.MlacpSyncRequestsOnAllLocalPorts, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(BundleInformation.MlacpBundleCounters.IccpGroups.IccpGroup.IccpGroupItem.IccpGroupData.MlacpSyncRequestsOnAllLocalPorts, self).__setattr__(name, value)


                            class ReceivedSyncRequests(Entity):
                                """
                                Number of mLACP sync request TLVs received
                                
                                .. attribute:: all_syncs
                                
                                	Total number of sync requests received
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: config_syncs
                                
                                	Number of config sync requests received
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: state_syncs
                                
                                	Number of state sync requests received
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'bundlemgr-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(BundleInformation.MlacpBundleCounters.IccpGroups.IccpGroup.IccpGroupItem.IccpGroupData.MlacpSyncRequestsOnAllLocalPorts.ReceivedSyncRequests, self).__init__()

                                    self.yang_name = "received-sync-requests"
                                    self.yang_parent_name = "mlacp-sync-requests-on-all-local-ports"

                                    self.all_syncs = YLeaf(YType.uint32, "all-syncs")

                                    self.config_syncs = YLeaf(YType.uint32, "config-syncs")

                                    self.state_syncs = YLeaf(YType.uint32, "state-syncs")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("all_syncs",
                                                    "config_syncs",
                                                    "state_syncs") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(BundleInformation.MlacpBundleCounters.IccpGroups.IccpGroup.IccpGroupItem.IccpGroupData.MlacpSyncRequestsOnAllLocalPorts.ReceivedSyncRequests, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(BundleInformation.MlacpBundleCounters.IccpGroups.IccpGroup.IccpGroupItem.IccpGroupData.MlacpSyncRequestsOnAllLocalPorts.ReceivedSyncRequests, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.all_syncs.is_set or
                                        self.config_syncs.is_set or
                                        self.state_syncs.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.all_syncs.yfilter != YFilter.not_set or
                                        self.config_syncs.yfilter != YFilter.not_set or
                                        self.state_syncs.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "received-sync-requests" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.all_syncs.is_set or self.all_syncs.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.all_syncs.get_name_leafdata())
                                    if (self.config_syncs.is_set or self.config_syncs.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.config_syncs.get_name_leafdata())
                                    if (self.state_syncs.is_set or self.state_syncs.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.state_syncs.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "all-syncs" or name == "config-syncs" or name == "state-syncs"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "all-syncs"):
                                        self.all_syncs = value
                                        self.all_syncs.value_namespace = name_space
                                        self.all_syncs.value_namespace_prefix = name_space_prefix
                                    if(value_path == "config-syncs"):
                                        self.config_syncs = value
                                        self.config_syncs.value_namespace = name_space
                                        self.config_syncs.value_namespace_prefix = name_space_prefix
                                    if(value_path == "state-syncs"):
                                        self.state_syncs = value
                                        self.state_syncs.value_namespace = name_space
                                        self.state_syncs.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.last_time_cleared.is_set or
                                    self.time_since_cleared.is_set or
                                    (self.received_sync_requests is not None and self.received_sync_requests.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.last_time_cleared.yfilter != YFilter.not_set or
                                    self.time_since_cleared.yfilter != YFilter.not_set or
                                    (self.received_sync_requests is not None and self.received_sync_requests.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "mlacp-sync-requests-on-all-local-ports" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.last_time_cleared.is_set or self.last_time_cleared.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.last_time_cleared.get_name_leafdata())
                                if (self.time_since_cleared.is_set or self.time_since_cleared.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.time_since_cleared.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "received-sync-requests"):
                                    if (self.received_sync_requests is None):
                                        self.received_sync_requests = BundleInformation.MlacpBundleCounters.IccpGroups.IccpGroup.IccpGroupItem.IccpGroupData.MlacpSyncRequestsOnAllLocalPorts.ReceivedSyncRequests()
                                        self.received_sync_requests.parent = self
                                        self._children_name_map["received_sync_requests"] = "received-sync-requests"
                                    return self.received_sync_requests

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "received-sync-requests" or name == "last-time-cleared" or name == "time-since-cleared"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "last-time-cleared"):
                                    self.last_time_cleared = value
                                    self.last_time_cleared.value_namespace = name_space
                                    self.last_time_cleared.value_namespace_prefix = name_space_prefix
                                if(value_path == "time-since-cleared"):
                                    self.time_since_cleared = value
                                    self.time_since_cleared.value_namespace = name_space
                                    self.time_since_cleared.value_namespace_prefix = name_space_prefix


                        class MlacpSyncRequestsOnAllLocalBundles(Entity):
                            """
                            Counts of mLACP sync request TLVs on all bundles
                            
                            .. attribute:: last_time_cleared
                            
                            	Time in nsecs from boot when counters were last cleared (deprecated)
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: nanosecond
                            
                            .. attribute:: received_sync_requests
                            
                            	Number of mLACP sync request TLVs received
                            	**type**\:   :py:class:`ReceivedSyncRequests <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.MlacpBundleCounters.IccpGroups.IccpGroup.IccpGroupItem.IccpGroupData.MlacpSyncRequestsOnAllLocalBundles.ReceivedSyncRequests>`
                            
                            .. attribute:: time_since_cleared
                            
                            	Elapsed time in nsecs since counters were last cleared
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: nanosecond
                            
                            

                            """

                            _prefix = 'bundlemgr-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(BundleInformation.MlacpBundleCounters.IccpGroups.IccpGroup.IccpGroupItem.IccpGroupData.MlacpSyncRequestsOnAllLocalBundles, self).__init__()

                                self.yang_name = "mlacp-sync-requests-on-all-local-bundles"
                                self.yang_parent_name = "iccp-group-data"

                                self.last_time_cleared = YLeaf(YType.uint64, "last-time-cleared")

                                self.time_since_cleared = YLeaf(YType.uint64, "time-since-cleared")

                                self.received_sync_requests = BundleInformation.MlacpBundleCounters.IccpGroups.IccpGroup.IccpGroupItem.IccpGroupData.MlacpSyncRequestsOnAllLocalBundles.ReceivedSyncRequests()
                                self.received_sync_requests.parent = self
                                self._children_name_map["received_sync_requests"] = "received-sync-requests"
                                self._children_yang_names.add("received-sync-requests")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("last_time_cleared",
                                                "time_since_cleared") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(BundleInformation.MlacpBundleCounters.IccpGroups.IccpGroup.IccpGroupItem.IccpGroupData.MlacpSyncRequestsOnAllLocalBundles, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(BundleInformation.MlacpBundleCounters.IccpGroups.IccpGroup.IccpGroupItem.IccpGroupData.MlacpSyncRequestsOnAllLocalBundles, self).__setattr__(name, value)


                            class ReceivedSyncRequests(Entity):
                                """
                                Number of mLACP sync request TLVs received
                                
                                .. attribute:: all_syncs
                                
                                	Total number of sync requests received
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: config_syncs
                                
                                	Number of config sync requests received
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: state_syncs
                                
                                	Number of state sync requests received
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'bundlemgr-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(BundleInformation.MlacpBundleCounters.IccpGroups.IccpGroup.IccpGroupItem.IccpGroupData.MlacpSyncRequestsOnAllLocalBundles.ReceivedSyncRequests, self).__init__()

                                    self.yang_name = "received-sync-requests"
                                    self.yang_parent_name = "mlacp-sync-requests-on-all-local-bundles"

                                    self.all_syncs = YLeaf(YType.uint32, "all-syncs")

                                    self.config_syncs = YLeaf(YType.uint32, "config-syncs")

                                    self.state_syncs = YLeaf(YType.uint32, "state-syncs")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("all_syncs",
                                                    "config_syncs",
                                                    "state_syncs") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(BundleInformation.MlacpBundleCounters.IccpGroups.IccpGroup.IccpGroupItem.IccpGroupData.MlacpSyncRequestsOnAllLocalBundles.ReceivedSyncRequests, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(BundleInformation.MlacpBundleCounters.IccpGroups.IccpGroup.IccpGroupItem.IccpGroupData.MlacpSyncRequestsOnAllLocalBundles.ReceivedSyncRequests, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.all_syncs.is_set or
                                        self.config_syncs.is_set or
                                        self.state_syncs.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.all_syncs.yfilter != YFilter.not_set or
                                        self.config_syncs.yfilter != YFilter.not_set or
                                        self.state_syncs.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "received-sync-requests" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.all_syncs.is_set or self.all_syncs.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.all_syncs.get_name_leafdata())
                                    if (self.config_syncs.is_set or self.config_syncs.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.config_syncs.get_name_leafdata())
                                    if (self.state_syncs.is_set or self.state_syncs.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.state_syncs.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "all-syncs" or name == "config-syncs" or name == "state-syncs"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "all-syncs"):
                                        self.all_syncs = value
                                        self.all_syncs.value_namespace = name_space
                                        self.all_syncs.value_namespace_prefix = name_space_prefix
                                    if(value_path == "config-syncs"):
                                        self.config_syncs = value
                                        self.config_syncs.value_namespace = name_space
                                        self.config_syncs.value_namespace_prefix = name_space_prefix
                                    if(value_path == "state-syncs"):
                                        self.state_syncs = value
                                        self.state_syncs.value_namespace = name_space
                                        self.state_syncs.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.last_time_cleared.is_set or
                                    self.time_since_cleared.is_set or
                                    (self.received_sync_requests is not None and self.received_sync_requests.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.last_time_cleared.yfilter != YFilter.not_set or
                                    self.time_since_cleared.yfilter != YFilter.not_set or
                                    (self.received_sync_requests is not None and self.received_sync_requests.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "mlacp-sync-requests-on-all-local-bundles" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.last_time_cleared.is_set or self.last_time_cleared.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.last_time_cleared.get_name_leafdata())
                                if (self.time_since_cleared.is_set or self.time_since_cleared.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.time_since_cleared.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "received-sync-requests"):
                                    if (self.received_sync_requests is None):
                                        self.received_sync_requests = BundleInformation.MlacpBundleCounters.IccpGroups.IccpGroup.IccpGroupItem.IccpGroupData.MlacpSyncRequestsOnAllLocalBundles.ReceivedSyncRequests()
                                        self.received_sync_requests.parent = self
                                        self._children_name_map["received_sync_requests"] = "received-sync-requests"
                                    return self.received_sync_requests

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "received-sync-requests" or name == "last-time-cleared" or name == "time-since-cleared"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "last-time-cleared"):
                                    self.last_time_cleared = value
                                    self.last_time_cleared.value_namespace = name_space
                                    self.last_time_cleared.value_namespace_prefix = name_space_prefix
                                if(value_path == "time-since-cleared"):
                                    self.time_since_cleared = value
                                    self.time_since_cleared.value_namespace = name_space
                                    self.time_since_cleared.value_namespace_prefix = name_space_prefix


                        class BundleData(Entity):
                            """
                            Local device bundle mLACP counter information
                            
                            .. attribute:: bundle_name
                            
                            	Bundle name
                            	**type**\:  str
                            
                            .. attribute:: mlacp_tlv_counters
                            
                            	Counts of mLACP TLVs sent and received
                            	**type**\:   :py:class:`MlacpTlvCounters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.MlacpBundleCounters.IccpGroups.IccpGroup.IccpGroupItem.IccpGroupData.BundleData.MlacpTlvCounters>`
                            
                            

                            """

                            _prefix = 'bundlemgr-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(BundleInformation.MlacpBundleCounters.IccpGroups.IccpGroup.IccpGroupItem.IccpGroupData.BundleData, self).__init__()

                                self.yang_name = "bundle-data"
                                self.yang_parent_name = "iccp-group-data"

                                self.bundle_name = YLeaf(YType.str, "bundle-name")

                                self.mlacp_tlv_counters = BundleInformation.MlacpBundleCounters.IccpGroups.IccpGroup.IccpGroupItem.IccpGroupData.BundleData.MlacpTlvCounters()
                                self.mlacp_tlv_counters.parent = self
                                self._children_name_map["mlacp_tlv_counters"] = "mlacp-tlv-counters"
                                self._children_yang_names.add("mlacp-tlv-counters")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("bundle_name") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(BundleInformation.MlacpBundleCounters.IccpGroups.IccpGroup.IccpGroupItem.IccpGroupData.BundleData, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(BundleInformation.MlacpBundleCounters.IccpGroups.IccpGroup.IccpGroupItem.IccpGroupData.BundleData, self).__setattr__(name, value)


                            class MlacpTlvCounters(Entity):
                                """
                                Counts of mLACP TLVs sent and received
                                
                                .. attribute:: last_time_cleared
                                
                                	Time in nsecs from boot when counters were last cleared (deprecated)
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: nanosecond
                                
                                .. attribute:: last_unexpected_event
                                
                                	Elapsed time in nsecs since last unexpected event
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: nanosecond
                                
                                .. attribute:: received_nak_tl_vs
                                
                                	Number of mLACP NAK TLVs received
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: received_priority_tl_vs
                                
                                	Number of mLACP priority TLVs received
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: received_sync_requests
                                
                                	Number of mLACP sync request TLVs received
                                	**type**\:   :py:class:`ReceivedSyncRequests <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.MlacpBundleCounters.IccpGroups.IccpGroup.IccpGroupItem.IccpGroupData.BundleData.MlacpTlvCounters.ReceivedSyncRequests>`
                                
                                .. attribute:: sent_config_tl_vs
                                
                                	Number of mLACP config TLVs sent
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: sent_priority_tl_vs
                                
                                	Number of mLACP priority TLVs sent
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: sent_state_tl_vs
                                
                                	Number of mLACP state TLVs sent
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: time_since_cleared
                                
                                	Elapsed time in nsecs since counters were last cleared
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: nanosecond
                                
                                

                                """

                                _prefix = 'bundlemgr-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(BundleInformation.MlacpBundleCounters.IccpGroups.IccpGroup.IccpGroupItem.IccpGroupData.BundleData.MlacpTlvCounters, self).__init__()

                                    self.yang_name = "mlacp-tlv-counters"
                                    self.yang_parent_name = "bundle-data"

                                    self.last_time_cleared = YLeaf(YType.uint64, "last-time-cleared")

                                    self.last_unexpected_event = YLeaf(YType.uint64, "last-unexpected-event")

                                    self.received_nak_tl_vs = YLeaf(YType.uint32, "received-nak-tl-vs")

                                    self.received_priority_tl_vs = YLeaf(YType.uint32, "received-priority-tl-vs")

                                    self.sent_config_tl_vs = YLeaf(YType.uint32, "sent-config-tl-vs")

                                    self.sent_priority_tl_vs = YLeaf(YType.uint32, "sent-priority-tl-vs")

                                    self.sent_state_tl_vs = YLeaf(YType.uint32, "sent-state-tl-vs")

                                    self.time_since_cleared = YLeaf(YType.uint64, "time-since-cleared")

                                    self.received_sync_requests = BundleInformation.MlacpBundleCounters.IccpGroups.IccpGroup.IccpGroupItem.IccpGroupData.BundleData.MlacpTlvCounters.ReceivedSyncRequests()
                                    self.received_sync_requests.parent = self
                                    self._children_name_map["received_sync_requests"] = "received-sync-requests"
                                    self._children_yang_names.add("received-sync-requests")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("last_time_cleared",
                                                    "last_unexpected_event",
                                                    "received_nak_tl_vs",
                                                    "received_priority_tl_vs",
                                                    "sent_config_tl_vs",
                                                    "sent_priority_tl_vs",
                                                    "sent_state_tl_vs",
                                                    "time_since_cleared") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(BundleInformation.MlacpBundleCounters.IccpGroups.IccpGroup.IccpGroupItem.IccpGroupData.BundleData.MlacpTlvCounters, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(BundleInformation.MlacpBundleCounters.IccpGroups.IccpGroup.IccpGroupItem.IccpGroupData.BundleData.MlacpTlvCounters, self).__setattr__(name, value)


                                class ReceivedSyncRequests(Entity):
                                    """
                                    Number of mLACP sync request TLVs received
                                    
                                    .. attribute:: all_syncs
                                    
                                    	Total number of sync requests received
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: config_syncs
                                    
                                    	Number of config sync requests received
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: state_syncs
                                    
                                    	Number of state sync requests received
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'bundlemgr-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(BundleInformation.MlacpBundleCounters.IccpGroups.IccpGroup.IccpGroupItem.IccpGroupData.BundleData.MlacpTlvCounters.ReceivedSyncRequests, self).__init__()

                                        self.yang_name = "received-sync-requests"
                                        self.yang_parent_name = "mlacp-tlv-counters"

                                        self.all_syncs = YLeaf(YType.uint32, "all-syncs")

                                        self.config_syncs = YLeaf(YType.uint32, "config-syncs")

                                        self.state_syncs = YLeaf(YType.uint32, "state-syncs")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("all_syncs",
                                                        "config_syncs",
                                                        "state_syncs") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(BundleInformation.MlacpBundleCounters.IccpGroups.IccpGroup.IccpGroupItem.IccpGroupData.BundleData.MlacpTlvCounters.ReceivedSyncRequests, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(BundleInformation.MlacpBundleCounters.IccpGroups.IccpGroup.IccpGroupItem.IccpGroupData.BundleData.MlacpTlvCounters.ReceivedSyncRequests, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.all_syncs.is_set or
                                            self.config_syncs.is_set or
                                            self.state_syncs.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.all_syncs.yfilter != YFilter.not_set or
                                            self.config_syncs.yfilter != YFilter.not_set or
                                            self.state_syncs.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "received-sync-requests" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.all_syncs.is_set or self.all_syncs.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.all_syncs.get_name_leafdata())
                                        if (self.config_syncs.is_set or self.config_syncs.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.config_syncs.get_name_leafdata())
                                        if (self.state_syncs.is_set or self.state_syncs.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.state_syncs.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "all-syncs" or name == "config-syncs" or name == "state-syncs"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "all-syncs"):
                                            self.all_syncs = value
                                            self.all_syncs.value_namespace = name_space
                                            self.all_syncs.value_namespace_prefix = name_space_prefix
                                        if(value_path == "config-syncs"):
                                            self.config_syncs = value
                                            self.config_syncs.value_namespace = name_space
                                            self.config_syncs.value_namespace_prefix = name_space_prefix
                                        if(value_path == "state-syncs"):
                                            self.state_syncs = value
                                            self.state_syncs.value_namespace = name_space
                                            self.state_syncs.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.last_time_cleared.is_set or
                                        self.last_unexpected_event.is_set or
                                        self.received_nak_tl_vs.is_set or
                                        self.received_priority_tl_vs.is_set or
                                        self.sent_config_tl_vs.is_set or
                                        self.sent_priority_tl_vs.is_set or
                                        self.sent_state_tl_vs.is_set or
                                        self.time_since_cleared.is_set or
                                        (self.received_sync_requests is not None and self.received_sync_requests.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.last_time_cleared.yfilter != YFilter.not_set or
                                        self.last_unexpected_event.yfilter != YFilter.not_set or
                                        self.received_nak_tl_vs.yfilter != YFilter.not_set or
                                        self.received_priority_tl_vs.yfilter != YFilter.not_set or
                                        self.sent_config_tl_vs.yfilter != YFilter.not_set or
                                        self.sent_priority_tl_vs.yfilter != YFilter.not_set or
                                        self.sent_state_tl_vs.yfilter != YFilter.not_set or
                                        self.time_since_cleared.yfilter != YFilter.not_set or
                                        (self.received_sync_requests is not None and self.received_sync_requests.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "mlacp-tlv-counters" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.last_time_cleared.is_set or self.last_time_cleared.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.last_time_cleared.get_name_leafdata())
                                    if (self.last_unexpected_event.is_set or self.last_unexpected_event.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.last_unexpected_event.get_name_leafdata())
                                    if (self.received_nak_tl_vs.is_set or self.received_nak_tl_vs.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.received_nak_tl_vs.get_name_leafdata())
                                    if (self.received_priority_tl_vs.is_set or self.received_priority_tl_vs.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.received_priority_tl_vs.get_name_leafdata())
                                    if (self.sent_config_tl_vs.is_set or self.sent_config_tl_vs.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.sent_config_tl_vs.get_name_leafdata())
                                    if (self.sent_priority_tl_vs.is_set or self.sent_priority_tl_vs.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.sent_priority_tl_vs.get_name_leafdata())
                                    if (self.sent_state_tl_vs.is_set or self.sent_state_tl_vs.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.sent_state_tl_vs.get_name_leafdata())
                                    if (self.time_since_cleared.is_set or self.time_since_cleared.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.time_since_cleared.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "received-sync-requests"):
                                        if (self.received_sync_requests is None):
                                            self.received_sync_requests = BundleInformation.MlacpBundleCounters.IccpGroups.IccpGroup.IccpGroupItem.IccpGroupData.BundleData.MlacpTlvCounters.ReceivedSyncRequests()
                                            self.received_sync_requests.parent = self
                                            self._children_name_map["received_sync_requests"] = "received-sync-requests"
                                        return self.received_sync_requests

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "received-sync-requests" or name == "last-time-cleared" or name == "last-unexpected-event" or name == "received-nak-tl-vs" or name == "received-priority-tl-vs" or name == "sent-config-tl-vs" or name == "sent-priority-tl-vs" or name == "sent-state-tl-vs" or name == "time-since-cleared"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "last-time-cleared"):
                                        self.last_time_cleared = value
                                        self.last_time_cleared.value_namespace = name_space
                                        self.last_time_cleared.value_namespace_prefix = name_space_prefix
                                    if(value_path == "last-unexpected-event"):
                                        self.last_unexpected_event = value
                                        self.last_unexpected_event.value_namespace = name_space
                                        self.last_unexpected_event.value_namespace_prefix = name_space_prefix
                                    if(value_path == "received-nak-tl-vs"):
                                        self.received_nak_tl_vs = value
                                        self.received_nak_tl_vs.value_namespace = name_space
                                        self.received_nak_tl_vs.value_namespace_prefix = name_space_prefix
                                    if(value_path == "received-priority-tl-vs"):
                                        self.received_priority_tl_vs = value
                                        self.received_priority_tl_vs.value_namespace = name_space
                                        self.received_priority_tl_vs.value_namespace_prefix = name_space_prefix
                                    if(value_path == "sent-config-tl-vs"):
                                        self.sent_config_tl_vs = value
                                        self.sent_config_tl_vs.value_namespace = name_space
                                        self.sent_config_tl_vs.value_namespace_prefix = name_space_prefix
                                    if(value_path == "sent-priority-tl-vs"):
                                        self.sent_priority_tl_vs = value
                                        self.sent_priority_tl_vs.value_namespace = name_space
                                        self.sent_priority_tl_vs.value_namespace_prefix = name_space_prefix
                                    if(value_path == "sent-state-tl-vs"):
                                        self.sent_state_tl_vs = value
                                        self.sent_state_tl_vs.value_namespace = name_space
                                        self.sent_state_tl_vs.value_namespace_prefix = name_space_prefix
                                    if(value_path == "time-since-cleared"):
                                        self.time_since_cleared = value
                                        self.time_since_cleared.value_namespace = name_space
                                        self.time_since_cleared.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.bundle_name.is_set or
                                    (self.mlacp_tlv_counters is not None and self.mlacp_tlv_counters.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.bundle_name.yfilter != YFilter.not_set or
                                    (self.mlacp_tlv_counters is not None and self.mlacp_tlv_counters.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "bundle-data" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.bundle_name.is_set or self.bundle_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.bundle_name.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "mlacp-tlv-counters"):
                                    if (self.mlacp_tlv_counters is None):
                                        self.mlacp_tlv_counters = BundleInformation.MlacpBundleCounters.IccpGroups.IccpGroup.IccpGroupItem.IccpGroupData.BundleData.MlacpTlvCounters()
                                        self.mlacp_tlv_counters.parent = self
                                        self._children_name_map["mlacp_tlv_counters"] = "mlacp-tlv-counters"
                                    return self.mlacp_tlv_counters

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "mlacp-tlv-counters" or name == "bundle-name"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "bundle-name"):
                                    self.bundle_name = value
                                    self.bundle_name.value_namespace = name_space
                                    self.bundle_name.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.bundle_data:
                                if (c.has_data()):
                                    return True
                            return (
                                self.iccp_group_id.is_set or
                                (self.mlacp_sync_requests_on_all_local_bundles is not None and self.mlacp_sync_requests_on_all_local_bundles.has_data()) or
                                (self.mlacp_sync_requests_on_all_local_ports is not None and self.mlacp_sync_requests_on_all_local_ports.has_data()))

                        def has_operation(self):
                            for c in self.bundle_data:
                                if (c.has_operation()):
                                    return True
                            return (
                                self.yfilter != YFilter.not_set or
                                self.iccp_group_id.yfilter != YFilter.not_set or
                                (self.mlacp_sync_requests_on_all_local_bundles is not None and self.mlacp_sync_requests_on_all_local_bundles.has_operation()) or
                                (self.mlacp_sync_requests_on_all_local_ports is not None and self.mlacp_sync_requests_on_all_local_ports.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "iccp-group-data" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.iccp_group_id.is_set or self.iccp_group_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.iccp_group_id.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "bundle-data"):
                                for c in self.bundle_data:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = BundleInformation.MlacpBundleCounters.IccpGroups.IccpGroup.IccpGroupItem.IccpGroupData.BundleData()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.bundle_data.append(c)
                                return c

                            if (child_yang_name == "mlacp-sync-requests-on-all-local-bundles"):
                                if (self.mlacp_sync_requests_on_all_local_bundles is None):
                                    self.mlacp_sync_requests_on_all_local_bundles = BundleInformation.MlacpBundleCounters.IccpGroups.IccpGroup.IccpGroupItem.IccpGroupData.MlacpSyncRequestsOnAllLocalBundles()
                                    self.mlacp_sync_requests_on_all_local_bundles.parent = self
                                    self._children_name_map["mlacp_sync_requests_on_all_local_bundles"] = "mlacp-sync-requests-on-all-local-bundles"
                                return self.mlacp_sync_requests_on_all_local_bundles

                            if (child_yang_name == "mlacp-sync-requests-on-all-local-ports"):
                                if (self.mlacp_sync_requests_on_all_local_ports is None):
                                    self.mlacp_sync_requests_on_all_local_ports = BundleInformation.MlacpBundleCounters.IccpGroups.IccpGroup.IccpGroupItem.IccpGroupData.MlacpSyncRequestsOnAllLocalPorts()
                                    self.mlacp_sync_requests_on_all_local_ports.parent = self
                                    self._children_name_map["mlacp_sync_requests_on_all_local_ports"] = "mlacp-sync-requests-on-all-local-ports"
                                return self.mlacp_sync_requests_on_all_local_ports

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "bundle-data" or name == "mlacp-sync-requests-on-all-local-bundles" or name == "mlacp-sync-requests-on-all-local-ports" or name == "iccp-group-id"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "iccp-group-id"):
                                self.iccp_group_id = value
                                self.iccp_group_id.value_namespace = name_space
                                self.iccp_group_id.value_namespace_prefix = name_space_prefix


                    class NodeData(Entity):
                        """
                        Peer device bundle mLACP counter information
                        
                        .. attribute:: bundle_data
                        
                        	Peer device bundle mLACP TLV counter information
                        	**type**\: list of    :py:class:`BundleData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.MlacpBundleCounters.IccpGroups.IccpGroup.IccpGroupItem.NodeData.BundleData>`
                        
                        .. attribute:: node_data
                        
                        	Peer device mLACP TLV counter information
                        	**type**\:   :py:class:`NodeData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.MlacpBundleCounters.IccpGroups.IccpGroup.IccpGroupItem.NodeData.NodeData>`
                        
                        

                        """

                        _prefix = 'bundlemgr-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(BundleInformation.MlacpBundleCounters.IccpGroups.IccpGroup.IccpGroupItem.NodeData, self).__init__()

                            self.yang_name = "node-data"
                            self.yang_parent_name = "iccp-group-item"

                            self.node_data = BundleInformation.MlacpBundleCounters.IccpGroups.IccpGroup.IccpGroupItem.NodeData.NodeData()
                            self.node_data.parent = self
                            self._children_name_map["node_data"] = "node-data"
                            self._children_yang_names.add("node-data")

                            self.bundle_data = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(BundleInformation.MlacpBundleCounters.IccpGroups.IccpGroup.IccpGroupItem.NodeData, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(BundleInformation.MlacpBundleCounters.IccpGroups.IccpGroup.IccpGroupItem.NodeData, self).__setattr__(name, value)


                        class NodeData(Entity):
                            """
                            Peer device mLACP TLV counter information
                            
                            .. attribute:: mlacp_sync_requests_on_all_foreign_bundles
                            
                            	Counts of mLACP sync request TLVs on all bundles
                            	**type**\:   :py:class:`MlacpSyncRequestsOnAllForeignBundles <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.MlacpBundleCounters.IccpGroups.IccpGroup.IccpGroupItem.NodeData.NodeData.MlacpSyncRequestsOnAllForeignBundles>`
                            
                            .. attribute:: mlacp_sync_requests_on_all_foreign_ports
                            
                            	Counts of mLACP sync request TLVs on all ports
                            	**type**\:   :py:class:`MlacpSyncRequestsOnAllForeignPorts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.MlacpBundleCounters.IccpGroups.IccpGroup.IccpGroupItem.NodeData.NodeData.MlacpSyncRequestsOnAllForeignPorts>`
                            
                            .. attribute:: node_id
                            
                            	Device ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'bundlemgr-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(BundleInformation.MlacpBundleCounters.IccpGroups.IccpGroup.IccpGroupItem.NodeData.NodeData, self).__init__()

                                self.yang_name = "node-data"
                                self.yang_parent_name = "node-data"

                                self.node_id = YLeaf(YType.uint32, "node-id")

                                self.mlacp_sync_requests_on_all_foreign_bundles = BundleInformation.MlacpBundleCounters.IccpGroups.IccpGroup.IccpGroupItem.NodeData.NodeData.MlacpSyncRequestsOnAllForeignBundles()
                                self.mlacp_sync_requests_on_all_foreign_bundles.parent = self
                                self._children_name_map["mlacp_sync_requests_on_all_foreign_bundles"] = "mlacp-sync-requests-on-all-foreign-bundles"
                                self._children_yang_names.add("mlacp-sync-requests-on-all-foreign-bundles")

                                self.mlacp_sync_requests_on_all_foreign_ports = BundleInformation.MlacpBundleCounters.IccpGroups.IccpGroup.IccpGroupItem.NodeData.NodeData.MlacpSyncRequestsOnAllForeignPorts()
                                self.mlacp_sync_requests_on_all_foreign_ports.parent = self
                                self._children_name_map["mlacp_sync_requests_on_all_foreign_ports"] = "mlacp-sync-requests-on-all-foreign-ports"
                                self._children_yang_names.add("mlacp-sync-requests-on-all-foreign-ports")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("node_id") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(BundleInformation.MlacpBundleCounters.IccpGroups.IccpGroup.IccpGroupItem.NodeData.NodeData, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(BundleInformation.MlacpBundleCounters.IccpGroups.IccpGroup.IccpGroupItem.NodeData.NodeData, self).__setattr__(name, value)


                            class MlacpSyncRequestsOnAllForeignPorts(Entity):
                                """
                                Counts of mLACP sync request TLVs on all ports
                                
                                .. attribute:: last_time_cleared
                                
                                	Time in nsecs from boot when counters were last cleared (deprecated)
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: nanosecond
                                
                                .. attribute:: received_sync_requests
                                
                                	Number of mLACP sync request TLVs received
                                	**type**\:   :py:class:`ReceivedSyncRequests <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.MlacpBundleCounters.IccpGroups.IccpGroup.IccpGroupItem.NodeData.NodeData.MlacpSyncRequestsOnAllForeignPorts.ReceivedSyncRequests>`
                                
                                .. attribute:: time_since_cleared
                                
                                	Elapsed time in nsecs since counters were last cleared
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: nanosecond
                                
                                

                                """

                                _prefix = 'bundlemgr-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(BundleInformation.MlacpBundleCounters.IccpGroups.IccpGroup.IccpGroupItem.NodeData.NodeData.MlacpSyncRequestsOnAllForeignPorts, self).__init__()

                                    self.yang_name = "mlacp-sync-requests-on-all-foreign-ports"
                                    self.yang_parent_name = "node-data"

                                    self.last_time_cleared = YLeaf(YType.uint64, "last-time-cleared")

                                    self.time_since_cleared = YLeaf(YType.uint64, "time-since-cleared")

                                    self.received_sync_requests = BundleInformation.MlacpBundleCounters.IccpGroups.IccpGroup.IccpGroupItem.NodeData.NodeData.MlacpSyncRequestsOnAllForeignPorts.ReceivedSyncRequests()
                                    self.received_sync_requests.parent = self
                                    self._children_name_map["received_sync_requests"] = "received-sync-requests"
                                    self._children_yang_names.add("received-sync-requests")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("last_time_cleared",
                                                    "time_since_cleared") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(BundleInformation.MlacpBundleCounters.IccpGroups.IccpGroup.IccpGroupItem.NodeData.NodeData.MlacpSyncRequestsOnAllForeignPorts, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(BundleInformation.MlacpBundleCounters.IccpGroups.IccpGroup.IccpGroupItem.NodeData.NodeData.MlacpSyncRequestsOnAllForeignPorts, self).__setattr__(name, value)


                                class ReceivedSyncRequests(Entity):
                                    """
                                    Number of mLACP sync request TLVs received
                                    
                                    .. attribute:: all_syncs
                                    
                                    	Total number of sync requests received
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: config_syncs
                                    
                                    	Number of config sync requests received
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: state_syncs
                                    
                                    	Number of state sync requests received
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'bundlemgr-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(BundleInformation.MlacpBundleCounters.IccpGroups.IccpGroup.IccpGroupItem.NodeData.NodeData.MlacpSyncRequestsOnAllForeignPorts.ReceivedSyncRequests, self).__init__()

                                        self.yang_name = "received-sync-requests"
                                        self.yang_parent_name = "mlacp-sync-requests-on-all-foreign-ports"

                                        self.all_syncs = YLeaf(YType.uint32, "all-syncs")

                                        self.config_syncs = YLeaf(YType.uint32, "config-syncs")

                                        self.state_syncs = YLeaf(YType.uint32, "state-syncs")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("all_syncs",
                                                        "config_syncs",
                                                        "state_syncs") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(BundleInformation.MlacpBundleCounters.IccpGroups.IccpGroup.IccpGroupItem.NodeData.NodeData.MlacpSyncRequestsOnAllForeignPorts.ReceivedSyncRequests, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(BundleInformation.MlacpBundleCounters.IccpGroups.IccpGroup.IccpGroupItem.NodeData.NodeData.MlacpSyncRequestsOnAllForeignPorts.ReceivedSyncRequests, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.all_syncs.is_set or
                                            self.config_syncs.is_set or
                                            self.state_syncs.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.all_syncs.yfilter != YFilter.not_set or
                                            self.config_syncs.yfilter != YFilter.not_set or
                                            self.state_syncs.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "received-sync-requests" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.all_syncs.is_set or self.all_syncs.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.all_syncs.get_name_leafdata())
                                        if (self.config_syncs.is_set or self.config_syncs.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.config_syncs.get_name_leafdata())
                                        if (self.state_syncs.is_set or self.state_syncs.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.state_syncs.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "all-syncs" or name == "config-syncs" or name == "state-syncs"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "all-syncs"):
                                            self.all_syncs = value
                                            self.all_syncs.value_namespace = name_space
                                            self.all_syncs.value_namespace_prefix = name_space_prefix
                                        if(value_path == "config-syncs"):
                                            self.config_syncs = value
                                            self.config_syncs.value_namespace = name_space
                                            self.config_syncs.value_namespace_prefix = name_space_prefix
                                        if(value_path == "state-syncs"):
                                            self.state_syncs = value
                                            self.state_syncs.value_namespace = name_space
                                            self.state_syncs.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.last_time_cleared.is_set or
                                        self.time_since_cleared.is_set or
                                        (self.received_sync_requests is not None and self.received_sync_requests.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.last_time_cleared.yfilter != YFilter.not_set or
                                        self.time_since_cleared.yfilter != YFilter.not_set or
                                        (self.received_sync_requests is not None and self.received_sync_requests.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "mlacp-sync-requests-on-all-foreign-ports" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.last_time_cleared.is_set or self.last_time_cleared.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.last_time_cleared.get_name_leafdata())
                                    if (self.time_since_cleared.is_set or self.time_since_cleared.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.time_since_cleared.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "received-sync-requests"):
                                        if (self.received_sync_requests is None):
                                            self.received_sync_requests = BundleInformation.MlacpBundleCounters.IccpGroups.IccpGroup.IccpGroupItem.NodeData.NodeData.MlacpSyncRequestsOnAllForeignPorts.ReceivedSyncRequests()
                                            self.received_sync_requests.parent = self
                                            self._children_name_map["received_sync_requests"] = "received-sync-requests"
                                        return self.received_sync_requests

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "received-sync-requests" or name == "last-time-cleared" or name == "time-since-cleared"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "last-time-cleared"):
                                        self.last_time_cleared = value
                                        self.last_time_cleared.value_namespace = name_space
                                        self.last_time_cleared.value_namespace_prefix = name_space_prefix
                                    if(value_path == "time-since-cleared"):
                                        self.time_since_cleared = value
                                        self.time_since_cleared.value_namespace = name_space
                                        self.time_since_cleared.value_namespace_prefix = name_space_prefix


                            class MlacpSyncRequestsOnAllForeignBundles(Entity):
                                """
                                Counts of mLACP sync request TLVs on all bundles
                                
                                .. attribute:: last_time_cleared
                                
                                	Time in nsecs from boot when counters were last cleared (deprecated)
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: nanosecond
                                
                                .. attribute:: received_sync_requests
                                
                                	Number of mLACP sync request TLVs received
                                	**type**\:   :py:class:`ReceivedSyncRequests <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.MlacpBundleCounters.IccpGroups.IccpGroup.IccpGroupItem.NodeData.NodeData.MlacpSyncRequestsOnAllForeignBundles.ReceivedSyncRequests>`
                                
                                .. attribute:: time_since_cleared
                                
                                	Elapsed time in nsecs since counters were last cleared
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: nanosecond
                                
                                

                                """

                                _prefix = 'bundlemgr-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(BundleInformation.MlacpBundleCounters.IccpGroups.IccpGroup.IccpGroupItem.NodeData.NodeData.MlacpSyncRequestsOnAllForeignBundles, self).__init__()

                                    self.yang_name = "mlacp-sync-requests-on-all-foreign-bundles"
                                    self.yang_parent_name = "node-data"

                                    self.last_time_cleared = YLeaf(YType.uint64, "last-time-cleared")

                                    self.time_since_cleared = YLeaf(YType.uint64, "time-since-cleared")

                                    self.received_sync_requests = BundleInformation.MlacpBundleCounters.IccpGroups.IccpGroup.IccpGroupItem.NodeData.NodeData.MlacpSyncRequestsOnAllForeignBundles.ReceivedSyncRequests()
                                    self.received_sync_requests.parent = self
                                    self._children_name_map["received_sync_requests"] = "received-sync-requests"
                                    self._children_yang_names.add("received-sync-requests")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("last_time_cleared",
                                                    "time_since_cleared") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(BundleInformation.MlacpBundleCounters.IccpGroups.IccpGroup.IccpGroupItem.NodeData.NodeData.MlacpSyncRequestsOnAllForeignBundles, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(BundleInformation.MlacpBundleCounters.IccpGroups.IccpGroup.IccpGroupItem.NodeData.NodeData.MlacpSyncRequestsOnAllForeignBundles, self).__setattr__(name, value)


                                class ReceivedSyncRequests(Entity):
                                    """
                                    Number of mLACP sync request TLVs received
                                    
                                    .. attribute:: all_syncs
                                    
                                    	Total number of sync requests received
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: config_syncs
                                    
                                    	Number of config sync requests received
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: state_syncs
                                    
                                    	Number of state sync requests received
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'bundlemgr-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(BundleInformation.MlacpBundleCounters.IccpGroups.IccpGroup.IccpGroupItem.NodeData.NodeData.MlacpSyncRequestsOnAllForeignBundles.ReceivedSyncRequests, self).__init__()

                                        self.yang_name = "received-sync-requests"
                                        self.yang_parent_name = "mlacp-sync-requests-on-all-foreign-bundles"

                                        self.all_syncs = YLeaf(YType.uint32, "all-syncs")

                                        self.config_syncs = YLeaf(YType.uint32, "config-syncs")

                                        self.state_syncs = YLeaf(YType.uint32, "state-syncs")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("all_syncs",
                                                        "config_syncs",
                                                        "state_syncs") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(BundleInformation.MlacpBundleCounters.IccpGroups.IccpGroup.IccpGroupItem.NodeData.NodeData.MlacpSyncRequestsOnAllForeignBundles.ReceivedSyncRequests, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(BundleInformation.MlacpBundleCounters.IccpGroups.IccpGroup.IccpGroupItem.NodeData.NodeData.MlacpSyncRequestsOnAllForeignBundles.ReceivedSyncRequests, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.all_syncs.is_set or
                                            self.config_syncs.is_set or
                                            self.state_syncs.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.all_syncs.yfilter != YFilter.not_set or
                                            self.config_syncs.yfilter != YFilter.not_set or
                                            self.state_syncs.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "received-sync-requests" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.all_syncs.is_set or self.all_syncs.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.all_syncs.get_name_leafdata())
                                        if (self.config_syncs.is_set or self.config_syncs.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.config_syncs.get_name_leafdata())
                                        if (self.state_syncs.is_set or self.state_syncs.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.state_syncs.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "all-syncs" or name == "config-syncs" or name == "state-syncs"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "all-syncs"):
                                            self.all_syncs = value
                                            self.all_syncs.value_namespace = name_space
                                            self.all_syncs.value_namespace_prefix = name_space_prefix
                                        if(value_path == "config-syncs"):
                                            self.config_syncs = value
                                            self.config_syncs.value_namespace = name_space
                                            self.config_syncs.value_namespace_prefix = name_space_prefix
                                        if(value_path == "state-syncs"):
                                            self.state_syncs = value
                                            self.state_syncs.value_namespace = name_space
                                            self.state_syncs.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.last_time_cleared.is_set or
                                        self.time_since_cleared.is_set or
                                        (self.received_sync_requests is not None and self.received_sync_requests.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.last_time_cleared.yfilter != YFilter.not_set or
                                        self.time_since_cleared.yfilter != YFilter.not_set or
                                        (self.received_sync_requests is not None and self.received_sync_requests.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "mlacp-sync-requests-on-all-foreign-bundles" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.last_time_cleared.is_set or self.last_time_cleared.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.last_time_cleared.get_name_leafdata())
                                    if (self.time_since_cleared.is_set or self.time_since_cleared.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.time_since_cleared.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "received-sync-requests"):
                                        if (self.received_sync_requests is None):
                                            self.received_sync_requests = BundleInformation.MlacpBundleCounters.IccpGroups.IccpGroup.IccpGroupItem.NodeData.NodeData.MlacpSyncRequestsOnAllForeignBundles.ReceivedSyncRequests()
                                            self.received_sync_requests.parent = self
                                            self._children_name_map["received_sync_requests"] = "received-sync-requests"
                                        return self.received_sync_requests

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "received-sync-requests" or name == "last-time-cleared" or name == "time-since-cleared"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "last-time-cleared"):
                                        self.last_time_cleared = value
                                        self.last_time_cleared.value_namespace = name_space
                                        self.last_time_cleared.value_namespace_prefix = name_space_prefix
                                    if(value_path == "time-since-cleared"):
                                        self.time_since_cleared = value
                                        self.time_since_cleared.value_namespace = name_space
                                        self.time_since_cleared.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.node_id.is_set or
                                    (self.mlacp_sync_requests_on_all_foreign_bundles is not None and self.mlacp_sync_requests_on_all_foreign_bundles.has_data()) or
                                    (self.mlacp_sync_requests_on_all_foreign_ports is not None and self.mlacp_sync_requests_on_all_foreign_ports.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.node_id.yfilter != YFilter.not_set or
                                    (self.mlacp_sync_requests_on_all_foreign_bundles is not None and self.mlacp_sync_requests_on_all_foreign_bundles.has_operation()) or
                                    (self.mlacp_sync_requests_on_all_foreign_ports is not None and self.mlacp_sync_requests_on_all_foreign_ports.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "node-data" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.node_id.is_set or self.node_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.node_id.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "mlacp-sync-requests-on-all-foreign-bundles"):
                                    if (self.mlacp_sync_requests_on_all_foreign_bundles is None):
                                        self.mlacp_sync_requests_on_all_foreign_bundles = BundleInformation.MlacpBundleCounters.IccpGroups.IccpGroup.IccpGroupItem.NodeData.NodeData.MlacpSyncRequestsOnAllForeignBundles()
                                        self.mlacp_sync_requests_on_all_foreign_bundles.parent = self
                                        self._children_name_map["mlacp_sync_requests_on_all_foreign_bundles"] = "mlacp-sync-requests-on-all-foreign-bundles"
                                    return self.mlacp_sync_requests_on_all_foreign_bundles

                                if (child_yang_name == "mlacp-sync-requests-on-all-foreign-ports"):
                                    if (self.mlacp_sync_requests_on_all_foreign_ports is None):
                                        self.mlacp_sync_requests_on_all_foreign_ports = BundleInformation.MlacpBundleCounters.IccpGroups.IccpGroup.IccpGroupItem.NodeData.NodeData.MlacpSyncRequestsOnAllForeignPorts()
                                        self.mlacp_sync_requests_on_all_foreign_ports.parent = self
                                        self._children_name_map["mlacp_sync_requests_on_all_foreign_ports"] = "mlacp-sync-requests-on-all-foreign-ports"
                                    return self.mlacp_sync_requests_on_all_foreign_ports

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "mlacp-sync-requests-on-all-foreign-bundles" or name == "mlacp-sync-requests-on-all-foreign-ports" or name == "node-id"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "node-id"):
                                    self.node_id = value
                                    self.node_id.value_namespace = name_space
                                    self.node_id.value_namespace_prefix = name_space_prefix


                        class BundleData(Entity):
                            """
                            Peer device bundle mLACP TLV counter information
                            
                            .. attribute:: bundle_name
                            
                            	Bundle name
                            	**type**\:  str
                            
                            .. attribute:: mlacp_tlv_counters
                            
                            	Counts of mLACP TLVs sent and received
                            	**type**\:   :py:class:`MlacpTlvCounters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.MlacpBundleCounters.IccpGroups.IccpGroup.IccpGroupItem.NodeData.BundleData.MlacpTlvCounters>`
                            
                            

                            """

                            _prefix = 'bundlemgr-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(BundleInformation.MlacpBundleCounters.IccpGroups.IccpGroup.IccpGroupItem.NodeData.BundleData, self).__init__()

                                self.yang_name = "bundle-data"
                                self.yang_parent_name = "node-data"

                                self.bundle_name = YLeaf(YType.str, "bundle-name")

                                self.mlacp_tlv_counters = BundleInformation.MlacpBundleCounters.IccpGroups.IccpGroup.IccpGroupItem.NodeData.BundleData.MlacpTlvCounters()
                                self.mlacp_tlv_counters.parent = self
                                self._children_name_map["mlacp_tlv_counters"] = "mlacp-tlv-counters"
                                self._children_yang_names.add("mlacp-tlv-counters")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("bundle_name") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(BundleInformation.MlacpBundleCounters.IccpGroups.IccpGroup.IccpGroupItem.NodeData.BundleData, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(BundleInformation.MlacpBundleCounters.IccpGroups.IccpGroup.IccpGroupItem.NodeData.BundleData, self).__setattr__(name, value)


                            class MlacpTlvCounters(Entity):
                                """
                                Counts of mLACP TLVs sent and received
                                
                                .. attribute:: last_time_cleared
                                
                                	Time in nsecs from boot when counters were last cleared (deprecated)
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: nanosecond
                                
                                .. attribute:: last_unexpected_event
                                
                                	Elapsed time in nsecs since last unexpected event
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: nanosecond
                                
                                .. attribute:: received_nak_tl_vs
                                
                                	Number of mLACP NAK TLVs received
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: received_priority_tl_vs
                                
                                	Number of mLACP priority TLVs received
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: received_sync_requests
                                
                                	Number of mLACP sync request TLVs received
                                	**type**\:   :py:class:`ReceivedSyncRequests <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.MlacpBundleCounters.IccpGroups.IccpGroup.IccpGroupItem.NodeData.BundleData.MlacpTlvCounters.ReceivedSyncRequests>`
                                
                                .. attribute:: sent_config_tl_vs
                                
                                	Number of mLACP config TLVs sent
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: sent_priority_tl_vs
                                
                                	Number of mLACP priority TLVs sent
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: sent_state_tl_vs
                                
                                	Number of mLACP state TLVs sent
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: time_since_cleared
                                
                                	Elapsed time in nsecs since counters were last cleared
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: nanosecond
                                
                                

                                """

                                _prefix = 'bundlemgr-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(BundleInformation.MlacpBundleCounters.IccpGroups.IccpGroup.IccpGroupItem.NodeData.BundleData.MlacpTlvCounters, self).__init__()

                                    self.yang_name = "mlacp-tlv-counters"
                                    self.yang_parent_name = "bundle-data"

                                    self.last_time_cleared = YLeaf(YType.uint64, "last-time-cleared")

                                    self.last_unexpected_event = YLeaf(YType.uint64, "last-unexpected-event")

                                    self.received_nak_tl_vs = YLeaf(YType.uint32, "received-nak-tl-vs")

                                    self.received_priority_tl_vs = YLeaf(YType.uint32, "received-priority-tl-vs")

                                    self.sent_config_tl_vs = YLeaf(YType.uint32, "sent-config-tl-vs")

                                    self.sent_priority_tl_vs = YLeaf(YType.uint32, "sent-priority-tl-vs")

                                    self.sent_state_tl_vs = YLeaf(YType.uint32, "sent-state-tl-vs")

                                    self.time_since_cleared = YLeaf(YType.uint64, "time-since-cleared")

                                    self.received_sync_requests = BundleInformation.MlacpBundleCounters.IccpGroups.IccpGroup.IccpGroupItem.NodeData.BundleData.MlacpTlvCounters.ReceivedSyncRequests()
                                    self.received_sync_requests.parent = self
                                    self._children_name_map["received_sync_requests"] = "received-sync-requests"
                                    self._children_yang_names.add("received-sync-requests")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("last_time_cleared",
                                                    "last_unexpected_event",
                                                    "received_nak_tl_vs",
                                                    "received_priority_tl_vs",
                                                    "sent_config_tl_vs",
                                                    "sent_priority_tl_vs",
                                                    "sent_state_tl_vs",
                                                    "time_since_cleared") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(BundleInformation.MlacpBundleCounters.IccpGroups.IccpGroup.IccpGroupItem.NodeData.BundleData.MlacpTlvCounters, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(BundleInformation.MlacpBundleCounters.IccpGroups.IccpGroup.IccpGroupItem.NodeData.BundleData.MlacpTlvCounters, self).__setattr__(name, value)


                                class ReceivedSyncRequests(Entity):
                                    """
                                    Number of mLACP sync request TLVs received
                                    
                                    .. attribute:: all_syncs
                                    
                                    	Total number of sync requests received
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: config_syncs
                                    
                                    	Number of config sync requests received
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: state_syncs
                                    
                                    	Number of state sync requests received
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'bundlemgr-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(BundleInformation.MlacpBundleCounters.IccpGroups.IccpGroup.IccpGroupItem.NodeData.BundleData.MlacpTlvCounters.ReceivedSyncRequests, self).__init__()

                                        self.yang_name = "received-sync-requests"
                                        self.yang_parent_name = "mlacp-tlv-counters"

                                        self.all_syncs = YLeaf(YType.uint32, "all-syncs")

                                        self.config_syncs = YLeaf(YType.uint32, "config-syncs")

                                        self.state_syncs = YLeaf(YType.uint32, "state-syncs")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("all_syncs",
                                                        "config_syncs",
                                                        "state_syncs") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(BundleInformation.MlacpBundleCounters.IccpGroups.IccpGroup.IccpGroupItem.NodeData.BundleData.MlacpTlvCounters.ReceivedSyncRequests, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(BundleInformation.MlacpBundleCounters.IccpGroups.IccpGroup.IccpGroupItem.NodeData.BundleData.MlacpTlvCounters.ReceivedSyncRequests, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.all_syncs.is_set or
                                            self.config_syncs.is_set or
                                            self.state_syncs.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.all_syncs.yfilter != YFilter.not_set or
                                            self.config_syncs.yfilter != YFilter.not_set or
                                            self.state_syncs.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "received-sync-requests" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.all_syncs.is_set or self.all_syncs.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.all_syncs.get_name_leafdata())
                                        if (self.config_syncs.is_set or self.config_syncs.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.config_syncs.get_name_leafdata())
                                        if (self.state_syncs.is_set or self.state_syncs.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.state_syncs.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "all-syncs" or name == "config-syncs" or name == "state-syncs"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "all-syncs"):
                                            self.all_syncs = value
                                            self.all_syncs.value_namespace = name_space
                                            self.all_syncs.value_namespace_prefix = name_space_prefix
                                        if(value_path == "config-syncs"):
                                            self.config_syncs = value
                                            self.config_syncs.value_namespace = name_space
                                            self.config_syncs.value_namespace_prefix = name_space_prefix
                                        if(value_path == "state-syncs"):
                                            self.state_syncs = value
                                            self.state_syncs.value_namespace = name_space
                                            self.state_syncs.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.last_time_cleared.is_set or
                                        self.last_unexpected_event.is_set or
                                        self.received_nak_tl_vs.is_set or
                                        self.received_priority_tl_vs.is_set or
                                        self.sent_config_tl_vs.is_set or
                                        self.sent_priority_tl_vs.is_set or
                                        self.sent_state_tl_vs.is_set or
                                        self.time_since_cleared.is_set or
                                        (self.received_sync_requests is not None and self.received_sync_requests.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.last_time_cleared.yfilter != YFilter.not_set or
                                        self.last_unexpected_event.yfilter != YFilter.not_set or
                                        self.received_nak_tl_vs.yfilter != YFilter.not_set or
                                        self.received_priority_tl_vs.yfilter != YFilter.not_set or
                                        self.sent_config_tl_vs.yfilter != YFilter.not_set or
                                        self.sent_priority_tl_vs.yfilter != YFilter.not_set or
                                        self.sent_state_tl_vs.yfilter != YFilter.not_set or
                                        self.time_since_cleared.yfilter != YFilter.not_set or
                                        (self.received_sync_requests is not None and self.received_sync_requests.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "mlacp-tlv-counters" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.last_time_cleared.is_set or self.last_time_cleared.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.last_time_cleared.get_name_leafdata())
                                    if (self.last_unexpected_event.is_set or self.last_unexpected_event.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.last_unexpected_event.get_name_leafdata())
                                    if (self.received_nak_tl_vs.is_set or self.received_nak_tl_vs.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.received_nak_tl_vs.get_name_leafdata())
                                    if (self.received_priority_tl_vs.is_set or self.received_priority_tl_vs.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.received_priority_tl_vs.get_name_leafdata())
                                    if (self.sent_config_tl_vs.is_set or self.sent_config_tl_vs.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.sent_config_tl_vs.get_name_leafdata())
                                    if (self.sent_priority_tl_vs.is_set or self.sent_priority_tl_vs.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.sent_priority_tl_vs.get_name_leafdata())
                                    if (self.sent_state_tl_vs.is_set or self.sent_state_tl_vs.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.sent_state_tl_vs.get_name_leafdata())
                                    if (self.time_since_cleared.is_set or self.time_since_cleared.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.time_since_cleared.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "received-sync-requests"):
                                        if (self.received_sync_requests is None):
                                            self.received_sync_requests = BundleInformation.MlacpBundleCounters.IccpGroups.IccpGroup.IccpGroupItem.NodeData.BundleData.MlacpTlvCounters.ReceivedSyncRequests()
                                            self.received_sync_requests.parent = self
                                            self._children_name_map["received_sync_requests"] = "received-sync-requests"
                                        return self.received_sync_requests

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "received-sync-requests" or name == "last-time-cleared" or name == "last-unexpected-event" or name == "received-nak-tl-vs" or name == "received-priority-tl-vs" or name == "sent-config-tl-vs" or name == "sent-priority-tl-vs" or name == "sent-state-tl-vs" or name == "time-since-cleared"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "last-time-cleared"):
                                        self.last_time_cleared = value
                                        self.last_time_cleared.value_namespace = name_space
                                        self.last_time_cleared.value_namespace_prefix = name_space_prefix
                                    if(value_path == "last-unexpected-event"):
                                        self.last_unexpected_event = value
                                        self.last_unexpected_event.value_namespace = name_space
                                        self.last_unexpected_event.value_namespace_prefix = name_space_prefix
                                    if(value_path == "received-nak-tl-vs"):
                                        self.received_nak_tl_vs = value
                                        self.received_nak_tl_vs.value_namespace = name_space
                                        self.received_nak_tl_vs.value_namespace_prefix = name_space_prefix
                                    if(value_path == "received-priority-tl-vs"):
                                        self.received_priority_tl_vs = value
                                        self.received_priority_tl_vs.value_namespace = name_space
                                        self.received_priority_tl_vs.value_namespace_prefix = name_space_prefix
                                    if(value_path == "sent-config-tl-vs"):
                                        self.sent_config_tl_vs = value
                                        self.sent_config_tl_vs.value_namespace = name_space
                                        self.sent_config_tl_vs.value_namespace_prefix = name_space_prefix
                                    if(value_path == "sent-priority-tl-vs"):
                                        self.sent_priority_tl_vs = value
                                        self.sent_priority_tl_vs.value_namespace = name_space
                                        self.sent_priority_tl_vs.value_namespace_prefix = name_space_prefix
                                    if(value_path == "sent-state-tl-vs"):
                                        self.sent_state_tl_vs = value
                                        self.sent_state_tl_vs.value_namespace = name_space
                                        self.sent_state_tl_vs.value_namespace_prefix = name_space_prefix
                                    if(value_path == "time-since-cleared"):
                                        self.time_since_cleared = value
                                        self.time_since_cleared.value_namespace = name_space
                                        self.time_since_cleared.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.bundle_name.is_set or
                                    (self.mlacp_tlv_counters is not None and self.mlacp_tlv_counters.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.bundle_name.yfilter != YFilter.not_set or
                                    (self.mlacp_tlv_counters is not None and self.mlacp_tlv_counters.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "bundle-data" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.bundle_name.is_set or self.bundle_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.bundle_name.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "mlacp-tlv-counters"):
                                    if (self.mlacp_tlv_counters is None):
                                        self.mlacp_tlv_counters = BundleInformation.MlacpBundleCounters.IccpGroups.IccpGroup.IccpGroupItem.NodeData.BundleData.MlacpTlvCounters()
                                        self.mlacp_tlv_counters.parent = self
                                        self._children_name_map["mlacp_tlv_counters"] = "mlacp-tlv-counters"
                                    return self.mlacp_tlv_counters

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "mlacp-tlv-counters" or name == "bundle-name"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "bundle-name"):
                                    self.bundle_name = value
                                    self.bundle_name.value_namespace = name_space
                                    self.bundle_name.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.bundle_data:
                                if (c.has_data()):
                                    return True
                            return (self.node_data is not None and self.node_data.has_data())

                        def has_operation(self):
                            for c in self.bundle_data:
                                if (c.has_operation()):
                                    return True
                            return (
                                self.yfilter != YFilter.not_set or
                                (self.node_data is not None and self.node_data.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "node-data" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "bundle-data"):
                                for c in self.bundle_data:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = BundleInformation.MlacpBundleCounters.IccpGroups.IccpGroup.IccpGroupItem.NodeData.BundleData()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.bundle_data.append(c)
                                return c

                            if (child_yang_name == "node-data"):
                                if (self.node_data is None):
                                    self.node_data = BundleInformation.MlacpBundleCounters.IccpGroups.IccpGroup.IccpGroupItem.NodeData.NodeData()
                                    self.node_data.parent = self
                                    self._children_name_map["node_data"] = "node-data"
                                return self.node_data

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "bundle-data" or name == "node-data"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass

                    def has_data(self):
                        for c in self.node_data:
                            if (c.has_data()):
                                return True
                        return (self.iccp_group_data is not None and self.iccp_group_data.has_data())

                    def has_operation(self):
                        for c in self.node_data:
                            if (c.has_operation()):
                                return True
                        return (
                            self.yfilter != YFilter.not_set or
                            (self.iccp_group_data is not None and self.iccp_group_data.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "iccp-group-item" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "iccp-group-data"):
                            if (self.iccp_group_data is None):
                                self.iccp_group_data = BundleInformation.MlacpBundleCounters.IccpGroups.IccpGroup.IccpGroupItem.IccpGroupData()
                                self.iccp_group_data.parent = self
                                self._children_name_map["iccp_group_data"] = "iccp-group-data"
                            return self.iccp_group_data

                        if (child_yang_name == "node-data"):
                            for c in self.node_data:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = BundleInformation.MlacpBundleCounters.IccpGroups.IccpGroup.IccpGroupItem.NodeData()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.node_data.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "iccp-group-data" or name == "node-data"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass

                def has_data(self):
                    return (
                        self.iccp_group.is_set or
                        (self.iccp_group_item is not None and self.iccp_group_item.has_data()))

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.iccp_group.yfilter != YFilter.not_set or
                        (self.iccp_group_item is not None and self.iccp_group_item.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "iccp-group" + "[iccp-group='" + self.iccp_group.get() + "']" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-bundlemgr-oper:bundle-information/mlacp-bundle-counters/iccp-groups/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.iccp_group.is_set or self.iccp_group.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.iccp_group.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "iccp-group-item"):
                        if (self.iccp_group_item is None):
                            self.iccp_group_item = BundleInformation.MlacpBundleCounters.IccpGroups.IccpGroup.IccpGroupItem()
                            self.iccp_group_item.parent = self
                            self._children_name_map["iccp_group_item"] = "iccp-group-item"
                        return self.iccp_group_item

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "iccp-group-item" or name == "iccp-group"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "iccp-group"):
                        self.iccp_group = value
                        self.iccp_group.value_namespace = name_space
                        self.iccp_group.value_namespace_prefix = name_space_prefix

            def has_data(self):
                for c in self.iccp_group:
                    if (c.has_data()):
                        return True
                return False

            def has_operation(self):
                for c in self.iccp_group:
                    if (c.has_operation()):
                        return True
                return self.yfilter != YFilter.not_set

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "iccp-groups" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-bundlemgr-oper:bundle-information/mlacp-bundle-counters/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "iccp-group"):
                    for c in self.iccp_group:
                        segment = c.get_segment_path()
                        if (segment_path == segment):
                            return c
                    c = BundleInformation.MlacpBundleCounters.IccpGroups.IccpGroup()
                    c.parent = self
                    local_reference_key = "ydk::seg::%s" % segment_path
                    self._local_refs[local_reference_key] = c
                    self.iccp_group.append(c)
                    return c

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "iccp-group"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                pass


        class Bundles(Entity):
            """
            Bundle interfaces with counters of mLACP events
            
            .. attribute:: bundle
            
            	Bundle interface
            	**type**\: list of    :py:class:`Bundle <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.MlacpBundleCounters.Bundles.Bundle>`
            
            

            """

            _prefix = 'bundlemgr-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(BundleInformation.MlacpBundleCounters.Bundles, self).__init__()

                self.yang_name = "bundles"
                self.yang_parent_name = "mlacp-bundle-counters"

                self.bundle = YList(self)

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in () and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(BundleInformation.MlacpBundleCounters.Bundles, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(BundleInformation.MlacpBundleCounters.Bundles, self).__setattr__(name, value)


            class Bundle(Entity):
                """
                Bundle interface
                
                .. attribute:: bundle_interface  <key>
                
                	Bundle interface
                	**type**\:  str
                
                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                
                .. attribute:: bundle_item
                
                	Data for this item
                	**type**\:   :py:class:`BundleItem <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.MlacpBundleCounters.Bundles.Bundle.BundleItem>`
                
                

                """

                _prefix = 'bundlemgr-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(BundleInformation.MlacpBundleCounters.Bundles.Bundle, self).__init__()

                    self.yang_name = "bundle"
                    self.yang_parent_name = "bundles"

                    self.bundle_interface = YLeaf(YType.str, "bundle-interface")

                    self.bundle_item = BundleInformation.MlacpBundleCounters.Bundles.Bundle.BundleItem()
                    self.bundle_item.parent = self
                    self._children_name_map["bundle_item"] = "bundle-item"
                    self._children_yang_names.add("bundle-item")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("bundle_interface") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(BundleInformation.MlacpBundleCounters.Bundles.Bundle, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(BundleInformation.MlacpBundleCounters.Bundles.Bundle, self).__setattr__(name, value)


                class BundleItem(Entity):
                    """
                    Data for this item
                    
                    .. attribute:: iccp_group
                    
                    	ICCP Group mLACP TLV counter information
                    	**type**\: list of    :py:class:`IccpGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.MlacpBundleCounters.Bundles.Bundle.BundleItem.IccpGroup>`
                    
                    

                    """

                    _prefix = 'bundlemgr-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(BundleInformation.MlacpBundleCounters.Bundles.Bundle.BundleItem, self).__init__()

                        self.yang_name = "bundle-item"
                        self.yang_parent_name = "bundle"

                        self.iccp_group = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(BundleInformation.MlacpBundleCounters.Bundles.Bundle.BundleItem, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(BundleInformation.MlacpBundleCounters.Bundles.Bundle.BundleItem, self).__setattr__(name, value)


                    class IccpGroup(Entity):
                        """
                        ICCP Group mLACP TLV counter information
                        
                        .. attribute:: iccp_group_data
                        
                        	ICCP Group mLACP TLV counter information
                        	**type**\:   :py:class:`IccpGroupData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.MlacpBundleCounters.Bundles.Bundle.BundleItem.IccpGroup.IccpGroupData>`
                        
                        .. attribute:: node_data
                        
                        	Peer device bundle mLACP counter information
                        	**type**\: list of    :py:class:`NodeData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.MlacpBundleCounters.Bundles.Bundle.BundleItem.IccpGroup.NodeData>`
                        
                        

                        """

                        _prefix = 'bundlemgr-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(BundleInformation.MlacpBundleCounters.Bundles.Bundle.BundleItem.IccpGroup, self).__init__()

                            self.yang_name = "iccp-group"
                            self.yang_parent_name = "bundle-item"

                            self.iccp_group_data = BundleInformation.MlacpBundleCounters.Bundles.Bundle.BundleItem.IccpGroup.IccpGroupData()
                            self.iccp_group_data.parent = self
                            self._children_name_map["iccp_group_data"] = "iccp-group-data"
                            self._children_yang_names.add("iccp-group-data")

                            self.node_data = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(BundleInformation.MlacpBundleCounters.Bundles.Bundle.BundleItem.IccpGroup, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(BundleInformation.MlacpBundleCounters.Bundles.Bundle.BundleItem.IccpGroup, self).__setattr__(name, value)


                        class IccpGroupData(Entity):
                            """
                            ICCP Group mLACP TLV counter information
                            
                            .. attribute:: bundle_data
                            
                            	Local device bundle mLACP counter information
                            	**type**\: list of    :py:class:`BundleData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.MlacpBundleCounters.Bundles.Bundle.BundleItem.IccpGroup.IccpGroupData.BundleData>`
                            
                            .. attribute:: iccp_group_id
                            
                            	ICCP Group ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: mlacp_sync_requests_on_all_local_bundles
                            
                            	Counts of mLACP sync request TLVs on all bundles
                            	**type**\:   :py:class:`MlacpSyncRequestsOnAllLocalBundles <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.MlacpBundleCounters.Bundles.Bundle.BundleItem.IccpGroup.IccpGroupData.MlacpSyncRequestsOnAllLocalBundles>`
                            
                            .. attribute:: mlacp_sync_requests_on_all_local_ports
                            
                            	Counts of mLACP sync request TLVs on all ports
                            	**type**\:   :py:class:`MlacpSyncRequestsOnAllLocalPorts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.MlacpBundleCounters.Bundles.Bundle.BundleItem.IccpGroup.IccpGroupData.MlacpSyncRequestsOnAllLocalPorts>`
                            
                            

                            """

                            _prefix = 'bundlemgr-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(BundleInformation.MlacpBundleCounters.Bundles.Bundle.BundleItem.IccpGroup.IccpGroupData, self).__init__()

                                self.yang_name = "iccp-group-data"
                                self.yang_parent_name = "iccp-group"

                                self.iccp_group_id = YLeaf(YType.uint32, "iccp-group-id")

                                self.mlacp_sync_requests_on_all_local_bundles = BundleInformation.MlacpBundleCounters.Bundles.Bundle.BundleItem.IccpGroup.IccpGroupData.MlacpSyncRequestsOnAllLocalBundles()
                                self.mlacp_sync_requests_on_all_local_bundles.parent = self
                                self._children_name_map["mlacp_sync_requests_on_all_local_bundles"] = "mlacp-sync-requests-on-all-local-bundles"
                                self._children_yang_names.add("mlacp-sync-requests-on-all-local-bundles")

                                self.mlacp_sync_requests_on_all_local_ports = BundleInformation.MlacpBundleCounters.Bundles.Bundle.BundleItem.IccpGroup.IccpGroupData.MlacpSyncRequestsOnAllLocalPorts()
                                self.mlacp_sync_requests_on_all_local_ports.parent = self
                                self._children_name_map["mlacp_sync_requests_on_all_local_ports"] = "mlacp-sync-requests-on-all-local-ports"
                                self._children_yang_names.add("mlacp-sync-requests-on-all-local-ports")

                                self.bundle_data = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("iccp_group_id") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(BundleInformation.MlacpBundleCounters.Bundles.Bundle.BundleItem.IccpGroup.IccpGroupData, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(BundleInformation.MlacpBundleCounters.Bundles.Bundle.BundleItem.IccpGroup.IccpGroupData, self).__setattr__(name, value)


                            class MlacpSyncRequestsOnAllLocalPorts(Entity):
                                """
                                Counts of mLACP sync request TLVs on all ports
                                
                                .. attribute:: last_time_cleared
                                
                                	Time in nsecs from boot when counters were last cleared (deprecated)
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: nanosecond
                                
                                .. attribute:: received_sync_requests
                                
                                	Number of mLACP sync request TLVs received
                                	**type**\:   :py:class:`ReceivedSyncRequests <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.MlacpBundleCounters.Bundles.Bundle.BundleItem.IccpGroup.IccpGroupData.MlacpSyncRequestsOnAllLocalPorts.ReceivedSyncRequests>`
                                
                                .. attribute:: time_since_cleared
                                
                                	Elapsed time in nsecs since counters were last cleared
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: nanosecond
                                
                                

                                """

                                _prefix = 'bundlemgr-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(BundleInformation.MlacpBundleCounters.Bundles.Bundle.BundleItem.IccpGroup.IccpGroupData.MlacpSyncRequestsOnAllLocalPorts, self).__init__()

                                    self.yang_name = "mlacp-sync-requests-on-all-local-ports"
                                    self.yang_parent_name = "iccp-group-data"

                                    self.last_time_cleared = YLeaf(YType.uint64, "last-time-cleared")

                                    self.time_since_cleared = YLeaf(YType.uint64, "time-since-cleared")

                                    self.received_sync_requests = BundleInformation.MlacpBundleCounters.Bundles.Bundle.BundleItem.IccpGroup.IccpGroupData.MlacpSyncRequestsOnAllLocalPorts.ReceivedSyncRequests()
                                    self.received_sync_requests.parent = self
                                    self._children_name_map["received_sync_requests"] = "received-sync-requests"
                                    self._children_yang_names.add("received-sync-requests")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("last_time_cleared",
                                                    "time_since_cleared") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(BundleInformation.MlacpBundleCounters.Bundles.Bundle.BundleItem.IccpGroup.IccpGroupData.MlacpSyncRequestsOnAllLocalPorts, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(BundleInformation.MlacpBundleCounters.Bundles.Bundle.BundleItem.IccpGroup.IccpGroupData.MlacpSyncRequestsOnAllLocalPorts, self).__setattr__(name, value)


                                class ReceivedSyncRequests(Entity):
                                    """
                                    Number of mLACP sync request TLVs received
                                    
                                    .. attribute:: all_syncs
                                    
                                    	Total number of sync requests received
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: config_syncs
                                    
                                    	Number of config sync requests received
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: state_syncs
                                    
                                    	Number of state sync requests received
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'bundlemgr-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(BundleInformation.MlacpBundleCounters.Bundles.Bundle.BundleItem.IccpGroup.IccpGroupData.MlacpSyncRequestsOnAllLocalPorts.ReceivedSyncRequests, self).__init__()

                                        self.yang_name = "received-sync-requests"
                                        self.yang_parent_name = "mlacp-sync-requests-on-all-local-ports"

                                        self.all_syncs = YLeaf(YType.uint32, "all-syncs")

                                        self.config_syncs = YLeaf(YType.uint32, "config-syncs")

                                        self.state_syncs = YLeaf(YType.uint32, "state-syncs")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("all_syncs",
                                                        "config_syncs",
                                                        "state_syncs") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(BundleInformation.MlacpBundleCounters.Bundles.Bundle.BundleItem.IccpGroup.IccpGroupData.MlacpSyncRequestsOnAllLocalPorts.ReceivedSyncRequests, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(BundleInformation.MlacpBundleCounters.Bundles.Bundle.BundleItem.IccpGroup.IccpGroupData.MlacpSyncRequestsOnAllLocalPorts.ReceivedSyncRequests, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.all_syncs.is_set or
                                            self.config_syncs.is_set or
                                            self.state_syncs.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.all_syncs.yfilter != YFilter.not_set or
                                            self.config_syncs.yfilter != YFilter.not_set or
                                            self.state_syncs.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "received-sync-requests" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.all_syncs.is_set or self.all_syncs.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.all_syncs.get_name_leafdata())
                                        if (self.config_syncs.is_set or self.config_syncs.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.config_syncs.get_name_leafdata())
                                        if (self.state_syncs.is_set or self.state_syncs.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.state_syncs.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "all-syncs" or name == "config-syncs" or name == "state-syncs"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "all-syncs"):
                                            self.all_syncs = value
                                            self.all_syncs.value_namespace = name_space
                                            self.all_syncs.value_namespace_prefix = name_space_prefix
                                        if(value_path == "config-syncs"):
                                            self.config_syncs = value
                                            self.config_syncs.value_namespace = name_space
                                            self.config_syncs.value_namespace_prefix = name_space_prefix
                                        if(value_path == "state-syncs"):
                                            self.state_syncs = value
                                            self.state_syncs.value_namespace = name_space
                                            self.state_syncs.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.last_time_cleared.is_set or
                                        self.time_since_cleared.is_set or
                                        (self.received_sync_requests is not None and self.received_sync_requests.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.last_time_cleared.yfilter != YFilter.not_set or
                                        self.time_since_cleared.yfilter != YFilter.not_set or
                                        (self.received_sync_requests is not None and self.received_sync_requests.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "mlacp-sync-requests-on-all-local-ports" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.last_time_cleared.is_set or self.last_time_cleared.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.last_time_cleared.get_name_leafdata())
                                    if (self.time_since_cleared.is_set or self.time_since_cleared.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.time_since_cleared.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "received-sync-requests"):
                                        if (self.received_sync_requests is None):
                                            self.received_sync_requests = BundleInformation.MlacpBundleCounters.Bundles.Bundle.BundleItem.IccpGroup.IccpGroupData.MlacpSyncRequestsOnAllLocalPorts.ReceivedSyncRequests()
                                            self.received_sync_requests.parent = self
                                            self._children_name_map["received_sync_requests"] = "received-sync-requests"
                                        return self.received_sync_requests

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "received-sync-requests" or name == "last-time-cleared" or name == "time-since-cleared"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "last-time-cleared"):
                                        self.last_time_cleared = value
                                        self.last_time_cleared.value_namespace = name_space
                                        self.last_time_cleared.value_namespace_prefix = name_space_prefix
                                    if(value_path == "time-since-cleared"):
                                        self.time_since_cleared = value
                                        self.time_since_cleared.value_namespace = name_space
                                        self.time_since_cleared.value_namespace_prefix = name_space_prefix


                            class MlacpSyncRequestsOnAllLocalBundles(Entity):
                                """
                                Counts of mLACP sync request TLVs on all bundles
                                
                                .. attribute:: last_time_cleared
                                
                                	Time in nsecs from boot when counters were last cleared (deprecated)
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: nanosecond
                                
                                .. attribute:: received_sync_requests
                                
                                	Number of mLACP sync request TLVs received
                                	**type**\:   :py:class:`ReceivedSyncRequests <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.MlacpBundleCounters.Bundles.Bundle.BundleItem.IccpGroup.IccpGroupData.MlacpSyncRequestsOnAllLocalBundles.ReceivedSyncRequests>`
                                
                                .. attribute:: time_since_cleared
                                
                                	Elapsed time in nsecs since counters were last cleared
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: nanosecond
                                
                                

                                """

                                _prefix = 'bundlemgr-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(BundleInformation.MlacpBundleCounters.Bundles.Bundle.BundleItem.IccpGroup.IccpGroupData.MlacpSyncRequestsOnAllLocalBundles, self).__init__()

                                    self.yang_name = "mlacp-sync-requests-on-all-local-bundles"
                                    self.yang_parent_name = "iccp-group-data"

                                    self.last_time_cleared = YLeaf(YType.uint64, "last-time-cleared")

                                    self.time_since_cleared = YLeaf(YType.uint64, "time-since-cleared")

                                    self.received_sync_requests = BundleInformation.MlacpBundleCounters.Bundles.Bundle.BundleItem.IccpGroup.IccpGroupData.MlacpSyncRequestsOnAllLocalBundles.ReceivedSyncRequests()
                                    self.received_sync_requests.parent = self
                                    self._children_name_map["received_sync_requests"] = "received-sync-requests"
                                    self._children_yang_names.add("received-sync-requests")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("last_time_cleared",
                                                    "time_since_cleared") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(BundleInformation.MlacpBundleCounters.Bundles.Bundle.BundleItem.IccpGroup.IccpGroupData.MlacpSyncRequestsOnAllLocalBundles, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(BundleInformation.MlacpBundleCounters.Bundles.Bundle.BundleItem.IccpGroup.IccpGroupData.MlacpSyncRequestsOnAllLocalBundles, self).__setattr__(name, value)


                                class ReceivedSyncRequests(Entity):
                                    """
                                    Number of mLACP sync request TLVs received
                                    
                                    .. attribute:: all_syncs
                                    
                                    	Total number of sync requests received
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: config_syncs
                                    
                                    	Number of config sync requests received
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: state_syncs
                                    
                                    	Number of state sync requests received
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'bundlemgr-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(BundleInformation.MlacpBundleCounters.Bundles.Bundle.BundleItem.IccpGroup.IccpGroupData.MlacpSyncRequestsOnAllLocalBundles.ReceivedSyncRequests, self).__init__()

                                        self.yang_name = "received-sync-requests"
                                        self.yang_parent_name = "mlacp-sync-requests-on-all-local-bundles"

                                        self.all_syncs = YLeaf(YType.uint32, "all-syncs")

                                        self.config_syncs = YLeaf(YType.uint32, "config-syncs")

                                        self.state_syncs = YLeaf(YType.uint32, "state-syncs")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("all_syncs",
                                                        "config_syncs",
                                                        "state_syncs") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(BundleInformation.MlacpBundleCounters.Bundles.Bundle.BundleItem.IccpGroup.IccpGroupData.MlacpSyncRequestsOnAllLocalBundles.ReceivedSyncRequests, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(BundleInformation.MlacpBundleCounters.Bundles.Bundle.BundleItem.IccpGroup.IccpGroupData.MlacpSyncRequestsOnAllLocalBundles.ReceivedSyncRequests, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.all_syncs.is_set or
                                            self.config_syncs.is_set or
                                            self.state_syncs.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.all_syncs.yfilter != YFilter.not_set or
                                            self.config_syncs.yfilter != YFilter.not_set or
                                            self.state_syncs.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "received-sync-requests" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.all_syncs.is_set or self.all_syncs.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.all_syncs.get_name_leafdata())
                                        if (self.config_syncs.is_set or self.config_syncs.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.config_syncs.get_name_leafdata())
                                        if (self.state_syncs.is_set or self.state_syncs.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.state_syncs.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "all-syncs" or name == "config-syncs" or name == "state-syncs"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "all-syncs"):
                                            self.all_syncs = value
                                            self.all_syncs.value_namespace = name_space
                                            self.all_syncs.value_namespace_prefix = name_space_prefix
                                        if(value_path == "config-syncs"):
                                            self.config_syncs = value
                                            self.config_syncs.value_namespace = name_space
                                            self.config_syncs.value_namespace_prefix = name_space_prefix
                                        if(value_path == "state-syncs"):
                                            self.state_syncs = value
                                            self.state_syncs.value_namespace = name_space
                                            self.state_syncs.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.last_time_cleared.is_set or
                                        self.time_since_cleared.is_set or
                                        (self.received_sync_requests is not None and self.received_sync_requests.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.last_time_cleared.yfilter != YFilter.not_set or
                                        self.time_since_cleared.yfilter != YFilter.not_set or
                                        (self.received_sync_requests is not None and self.received_sync_requests.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "mlacp-sync-requests-on-all-local-bundles" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.last_time_cleared.is_set or self.last_time_cleared.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.last_time_cleared.get_name_leafdata())
                                    if (self.time_since_cleared.is_set or self.time_since_cleared.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.time_since_cleared.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "received-sync-requests"):
                                        if (self.received_sync_requests is None):
                                            self.received_sync_requests = BundleInformation.MlacpBundleCounters.Bundles.Bundle.BundleItem.IccpGroup.IccpGroupData.MlacpSyncRequestsOnAllLocalBundles.ReceivedSyncRequests()
                                            self.received_sync_requests.parent = self
                                            self._children_name_map["received_sync_requests"] = "received-sync-requests"
                                        return self.received_sync_requests

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "received-sync-requests" or name == "last-time-cleared" or name == "time-since-cleared"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "last-time-cleared"):
                                        self.last_time_cleared = value
                                        self.last_time_cleared.value_namespace = name_space
                                        self.last_time_cleared.value_namespace_prefix = name_space_prefix
                                    if(value_path == "time-since-cleared"):
                                        self.time_since_cleared = value
                                        self.time_since_cleared.value_namespace = name_space
                                        self.time_since_cleared.value_namespace_prefix = name_space_prefix


                            class BundleData(Entity):
                                """
                                Local device bundle mLACP counter information
                                
                                .. attribute:: bundle_name
                                
                                	Bundle name
                                	**type**\:  str
                                
                                .. attribute:: mlacp_tlv_counters
                                
                                	Counts of mLACP TLVs sent and received
                                	**type**\:   :py:class:`MlacpTlvCounters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.MlacpBundleCounters.Bundles.Bundle.BundleItem.IccpGroup.IccpGroupData.BundleData.MlacpTlvCounters>`
                                
                                

                                """

                                _prefix = 'bundlemgr-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(BundleInformation.MlacpBundleCounters.Bundles.Bundle.BundleItem.IccpGroup.IccpGroupData.BundleData, self).__init__()

                                    self.yang_name = "bundle-data"
                                    self.yang_parent_name = "iccp-group-data"

                                    self.bundle_name = YLeaf(YType.str, "bundle-name")

                                    self.mlacp_tlv_counters = BundleInformation.MlacpBundleCounters.Bundles.Bundle.BundleItem.IccpGroup.IccpGroupData.BundleData.MlacpTlvCounters()
                                    self.mlacp_tlv_counters.parent = self
                                    self._children_name_map["mlacp_tlv_counters"] = "mlacp-tlv-counters"
                                    self._children_yang_names.add("mlacp-tlv-counters")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("bundle_name") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(BundleInformation.MlacpBundleCounters.Bundles.Bundle.BundleItem.IccpGroup.IccpGroupData.BundleData, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(BundleInformation.MlacpBundleCounters.Bundles.Bundle.BundleItem.IccpGroup.IccpGroupData.BundleData, self).__setattr__(name, value)


                                class MlacpTlvCounters(Entity):
                                    """
                                    Counts of mLACP TLVs sent and received
                                    
                                    .. attribute:: last_time_cleared
                                    
                                    	Time in nsecs from boot when counters were last cleared (deprecated)
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: nanosecond
                                    
                                    .. attribute:: last_unexpected_event
                                    
                                    	Elapsed time in nsecs since last unexpected event
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: nanosecond
                                    
                                    .. attribute:: received_nak_tl_vs
                                    
                                    	Number of mLACP NAK TLVs received
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: received_priority_tl_vs
                                    
                                    	Number of mLACP priority TLVs received
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: received_sync_requests
                                    
                                    	Number of mLACP sync request TLVs received
                                    	**type**\:   :py:class:`ReceivedSyncRequests <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.MlacpBundleCounters.Bundles.Bundle.BundleItem.IccpGroup.IccpGroupData.BundleData.MlacpTlvCounters.ReceivedSyncRequests>`
                                    
                                    .. attribute:: sent_config_tl_vs
                                    
                                    	Number of mLACP config TLVs sent
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: sent_priority_tl_vs
                                    
                                    	Number of mLACP priority TLVs sent
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: sent_state_tl_vs
                                    
                                    	Number of mLACP state TLVs sent
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: time_since_cleared
                                    
                                    	Elapsed time in nsecs since counters were last cleared
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: nanosecond
                                    
                                    

                                    """

                                    _prefix = 'bundlemgr-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(BundleInformation.MlacpBundleCounters.Bundles.Bundle.BundleItem.IccpGroup.IccpGroupData.BundleData.MlacpTlvCounters, self).__init__()

                                        self.yang_name = "mlacp-tlv-counters"
                                        self.yang_parent_name = "bundle-data"

                                        self.last_time_cleared = YLeaf(YType.uint64, "last-time-cleared")

                                        self.last_unexpected_event = YLeaf(YType.uint64, "last-unexpected-event")

                                        self.received_nak_tl_vs = YLeaf(YType.uint32, "received-nak-tl-vs")

                                        self.received_priority_tl_vs = YLeaf(YType.uint32, "received-priority-tl-vs")

                                        self.sent_config_tl_vs = YLeaf(YType.uint32, "sent-config-tl-vs")

                                        self.sent_priority_tl_vs = YLeaf(YType.uint32, "sent-priority-tl-vs")

                                        self.sent_state_tl_vs = YLeaf(YType.uint32, "sent-state-tl-vs")

                                        self.time_since_cleared = YLeaf(YType.uint64, "time-since-cleared")

                                        self.received_sync_requests = BundleInformation.MlacpBundleCounters.Bundles.Bundle.BundleItem.IccpGroup.IccpGroupData.BundleData.MlacpTlvCounters.ReceivedSyncRequests()
                                        self.received_sync_requests.parent = self
                                        self._children_name_map["received_sync_requests"] = "received-sync-requests"
                                        self._children_yang_names.add("received-sync-requests")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("last_time_cleared",
                                                        "last_unexpected_event",
                                                        "received_nak_tl_vs",
                                                        "received_priority_tl_vs",
                                                        "sent_config_tl_vs",
                                                        "sent_priority_tl_vs",
                                                        "sent_state_tl_vs",
                                                        "time_since_cleared") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(BundleInformation.MlacpBundleCounters.Bundles.Bundle.BundleItem.IccpGroup.IccpGroupData.BundleData.MlacpTlvCounters, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(BundleInformation.MlacpBundleCounters.Bundles.Bundle.BundleItem.IccpGroup.IccpGroupData.BundleData.MlacpTlvCounters, self).__setattr__(name, value)


                                    class ReceivedSyncRequests(Entity):
                                        """
                                        Number of mLACP sync request TLVs received
                                        
                                        .. attribute:: all_syncs
                                        
                                        	Total number of sync requests received
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: config_syncs
                                        
                                        	Number of config sync requests received
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: state_syncs
                                        
                                        	Number of state sync requests received
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'bundlemgr-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(BundleInformation.MlacpBundleCounters.Bundles.Bundle.BundleItem.IccpGroup.IccpGroupData.BundleData.MlacpTlvCounters.ReceivedSyncRequests, self).__init__()

                                            self.yang_name = "received-sync-requests"
                                            self.yang_parent_name = "mlacp-tlv-counters"

                                            self.all_syncs = YLeaf(YType.uint32, "all-syncs")

                                            self.config_syncs = YLeaf(YType.uint32, "config-syncs")

                                            self.state_syncs = YLeaf(YType.uint32, "state-syncs")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("all_syncs",
                                                            "config_syncs",
                                                            "state_syncs") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(BundleInformation.MlacpBundleCounters.Bundles.Bundle.BundleItem.IccpGroup.IccpGroupData.BundleData.MlacpTlvCounters.ReceivedSyncRequests, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(BundleInformation.MlacpBundleCounters.Bundles.Bundle.BundleItem.IccpGroup.IccpGroupData.BundleData.MlacpTlvCounters.ReceivedSyncRequests, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.all_syncs.is_set or
                                                self.config_syncs.is_set or
                                                self.state_syncs.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.all_syncs.yfilter != YFilter.not_set or
                                                self.config_syncs.yfilter != YFilter.not_set or
                                                self.state_syncs.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "received-sync-requests" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.all_syncs.is_set or self.all_syncs.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.all_syncs.get_name_leafdata())
                                            if (self.config_syncs.is_set or self.config_syncs.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.config_syncs.get_name_leafdata())
                                            if (self.state_syncs.is_set or self.state_syncs.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.state_syncs.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "all-syncs" or name == "config-syncs" or name == "state-syncs"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "all-syncs"):
                                                self.all_syncs = value
                                                self.all_syncs.value_namespace = name_space
                                                self.all_syncs.value_namespace_prefix = name_space_prefix
                                            if(value_path == "config-syncs"):
                                                self.config_syncs = value
                                                self.config_syncs.value_namespace = name_space
                                                self.config_syncs.value_namespace_prefix = name_space_prefix
                                            if(value_path == "state-syncs"):
                                                self.state_syncs = value
                                                self.state_syncs.value_namespace = name_space
                                                self.state_syncs.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.last_time_cleared.is_set or
                                            self.last_unexpected_event.is_set or
                                            self.received_nak_tl_vs.is_set or
                                            self.received_priority_tl_vs.is_set or
                                            self.sent_config_tl_vs.is_set or
                                            self.sent_priority_tl_vs.is_set or
                                            self.sent_state_tl_vs.is_set or
                                            self.time_since_cleared.is_set or
                                            (self.received_sync_requests is not None and self.received_sync_requests.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.last_time_cleared.yfilter != YFilter.not_set or
                                            self.last_unexpected_event.yfilter != YFilter.not_set or
                                            self.received_nak_tl_vs.yfilter != YFilter.not_set or
                                            self.received_priority_tl_vs.yfilter != YFilter.not_set or
                                            self.sent_config_tl_vs.yfilter != YFilter.not_set or
                                            self.sent_priority_tl_vs.yfilter != YFilter.not_set or
                                            self.sent_state_tl_vs.yfilter != YFilter.not_set or
                                            self.time_since_cleared.yfilter != YFilter.not_set or
                                            (self.received_sync_requests is not None and self.received_sync_requests.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "mlacp-tlv-counters" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.last_time_cleared.is_set or self.last_time_cleared.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.last_time_cleared.get_name_leafdata())
                                        if (self.last_unexpected_event.is_set or self.last_unexpected_event.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.last_unexpected_event.get_name_leafdata())
                                        if (self.received_nak_tl_vs.is_set or self.received_nak_tl_vs.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.received_nak_tl_vs.get_name_leafdata())
                                        if (self.received_priority_tl_vs.is_set or self.received_priority_tl_vs.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.received_priority_tl_vs.get_name_leafdata())
                                        if (self.sent_config_tl_vs.is_set or self.sent_config_tl_vs.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.sent_config_tl_vs.get_name_leafdata())
                                        if (self.sent_priority_tl_vs.is_set or self.sent_priority_tl_vs.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.sent_priority_tl_vs.get_name_leafdata())
                                        if (self.sent_state_tl_vs.is_set or self.sent_state_tl_vs.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.sent_state_tl_vs.get_name_leafdata())
                                        if (self.time_since_cleared.is_set or self.time_since_cleared.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.time_since_cleared.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "received-sync-requests"):
                                            if (self.received_sync_requests is None):
                                                self.received_sync_requests = BundleInformation.MlacpBundleCounters.Bundles.Bundle.BundleItem.IccpGroup.IccpGroupData.BundleData.MlacpTlvCounters.ReceivedSyncRequests()
                                                self.received_sync_requests.parent = self
                                                self._children_name_map["received_sync_requests"] = "received-sync-requests"
                                            return self.received_sync_requests

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "received-sync-requests" or name == "last-time-cleared" or name == "last-unexpected-event" or name == "received-nak-tl-vs" or name == "received-priority-tl-vs" or name == "sent-config-tl-vs" or name == "sent-priority-tl-vs" or name == "sent-state-tl-vs" or name == "time-since-cleared"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "last-time-cleared"):
                                            self.last_time_cleared = value
                                            self.last_time_cleared.value_namespace = name_space
                                            self.last_time_cleared.value_namespace_prefix = name_space_prefix
                                        if(value_path == "last-unexpected-event"):
                                            self.last_unexpected_event = value
                                            self.last_unexpected_event.value_namespace = name_space
                                            self.last_unexpected_event.value_namespace_prefix = name_space_prefix
                                        if(value_path == "received-nak-tl-vs"):
                                            self.received_nak_tl_vs = value
                                            self.received_nak_tl_vs.value_namespace = name_space
                                            self.received_nak_tl_vs.value_namespace_prefix = name_space_prefix
                                        if(value_path == "received-priority-tl-vs"):
                                            self.received_priority_tl_vs = value
                                            self.received_priority_tl_vs.value_namespace = name_space
                                            self.received_priority_tl_vs.value_namespace_prefix = name_space_prefix
                                        if(value_path == "sent-config-tl-vs"):
                                            self.sent_config_tl_vs = value
                                            self.sent_config_tl_vs.value_namespace = name_space
                                            self.sent_config_tl_vs.value_namespace_prefix = name_space_prefix
                                        if(value_path == "sent-priority-tl-vs"):
                                            self.sent_priority_tl_vs = value
                                            self.sent_priority_tl_vs.value_namespace = name_space
                                            self.sent_priority_tl_vs.value_namespace_prefix = name_space_prefix
                                        if(value_path == "sent-state-tl-vs"):
                                            self.sent_state_tl_vs = value
                                            self.sent_state_tl_vs.value_namespace = name_space
                                            self.sent_state_tl_vs.value_namespace_prefix = name_space_prefix
                                        if(value_path == "time-since-cleared"):
                                            self.time_since_cleared = value
                                            self.time_since_cleared.value_namespace = name_space
                                            self.time_since_cleared.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.bundle_name.is_set or
                                        (self.mlacp_tlv_counters is not None and self.mlacp_tlv_counters.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.bundle_name.yfilter != YFilter.not_set or
                                        (self.mlacp_tlv_counters is not None and self.mlacp_tlv_counters.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "bundle-data" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.bundle_name.is_set or self.bundle_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.bundle_name.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "mlacp-tlv-counters"):
                                        if (self.mlacp_tlv_counters is None):
                                            self.mlacp_tlv_counters = BundleInformation.MlacpBundleCounters.Bundles.Bundle.BundleItem.IccpGroup.IccpGroupData.BundleData.MlacpTlvCounters()
                                            self.mlacp_tlv_counters.parent = self
                                            self._children_name_map["mlacp_tlv_counters"] = "mlacp-tlv-counters"
                                        return self.mlacp_tlv_counters

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "mlacp-tlv-counters" or name == "bundle-name"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "bundle-name"):
                                        self.bundle_name = value
                                        self.bundle_name.value_namespace = name_space
                                        self.bundle_name.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.bundle_data:
                                    if (c.has_data()):
                                        return True
                                return (
                                    self.iccp_group_id.is_set or
                                    (self.mlacp_sync_requests_on_all_local_bundles is not None and self.mlacp_sync_requests_on_all_local_bundles.has_data()) or
                                    (self.mlacp_sync_requests_on_all_local_ports is not None and self.mlacp_sync_requests_on_all_local_ports.has_data()))

                            def has_operation(self):
                                for c in self.bundle_data:
                                    if (c.has_operation()):
                                        return True
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.iccp_group_id.yfilter != YFilter.not_set or
                                    (self.mlacp_sync_requests_on_all_local_bundles is not None and self.mlacp_sync_requests_on_all_local_bundles.has_operation()) or
                                    (self.mlacp_sync_requests_on_all_local_ports is not None and self.mlacp_sync_requests_on_all_local_ports.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "iccp-group-data" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.iccp_group_id.is_set or self.iccp_group_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.iccp_group_id.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "bundle-data"):
                                    for c in self.bundle_data:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = BundleInformation.MlacpBundleCounters.Bundles.Bundle.BundleItem.IccpGroup.IccpGroupData.BundleData()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.bundle_data.append(c)
                                    return c

                                if (child_yang_name == "mlacp-sync-requests-on-all-local-bundles"):
                                    if (self.mlacp_sync_requests_on_all_local_bundles is None):
                                        self.mlacp_sync_requests_on_all_local_bundles = BundleInformation.MlacpBundleCounters.Bundles.Bundle.BundleItem.IccpGroup.IccpGroupData.MlacpSyncRequestsOnAllLocalBundles()
                                        self.mlacp_sync_requests_on_all_local_bundles.parent = self
                                        self._children_name_map["mlacp_sync_requests_on_all_local_bundles"] = "mlacp-sync-requests-on-all-local-bundles"
                                    return self.mlacp_sync_requests_on_all_local_bundles

                                if (child_yang_name == "mlacp-sync-requests-on-all-local-ports"):
                                    if (self.mlacp_sync_requests_on_all_local_ports is None):
                                        self.mlacp_sync_requests_on_all_local_ports = BundleInformation.MlacpBundleCounters.Bundles.Bundle.BundleItem.IccpGroup.IccpGroupData.MlacpSyncRequestsOnAllLocalPorts()
                                        self.mlacp_sync_requests_on_all_local_ports.parent = self
                                        self._children_name_map["mlacp_sync_requests_on_all_local_ports"] = "mlacp-sync-requests-on-all-local-ports"
                                    return self.mlacp_sync_requests_on_all_local_ports

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "bundle-data" or name == "mlacp-sync-requests-on-all-local-bundles" or name == "mlacp-sync-requests-on-all-local-ports" or name == "iccp-group-id"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "iccp-group-id"):
                                    self.iccp_group_id = value
                                    self.iccp_group_id.value_namespace = name_space
                                    self.iccp_group_id.value_namespace_prefix = name_space_prefix


                        class NodeData(Entity):
                            """
                            Peer device bundle mLACP counter information
                            
                            .. attribute:: bundle_data
                            
                            	Peer device bundle mLACP TLV counter information
                            	**type**\: list of    :py:class:`BundleData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.MlacpBundleCounters.Bundles.Bundle.BundleItem.IccpGroup.NodeData.BundleData>`
                            
                            .. attribute:: node_data
                            
                            	Peer device mLACP TLV counter information
                            	**type**\:   :py:class:`NodeData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.MlacpBundleCounters.Bundles.Bundle.BundleItem.IccpGroup.NodeData.NodeData>`
                            
                            

                            """

                            _prefix = 'bundlemgr-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(BundleInformation.MlacpBundleCounters.Bundles.Bundle.BundleItem.IccpGroup.NodeData, self).__init__()

                                self.yang_name = "node-data"
                                self.yang_parent_name = "iccp-group"

                                self.node_data = BundleInformation.MlacpBundleCounters.Bundles.Bundle.BundleItem.IccpGroup.NodeData.NodeData()
                                self.node_data.parent = self
                                self._children_name_map["node_data"] = "node-data"
                                self._children_yang_names.add("node-data")

                                self.bundle_data = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in () and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(BundleInformation.MlacpBundleCounters.Bundles.Bundle.BundleItem.IccpGroup.NodeData, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(BundleInformation.MlacpBundleCounters.Bundles.Bundle.BundleItem.IccpGroup.NodeData, self).__setattr__(name, value)


                            class NodeData(Entity):
                                """
                                Peer device mLACP TLV counter information
                                
                                .. attribute:: mlacp_sync_requests_on_all_foreign_bundles
                                
                                	Counts of mLACP sync request TLVs on all bundles
                                	**type**\:   :py:class:`MlacpSyncRequestsOnAllForeignBundles <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.MlacpBundleCounters.Bundles.Bundle.BundleItem.IccpGroup.NodeData.NodeData.MlacpSyncRequestsOnAllForeignBundles>`
                                
                                .. attribute:: mlacp_sync_requests_on_all_foreign_ports
                                
                                	Counts of mLACP sync request TLVs on all ports
                                	**type**\:   :py:class:`MlacpSyncRequestsOnAllForeignPorts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.MlacpBundleCounters.Bundles.Bundle.BundleItem.IccpGroup.NodeData.NodeData.MlacpSyncRequestsOnAllForeignPorts>`
                                
                                .. attribute:: node_id
                                
                                	Device ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'bundlemgr-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(BundleInformation.MlacpBundleCounters.Bundles.Bundle.BundleItem.IccpGroup.NodeData.NodeData, self).__init__()

                                    self.yang_name = "node-data"
                                    self.yang_parent_name = "node-data"

                                    self.node_id = YLeaf(YType.uint32, "node-id")

                                    self.mlacp_sync_requests_on_all_foreign_bundles = BundleInformation.MlacpBundleCounters.Bundles.Bundle.BundleItem.IccpGroup.NodeData.NodeData.MlacpSyncRequestsOnAllForeignBundles()
                                    self.mlacp_sync_requests_on_all_foreign_bundles.parent = self
                                    self._children_name_map["mlacp_sync_requests_on_all_foreign_bundles"] = "mlacp-sync-requests-on-all-foreign-bundles"
                                    self._children_yang_names.add("mlacp-sync-requests-on-all-foreign-bundles")

                                    self.mlacp_sync_requests_on_all_foreign_ports = BundleInformation.MlacpBundleCounters.Bundles.Bundle.BundleItem.IccpGroup.NodeData.NodeData.MlacpSyncRequestsOnAllForeignPorts()
                                    self.mlacp_sync_requests_on_all_foreign_ports.parent = self
                                    self._children_name_map["mlacp_sync_requests_on_all_foreign_ports"] = "mlacp-sync-requests-on-all-foreign-ports"
                                    self._children_yang_names.add("mlacp-sync-requests-on-all-foreign-ports")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("node_id") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(BundleInformation.MlacpBundleCounters.Bundles.Bundle.BundleItem.IccpGroup.NodeData.NodeData, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(BundleInformation.MlacpBundleCounters.Bundles.Bundle.BundleItem.IccpGroup.NodeData.NodeData, self).__setattr__(name, value)


                                class MlacpSyncRequestsOnAllForeignPorts(Entity):
                                    """
                                    Counts of mLACP sync request TLVs on all ports
                                    
                                    .. attribute:: last_time_cleared
                                    
                                    	Time in nsecs from boot when counters were last cleared (deprecated)
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: nanosecond
                                    
                                    .. attribute:: received_sync_requests
                                    
                                    	Number of mLACP sync request TLVs received
                                    	**type**\:   :py:class:`ReceivedSyncRequests <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.MlacpBundleCounters.Bundles.Bundle.BundleItem.IccpGroup.NodeData.NodeData.MlacpSyncRequestsOnAllForeignPorts.ReceivedSyncRequests>`
                                    
                                    .. attribute:: time_since_cleared
                                    
                                    	Elapsed time in nsecs since counters were last cleared
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: nanosecond
                                    
                                    

                                    """

                                    _prefix = 'bundlemgr-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(BundleInformation.MlacpBundleCounters.Bundles.Bundle.BundleItem.IccpGroup.NodeData.NodeData.MlacpSyncRequestsOnAllForeignPorts, self).__init__()

                                        self.yang_name = "mlacp-sync-requests-on-all-foreign-ports"
                                        self.yang_parent_name = "node-data"

                                        self.last_time_cleared = YLeaf(YType.uint64, "last-time-cleared")

                                        self.time_since_cleared = YLeaf(YType.uint64, "time-since-cleared")

                                        self.received_sync_requests = BundleInformation.MlacpBundleCounters.Bundles.Bundle.BundleItem.IccpGroup.NodeData.NodeData.MlacpSyncRequestsOnAllForeignPorts.ReceivedSyncRequests()
                                        self.received_sync_requests.parent = self
                                        self._children_name_map["received_sync_requests"] = "received-sync-requests"
                                        self._children_yang_names.add("received-sync-requests")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("last_time_cleared",
                                                        "time_since_cleared") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(BundleInformation.MlacpBundleCounters.Bundles.Bundle.BundleItem.IccpGroup.NodeData.NodeData.MlacpSyncRequestsOnAllForeignPorts, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(BundleInformation.MlacpBundleCounters.Bundles.Bundle.BundleItem.IccpGroup.NodeData.NodeData.MlacpSyncRequestsOnAllForeignPorts, self).__setattr__(name, value)


                                    class ReceivedSyncRequests(Entity):
                                        """
                                        Number of mLACP sync request TLVs received
                                        
                                        .. attribute:: all_syncs
                                        
                                        	Total number of sync requests received
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: config_syncs
                                        
                                        	Number of config sync requests received
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: state_syncs
                                        
                                        	Number of state sync requests received
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'bundlemgr-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(BundleInformation.MlacpBundleCounters.Bundles.Bundle.BundleItem.IccpGroup.NodeData.NodeData.MlacpSyncRequestsOnAllForeignPorts.ReceivedSyncRequests, self).__init__()

                                            self.yang_name = "received-sync-requests"
                                            self.yang_parent_name = "mlacp-sync-requests-on-all-foreign-ports"

                                            self.all_syncs = YLeaf(YType.uint32, "all-syncs")

                                            self.config_syncs = YLeaf(YType.uint32, "config-syncs")

                                            self.state_syncs = YLeaf(YType.uint32, "state-syncs")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("all_syncs",
                                                            "config_syncs",
                                                            "state_syncs") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(BundleInformation.MlacpBundleCounters.Bundles.Bundle.BundleItem.IccpGroup.NodeData.NodeData.MlacpSyncRequestsOnAllForeignPorts.ReceivedSyncRequests, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(BundleInformation.MlacpBundleCounters.Bundles.Bundle.BundleItem.IccpGroup.NodeData.NodeData.MlacpSyncRequestsOnAllForeignPorts.ReceivedSyncRequests, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.all_syncs.is_set or
                                                self.config_syncs.is_set or
                                                self.state_syncs.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.all_syncs.yfilter != YFilter.not_set or
                                                self.config_syncs.yfilter != YFilter.not_set or
                                                self.state_syncs.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "received-sync-requests" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.all_syncs.is_set or self.all_syncs.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.all_syncs.get_name_leafdata())
                                            if (self.config_syncs.is_set or self.config_syncs.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.config_syncs.get_name_leafdata())
                                            if (self.state_syncs.is_set or self.state_syncs.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.state_syncs.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "all-syncs" or name == "config-syncs" or name == "state-syncs"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "all-syncs"):
                                                self.all_syncs = value
                                                self.all_syncs.value_namespace = name_space
                                                self.all_syncs.value_namespace_prefix = name_space_prefix
                                            if(value_path == "config-syncs"):
                                                self.config_syncs = value
                                                self.config_syncs.value_namespace = name_space
                                                self.config_syncs.value_namespace_prefix = name_space_prefix
                                            if(value_path == "state-syncs"):
                                                self.state_syncs = value
                                                self.state_syncs.value_namespace = name_space
                                                self.state_syncs.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.last_time_cleared.is_set or
                                            self.time_since_cleared.is_set or
                                            (self.received_sync_requests is not None and self.received_sync_requests.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.last_time_cleared.yfilter != YFilter.not_set or
                                            self.time_since_cleared.yfilter != YFilter.not_set or
                                            (self.received_sync_requests is not None and self.received_sync_requests.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "mlacp-sync-requests-on-all-foreign-ports" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.last_time_cleared.is_set or self.last_time_cleared.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.last_time_cleared.get_name_leafdata())
                                        if (self.time_since_cleared.is_set or self.time_since_cleared.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.time_since_cleared.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "received-sync-requests"):
                                            if (self.received_sync_requests is None):
                                                self.received_sync_requests = BundleInformation.MlacpBundleCounters.Bundles.Bundle.BundleItem.IccpGroup.NodeData.NodeData.MlacpSyncRequestsOnAllForeignPorts.ReceivedSyncRequests()
                                                self.received_sync_requests.parent = self
                                                self._children_name_map["received_sync_requests"] = "received-sync-requests"
                                            return self.received_sync_requests

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "received-sync-requests" or name == "last-time-cleared" or name == "time-since-cleared"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "last-time-cleared"):
                                            self.last_time_cleared = value
                                            self.last_time_cleared.value_namespace = name_space
                                            self.last_time_cleared.value_namespace_prefix = name_space_prefix
                                        if(value_path == "time-since-cleared"):
                                            self.time_since_cleared = value
                                            self.time_since_cleared.value_namespace = name_space
                                            self.time_since_cleared.value_namespace_prefix = name_space_prefix


                                class MlacpSyncRequestsOnAllForeignBundles(Entity):
                                    """
                                    Counts of mLACP sync request TLVs on all bundles
                                    
                                    .. attribute:: last_time_cleared
                                    
                                    	Time in nsecs from boot when counters were last cleared (deprecated)
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: nanosecond
                                    
                                    .. attribute:: received_sync_requests
                                    
                                    	Number of mLACP sync request TLVs received
                                    	**type**\:   :py:class:`ReceivedSyncRequests <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.MlacpBundleCounters.Bundles.Bundle.BundleItem.IccpGroup.NodeData.NodeData.MlacpSyncRequestsOnAllForeignBundles.ReceivedSyncRequests>`
                                    
                                    .. attribute:: time_since_cleared
                                    
                                    	Elapsed time in nsecs since counters were last cleared
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: nanosecond
                                    
                                    

                                    """

                                    _prefix = 'bundlemgr-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(BundleInformation.MlacpBundleCounters.Bundles.Bundle.BundleItem.IccpGroup.NodeData.NodeData.MlacpSyncRequestsOnAllForeignBundles, self).__init__()

                                        self.yang_name = "mlacp-sync-requests-on-all-foreign-bundles"
                                        self.yang_parent_name = "node-data"

                                        self.last_time_cleared = YLeaf(YType.uint64, "last-time-cleared")

                                        self.time_since_cleared = YLeaf(YType.uint64, "time-since-cleared")

                                        self.received_sync_requests = BundleInformation.MlacpBundleCounters.Bundles.Bundle.BundleItem.IccpGroup.NodeData.NodeData.MlacpSyncRequestsOnAllForeignBundles.ReceivedSyncRequests()
                                        self.received_sync_requests.parent = self
                                        self._children_name_map["received_sync_requests"] = "received-sync-requests"
                                        self._children_yang_names.add("received-sync-requests")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("last_time_cleared",
                                                        "time_since_cleared") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(BundleInformation.MlacpBundleCounters.Bundles.Bundle.BundleItem.IccpGroup.NodeData.NodeData.MlacpSyncRequestsOnAllForeignBundles, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(BundleInformation.MlacpBundleCounters.Bundles.Bundle.BundleItem.IccpGroup.NodeData.NodeData.MlacpSyncRequestsOnAllForeignBundles, self).__setattr__(name, value)


                                    class ReceivedSyncRequests(Entity):
                                        """
                                        Number of mLACP sync request TLVs received
                                        
                                        .. attribute:: all_syncs
                                        
                                        	Total number of sync requests received
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: config_syncs
                                        
                                        	Number of config sync requests received
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: state_syncs
                                        
                                        	Number of state sync requests received
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'bundlemgr-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(BundleInformation.MlacpBundleCounters.Bundles.Bundle.BundleItem.IccpGroup.NodeData.NodeData.MlacpSyncRequestsOnAllForeignBundles.ReceivedSyncRequests, self).__init__()

                                            self.yang_name = "received-sync-requests"
                                            self.yang_parent_name = "mlacp-sync-requests-on-all-foreign-bundles"

                                            self.all_syncs = YLeaf(YType.uint32, "all-syncs")

                                            self.config_syncs = YLeaf(YType.uint32, "config-syncs")

                                            self.state_syncs = YLeaf(YType.uint32, "state-syncs")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("all_syncs",
                                                            "config_syncs",
                                                            "state_syncs") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(BundleInformation.MlacpBundleCounters.Bundles.Bundle.BundleItem.IccpGroup.NodeData.NodeData.MlacpSyncRequestsOnAllForeignBundles.ReceivedSyncRequests, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(BundleInformation.MlacpBundleCounters.Bundles.Bundle.BundleItem.IccpGroup.NodeData.NodeData.MlacpSyncRequestsOnAllForeignBundles.ReceivedSyncRequests, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.all_syncs.is_set or
                                                self.config_syncs.is_set or
                                                self.state_syncs.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.all_syncs.yfilter != YFilter.not_set or
                                                self.config_syncs.yfilter != YFilter.not_set or
                                                self.state_syncs.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "received-sync-requests" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.all_syncs.is_set or self.all_syncs.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.all_syncs.get_name_leafdata())
                                            if (self.config_syncs.is_set or self.config_syncs.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.config_syncs.get_name_leafdata())
                                            if (self.state_syncs.is_set or self.state_syncs.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.state_syncs.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "all-syncs" or name == "config-syncs" or name == "state-syncs"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "all-syncs"):
                                                self.all_syncs = value
                                                self.all_syncs.value_namespace = name_space
                                                self.all_syncs.value_namespace_prefix = name_space_prefix
                                            if(value_path == "config-syncs"):
                                                self.config_syncs = value
                                                self.config_syncs.value_namespace = name_space
                                                self.config_syncs.value_namespace_prefix = name_space_prefix
                                            if(value_path == "state-syncs"):
                                                self.state_syncs = value
                                                self.state_syncs.value_namespace = name_space
                                                self.state_syncs.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.last_time_cleared.is_set or
                                            self.time_since_cleared.is_set or
                                            (self.received_sync_requests is not None and self.received_sync_requests.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.last_time_cleared.yfilter != YFilter.not_set or
                                            self.time_since_cleared.yfilter != YFilter.not_set or
                                            (self.received_sync_requests is not None and self.received_sync_requests.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "mlacp-sync-requests-on-all-foreign-bundles" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.last_time_cleared.is_set or self.last_time_cleared.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.last_time_cleared.get_name_leafdata())
                                        if (self.time_since_cleared.is_set or self.time_since_cleared.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.time_since_cleared.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "received-sync-requests"):
                                            if (self.received_sync_requests is None):
                                                self.received_sync_requests = BundleInformation.MlacpBundleCounters.Bundles.Bundle.BundleItem.IccpGroup.NodeData.NodeData.MlacpSyncRequestsOnAllForeignBundles.ReceivedSyncRequests()
                                                self.received_sync_requests.parent = self
                                                self._children_name_map["received_sync_requests"] = "received-sync-requests"
                                            return self.received_sync_requests

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "received-sync-requests" or name == "last-time-cleared" or name == "time-since-cleared"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "last-time-cleared"):
                                            self.last_time_cleared = value
                                            self.last_time_cleared.value_namespace = name_space
                                            self.last_time_cleared.value_namespace_prefix = name_space_prefix
                                        if(value_path == "time-since-cleared"):
                                            self.time_since_cleared = value
                                            self.time_since_cleared.value_namespace = name_space
                                            self.time_since_cleared.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.node_id.is_set or
                                        (self.mlacp_sync_requests_on_all_foreign_bundles is not None and self.mlacp_sync_requests_on_all_foreign_bundles.has_data()) or
                                        (self.mlacp_sync_requests_on_all_foreign_ports is not None and self.mlacp_sync_requests_on_all_foreign_ports.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.node_id.yfilter != YFilter.not_set or
                                        (self.mlacp_sync_requests_on_all_foreign_bundles is not None and self.mlacp_sync_requests_on_all_foreign_bundles.has_operation()) or
                                        (self.mlacp_sync_requests_on_all_foreign_ports is not None and self.mlacp_sync_requests_on_all_foreign_ports.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "node-data" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.node_id.is_set or self.node_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.node_id.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "mlacp-sync-requests-on-all-foreign-bundles"):
                                        if (self.mlacp_sync_requests_on_all_foreign_bundles is None):
                                            self.mlacp_sync_requests_on_all_foreign_bundles = BundleInformation.MlacpBundleCounters.Bundles.Bundle.BundleItem.IccpGroup.NodeData.NodeData.MlacpSyncRequestsOnAllForeignBundles()
                                            self.mlacp_sync_requests_on_all_foreign_bundles.parent = self
                                            self._children_name_map["mlacp_sync_requests_on_all_foreign_bundles"] = "mlacp-sync-requests-on-all-foreign-bundles"
                                        return self.mlacp_sync_requests_on_all_foreign_bundles

                                    if (child_yang_name == "mlacp-sync-requests-on-all-foreign-ports"):
                                        if (self.mlacp_sync_requests_on_all_foreign_ports is None):
                                            self.mlacp_sync_requests_on_all_foreign_ports = BundleInformation.MlacpBundleCounters.Bundles.Bundle.BundleItem.IccpGroup.NodeData.NodeData.MlacpSyncRequestsOnAllForeignPorts()
                                            self.mlacp_sync_requests_on_all_foreign_ports.parent = self
                                            self._children_name_map["mlacp_sync_requests_on_all_foreign_ports"] = "mlacp-sync-requests-on-all-foreign-ports"
                                        return self.mlacp_sync_requests_on_all_foreign_ports

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "mlacp-sync-requests-on-all-foreign-bundles" or name == "mlacp-sync-requests-on-all-foreign-ports" or name == "node-id"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "node-id"):
                                        self.node_id = value
                                        self.node_id.value_namespace = name_space
                                        self.node_id.value_namespace_prefix = name_space_prefix


                            class BundleData(Entity):
                                """
                                Peer device bundle mLACP TLV counter information
                                
                                .. attribute:: bundle_name
                                
                                	Bundle name
                                	**type**\:  str
                                
                                .. attribute:: mlacp_tlv_counters
                                
                                	Counts of mLACP TLVs sent and received
                                	**type**\:   :py:class:`MlacpTlvCounters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.MlacpBundleCounters.Bundles.Bundle.BundleItem.IccpGroup.NodeData.BundleData.MlacpTlvCounters>`
                                
                                

                                """

                                _prefix = 'bundlemgr-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(BundleInformation.MlacpBundleCounters.Bundles.Bundle.BundleItem.IccpGroup.NodeData.BundleData, self).__init__()

                                    self.yang_name = "bundle-data"
                                    self.yang_parent_name = "node-data"

                                    self.bundle_name = YLeaf(YType.str, "bundle-name")

                                    self.mlacp_tlv_counters = BundleInformation.MlacpBundleCounters.Bundles.Bundle.BundleItem.IccpGroup.NodeData.BundleData.MlacpTlvCounters()
                                    self.mlacp_tlv_counters.parent = self
                                    self._children_name_map["mlacp_tlv_counters"] = "mlacp-tlv-counters"
                                    self._children_yang_names.add("mlacp-tlv-counters")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("bundle_name") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(BundleInformation.MlacpBundleCounters.Bundles.Bundle.BundleItem.IccpGroup.NodeData.BundleData, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(BundleInformation.MlacpBundleCounters.Bundles.Bundle.BundleItem.IccpGroup.NodeData.BundleData, self).__setattr__(name, value)


                                class MlacpTlvCounters(Entity):
                                    """
                                    Counts of mLACP TLVs sent and received
                                    
                                    .. attribute:: last_time_cleared
                                    
                                    	Time in nsecs from boot when counters were last cleared (deprecated)
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: nanosecond
                                    
                                    .. attribute:: last_unexpected_event
                                    
                                    	Elapsed time in nsecs since last unexpected event
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: nanosecond
                                    
                                    .. attribute:: received_nak_tl_vs
                                    
                                    	Number of mLACP NAK TLVs received
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: received_priority_tl_vs
                                    
                                    	Number of mLACP priority TLVs received
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: received_sync_requests
                                    
                                    	Number of mLACP sync request TLVs received
                                    	**type**\:   :py:class:`ReceivedSyncRequests <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.MlacpBundleCounters.Bundles.Bundle.BundleItem.IccpGroup.NodeData.BundleData.MlacpTlvCounters.ReceivedSyncRequests>`
                                    
                                    .. attribute:: sent_config_tl_vs
                                    
                                    	Number of mLACP config TLVs sent
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: sent_priority_tl_vs
                                    
                                    	Number of mLACP priority TLVs sent
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: sent_state_tl_vs
                                    
                                    	Number of mLACP state TLVs sent
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: time_since_cleared
                                    
                                    	Elapsed time in nsecs since counters were last cleared
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: nanosecond
                                    
                                    

                                    """

                                    _prefix = 'bundlemgr-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(BundleInformation.MlacpBundleCounters.Bundles.Bundle.BundleItem.IccpGroup.NodeData.BundleData.MlacpTlvCounters, self).__init__()

                                        self.yang_name = "mlacp-tlv-counters"
                                        self.yang_parent_name = "bundle-data"

                                        self.last_time_cleared = YLeaf(YType.uint64, "last-time-cleared")

                                        self.last_unexpected_event = YLeaf(YType.uint64, "last-unexpected-event")

                                        self.received_nak_tl_vs = YLeaf(YType.uint32, "received-nak-tl-vs")

                                        self.received_priority_tl_vs = YLeaf(YType.uint32, "received-priority-tl-vs")

                                        self.sent_config_tl_vs = YLeaf(YType.uint32, "sent-config-tl-vs")

                                        self.sent_priority_tl_vs = YLeaf(YType.uint32, "sent-priority-tl-vs")

                                        self.sent_state_tl_vs = YLeaf(YType.uint32, "sent-state-tl-vs")

                                        self.time_since_cleared = YLeaf(YType.uint64, "time-since-cleared")

                                        self.received_sync_requests = BundleInformation.MlacpBundleCounters.Bundles.Bundle.BundleItem.IccpGroup.NodeData.BundleData.MlacpTlvCounters.ReceivedSyncRequests()
                                        self.received_sync_requests.parent = self
                                        self._children_name_map["received_sync_requests"] = "received-sync-requests"
                                        self._children_yang_names.add("received-sync-requests")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("last_time_cleared",
                                                        "last_unexpected_event",
                                                        "received_nak_tl_vs",
                                                        "received_priority_tl_vs",
                                                        "sent_config_tl_vs",
                                                        "sent_priority_tl_vs",
                                                        "sent_state_tl_vs",
                                                        "time_since_cleared") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(BundleInformation.MlacpBundleCounters.Bundles.Bundle.BundleItem.IccpGroup.NodeData.BundleData.MlacpTlvCounters, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(BundleInformation.MlacpBundleCounters.Bundles.Bundle.BundleItem.IccpGroup.NodeData.BundleData.MlacpTlvCounters, self).__setattr__(name, value)


                                    class ReceivedSyncRequests(Entity):
                                        """
                                        Number of mLACP sync request TLVs received
                                        
                                        .. attribute:: all_syncs
                                        
                                        	Total number of sync requests received
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: config_syncs
                                        
                                        	Number of config sync requests received
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: state_syncs
                                        
                                        	Number of state sync requests received
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'bundlemgr-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(BundleInformation.MlacpBundleCounters.Bundles.Bundle.BundleItem.IccpGroup.NodeData.BundleData.MlacpTlvCounters.ReceivedSyncRequests, self).__init__()

                                            self.yang_name = "received-sync-requests"
                                            self.yang_parent_name = "mlacp-tlv-counters"

                                            self.all_syncs = YLeaf(YType.uint32, "all-syncs")

                                            self.config_syncs = YLeaf(YType.uint32, "config-syncs")

                                            self.state_syncs = YLeaf(YType.uint32, "state-syncs")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("all_syncs",
                                                            "config_syncs",
                                                            "state_syncs") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(BundleInformation.MlacpBundleCounters.Bundles.Bundle.BundleItem.IccpGroup.NodeData.BundleData.MlacpTlvCounters.ReceivedSyncRequests, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(BundleInformation.MlacpBundleCounters.Bundles.Bundle.BundleItem.IccpGroup.NodeData.BundleData.MlacpTlvCounters.ReceivedSyncRequests, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.all_syncs.is_set or
                                                self.config_syncs.is_set or
                                                self.state_syncs.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.all_syncs.yfilter != YFilter.not_set or
                                                self.config_syncs.yfilter != YFilter.not_set or
                                                self.state_syncs.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "received-sync-requests" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.all_syncs.is_set or self.all_syncs.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.all_syncs.get_name_leafdata())
                                            if (self.config_syncs.is_set or self.config_syncs.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.config_syncs.get_name_leafdata())
                                            if (self.state_syncs.is_set or self.state_syncs.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.state_syncs.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "all-syncs" or name == "config-syncs" or name == "state-syncs"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "all-syncs"):
                                                self.all_syncs = value
                                                self.all_syncs.value_namespace = name_space
                                                self.all_syncs.value_namespace_prefix = name_space_prefix
                                            if(value_path == "config-syncs"):
                                                self.config_syncs = value
                                                self.config_syncs.value_namespace = name_space
                                                self.config_syncs.value_namespace_prefix = name_space_prefix
                                            if(value_path == "state-syncs"):
                                                self.state_syncs = value
                                                self.state_syncs.value_namespace = name_space
                                                self.state_syncs.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.last_time_cleared.is_set or
                                            self.last_unexpected_event.is_set or
                                            self.received_nak_tl_vs.is_set or
                                            self.received_priority_tl_vs.is_set or
                                            self.sent_config_tl_vs.is_set or
                                            self.sent_priority_tl_vs.is_set or
                                            self.sent_state_tl_vs.is_set or
                                            self.time_since_cleared.is_set or
                                            (self.received_sync_requests is not None and self.received_sync_requests.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.last_time_cleared.yfilter != YFilter.not_set or
                                            self.last_unexpected_event.yfilter != YFilter.not_set or
                                            self.received_nak_tl_vs.yfilter != YFilter.not_set or
                                            self.received_priority_tl_vs.yfilter != YFilter.not_set or
                                            self.sent_config_tl_vs.yfilter != YFilter.not_set or
                                            self.sent_priority_tl_vs.yfilter != YFilter.not_set or
                                            self.sent_state_tl_vs.yfilter != YFilter.not_set or
                                            self.time_since_cleared.yfilter != YFilter.not_set or
                                            (self.received_sync_requests is not None and self.received_sync_requests.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "mlacp-tlv-counters" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.last_time_cleared.is_set or self.last_time_cleared.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.last_time_cleared.get_name_leafdata())
                                        if (self.last_unexpected_event.is_set or self.last_unexpected_event.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.last_unexpected_event.get_name_leafdata())
                                        if (self.received_nak_tl_vs.is_set or self.received_nak_tl_vs.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.received_nak_tl_vs.get_name_leafdata())
                                        if (self.received_priority_tl_vs.is_set or self.received_priority_tl_vs.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.received_priority_tl_vs.get_name_leafdata())
                                        if (self.sent_config_tl_vs.is_set or self.sent_config_tl_vs.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.sent_config_tl_vs.get_name_leafdata())
                                        if (self.sent_priority_tl_vs.is_set or self.sent_priority_tl_vs.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.sent_priority_tl_vs.get_name_leafdata())
                                        if (self.sent_state_tl_vs.is_set or self.sent_state_tl_vs.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.sent_state_tl_vs.get_name_leafdata())
                                        if (self.time_since_cleared.is_set or self.time_since_cleared.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.time_since_cleared.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "received-sync-requests"):
                                            if (self.received_sync_requests is None):
                                                self.received_sync_requests = BundleInformation.MlacpBundleCounters.Bundles.Bundle.BundleItem.IccpGroup.NodeData.BundleData.MlacpTlvCounters.ReceivedSyncRequests()
                                                self.received_sync_requests.parent = self
                                                self._children_name_map["received_sync_requests"] = "received-sync-requests"
                                            return self.received_sync_requests

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "received-sync-requests" or name == "last-time-cleared" or name == "last-unexpected-event" or name == "received-nak-tl-vs" or name == "received-priority-tl-vs" or name == "sent-config-tl-vs" or name == "sent-priority-tl-vs" or name == "sent-state-tl-vs" or name == "time-since-cleared"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "last-time-cleared"):
                                            self.last_time_cleared = value
                                            self.last_time_cleared.value_namespace = name_space
                                            self.last_time_cleared.value_namespace_prefix = name_space_prefix
                                        if(value_path == "last-unexpected-event"):
                                            self.last_unexpected_event = value
                                            self.last_unexpected_event.value_namespace = name_space
                                            self.last_unexpected_event.value_namespace_prefix = name_space_prefix
                                        if(value_path == "received-nak-tl-vs"):
                                            self.received_nak_tl_vs = value
                                            self.received_nak_tl_vs.value_namespace = name_space
                                            self.received_nak_tl_vs.value_namespace_prefix = name_space_prefix
                                        if(value_path == "received-priority-tl-vs"):
                                            self.received_priority_tl_vs = value
                                            self.received_priority_tl_vs.value_namespace = name_space
                                            self.received_priority_tl_vs.value_namespace_prefix = name_space_prefix
                                        if(value_path == "sent-config-tl-vs"):
                                            self.sent_config_tl_vs = value
                                            self.sent_config_tl_vs.value_namespace = name_space
                                            self.sent_config_tl_vs.value_namespace_prefix = name_space_prefix
                                        if(value_path == "sent-priority-tl-vs"):
                                            self.sent_priority_tl_vs = value
                                            self.sent_priority_tl_vs.value_namespace = name_space
                                            self.sent_priority_tl_vs.value_namespace_prefix = name_space_prefix
                                        if(value_path == "sent-state-tl-vs"):
                                            self.sent_state_tl_vs = value
                                            self.sent_state_tl_vs.value_namespace = name_space
                                            self.sent_state_tl_vs.value_namespace_prefix = name_space_prefix
                                        if(value_path == "time-since-cleared"):
                                            self.time_since_cleared = value
                                            self.time_since_cleared.value_namespace = name_space
                                            self.time_since_cleared.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.bundle_name.is_set or
                                        (self.mlacp_tlv_counters is not None and self.mlacp_tlv_counters.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.bundle_name.yfilter != YFilter.not_set or
                                        (self.mlacp_tlv_counters is not None and self.mlacp_tlv_counters.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "bundle-data" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.bundle_name.is_set or self.bundle_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.bundle_name.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "mlacp-tlv-counters"):
                                        if (self.mlacp_tlv_counters is None):
                                            self.mlacp_tlv_counters = BundleInformation.MlacpBundleCounters.Bundles.Bundle.BundleItem.IccpGroup.NodeData.BundleData.MlacpTlvCounters()
                                            self.mlacp_tlv_counters.parent = self
                                            self._children_name_map["mlacp_tlv_counters"] = "mlacp-tlv-counters"
                                        return self.mlacp_tlv_counters

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "mlacp-tlv-counters" or name == "bundle-name"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "bundle-name"):
                                        self.bundle_name = value
                                        self.bundle_name.value_namespace = name_space
                                        self.bundle_name.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.bundle_data:
                                    if (c.has_data()):
                                        return True
                                return (self.node_data is not None and self.node_data.has_data())

                            def has_operation(self):
                                for c in self.bundle_data:
                                    if (c.has_operation()):
                                        return True
                                return (
                                    self.yfilter != YFilter.not_set or
                                    (self.node_data is not None and self.node_data.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "node-data" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "bundle-data"):
                                    for c in self.bundle_data:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = BundleInformation.MlacpBundleCounters.Bundles.Bundle.BundleItem.IccpGroup.NodeData.BundleData()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.bundle_data.append(c)
                                    return c

                                if (child_yang_name == "node-data"):
                                    if (self.node_data is None):
                                        self.node_data = BundleInformation.MlacpBundleCounters.Bundles.Bundle.BundleItem.IccpGroup.NodeData.NodeData()
                                        self.node_data.parent = self
                                        self._children_name_map["node_data"] = "node-data"
                                    return self.node_data

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "bundle-data" or name == "node-data"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass

                        def has_data(self):
                            for c in self.node_data:
                                if (c.has_data()):
                                    return True
                            return (self.iccp_group_data is not None and self.iccp_group_data.has_data())

                        def has_operation(self):
                            for c in self.node_data:
                                if (c.has_operation()):
                                    return True
                            return (
                                self.yfilter != YFilter.not_set or
                                (self.iccp_group_data is not None and self.iccp_group_data.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "iccp-group" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "iccp-group-data"):
                                if (self.iccp_group_data is None):
                                    self.iccp_group_data = BundleInformation.MlacpBundleCounters.Bundles.Bundle.BundleItem.IccpGroup.IccpGroupData()
                                    self.iccp_group_data.parent = self
                                    self._children_name_map["iccp_group_data"] = "iccp-group-data"
                                return self.iccp_group_data

                            if (child_yang_name == "node-data"):
                                for c in self.node_data:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = BundleInformation.MlacpBundleCounters.Bundles.Bundle.BundleItem.IccpGroup.NodeData()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.node_data.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "iccp-group-data" or name == "node-data"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass

                    def has_data(self):
                        for c in self.iccp_group:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.iccp_group:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "bundle-item" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "iccp-group"):
                            for c in self.iccp_group:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = BundleInformation.MlacpBundleCounters.Bundles.Bundle.BundleItem.IccpGroup()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.iccp_group.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "iccp-group"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass

                def has_data(self):
                    return (
                        self.bundle_interface.is_set or
                        (self.bundle_item is not None and self.bundle_item.has_data()))

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.bundle_interface.yfilter != YFilter.not_set or
                        (self.bundle_item is not None and self.bundle_item.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "bundle" + "[bundle-interface='" + self.bundle_interface.get() + "']" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-bundlemgr-oper:bundle-information/mlacp-bundle-counters/bundles/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.bundle_interface.is_set or self.bundle_interface.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.bundle_interface.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "bundle-item"):
                        if (self.bundle_item is None):
                            self.bundle_item = BundleInformation.MlacpBundleCounters.Bundles.Bundle.BundleItem()
                            self.bundle_item.parent = self
                            self._children_name_map["bundle_item"] = "bundle-item"
                        return self.bundle_item

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "bundle-item" or name == "bundle-interface"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "bundle-interface"):
                        self.bundle_interface = value
                        self.bundle_interface.value_namespace = name_space
                        self.bundle_interface.value_namespace_prefix = name_space_prefix

            def has_data(self):
                for c in self.bundle:
                    if (c.has_data()):
                        return True
                return False

            def has_operation(self):
                for c in self.bundle:
                    if (c.has_operation()):
                        return True
                return self.yfilter != YFilter.not_set

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "bundles" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-bundlemgr-oper:bundle-information/mlacp-bundle-counters/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "bundle"):
                    for c in self.bundle:
                        segment = c.get_segment_path()
                        if (segment_path == segment):
                            return c
                    c = BundleInformation.MlacpBundleCounters.Bundles.Bundle()
                    c.parent = self
                    local_reference_key = "ydk::seg::%s" % segment_path
                    self._local_refs[local_reference_key] = c
                    self.bundle.append(c)
                    return c

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "bundle"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                pass


        class Nodes(Entity):
            """
            Devices with counters of their bundle's mLACP
            events
            
            .. attribute:: node
            
            	Node ID
            	**type**\: list of    :py:class:`Node <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.MlacpBundleCounters.Nodes.Node>`
            
            

            """

            _prefix = 'bundlemgr-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(BundleInformation.MlacpBundleCounters.Nodes, self).__init__()

                self.yang_name = "nodes"
                self.yang_parent_name = "mlacp-bundle-counters"

                self.node = YList(self)

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in () and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(BundleInformation.MlacpBundleCounters.Nodes, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(BundleInformation.MlacpBundleCounters.Nodes, self).__setattr__(name, value)


            class Node(Entity):
                """
                Node ID
                
                .. attribute:: node  <key>
                
                	For a local device the Node ID e.g. '0\_0\_CPU0', for a peer device the LDP ID followed by the ICCP Group ID e.g. '5.4.3.2 ,4'
                	**type**\:  str
                
                .. attribute:: node_item
                
                	Data for this item
                	**type**\:   :py:class:`NodeItem <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.MlacpBundleCounters.Nodes.Node.NodeItem>`
                
                

                """

                _prefix = 'bundlemgr-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(BundleInformation.MlacpBundleCounters.Nodes.Node, self).__init__()

                    self.yang_name = "node"
                    self.yang_parent_name = "nodes"

                    self.node = YLeaf(YType.str, "node")

                    self.node_item = BundleInformation.MlacpBundleCounters.Nodes.Node.NodeItem()
                    self.node_item.parent = self
                    self._children_name_map["node_item"] = "node-item"
                    self._children_yang_names.add("node-item")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("node") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(BundleInformation.MlacpBundleCounters.Nodes.Node, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(BundleInformation.MlacpBundleCounters.Nodes.Node, self).__setattr__(name, value)


                class NodeItem(Entity):
                    """
                    Data for this item
                    
                    .. attribute:: iccp_group_data
                    
                    	ICCP Group mLACP TLV counter information
                    	**type**\:   :py:class:`IccpGroupData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.MlacpBundleCounters.Nodes.Node.NodeItem.IccpGroupData>`
                    
                    .. attribute:: node_data
                    
                    	Peer device bundle mLACP counter information
                    	**type**\: list of    :py:class:`NodeData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.MlacpBundleCounters.Nodes.Node.NodeItem.NodeData>`
                    
                    

                    """

                    _prefix = 'bundlemgr-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(BundleInformation.MlacpBundleCounters.Nodes.Node.NodeItem, self).__init__()

                        self.yang_name = "node-item"
                        self.yang_parent_name = "node"

                        self.iccp_group_data = BundleInformation.MlacpBundleCounters.Nodes.Node.NodeItem.IccpGroupData()
                        self.iccp_group_data.parent = self
                        self._children_name_map["iccp_group_data"] = "iccp-group-data"
                        self._children_yang_names.add("iccp-group-data")

                        self.node_data = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(BundleInformation.MlacpBundleCounters.Nodes.Node.NodeItem, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(BundleInformation.MlacpBundleCounters.Nodes.Node.NodeItem, self).__setattr__(name, value)


                    class IccpGroupData(Entity):
                        """
                        ICCP Group mLACP TLV counter information
                        
                        .. attribute:: bundle_data
                        
                        	Local device bundle mLACP counter information
                        	**type**\: list of    :py:class:`BundleData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.MlacpBundleCounters.Nodes.Node.NodeItem.IccpGroupData.BundleData>`
                        
                        .. attribute:: iccp_group_id
                        
                        	ICCP Group ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: mlacp_sync_requests_on_all_local_bundles
                        
                        	Counts of mLACP sync request TLVs on all bundles
                        	**type**\:   :py:class:`MlacpSyncRequestsOnAllLocalBundles <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.MlacpBundleCounters.Nodes.Node.NodeItem.IccpGroupData.MlacpSyncRequestsOnAllLocalBundles>`
                        
                        .. attribute:: mlacp_sync_requests_on_all_local_ports
                        
                        	Counts of mLACP sync request TLVs on all ports
                        	**type**\:   :py:class:`MlacpSyncRequestsOnAllLocalPorts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.MlacpBundleCounters.Nodes.Node.NodeItem.IccpGroupData.MlacpSyncRequestsOnAllLocalPorts>`
                        
                        

                        """

                        _prefix = 'bundlemgr-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(BundleInformation.MlacpBundleCounters.Nodes.Node.NodeItem.IccpGroupData, self).__init__()

                            self.yang_name = "iccp-group-data"
                            self.yang_parent_name = "node-item"

                            self.iccp_group_id = YLeaf(YType.uint32, "iccp-group-id")

                            self.mlacp_sync_requests_on_all_local_bundles = BundleInformation.MlacpBundleCounters.Nodes.Node.NodeItem.IccpGroupData.MlacpSyncRequestsOnAllLocalBundles()
                            self.mlacp_sync_requests_on_all_local_bundles.parent = self
                            self._children_name_map["mlacp_sync_requests_on_all_local_bundles"] = "mlacp-sync-requests-on-all-local-bundles"
                            self._children_yang_names.add("mlacp-sync-requests-on-all-local-bundles")

                            self.mlacp_sync_requests_on_all_local_ports = BundleInformation.MlacpBundleCounters.Nodes.Node.NodeItem.IccpGroupData.MlacpSyncRequestsOnAllLocalPorts()
                            self.mlacp_sync_requests_on_all_local_ports.parent = self
                            self._children_name_map["mlacp_sync_requests_on_all_local_ports"] = "mlacp-sync-requests-on-all-local-ports"
                            self._children_yang_names.add("mlacp-sync-requests-on-all-local-ports")

                            self.bundle_data = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("iccp_group_id") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(BundleInformation.MlacpBundleCounters.Nodes.Node.NodeItem.IccpGroupData, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(BundleInformation.MlacpBundleCounters.Nodes.Node.NodeItem.IccpGroupData, self).__setattr__(name, value)


                        class MlacpSyncRequestsOnAllLocalPorts(Entity):
                            """
                            Counts of mLACP sync request TLVs on all ports
                            
                            .. attribute:: last_time_cleared
                            
                            	Time in nsecs from boot when counters were last cleared (deprecated)
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: nanosecond
                            
                            .. attribute:: received_sync_requests
                            
                            	Number of mLACP sync request TLVs received
                            	**type**\:   :py:class:`ReceivedSyncRequests <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.MlacpBundleCounters.Nodes.Node.NodeItem.IccpGroupData.MlacpSyncRequestsOnAllLocalPorts.ReceivedSyncRequests>`
                            
                            .. attribute:: time_since_cleared
                            
                            	Elapsed time in nsecs since counters were last cleared
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: nanosecond
                            
                            

                            """

                            _prefix = 'bundlemgr-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(BundleInformation.MlacpBundleCounters.Nodes.Node.NodeItem.IccpGroupData.MlacpSyncRequestsOnAllLocalPorts, self).__init__()

                                self.yang_name = "mlacp-sync-requests-on-all-local-ports"
                                self.yang_parent_name = "iccp-group-data"

                                self.last_time_cleared = YLeaf(YType.uint64, "last-time-cleared")

                                self.time_since_cleared = YLeaf(YType.uint64, "time-since-cleared")

                                self.received_sync_requests = BundleInformation.MlacpBundleCounters.Nodes.Node.NodeItem.IccpGroupData.MlacpSyncRequestsOnAllLocalPorts.ReceivedSyncRequests()
                                self.received_sync_requests.parent = self
                                self._children_name_map["received_sync_requests"] = "received-sync-requests"
                                self._children_yang_names.add("received-sync-requests")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("last_time_cleared",
                                                "time_since_cleared") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(BundleInformation.MlacpBundleCounters.Nodes.Node.NodeItem.IccpGroupData.MlacpSyncRequestsOnAllLocalPorts, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(BundleInformation.MlacpBundleCounters.Nodes.Node.NodeItem.IccpGroupData.MlacpSyncRequestsOnAllLocalPorts, self).__setattr__(name, value)


                            class ReceivedSyncRequests(Entity):
                                """
                                Number of mLACP sync request TLVs received
                                
                                .. attribute:: all_syncs
                                
                                	Total number of sync requests received
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: config_syncs
                                
                                	Number of config sync requests received
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: state_syncs
                                
                                	Number of state sync requests received
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'bundlemgr-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(BundleInformation.MlacpBundleCounters.Nodes.Node.NodeItem.IccpGroupData.MlacpSyncRequestsOnAllLocalPorts.ReceivedSyncRequests, self).__init__()

                                    self.yang_name = "received-sync-requests"
                                    self.yang_parent_name = "mlacp-sync-requests-on-all-local-ports"

                                    self.all_syncs = YLeaf(YType.uint32, "all-syncs")

                                    self.config_syncs = YLeaf(YType.uint32, "config-syncs")

                                    self.state_syncs = YLeaf(YType.uint32, "state-syncs")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("all_syncs",
                                                    "config_syncs",
                                                    "state_syncs") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(BundleInformation.MlacpBundleCounters.Nodes.Node.NodeItem.IccpGroupData.MlacpSyncRequestsOnAllLocalPorts.ReceivedSyncRequests, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(BundleInformation.MlacpBundleCounters.Nodes.Node.NodeItem.IccpGroupData.MlacpSyncRequestsOnAllLocalPorts.ReceivedSyncRequests, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.all_syncs.is_set or
                                        self.config_syncs.is_set or
                                        self.state_syncs.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.all_syncs.yfilter != YFilter.not_set or
                                        self.config_syncs.yfilter != YFilter.not_set or
                                        self.state_syncs.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "received-sync-requests" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.all_syncs.is_set or self.all_syncs.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.all_syncs.get_name_leafdata())
                                    if (self.config_syncs.is_set or self.config_syncs.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.config_syncs.get_name_leafdata())
                                    if (self.state_syncs.is_set or self.state_syncs.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.state_syncs.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "all-syncs" or name == "config-syncs" or name == "state-syncs"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "all-syncs"):
                                        self.all_syncs = value
                                        self.all_syncs.value_namespace = name_space
                                        self.all_syncs.value_namespace_prefix = name_space_prefix
                                    if(value_path == "config-syncs"):
                                        self.config_syncs = value
                                        self.config_syncs.value_namespace = name_space
                                        self.config_syncs.value_namespace_prefix = name_space_prefix
                                    if(value_path == "state-syncs"):
                                        self.state_syncs = value
                                        self.state_syncs.value_namespace = name_space
                                        self.state_syncs.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.last_time_cleared.is_set or
                                    self.time_since_cleared.is_set or
                                    (self.received_sync_requests is not None and self.received_sync_requests.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.last_time_cleared.yfilter != YFilter.not_set or
                                    self.time_since_cleared.yfilter != YFilter.not_set or
                                    (self.received_sync_requests is not None and self.received_sync_requests.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "mlacp-sync-requests-on-all-local-ports" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.last_time_cleared.is_set or self.last_time_cleared.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.last_time_cleared.get_name_leafdata())
                                if (self.time_since_cleared.is_set or self.time_since_cleared.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.time_since_cleared.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "received-sync-requests"):
                                    if (self.received_sync_requests is None):
                                        self.received_sync_requests = BundleInformation.MlacpBundleCounters.Nodes.Node.NodeItem.IccpGroupData.MlacpSyncRequestsOnAllLocalPorts.ReceivedSyncRequests()
                                        self.received_sync_requests.parent = self
                                        self._children_name_map["received_sync_requests"] = "received-sync-requests"
                                    return self.received_sync_requests

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "received-sync-requests" or name == "last-time-cleared" or name == "time-since-cleared"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "last-time-cleared"):
                                    self.last_time_cleared = value
                                    self.last_time_cleared.value_namespace = name_space
                                    self.last_time_cleared.value_namespace_prefix = name_space_prefix
                                if(value_path == "time-since-cleared"):
                                    self.time_since_cleared = value
                                    self.time_since_cleared.value_namespace = name_space
                                    self.time_since_cleared.value_namespace_prefix = name_space_prefix


                        class MlacpSyncRequestsOnAllLocalBundles(Entity):
                            """
                            Counts of mLACP sync request TLVs on all bundles
                            
                            .. attribute:: last_time_cleared
                            
                            	Time in nsecs from boot when counters were last cleared (deprecated)
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: nanosecond
                            
                            .. attribute:: received_sync_requests
                            
                            	Number of mLACP sync request TLVs received
                            	**type**\:   :py:class:`ReceivedSyncRequests <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.MlacpBundleCounters.Nodes.Node.NodeItem.IccpGroupData.MlacpSyncRequestsOnAllLocalBundles.ReceivedSyncRequests>`
                            
                            .. attribute:: time_since_cleared
                            
                            	Elapsed time in nsecs since counters were last cleared
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: nanosecond
                            
                            

                            """

                            _prefix = 'bundlemgr-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(BundleInformation.MlacpBundleCounters.Nodes.Node.NodeItem.IccpGroupData.MlacpSyncRequestsOnAllLocalBundles, self).__init__()

                                self.yang_name = "mlacp-sync-requests-on-all-local-bundles"
                                self.yang_parent_name = "iccp-group-data"

                                self.last_time_cleared = YLeaf(YType.uint64, "last-time-cleared")

                                self.time_since_cleared = YLeaf(YType.uint64, "time-since-cleared")

                                self.received_sync_requests = BundleInformation.MlacpBundleCounters.Nodes.Node.NodeItem.IccpGroupData.MlacpSyncRequestsOnAllLocalBundles.ReceivedSyncRequests()
                                self.received_sync_requests.parent = self
                                self._children_name_map["received_sync_requests"] = "received-sync-requests"
                                self._children_yang_names.add("received-sync-requests")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("last_time_cleared",
                                                "time_since_cleared") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(BundleInformation.MlacpBundleCounters.Nodes.Node.NodeItem.IccpGroupData.MlacpSyncRequestsOnAllLocalBundles, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(BundleInformation.MlacpBundleCounters.Nodes.Node.NodeItem.IccpGroupData.MlacpSyncRequestsOnAllLocalBundles, self).__setattr__(name, value)


                            class ReceivedSyncRequests(Entity):
                                """
                                Number of mLACP sync request TLVs received
                                
                                .. attribute:: all_syncs
                                
                                	Total number of sync requests received
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: config_syncs
                                
                                	Number of config sync requests received
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: state_syncs
                                
                                	Number of state sync requests received
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'bundlemgr-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(BundleInformation.MlacpBundleCounters.Nodes.Node.NodeItem.IccpGroupData.MlacpSyncRequestsOnAllLocalBundles.ReceivedSyncRequests, self).__init__()

                                    self.yang_name = "received-sync-requests"
                                    self.yang_parent_name = "mlacp-sync-requests-on-all-local-bundles"

                                    self.all_syncs = YLeaf(YType.uint32, "all-syncs")

                                    self.config_syncs = YLeaf(YType.uint32, "config-syncs")

                                    self.state_syncs = YLeaf(YType.uint32, "state-syncs")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("all_syncs",
                                                    "config_syncs",
                                                    "state_syncs") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(BundleInformation.MlacpBundleCounters.Nodes.Node.NodeItem.IccpGroupData.MlacpSyncRequestsOnAllLocalBundles.ReceivedSyncRequests, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(BundleInformation.MlacpBundleCounters.Nodes.Node.NodeItem.IccpGroupData.MlacpSyncRequestsOnAllLocalBundles.ReceivedSyncRequests, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.all_syncs.is_set or
                                        self.config_syncs.is_set or
                                        self.state_syncs.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.all_syncs.yfilter != YFilter.not_set or
                                        self.config_syncs.yfilter != YFilter.not_set or
                                        self.state_syncs.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "received-sync-requests" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.all_syncs.is_set or self.all_syncs.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.all_syncs.get_name_leafdata())
                                    if (self.config_syncs.is_set or self.config_syncs.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.config_syncs.get_name_leafdata())
                                    if (self.state_syncs.is_set or self.state_syncs.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.state_syncs.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "all-syncs" or name == "config-syncs" or name == "state-syncs"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "all-syncs"):
                                        self.all_syncs = value
                                        self.all_syncs.value_namespace = name_space
                                        self.all_syncs.value_namespace_prefix = name_space_prefix
                                    if(value_path == "config-syncs"):
                                        self.config_syncs = value
                                        self.config_syncs.value_namespace = name_space
                                        self.config_syncs.value_namespace_prefix = name_space_prefix
                                    if(value_path == "state-syncs"):
                                        self.state_syncs = value
                                        self.state_syncs.value_namespace = name_space
                                        self.state_syncs.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.last_time_cleared.is_set or
                                    self.time_since_cleared.is_set or
                                    (self.received_sync_requests is not None and self.received_sync_requests.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.last_time_cleared.yfilter != YFilter.not_set or
                                    self.time_since_cleared.yfilter != YFilter.not_set or
                                    (self.received_sync_requests is not None and self.received_sync_requests.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "mlacp-sync-requests-on-all-local-bundles" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.last_time_cleared.is_set or self.last_time_cleared.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.last_time_cleared.get_name_leafdata())
                                if (self.time_since_cleared.is_set or self.time_since_cleared.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.time_since_cleared.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "received-sync-requests"):
                                    if (self.received_sync_requests is None):
                                        self.received_sync_requests = BundleInformation.MlacpBundleCounters.Nodes.Node.NodeItem.IccpGroupData.MlacpSyncRequestsOnAllLocalBundles.ReceivedSyncRequests()
                                        self.received_sync_requests.parent = self
                                        self._children_name_map["received_sync_requests"] = "received-sync-requests"
                                    return self.received_sync_requests

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "received-sync-requests" or name == "last-time-cleared" or name == "time-since-cleared"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "last-time-cleared"):
                                    self.last_time_cleared = value
                                    self.last_time_cleared.value_namespace = name_space
                                    self.last_time_cleared.value_namespace_prefix = name_space_prefix
                                if(value_path == "time-since-cleared"):
                                    self.time_since_cleared = value
                                    self.time_since_cleared.value_namespace = name_space
                                    self.time_since_cleared.value_namespace_prefix = name_space_prefix


                        class BundleData(Entity):
                            """
                            Local device bundle mLACP counter information
                            
                            .. attribute:: bundle_name
                            
                            	Bundle name
                            	**type**\:  str
                            
                            .. attribute:: mlacp_tlv_counters
                            
                            	Counts of mLACP TLVs sent and received
                            	**type**\:   :py:class:`MlacpTlvCounters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.MlacpBundleCounters.Nodes.Node.NodeItem.IccpGroupData.BundleData.MlacpTlvCounters>`
                            
                            

                            """

                            _prefix = 'bundlemgr-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(BundleInformation.MlacpBundleCounters.Nodes.Node.NodeItem.IccpGroupData.BundleData, self).__init__()

                                self.yang_name = "bundle-data"
                                self.yang_parent_name = "iccp-group-data"

                                self.bundle_name = YLeaf(YType.str, "bundle-name")

                                self.mlacp_tlv_counters = BundleInformation.MlacpBundleCounters.Nodes.Node.NodeItem.IccpGroupData.BundleData.MlacpTlvCounters()
                                self.mlacp_tlv_counters.parent = self
                                self._children_name_map["mlacp_tlv_counters"] = "mlacp-tlv-counters"
                                self._children_yang_names.add("mlacp-tlv-counters")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("bundle_name") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(BundleInformation.MlacpBundleCounters.Nodes.Node.NodeItem.IccpGroupData.BundleData, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(BundleInformation.MlacpBundleCounters.Nodes.Node.NodeItem.IccpGroupData.BundleData, self).__setattr__(name, value)


                            class MlacpTlvCounters(Entity):
                                """
                                Counts of mLACP TLVs sent and received
                                
                                .. attribute:: last_time_cleared
                                
                                	Time in nsecs from boot when counters were last cleared (deprecated)
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: nanosecond
                                
                                .. attribute:: last_unexpected_event
                                
                                	Elapsed time in nsecs since last unexpected event
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: nanosecond
                                
                                .. attribute:: received_nak_tl_vs
                                
                                	Number of mLACP NAK TLVs received
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: received_priority_tl_vs
                                
                                	Number of mLACP priority TLVs received
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: received_sync_requests
                                
                                	Number of mLACP sync request TLVs received
                                	**type**\:   :py:class:`ReceivedSyncRequests <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.MlacpBundleCounters.Nodes.Node.NodeItem.IccpGroupData.BundleData.MlacpTlvCounters.ReceivedSyncRequests>`
                                
                                .. attribute:: sent_config_tl_vs
                                
                                	Number of mLACP config TLVs sent
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: sent_priority_tl_vs
                                
                                	Number of mLACP priority TLVs sent
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: sent_state_tl_vs
                                
                                	Number of mLACP state TLVs sent
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: time_since_cleared
                                
                                	Elapsed time in nsecs since counters were last cleared
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: nanosecond
                                
                                

                                """

                                _prefix = 'bundlemgr-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(BundleInformation.MlacpBundleCounters.Nodes.Node.NodeItem.IccpGroupData.BundleData.MlacpTlvCounters, self).__init__()

                                    self.yang_name = "mlacp-tlv-counters"
                                    self.yang_parent_name = "bundle-data"

                                    self.last_time_cleared = YLeaf(YType.uint64, "last-time-cleared")

                                    self.last_unexpected_event = YLeaf(YType.uint64, "last-unexpected-event")

                                    self.received_nak_tl_vs = YLeaf(YType.uint32, "received-nak-tl-vs")

                                    self.received_priority_tl_vs = YLeaf(YType.uint32, "received-priority-tl-vs")

                                    self.sent_config_tl_vs = YLeaf(YType.uint32, "sent-config-tl-vs")

                                    self.sent_priority_tl_vs = YLeaf(YType.uint32, "sent-priority-tl-vs")

                                    self.sent_state_tl_vs = YLeaf(YType.uint32, "sent-state-tl-vs")

                                    self.time_since_cleared = YLeaf(YType.uint64, "time-since-cleared")

                                    self.received_sync_requests = BundleInformation.MlacpBundleCounters.Nodes.Node.NodeItem.IccpGroupData.BundleData.MlacpTlvCounters.ReceivedSyncRequests()
                                    self.received_sync_requests.parent = self
                                    self._children_name_map["received_sync_requests"] = "received-sync-requests"
                                    self._children_yang_names.add("received-sync-requests")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("last_time_cleared",
                                                    "last_unexpected_event",
                                                    "received_nak_tl_vs",
                                                    "received_priority_tl_vs",
                                                    "sent_config_tl_vs",
                                                    "sent_priority_tl_vs",
                                                    "sent_state_tl_vs",
                                                    "time_since_cleared") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(BundleInformation.MlacpBundleCounters.Nodes.Node.NodeItem.IccpGroupData.BundleData.MlacpTlvCounters, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(BundleInformation.MlacpBundleCounters.Nodes.Node.NodeItem.IccpGroupData.BundleData.MlacpTlvCounters, self).__setattr__(name, value)


                                class ReceivedSyncRequests(Entity):
                                    """
                                    Number of mLACP sync request TLVs received
                                    
                                    .. attribute:: all_syncs
                                    
                                    	Total number of sync requests received
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: config_syncs
                                    
                                    	Number of config sync requests received
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: state_syncs
                                    
                                    	Number of state sync requests received
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'bundlemgr-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(BundleInformation.MlacpBundleCounters.Nodes.Node.NodeItem.IccpGroupData.BundleData.MlacpTlvCounters.ReceivedSyncRequests, self).__init__()

                                        self.yang_name = "received-sync-requests"
                                        self.yang_parent_name = "mlacp-tlv-counters"

                                        self.all_syncs = YLeaf(YType.uint32, "all-syncs")

                                        self.config_syncs = YLeaf(YType.uint32, "config-syncs")

                                        self.state_syncs = YLeaf(YType.uint32, "state-syncs")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("all_syncs",
                                                        "config_syncs",
                                                        "state_syncs") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(BundleInformation.MlacpBundleCounters.Nodes.Node.NodeItem.IccpGroupData.BundleData.MlacpTlvCounters.ReceivedSyncRequests, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(BundleInformation.MlacpBundleCounters.Nodes.Node.NodeItem.IccpGroupData.BundleData.MlacpTlvCounters.ReceivedSyncRequests, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.all_syncs.is_set or
                                            self.config_syncs.is_set or
                                            self.state_syncs.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.all_syncs.yfilter != YFilter.not_set or
                                            self.config_syncs.yfilter != YFilter.not_set or
                                            self.state_syncs.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "received-sync-requests" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.all_syncs.is_set or self.all_syncs.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.all_syncs.get_name_leafdata())
                                        if (self.config_syncs.is_set or self.config_syncs.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.config_syncs.get_name_leafdata())
                                        if (self.state_syncs.is_set or self.state_syncs.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.state_syncs.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "all-syncs" or name == "config-syncs" or name == "state-syncs"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "all-syncs"):
                                            self.all_syncs = value
                                            self.all_syncs.value_namespace = name_space
                                            self.all_syncs.value_namespace_prefix = name_space_prefix
                                        if(value_path == "config-syncs"):
                                            self.config_syncs = value
                                            self.config_syncs.value_namespace = name_space
                                            self.config_syncs.value_namespace_prefix = name_space_prefix
                                        if(value_path == "state-syncs"):
                                            self.state_syncs = value
                                            self.state_syncs.value_namespace = name_space
                                            self.state_syncs.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.last_time_cleared.is_set or
                                        self.last_unexpected_event.is_set or
                                        self.received_nak_tl_vs.is_set or
                                        self.received_priority_tl_vs.is_set or
                                        self.sent_config_tl_vs.is_set or
                                        self.sent_priority_tl_vs.is_set or
                                        self.sent_state_tl_vs.is_set or
                                        self.time_since_cleared.is_set or
                                        (self.received_sync_requests is not None and self.received_sync_requests.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.last_time_cleared.yfilter != YFilter.not_set or
                                        self.last_unexpected_event.yfilter != YFilter.not_set or
                                        self.received_nak_tl_vs.yfilter != YFilter.not_set or
                                        self.received_priority_tl_vs.yfilter != YFilter.not_set or
                                        self.sent_config_tl_vs.yfilter != YFilter.not_set or
                                        self.sent_priority_tl_vs.yfilter != YFilter.not_set or
                                        self.sent_state_tl_vs.yfilter != YFilter.not_set or
                                        self.time_since_cleared.yfilter != YFilter.not_set or
                                        (self.received_sync_requests is not None and self.received_sync_requests.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "mlacp-tlv-counters" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.last_time_cleared.is_set or self.last_time_cleared.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.last_time_cleared.get_name_leafdata())
                                    if (self.last_unexpected_event.is_set or self.last_unexpected_event.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.last_unexpected_event.get_name_leafdata())
                                    if (self.received_nak_tl_vs.is_set or self.received_nak_tl_vs.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.received_nak_tl_vs.get_name_leafdata())
                                    if (self.received_priority_tl_vs.is_set or self.received_priority_tl_vs.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.received_priority_tl_vs.get_name_leafdata())
                                    if (self.sent_config_tl_vs.is_set or self.sent_config_tl_vs.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.sent_config_tl_vs.get_name_leafdata())
                                    if (self.sent_priority_tl_vs.is_set or self.sent_priority_tl_vs.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.sent_priority_tl_vs.get_name_leafdata())
                                    if (self.sent_state_tl_vs.is_set or self.sent_state_tl_vs.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.sent_state_tl_vs.get_name_leafdata())
                                    if (self.time_since_cleared.is_set or self.time_since_cleared.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.time_since_cleared.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "received-sync-requests"):
                                        if (self.received_sync_requests is None):
                                            self.received_sync_requests = BundleInformation.MlacpBundleCounters.Nodes.Node.NodeItem.IccpGroupData.BundleData.MlacpTlvCounters.ReceivedSyncRequests()
                                            self.received_sync_requests.parent = self
                                            self._children_name_map["received_sync_requests"] = "received-sync-requests"
                                        return self.received_sync_requests

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "received-sync-requests" or name == "last-time-cleared" or name == "last-unexpected-event" or name == "received-nak-tl-vs" or name == "received-priority-tl-vs" or name == "sent-config-tl-vs" or name == "sent-priority-tl-vs" or name == "sent-state-tl-vs" or name == "time-since-cleared"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "last-time-cleared"):
                                        self.last_time_cleared = value
                                        self.last_time_cleared.value_namespace = name_space
                                        self.last_time_cleared.value_namespace_prefix = name_space_prefix
                                    if(value_path == "last-unexpected-event"):
                                        self.last_unexpected_event = value
                                        self.last_unexpected_event.value_namespace = name_space
                                        self.last_unexpected_event.value_namespace_prefix = name_space_prefix
                                    if(value_path == "received-nak-tl-vs"):
                                        self.received_nak_tl_vs = value
                                        self.received_nak_tl_vs.value_namespace = name_space
                                        self.received_nak_tl_vs.value_namespace_prefix = name_space_prefix
                                    if(value_path == "received-priority-tl-vs"):
                                        self.received_priority_tl_vs = value
                                        self.received_priority_tl_vs.value_namespace = name_space
                                        self.received_priority_tl_vs.value_namespace_prefix = name_space_prefix
                                    if(value_path == "sent-config-tl-vs"):
                                        self.sent_config_tl_vs = value
                                        self.sent_config_tl_vs.value_namespace = name_space
                                        self.sent_config_tl_vs.value_namespace_prefix = name_space_prefix
                                    if(value_path == "sent-priority-tl-vs"):
                                        self.sent_priority_tl_vs = value
                                        self.sent_priority_tl_vs.value_namespace = name_space
                                        self.sent_priority_tl_vs.value_namespace_prefix = name_space_prefix
                                    if(value_path == "sent-state-tl-vs"):
                                        self.sent_state_tl_vs = value
                                        self.sent_state_tl_vs.value_namespace = name_space
                                        self.sent_state_tl_vs.value_namespace_prefix = name_space_prefix
                                    if(value_path == "time-since-cleared"):
                                        self.time_since_cleared = value
                                        self.time_since_cleared.value_namespace = name_space
                                        self.time_since_cleared.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.bundle_name.is_set or
                                    (self.mlacp_tlv_counters is not None and self.mlacp_tlv_counters.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.bundle_name.yfilter != YFilter.not_set or
                                    (self.mlacp_tlv_counters is not None and self.mlacp_tlv_counters.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "bundle-data" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.bundle_name.is_set or self.bundle_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.bundle_name.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "mlacp-tlv-counters"):
                                    if (self.mlacp_tlv_counters is None):
                                        self.mlacp_tlv_counters = BundleInformation.MlacpBundleCounters.Nodes.Node.NodeItem.IccpGroupData.BundleData.MlacpTlvCounters()
                                        self.mlacp_tlv_counters.parent = self
                                        self._children_name_map["mlacp_tlv_counters"] = "mlacp-tlv-counters"
                                    return self.mlacp_tlv_counters

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "mlacp-tlv-counters" or name == "bundle-name"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "bundle-name"):
                                    self.bundle_name = value
                                    self.bundle_name.value_namespace = name_space
                                    self.bundle_name.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.bundle_data:
                                if (c.has_data()):
                                    return True
                            return (
                                self.iccp_group_id.is_set or
                                (self.mlacp_sync_requests_on_all_local_bundles is not None and self.mlacp_sync_requests_on_all_local_bundles.has_data()) or
                                (self.mlacp_sync_requests_on_all_local_ports is not None and self.mlacp_sync_requests_on_all_local_ports.has_data()))

                        def has_operation(self):
                            for c in self.bundle_data:
                                if (c.has_operation()):
                                    return True
                            return (
                                self.yfilter != YFilter.not_set or
                                self.iccp_group_id.yfilter != YFilter.not_set or
                                (self.mlacp_sync_requests_on_all_local_bundles is not None and self.mlacp_sync_requests_on_all_local_bundles.has_operation()) or
                                (self.mlacp_sync_requests_on_all_local_ports is not None and self.mlacp_sync_requests_on_all_local_ports.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "iccp-group-data" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.iccp_group_id.is_set or self.iccp_group_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.iccp_group_id.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "bundle-data"):
                                for c in self.bundle_data:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = BundleInformation.MlacpBundleCounters.Nodes.Node.NodeItem.IccpGroupData.BundleData()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.bundle_data.append(c)
                                return c

                            if (child_yang_name == "mlacp-sync-requests-on-all-local-bundles"):
                                if (self.mlacp_sync_requests_on_all_local_bundles is None):
                                    self.mlacp_sync_requests_on_all_local_bundles = BundleInformation.MlacpBundleCounters.Nodes.Node.NodeItem.IccpGroupData.MlacpSyncRequestsOnAllLocalBundles()
                                    self.mlacp_sync_requests_on_all_local_bundles.parent = self
                                    self._children_name_map["mlacp_sync_requests_on_all_local_bundles"] = "mlacp-sync-requests-on-all-local-bundles"
                                return self.mlacp_sync_requests_on_all_local_bundles

                            if (child_yang_name == "mlacp-sync-requests-on-all-local-ports"):
                                if (self.mlacp_sync_requests_on_all_local_ports is None):
                                    self.mlacp_sync_requests_on_all_local_ports = BundleInformation.MlacpBundleCounters.Nodes.Node.NodeItem.IccpGroupData.MlacpSyncRequestsOnAllLocalPorts()
                                    self.mlacp_sync_requests_on_all_local_ports.parent = self
                                    self._children_name_map["mlacp_sync_requests_on_all_local_ports"] = "mlacp-sync-requests-on-all-local-ports"
                                return self.mlacp_sync_requests_on_all_local_ports

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "bundle-data" or name == "mlacp-sync-requests-on-all-local-bundles" or name == "mlacp-sync-requests-on-all-local-ports" or name == "iccp-group-id"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "iccp-group-id"):
                                self.iccp_group_id = value
                                self.iccp_group_id.value_namespace = name_space
                                self.iccp_group_id.value_namespace_prefix = name_space_prefix


                    class NodeData(Entity):
                        """
                        Peer device bundle mLACP counter information
                        
                        .. attribute:: bundle_data
                        
                        	Peer device bundle mLACP TLV counter information
                        	**type**\: list of    :py:class:`BundleData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.MlacpBundleCounters.Nodes.Node.NodeItem.NodeData.BundleData>`
                        
                        .. attribute:: node_data
                        
                        	Peer device mLACP TLV counter information
                        	**type**\:   :py:class:`NodeData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.MlacpBundleCounters.Nodes.Node.NodeItem.NodeData.NodeData>`
                        
                        

                        """

                        _prefix = 'bundlemgr-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(BundleInformation.MlacpBundleCounters.Nodes.Node.NodeItem.NodeData, self).__init__()

                            self.yang_name = "node-data"
                            self.yang_parent_name = "node-item"

                            self.node_data = BundleInformation.MlacpBundleCounters.Nodes.Node.NodeItem.NodeData.NodeData()
                            self.node_data.parent = self
                            self._children_name_map["node_data"] = "node-data"
                            self._children_yang_names.add("node-data")

                            self.bundle_data = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(BundleInformation.MlacpBundleCounters.Nodes.Node.NodeItem.NodeData, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(BundleInformation.MlacpBundleCounters.Nodes.Node.NodeItem.NodeData, self).__setattr__(name, value)


                        class NodeData(Entity):
                            """
                            Peer device mLACP TLV counter information
                            
                            .. attribute:: mlacp_sync_requests_on_all_foreign_bundles
                            
                            	Counts of mLACP sync request TLVs on all bundles
                            	**type**\:   :py:class:`MlacpSyncRequestsOnAllForeignBundles <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.MlacpBundleCounters.Nodes.Node.NodeItem.NodeData.NodeData.MlacpSyncRequestsOnAllForeignBundles>`
                            
                            .. attribute:: mlacp_sync_requests_on_all_foreign_ports
                            
                            	Counts of mLACP sync request TLVs on all ports
                            	**type**\:   :py:class:`MlacpSyncRequestsOnAllForeignPorts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.MlacpBundleCounters.Nodes.Node.NodeItem.NodeData.NodeData.MlacpSyncRequestsOnAllForeignPorts>`
                            
                            .. attribute:: node_id
                            
                            	Device ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'bundlemgr-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(BundleInformation.MlacpBundleCounters.Nodes.Node.NodeItem.NodeData.NodeData, self).__init__()

                                self.yang_name = "node-data"
                                self.yang_parent_name = "node-data"

                                self.node_id = YLeaf(YType.uint32, "node-id")

                                self.mlacp_sync_requests_on_all_foreign_bundles = BundleInformation.MlacpBundleCounters.Nodes.Node.NodeItem.NodeData.NodeData.MlacpSyncRequestsOnAllForeignBundles()
                                self.mlacp_sync_requests_on_all_foreign_bundles.parent = self
                                self._children_name_map["mlacp_sync_requests_on_all_foreign_bundles"] = "mlacp-sync-requests-on-all-foreign-bundles"
                                self._children_yang_names.add("mlacp-sync-requests-on-all-foreign-bundles")

                                self.mlacp_sync_requests_on_all_foreign_ports = BundleInformation.MlacpBundleCounters.Nodes.Node.NodeItem.NodeData.NodeData.MlacpSyncRequestsOnAllForeignPorts()
                                self.mlacp_sync_requests_on_all_foreign_ports.parent = self
                                self._children_name_map["mlacp_sync_requests_on_all_foreign_ports"] = "mlacp-sync-requests-on-all-foreign-ports"
                                self._children_yang_names.add("mlacp-sync-requests-on-all-foreign-ports")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("node_id") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(BundleInformation.MlacpBundleCounters.Nodes.Node.NodeItem.NodeData.NodeData, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(BundleInformation.MlacpBundleCounters.Nodes.Node.NodeItem.NodeData.NodeData, self).__setattr__(name, value)


                            class MlacpSyncRequestsOnAllForeignPorts(Entity):
                                """
                                Counts of mLACP sync request TLVs on all ports
                                
                                .. attribute:: last_time_cleared
                                
                                	Time in nsecs from boot when counters were last cleared (deprecated)
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: nanosecond
                                
                                .. attribute:: received_sync_requests
                                
                                	Number of mLACP sync request TLVs received
                                	**type**\:   :py:class:`ReceivedSyncRequests <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.MlacpBundleCounters.Nodes.Node.NodeItem.NodeData.NodeData.MlacpSyncRequestsOnAllForeignPorts.ReceivedSyncRequests>`
                                
                                .. attribute:: time_since_cleared
                                
                                	Elapsed time in nsecs since counters were last cleared
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: nanosecond
                                
                                

                                """

                                _prefix = 'bundlemgr-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(BundleInformation.MlacpBundleCounters.Nodes.Node.NodeItem.NodeData.NodeData.MlacpSyncRequestsOnAllForeignPorts, self).__init__()

                                    self.yang_name = "mlacp-sync-requests-on-all-foreign-ports"
                                    self.yang_parent_name = "node-data"

                                    self.last_time_cleared = YLeaf(YType.uint64, "last-time-cleared")

                                    self.time_since_cleared = YLeaf(YType.uint64, "time-since-cleared")

                                    self.received_sync_requests = BundleInformation.MlacpBundleCounters.Nodes.Node.NodeItem.NodeData.NodeData.MlacpSyncRequestsOnAllForeignPorts.ReceivedSyncRequests()
                                    self.received_sync_requests.parent = self
                                    self._children_name_map["received_sync_requests"] = "received-sync-requests"
                                    self._children_yang_names.add("received-sync-requests")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("last_time_cleared",
                                                    "time_since_cleared") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(BundleInformation.MlacpBundleCounters.Nodes.Node.NodeItem.NodeData.NodeData.MlacpSyncRequestsOnAllForeignPorts, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(BundleInformation.MlacpBundleCounters.Nodes.Node.NodeItem.NodeData.NodeData.MlacpSyncRequestsOnAllForeignPorts, self).__setattr__(name, value)


                                class ReceivedSyncRequests(Entity):
                                    """
                                    Number of mLACP sync request TLVs received
                                    
                                    .. attribute:: all_syncs
                                    
                                    	Total number of sync requests received
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: config_syncs
                                    
                                    	Number of config sync requests received
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: state_syncs
                                    
                                    	Number of state sync requests received
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'bundlemgr-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(BundleInformation.MlacpBundleCounters.Nodes.Node.NodeItem.NodeData.NodeData.MlacpSyncRequestsOnAllForeignPorts.ReceivedSyncRequests, self).__init__()

                                        self.yang_name = "received-sync-requests"
                                        self.yang_parent_name = "mlacp-sync-requests-on-all-foreign-ports"

                                        self.all_syncs = YLeaf(YType.uint32, "all-syncs")

                                        self.config_syncs = YLeaf(YType.uint32, "config-syncs")

                                        self.state_syncs = YLeaf(YType.uint32, "state-syncs")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("all_syncs",
                                                        "config_syncs",
                                                        "state_syncs") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(BundleInformation.MlacpBundleCounters.Nodes.Node.NodeItem.NodeData.NodeData.MlacpSyncRequestsOnAllForeignPorts.ReceivedSyncRequests, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(BundleInformation.MlacpBundleCounters.Nodes.Node.NodeItem.NodeData.NodeData.MlacpSyncRequestsOnAllForeignPorts.ReceivedSyncRequests, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.all_syncs.is_set or
                                            self.config_syncs.is_set or
                                            self.state_syncs.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.all_syncs.yfilter != YFilter.not_set or
                                            self.config_syncs.yfilter != YFilter.not_set or
                                            self.state_syncs.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "received-sync-requests" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.all_syncs.is_set or self.all_syncs.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.all_syncs.get_name_leafdata())
                                        if (self.config_syncs.is_set or self.config_syncs.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.config_syncs.get_name_leafdata())
                                        if (self.state_syncs.is_set or self.state_syncs.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.state_syncs.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "all-syncs" or name == "config-syncs" or name == "state-syncs"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "all-syncs"):
                                            self.all_syncs = value
                                            self.all_syncs.value_namespace = name_space
                                            self.all_syncs.value_namespace_prefix = name_space_prefix
                                        if(value_path == "config-syncs"):
                                            self.config_syncs = value
                                            self.config_syncs.value_namespace = name_space
                                            self.config_syncs.value_namespace_prefix = name_space_prefix
                                        if(value_path == "state-syncs"):
                                            self.state_syncs = value
                                            self.state_syncs.value_namespace = name_space
                                            self.state_syncs.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.last_time_cleared.is_set or
                                        self.time_since_cleared.is_set or
                                        (self.received_sync_requests is not None and self.received_sync_requests.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.last_time_cleared.yfilter != YFilter.not_set or
                                        self.time_since_cleared.yfilter != YFilter.not_set or
                                        (self.received_sync_requests is not None and self.received_sync_requests.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "mlacp-sync-requests-on-all-foreign-ports" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.last_time_cleared.is_set or self.last_time_cleared.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.last_time_cleared.get_name_leafdata())
                                    if (self.time_since_cleared.is_set or self.time_since_cleared.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.time_since_cleared.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "received-sync-requests"):
                                        if (self.received_sync_requests is None):
                                            self.received_sync_requests = BundleInformation.MlacpBundleCounters.Nodes.Node.NodeItem.NodeData.NodeData.MlacpSyncRequestsOnAllForeignPorts.ReceivedSyncRequests()
                                            self.received_sync_requests.parent = self
                                            self._children_name_map["received_sync_requests"] = "received-sync-requests"
                                        return self.received_sync_requests

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "received-sync-requests" or name == "last-time-cleared" or name == "time-since-cleared"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "last-time-cleared"):
                                        self.last_time_cleared = value
                                        self.last_time_cleared.value_namespace = name_space
                                        self.last_time_cleared.value_namespace_prefix = name_space_prefix
                                    if(value_path == "time-since-cleared"):
                                        self.time_since_cleared = value
                                        self.time_since_cleared.value_namespace = name_space
                                        self.time_since_cleared.value_namespace_prefix = name_space_prefix


                            class MlacpSyncRequestsOnAllForeignBundles(Entity):
                                """
                                Counts of mLACP sync request TLVs on all bundles
                                
                                .. attribute:: last_time_cleared
                                
                                	Time in nsecs from boot when counters were last cleared (deprecated)
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: nanosecond
                                
                                .. attribute:: received_sync_requests
                                
                                	Number of mLACP sync request TLVs received
                                	**type**\:   :py:class:`ReceivedSyncRequests <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.MlacpBundleCounters.Nodes.Node.NodeItem.NodeData.NodeData.MlacpSyncRequestsOnAllForeignBundles.ReceivedSyncRequests>`
                                
                                .. attribute:: time_since_cleared
                                
                                	Elapsed time in nsecs since counters were last cleared
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: nanosecond
                                
                                

                                """

                                _prefix = 'bundlemgr-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(BundleInformation.MlacpBundleCounters.Nodes.Node.NodeItem.NodeData.NodeData.MlacpSyncRequestsOnAllForeignBundles, self).__init__()

                                    self.yang_name = "mlacp-sync-requests-on-all-foreign-bundles"
                                    self.yang_parent_name = "node-data"

                                    self.last_time_cleared = YLeaf(YType.uint64, "last-time-cleared")

                                    self.time_since_cleared = YLeaf(YType.uint64, "time-since-cleared")

                                    self.received_sync_requests = BundleInformation.MlacpBundleCounters.Nodes.Node.NodeItem.NodeData.NodeData.MlacpSyncRequestsOnAllForeignBundles.ReceivedSyncRequests()
                                    self.received_sync_requests.parent = self
                                    self._children_name_map["received_sync_requests"] = "received-sync-requests"
                                    self._children_yang_names.add("received-sync-requests")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("last_time_cleared",
                                                    "time_since_cleared") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(BundleInformation.MlacpBundleCounters.Nodes.Node.NodeItem.NodeData.NodeData.MlacpSyncRequestsOnAllForeignBundles, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(BundleInformation.MlacpBundleCounters.Nodes.Node.NodeItem.NodeData.NodeData.MlacpSyncRequestsOnAllForeignBundles, self).__setattr__(name, value)


                                class ReceivedSyncRequests(Entity):
                                    """
                                    Number of mLACP sync request TLVs received
                                    
                                    .. attribute:: all_syncs
                                    
                                    	Total number of sync requests received
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: config_syncs
                                    
                                    	Number of config sync requests received
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: state_syncs
                                    
                                    	Number of state sync requests received
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'bundlemgr-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(BundleInformation.MlacpBundleCounters.Nodes.Node.NodeItem.NodeData.NodeData.MlacpSyncRequestsOnAllForeignBundles.ReceivedSyncRequests, self).__init__()

                                        self.yang_name = "received-sync-requests"
                                        self.yang_parent_name = "mlacp-sync-requests-on-all-foreign-bundles"

                                        self.all_syncs = YLeaf(YType.uint32, "all-syncs")

                                        self.config_syncs = YLeaf(YType.uint32, "config-syncs")

                                        self.state_syncs = YLeaf(YType.uint32, "state-syncs")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("all_syncs",
                                                        "config_syncs",
                                                        "state_syncs") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(BundleInformation.MlacpBundleCounters.Nodes.Node.NodeItem.NodeData.NodeData.MlacpSyncRequestsOnAllForeignBundles.ReceivedSyncRequests, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(BundleInformation.MlacpBundleCounters.Nodes.Node.NodeItem.NodeData.NodeData.MlacpSyncRequestsOnAllForeignBundles.ReceivedSyncRequests, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.all_syncs.is_set or
                                            self.config_syncs.is_set or
                                            self.state_syncs.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.all_syncs.yfilter != YFilter.not_set or
                                            self.config_syncs.yfilter != YFilter.not_set or
                                            self.state_syncs.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "received-sync-requests" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.all_syncs.is_set or self.all_syncs.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.all_syncs.get_name_leafdata())
                                        if (self.config_syncs.is_set or self.config_syncs.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.config_syncs.get_name_leafdata())
                                        if (self.state_syncs.is_set or self.state_syncs.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.state_syncs.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "all-syncs" or name == "config-syncs" or name == "state-syncs"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "all-syncs"):
                                            self.all_syncs = value
                                            self.all_syncs.value_namespace = name_space
                                            self.all_syncs.value_namespace_prefix = name_space_prefix
                                        if(value_path == "config-syncs"):
                                            self.config_syncs = value
                                            self.config_syncs.value_namespace = name_space
                                            self.config_syncs.value_namespace_prefix = name_space_prefix
                                        if(value_path == "state-syncs"):
                                            self.state_syncs = value
                                            self.state_syncs.value_namespace = name_space
                                            self.state_syncs.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.last_time_cleared.is_set or
                                        self.time_since_cleared.is_set or
                                        (self.received_sync_requests is not None and self.received_sync_requests.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.last_time_cleared.yfilter != YFilter.not_set or
                                        self.time_since_cleared.yfilter != YFilter.not_set or
                                        (self.received_sync_requests is not None and self.received_sync_requests.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "mlacp-sync-requests-on-all-foreign-bundles" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.last_time_cleared.is_set or self.last_time_cleared.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.last_time_cleared.get_name_leafdata())
                                    if (self.time_since_cleared.is_set or self.time_since_cleared.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.time_since_cleared.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "received-sync-requests"):
                                        if (self.received_sync_requests is None):
                                            self.received_sync_requests = BundleInformation.MlacpBundleCounters.Nodes.Node.NodeItem.NodeData.NodeData.MlacpSyncRequestsOnAllForeignBundles.ReceivedSyncRequests()
                                            self.received_sync_requests.parent = self
                                            self._children_name_map["received_sync_requests"] = "received-sync-requests"
                                        return self.received_sync_requests

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "received-sync-requests" or name == "last-time-cleared" or name == "time-since-cleared"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "last-time-cleared"):
                                        self.last_time_cleared = value
                                        self.last_time_cleared.value_namespace = name_space
                                        self.last_time_cleared.value_namespace_prefix = name_space_prefix
                                    if(value_path == "time-since-cleared"):
                                        self.time_since_cleared = value
                                        self.time_since_cleared.value_namespace = name_space
                                        self.time_since_cleared.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.node_id.is_set or
                                    (self.mlacp_sync_requests_on_all_foreign_bundles is not None and self.mlacp_sync_requests_on_all_foreign_bundles.has_data()) or
                                    (self.mlacp_sync_requests_on_all_foreign_ports is not None and self.mlacp_sync_requests_on_all_foreign_ports.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.node_id.yfilter != YFilter.not_set or
                                    (self.mlacp_sync_requests_on_all_foreign_bundles is not None and self.mlacp_sync_requests_on_all_foreign_bundles.has_operation()) or
                                    (self.mlacp_sync_requests_on_all_foreign_ports is not None and self.mlacp_sync_requests_on_all_foreign_ports.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "node-data" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.node_id.is_set or self.node_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.node_id.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "mlacp-sync-requests-on-all-foreign-bundles"):
                                    if (self.mlacp_sync_requests_on_all_foreign_bundles is None):
                                        self.mlacp_sync_requests_on_all_foreign_bundles = BundleInformation.MlacpBundleCounters.Nodes.Node.NodeItem.NodeData.NodeData.MlacpSyncRequestsOnAllForeignBundles()
                                        self.mlacp_sync_requests_on_all_foreign_bundles.parent = self
                                        self._children_name_map["mlacp_sync_requests_on_all_foreign_bundles"] = "mlacp-sync-requests-on-all-foreign-bundles"
                                    return self.mlacp_sync_requests_on_all_foreign_bundles

                                if (child_yang_name == "mlacp-sync-requests-on-all-foreign-ports"):
                                    if (self.mlacp_sync_requests_on_all_foreign_ports is None):
                                        self.mlacp_sync_requests_on_all_foreign_ports = BundleInformation.MlacpBundleCounters.Nodes.Node.NodeItem.NodeData.NodeData.MlacpSyncRequestsOnAllForeignPorts()
                                        self.mlacp_sync_requests_on_all_foreign_ports.parent = self
                                        self._children_name_map["mlacp_sync_requests_on_all_foreign_ports"] = "mlacp-sync-requests-on-all-foreign-ports"
                                    return self.mlacp_sync_requests_on_all_foreign_ports

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "mlacp-sync-requests-on-all-foreign-bundles" or name == "mlacp-sync-requests-on-all-foreign-ports" or name == "node-id"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "node-id"):
                                    self.node_id = value
                                    self.node_id.value_namespace = name_space
                                    self.node_id.value_namespace_prefix = name_space_prefix


                        class BundleData(Entity):
                            """
                            Peer device bundle mLACP TLV counter information
                            
                            .. attribute:: bundle_name
                            
                            	Bundle name
                            	**type**\:  str
                            
                            .. attribute:: mlacp_tlv_counters
                            
                            	Counts of mLACP TLVs sent and received
                            	**type**\:   :py:class:`MlacpTlvCounters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.MlacpBundleCounters.Nodes.Node.NodeItem.NodeData.BundleData.MlacpTlvCounters>`
                            
                            

                            """

                            _prefix = 'bundlemgr-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(BundleInformation.MlacpBundleCounters.Nodes.Node.NodeItem.NodeData.BundleData, self).__init__()

                                self.yang_name = "bundle-data"
                                self.yang_parent_name = "node-data"

                                self.bundle_name = YLeaf(YType.str, "bundle-name")

                                self.mlacp_tlv_counters = BundleInformation.MlacpBundleCounters.Nodes.Node.NodeItem.NodeData.BundleData.MlacpTlvCounters()
                                self.mlacp_tlv_counters.parent = self
                                self._children_name_map["mlacp_tlv_counters"] = "mlacp-tlv-counters"
                                self._children_yang_names.add("mlacp-tlv-counters")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("bundle_name") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(BundleInformation.MlacpBundleCounters.Nodes.Node.NodeItem.NodeData.BundleData, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(BundleInformation.MlacpBundleCounters.Nodes.Node.NodeItem.NodeData.BundleData, self).__setattr__(name, value)


                            class MlacpTlvCounters(Entity):
                                """
                                Counts of mLACP TLVs sent and received
                                
                                .. attribute:: last_time_cleared
                                
                                	Time in nsecs from boot when counters were last cleared (deprecated)
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: nanosecond
                                
                                .. attribute:: last_unexpected_event
                                
                                	Elapsed time in nsecs since last unexpected event
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: nanosecond
                                
                                .. attribute:: received_nak_tl_vs
                                
                                	Number of mLACP NAK TLVs received
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: received_priority_tl_vs
                                
                                	Number of mLACP priority TLVs received
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: received_sync_requests
                                
                                	Number of mLACP sync request TLVs received
                                	**type**\:   :py:class:`ReceivedSyncRequests <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.MlacpBundleCounters.Nodes.Node.NodeItem.NodeData.BundleData.MlacpTlvCounters.ReceivedSyncRequests>`
                                
                                .. attribute:: sent_config_tl_vs
                                
                                	Number of mLACP config TLVs sent
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: sent_priority_tl_vs
                                
                                	Number of mLACP priority TLVs sent
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: sent_state_tl_vs
                                
                                	Number of mLACP state TLVs sent
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: time_since_cleared
                                
                                	Elapsed time in nsecs since counters were last cleared
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: nanosecond
                                
                                

                                """

                                _prefix = 'bundlemgr-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(BundleInformation.MlacpBundleCounters.Nodes.Node.NodeItem.NodeData.BundleData.MlacpTlvCounters, self).__init__()

                                    self.yang_name = "mlacp-tlv-counters"
                                    self.yang_parent_name = "bundle-data"

                                    self.last_time_cleared = YLeaf(YType.uint64, "last-time-cleared")

                                    self.last_unexpected_event = YLeaf(YType.uint64, "last-unexpected-event")

                                    self.received_nak_tl_vs = YLeaf(YType.uint32, "received-nak-tl-vs")

                                    self.received_priority_tl_vs = YLeaf(YType.uint32, "received-priority-tl-vs")

                                    self.sent_config_tl_vs = YLeaf(YType.uint32, "sent-config-tl-vs")

                                    self.sent_priority_tl_vs = YLeaf(YType.uint32, "sent-priority-tl-vs")

                                    self.sent_state_tl_vs = YLeaf(YType.uint32, "sent-state-tl-vs")

                                    self.time_since_cleared = YLeaf(YType.uint64, "time-since-cleared")

                                    self.received_sync_requests = BundleInformation.MlacpBundleCounters.Nodes.Node.NodeItem.NodeData.BundleData.MlacpTlvCounters.ReceivedSyncRequests()
                                    self.received_sync_requests.parent = self
                                    self._children_name_map["received_sync_requests"] = "received-sync-requests"
                                    self._children_yang_names.add("received-sync-requests")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("last_time_cleared",
                                                    "last_unexpected_event",
                                                    "received_nak_tl_vs",
                                                    "received_priority_tl_vs",
                                                    "sent_config_tl_vs",
                                                    "sent_priority_tl_vs",
                                                    "sent_state_tl_vs",
                                                    "time_since_cleared") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(BundleInformation.MlacpBundleCounters.Nodes.Node.NodeItem.NodeData.BundleData.MlacpTlvCounters, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(BundleInformation.MlacpBundleCounters.Nodes.Node.NodeItem.NodeData.BundleData.MlacpTlvCounters, self).__setattr__(name, value)


                                class ReceivedSyncRequests(Entity):
                                    """
                                    Number of mLACP sync request TLVs received
                                    
                                    .. attribute:: all_syncs
                                    
                                    	Total number of sync requests received
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: config_syncs
                                    
                                    	Number of config sync requests received
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: state_syncs
                                    
                                    	Number of state sync requests received
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'bundlemgr-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(BundleInformation.MlacpBundleCounters.Nodes.Node.NodeItem.NodeData.BundleData.MlacpTlvCounters.ReceivedSyncRequests, self).__init__()

                                        self.yang_name = "received-sync-requests"
                                        self.yang_parent_name = "mlacp-tlv-counters"

                                        self.all_syncs = YLeaf(YType.uint32, "all-syncs")

                                        self.config_syncs = YLeaf(YType.uint32, "config-syncs")

                                        self.state_syncs = YLeaf(YType.uint32, "state-syncs")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("all_syncs",
                                                        "config_syncs",
                                                        "state_syncs") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(BundleInformation.MlacpBundleCounters.Nodes.Node.NodeItem.NodeData.BundleData.MlacpTlvCounters.ReceivedSyncRequests, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(BundleInformation.MlacpBundleCounters.Nodes.Node.NodeItem.NodeData.BundleData.MlacpTlvCounters.ReceivedSyncRequests, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.all_syncs.is_set or
                                            self.config_syncs.is_set or
                                            self.state_syncs.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.all_syncs.yfilter != YFilter.not_set or
                                            self.config_syncs.yfilter != YFilter.not_set or
                                            self.state_syncs.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "received-sync-requests" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.all_syncs.is_set or self.all_syncs.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.all_syncs.get_name_leafdata())
                                        if (self.config_syncs.is_set or self.config_syncs.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.config_syncs.get_name_leafdata())
                                        if (self.state_syncs.is_set or self.state_syncs.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.state_syncs.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "all-syncs" or name == "config-syncs" or name == "state-syncs"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "all-syncs"):
                                            self.all_syncs = value
                                            self.all_syncs.value_namespace = name_space
                                            self.all_syncs.value_namespace_prefix = name_space_prefix
                                        if(value_path == "config-syncs"):
                                            self.config_syncs = value
                                            self.config_syncs.value_namespace = name_space
                                            self.config_syncs.value_namespace_prefix = name_space_prefix
                                        if(value_path == "state-syncs"):
                                            self.state_syncs = value
                                            self.state_syncs.value_namespace = name_space
                                            self.state_syncs.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.last_time_cleared.is_set or
                                        self.last_unexpected_event.is_set or
                                        self.received_nak_tl_vs.is_set or
                                        self.received_priority_tl_vs.is_set or
                                        self.sent_config_tl_vs.is_set or
                                        self.sent_priority_tl_vs.is_set or
                                        self.sent_state_tl_vs.is_set or
                                        self.time_since_cleared.is_set or
                                        (self.received_sync_requests is not None and self.received_sync_requests.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.last_time_cleared.yfilter != YFilter.not_set or
                                        self.last_unexpected_event.yfilter != YFilter.not_set or
                                        self.received_nak_tl_vs.yfilter != YFilter.not_set or
                                        self.received_priority_tl_vs.yfilter != YFilter.not_set or
                                        self.sent_config_tl_vs.yfilter != YFilter.not_set or
                                        self.sent_priority_tl_vs.yfilter != YFilter.not_set or
                                        self.sent_state_tl_vs.yfilter != YFilter.not_set or
                                        self.time_since_cleared.yfilter != YFilter.not_set or
                                        (self.received_sync_requests is not None and self.received_sync_requests.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "mlacp-tlv-counters" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.last_time_cleared.is_set or self.last_time_cleared.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.last_time_cleared.get_name_leafdata())
                                    if (self.last_unexpected_event.is_set or self.last_unexpected_event.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.last_unexpected_event.get_name_leafdata())
                                    if (self.received_nak_tl_vs.is_set or self.received_nak_tl_vs.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.received_nak_tl_vs.get_name_leafdata())
                                    if (self.received_priority_tl_vs.is_set or self.received_priority_tl_vs.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.received_priority_tl_vs.get_name_leafdata())
                                    if (self.sent_config_tl_vs.is_set or self.sent_config_tl_vs.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.sent_config_tl_vs.get_name_leafdata())
                                    if (self.sent_priority_tl_vs.is_set or self.sent_priority_tl_vs.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.sent_priority_tl_vs.get_name_leafdata())
                                    if (self.sent_state_tl_vs.is_set or self.sent_state_tl_vs.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.sent_state_tl_vs.get_name_leafdata())
                                    if (self.time_since_cleared.is_set or self.time_since_cleared.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.time_since_cleared.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "received-sync-requests"):
                                        if (self.received_sync_requests is None):
                                            self.received_sync_requests = BundleInformation.MlacpBundleCounters.Nodes.Node.NodeItem.NodeData.BundleData.MlacpTlvCounters.ReceivedSyncRequests()
                                            self.received_sync_requests.parent = self
                                            self._children_name_map["received_sync_requests"] = "received-sync-requests"
                                        return self.received_sync_requests

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "received-sync-requests" or name == "last-time-cleared" or name == "last-unexpected-event" or name == "received-nak-tl-vs" or name == "received-priority-tl-vs" or name == "sent-config-tl-vs" or name == "sent-priority-tl-vs" or name == "sent-state-tl-vs" or name == "time-since-cleared"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "last-time-cleared"):
                                        self.last_time_cleared = value
                                        self.last_time_cleared.value_namespace = name_space
                                        self.last_time_cleared.value_namespace_prefix = name_space_prefix
                                    if(value_path == "last-unexpected-event"):
                                        self.last_unexpected_event = value
                                        self.last_unexpected_event.value_namespace = name_space
                                        self.last_unexpected_event.value_namespace_prefix = name_space_prefix
                                    if(value_path == "received-nak-tl-vs"):
                                        self.received_nak_tl_vs = value
                                        self.received_nak_tl_vs.value_namespace = name_space
                                        self.received_nak_tl_vs.value_namespace_prefix = name_space_prefix
                                    if(value_path == "received-priority-tl-vs"):
                                        self.received_priority_tl_vs = value
                                        self.received_priority_tl_vs.value_namespace = name_space
                                        self.received_priority_tl_vs.value_namespace_prefix = name_space_prefix
                                    if(value_path == "sent-config-tl-vs"):
                                        self.sent_config_tl_vs = value
                                        self.sent_config_tl_vs.value_namespace = name_space
                                        self.sent_config_tl_vs.value_namespace_prefix = name_space_prefix
                                    if(value_path == "sent-priority-tl-vs"):
                                        self.sent_priority_tl_vs = value
                                        self.sent_priority_tl_vs.value_namespace = name_space
                                        self.sent_priority_tl_vs.value_namespace_prefix = name_space_prefix
                                    if(value_path == "sent-state-tl-vs"):
                                        self.sent_state_tl_vs = value
                                        self.sent_state_tl_vs.value_namespace = name_space
                                        self.sent_state_tl_vs.value_namespace_prefix = name_space_prefix
                                    if(value_path == "time-since-cleared"):
                                        self.time_since_cleared = value
                                        self.time_since_cleared.value_namespace = name_space
                                        self.time_since_cleared.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.bundle_name.is_set or
                                    (self.mlacp_tlv_counters is not None and self.mlacp_tlv_counters.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.bundle_name.yfilter != YFilter.not_set or
                                    (self.mlacp_tlv_counters is not None and self.mlacp_tlv_counters.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "bundle-data" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.bundle_name.is_set or self.bundle_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.bundle_name.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "mlacp-tlv-counters"):
                                    if (self.mlacp_tlv_counters is None):
                                        self.mlacp_tlv_counters = BundleInformation.MlacpBundleCounters.Nodes.Node.NodeItem.NodeData.BundleData.MlacpTlvCounters()
                                        self.mlacp_tlv_counters.parent = self
                                        self._children_name_map["mlacp_tlv_counters"] = "mlacp-tlv-counters"
                                    return self.mlacp_tlv_counters

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "mlacp-tlv-counters" or name == "bundle-name"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "bundle-name"):
                                    self.bundle_name = value
                                    self.bundle_name.value_namespace = name_space
                                    self.bundle_name.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.bundle_data:
                                if (c.has_data()):
                                    return True
                            return (self.node_data is not None and self.node_data.has_data())

                        def has_operation(self):
                            for c in self.bundle_data:
                                if (c.has_operation()):
                                    return True
                            return (
                                self.yfilter != YFilter.not_set or
                                (self.node_data is not None and self.node_data.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "node-data" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "bundle-data"):
                                for c in self.bundle_data:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = BundleInformation.MlacpBundleCounters.Nodes.Node.NodeItem.NodeData.BundleData()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.bundle_data.append(c)
                                return c

                            if (child_yang_name == "node-data"):
                                if (self.node_data is None):
                                    self.node_data = BundleInformation.MlacpBundleCounters.Nodes.Node.NodeItem.NodeData.NodeData()
                                    self.node_data.parent = self
                                    self._children_name_map["node_data"] = "node-data"
                                return self.node_data

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "bundle-data" or name == "node-data"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass

                    def has_data(self):
                        for c in self.node_data:
                            if (c.has_data()):
                                return True
                        return (self.iccp_group_data is not None and self.iccp_group_data.has_data())

                    def has_operation(self):
                        for c in self.node_data:
                            if (c.has_operation()):
                                return True
                        return (
                            self.yfilter != YFilter.not_set or
                            (self.iccp_group_data is not None and self.iccp_group_data.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "node-item" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "iccp-group-data"):
                            if (self.iccp_group_data is None):
                                self.iccp_group_data = BundleInformation.MlacpBundleCounters.Nodes.Node.NodeItem.IccpGroupData()
                                self.iccp_group_data.parent = self
                                self._children_name_map["iccp_group_data"] = "iccp-group-data"
                            return self.iccp_group_data

                        if (child_yang_name == "node-data"):
                            for c in self.node_data:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = BundleInformation.MlacpBundleCounters.Nodes.Node.NodeItem.NodeData()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.node_data.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "iccp-group-data" or name == "node-data"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass

                def has_data(self):
                    return (
                        self.node.is_set or
                        (self.node_item is not None and self.node_item.has_data()))

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.node.yfilter != YFilter.not_set or
                        (self.node_item is not None and self.node_item.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "node" + "[node='" + self.node.get() + "']" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-bundlemgr-oper:bundle-information/mlacp-bundle-counters/nodes/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.node.is_set or self.node.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.node.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "node-item"):
                        if (self.node_item is None):
                            self.node_item = BundleInformation.MlacpBundleCounters.Nodes.Node.NodeItem()
                            self.node_item.parent = self
                            self._children_name_map["node_item"] = "node-item"
                        return self.node_item

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "node-item" or name == "node"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "node"):
                        self.node = value
                        self.node.value_namespace = name_space
                        self.node.value_namespace_prefix = name_space_prefix

            def has_data(self):
                for c in self.node:
                    if (c.has_data()):
                        return True
                return False

            def has_operation(self):
                for c in self.node:
                    if (c.has_operation()):
                        return True
                return self.yfilter != YFilter.not_set

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "nodes" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-bundlemgr-oper:bundle-information/mlacp-bundle-counters/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "node"):
                    for c in self.node:
                        segment = c.get_segment_path()
                        if (segment_path == segment):
                            return c
                    c = BundleInformation.MlacpBundleCounters.Nodes.Node()
                    c.parent = self
                    local_reference_key = "ydk::seg::%s" % segment_path
                    self._local_refs[local_reference_key] = c
                    self.node.append(c)
                    return c

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "node"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                pass

        def has_data(self):
            return (
                (self.bundles is not None and self.bundles.has_data()) or
                (self.iccp_groups is not None and self.iccp_groups.has_data()) or
                (self.nodes is not None and self.nodes.has_data()))

        def has_operation(self):
            return (
                self.yfilter != YFilter.not_set or
                (self.bundles is not None and self.bundles.has_operation()) or
                (self.iccp_groups is not None and self.iccp_groups.has_operation()) or
                (self.nodes is not None and self.nodes.has_operation()))

        def get_segment_path(self):
            path_buffer = ""
            path_buffer = "mlacp-bundle-counters" + path_buffer

            return path_buffer

        def get_entity_path(self, ancestor):
            path_buffer = ""
            if (ancestor is None):
                path_buffer = "Cisco-IOS-XR-bundlemgr-oper:bundle-information/%s" % self.get_segment_path()
            else:
                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

            leaf_name_data = LeafDataList()

            entity_path = EntityPath(path_buffer, leaf_name_data)
            return entity_path

        def get_child_by_name(self, child_yang_name, segment_path):
            child = self._get_child_by_seg_name([child_yang_name, segment_path])
            if child is not None:
                return child

            if (child_yang_name == "bundles"):
                if (self.bundles is None):
                    self.bundles = BundleInformation.MlacpBundleCounters.Bundles()
                    self.bundles.parent = self
                    self._children_name_map["bundles"] = "bundles"
                return self.bundles

            if (child_yang_name == "iccp-groups"):
                if (self.iccp_groups is None):
                    self.iccp_groups = BundleInformation.MlacpBundleCounters.IccpGroups()
                    self.iccp_groups.parent = self
                    self._children_name_map["iccp_groups"] = "iccp-groups"
                return self.iccp_groups

            if (child_yang_name == "nodes"):
                if (self.nodes is None):
                    self.nodes = BundleInformation.MlacpBundleCounters.Nodes()
                    self.nodes.parent = self
                    self._children_name_map["nodes"] = "nodes"
                return self.nodes

            return None

        def has_leaf_or_child_of_name(self, name):
            if(name == "bundles" or name == "iccp-groups" or name == "nodes"):
                return True
            return False

        def set_value(self, value_path, value, name_space, name_space_prefix):
            pass


    class Protect(Entity):
        """
        Information for bundles and members that are in
        the protect database
        
        .. attribute:: protect_bundles
        
        	Bundle interfaces with information in the protect database
        	**type**\:   :py:class:`ProtectBundles <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.Protect.ProtectBundles>`
        
        

        """

        _prefix = 'bundlemgr-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(BundleInformation.Protect, self).__init__()

            self.yang_name = "protect"
            self.yang_parent_name = "bundle-information"

            self.protect_bundles = BundleInformation.Protect.ProtectBundles()
            self.protect_bundles.parent = self
            self._children_name_map["protect_bundles"] = "protect-bundles"
            self._children_yang_names.add("protect-bundles")


        class ProtectBundles(Entity):
            """
            Bundle interfaces with information in the
            protect database
            
            .. attribute:: protect_bundle
            
            	Bundle interface
            	**type**\: list of    :py:class:`ProtectBundle <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.Protect.ProtectBundles.ProtectBundle>`
            
            

            """

            _prefix = 'bundlemgr-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(BundleInformation.Protect.ProtectBundles, self).__init__()

                self.yang_name = "protect-bundles"
                self.yang_parent_name = "protect"

                self.protect_bundle = YList(self)

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in () and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(BundleInformation.Protect.ProtectBundles, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(BundleInformation.Protect.ProtectBundles, self).__setattr__(name, value)


            class ProtectBundle(Entity):
                """
                Bundle interface
                
                .. attribute:: bundle_interface  <key>
                
                	Bundle interface
                	**type**\:  str
                
                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                
                .. attribute:: protect_bundle_item
                
                	Data for this item
                	**type**\:   :py:class:`ProtectBundleItem <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.Protect.ProtectBundles.ProtectBundle.ProtectBundleItem>`
                
                

                """

                _prefix = 'bundlemgr-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(BundleInformation.Protect.ProtectBundles.ProtectBundle, self).__init__()

                    self.yang_name = "protect-bundle"
                    self.yang_parent_name = "protect-bundles"

                    self.bundle_interface = YLeaf(YType.str, "bundle-interface")

                    self.protect_bundle_item = BundleInformation.Protect.ProtectBundles.ProtectBundle.ProtectBundleItem()
                    self.protect_bundle_item.parent = self
                    self._children_name_map["protect_bundle_item"] = "protect-bundle-item"
                    self._children_yang_names.add("protect-bundle-item")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("bundle_interface") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(BundleInformation.Protect.ProtectBundles.ProtectBundle, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(BundleInformation.Protect.ProtectBundles.ProtectBundle, self).__setattr__(name, value)


                class ProtectBundleItem(Entity):
                    """
                    Data for this item
                    
                    .. attribute:: bundle_interface_handle
                    
                    	Bundle's interface handle
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: event_type
                    
                    	Scope of the last event that impacted the bundle
                    	**type**\:   :py:class:`BmdBagTarget <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmdBagTarget>`
                    
                    .. attribute:: interface_up
                    
                    	Whether the bundle interface is up
                    	**type**\:  bool
                    
                    .. attribute:: member_info
                    
                    	Information about the members
                    	**type**\: list of    :py:class:`MemberInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.Protect.ProtectBundles.ProtectBundle.ProtectBundleItem.MemberInfo>`
                    
                    .. attribute:: minimum_active_links
                    
                    	Minimum active links threshold
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: minimum_bandwidth
                    
                    	Minimum bandwidth threshold
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: registered
                    
                    	Whether there is a client protect registration on the bundle interface
                    	**type**\:  bool
                    
                    .. attribute:: slow_path_trigger
                    
                    	Whether the last protect trigger originated in the slow path
                    	**type**\:  bool
                    
                    .. attribute:: slow_path_up
                    
                    	Bundle is up in the slow path
                    	**type**\:  bool
                    
                    .. attribute:: time_stamp
                    
                    	Last event for the bundle
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    

                    """

                    _prefix = 'bundlemgr-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(BundleInformation.Protect.ProtectBundles.ProtectBundle.ProtectBundleItem, self).__init__()

                        self.yang_name = "protect-bundle-item"
                        self.yang_parent_name = "protect-bundle"

                        self.bundle_interface_handle = YLeaf(YType.str, "bundle-interface-handle")

                        self.event_type = YLeaf(YType.enumeration, "event-type")

                        self.interface_up = YLeaf(YType.boolean, "interface-up")

                        self.minimum_active_links = YLeaf(YType.uint32, "minimum-active-links")

                        self.minimum_bandwidth = YLeaf(YType.uint32, "minimum-bandwidth")

                        self.registered = YLeaf(YType.boolean, "registered")

                        self.slow_path_trigger = YLeaf(YType.boolean, "slow-path-trigger")

                        self.slow_path_up = YLeaf(YType.boolean, "slow-path-up")

                        self.time_stamp = YLeaf(YType.uint64, "time-stamp")

                        self.member_info = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("bundle_interface_handle",
                                        "event_type",
                                        "interface_up",
                                        "minimum_active_links",
                                        "minimum_bandwidth",
                                        "registered",
                                        "slow_path_trigger",
                                        "slow_path_up",
                                        "time_stamp") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(BundleInformation.Protect.ProtectBundles.ProtectBundle.ProtectBundleItem, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(BundleInformation.Protect.ProtectBundles.ProtectBundle.ProtectBundleItem, self).__setattr__(name, value)


                    class MemberInfo(Entity):
                        """
                        Information about the members
                        
                        .. attribute:: active
                        
                        	Member is active within its bundle
                        	**type**\:  bool
                        
                        .. attribute:: bandwidth
                        
                        	Member's bandwidth
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: interface_handle
                        
                        	Member's interface handle
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: link_order_number
                        
                        	Member's link order number
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: node
                        
                        	Member's node ID
                        	**type**\:  str
                        
                        	**pattern:** ([a\-zA\-Z0\-9\_]\*\\d+/){1,2}([a\-zA\-Z0\-9\_]\*\\d+)
                        
                        .. attribute:: notification_received
                        
                        	Received a notification on the member
                        	**type**\:  bool
                        
                        .. attribute:: slow_path_up
                        
                        	Member is up in the slow path
                        	**type**\:  bool
                        
                        .. attribute:: time_stamp
                        
                        	Last event for the member
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: underlying_link_id
                        
                        	Member's underlying link ID
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'bundlemgr-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(BundleInformation.Protect.ProtectBundles.ProtectBundle.ProtectBundleItem.MemberInfo, self).__init__()

                            self.yang_name = "member-info"
                            self.yang_parent_name = "protect-bundle-item"

                            self.active = YLeaf(YType.boolean, "active")

                            self.bandwidth = YLeaf(YType.uint32, "bandwidth")

                            self.interface_handle = YLeaf(YType.str, "interface-handle")

                            self.link_order_number = YLeaf(YType.uint16, "link-order-number")

                            self.node = YLeaf(YType.str, "node")

                            self.notification_received = YLeaf(YType.boolean, "notification-received")

                            self.slow_path_up = YLeaf(YType.boolean, "slow-path-up")

                            self.time_stamp = YLeaf(YType.uint64, "time-stamp")

                            self.underlying_link_id = YLeaf(YType.uint16, "underlying-link-id")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("active",
                                            "bandwidth",
                                            "interface_handle",
                                            "link_order_number",
                                            "node",
                                            "notification_received",
                                            "slow_path_up",
                                            "time_stamp",
                                            "underlying_link_id") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(BundleInformation.Protect.ProtectBundles.ProtectBundle.ProtectBundleItem.MemberInfo, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(BundleInformation.Protect.ProtectBundles.ProtectBundle.ProtectBundleItem.MemberInfo, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.active.is_set or
                                self.bandwidth.is_set or
                                self.interface_handle.is_set or
                                self.link_order_number.is_set or
                                self.node.is_set or
                                self.notification_received.is_set or
                                self.slow_path_up.is_set or
                                self.time_stamp.is_set or
                                self.underlying_link_id.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.active.yfilter != YFilter.not_set or
                                self.bandwidth.yfilter != YFilter.not_set or
                                self.interface_handle.yfilter != YFilter.not_set or
                                self.link_order_number.yfilter != YFilter.not_set or
                                self.node.yfilter != YFilter.not_set or
                                self.notification_received.yfilter != YFilter.not_set or
                                self.slow_path_up.yfilter != YFilter.not_set or
                                self.time_stamp.yfilter != YFilter.not_set or
                                self.underlying_link_id.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "member-info" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.active.is_set or self.active.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.active.get_name_leafdata())
                            if (self.bandwidth.is_set or self.bandwidth.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.bandwidth.get_name_leafdata())
                            if (self.interface_handle.is_set or self.interface_handle.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface_handle.get_name_leafdata())
                            if (self.link_order_number.is_set or self.link_order_number.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.link_order_number.get_name_leafdata())
                            if (self.node.is_set or self.node.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.node.get_name_leafdata())
                            if (self.notification_received.is_set or self.notification_received.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.notification_received.get_name_leafdata())
                            if (self.slow_path_up.is_set or self.slow_path_up.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.slow_path_up.get_name_leafdata())
                            if (self.time_stamp.is_set or self.time_stamp.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.time_stamp.get_name_leafdata())
                            if (self.underlying_link_id.is_set or self.underlying_link_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.underlying_link_id.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "active" or name == "bandwidth" or name == "interface-handle" or name == "link-order-number" or name == "node" or name == "notification-received" or name == "slow-path-up" or name == "time-stamp" or name == "underlying-link-id"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "active"):
                                self.active = value
                                self.active.value_namespace = name_space
                                self.active.value_namespace_prefix = name_space_prefix
                            if(value_path == "bandwidth"):
                                self.bandwidth = value
                                self.bandwidth.value_namespace = name_space
                                self.bandwidth.value_namespace_prefix = name_space_prefix
                            if(value_path == "interface-handle"):
                                self.interface_handle = value
                                self.interface_handle.value_namespace = name_space
                                self.interface_handle.value_namespace_prefix = name_space_prefix
                            if(value_path == "link-order-number"):
                                self.link_order_number = value
                                self.link_order_number.value_namespace = name_space
                                self.link_order_number.value_namespace_prefix = name_space_prefix
                            if(value_path == "node"):
                                self.node = value
                                self.node.value_namespace = name_space
                                self.node.value_namespace_prefix = name_space_prefix
                            if(value_path == "notification-received"):
                                self.notification_received = value
                                self.notification_received.value_namespace = name_space
                                self.notification_received.value_namespace_prefix = name_space_prefix
                            if(value_path == "slow-path-up"):
                                self.slow_path_up = value
                                self.slow_path_up.value_namespace = name_space
                                self.slow_path_up.value_namespace_prefix = name_space_prefix
                            if(value_path == "time-stamp"):
                                self.time_stamp = value
                                self.time_stamp.value_namespace = name_space
                                self.time_stamp.value_namespace_prefix = name_space_prefix
                            if(value_path == "underlying-link-id"):
                                self.underlying_link_id = value
                                self.underlying_link_id.value_namespace = name_space
                                self.underlying_link_id.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.member_info:
                            if (c.has_data()):
                                return True
                        return (
                            self.bundle_interface_handle.is_set or
                            self.event_type.is_set or
                            self.interface_up.is_set or
                            self.minimum_active_links.is_set or
                            self.minimum_bandwidth.is_set or
                            self.registered.is_set or
                            self.slow_path_trigger.is_set or
                            self.slow_path_up.is_set or
                            self.time_stamp.is_set)

                    def has_operation(self):
                        for c in self.member_info:
                            if (c.has_operation()):
                                return True
                        return (
                            self.yfilter != YFilter.not_set or
                            self.bundle_interface_handle.yfilter != YFilter.not_set or
                            self.event_type.yfilter != YFilter.not_set or
                            self.interface_up.yfilter != YFilter.not_set or
                            self.minimum_active_links.yfilter != YFilter.not_set or
                            self.minimum_bandwidth.yfilter != YFilter.not_set or
                            self.registered.yfilter != YFilter.not_set or
                            self.slow_path_trigger.yfilter != YFilter.not_set or
                            self.slow_path_up.yfilter != YFilter.not_set or
                            self.time_stamp.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "protect-bundle-item" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.bundle_interface_handle.is_set or self.bundle_interface_handle.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bundle_interface_handle.get_name_leafdata())
                        if (self.event_type.is_set or self.event_type.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.event_type.get_name_leafdata())
                        if (self.interface_up.is_set or self.interface_up.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_up.get_name_leafdata())
                        if (self.minimum_active_links.is_set or self.minimum_active_links.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.minimum_active_links.get_name_leafdata())
                        if (self.minimum_bandwidth.is_set or self.minimum_bandwidth.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.minimum_bandwidth.get_name_leafdata())
                        if (self.registered.is_set or self.registered.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.registered.get_name_leafdata())
                        if (self.slow_path_trigger.is_set or self.slow_path_trigger.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.slow_path_trigger.get_name_leafdata())
                        if (self.slow_path_up.is_set or self.slow_path_up.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.slow_path_up.get_name_leafdata())
                        if (self.time_stamp.is_set or self.time_stamp.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.time_stamp.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "member-info"):
                            for c in self.member_info:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = BundleInformation.Protect.ProtectBundles.ProtectBundle.ProtectBundleItem.MemberInfo()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.member_info.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "member-info" or name == "bundle-interface-handle" or name == "event-type" or name == "interface-up" or name == "minimum-active-links" or name == "minimum-bandwidth" or name == "registered" or name == "slow-path-trigger" or name == "slow-path-up" or name == "time-stamp"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "bundle-interface-handle"):
                            self.bundle_interface_handle = value
                            self.bundle_interface_handle.value_namespace = name_space
                            self.bundle_interface_handle.value_namespace_prefix = name_space_prefix
                        if(value_path == "event-type"):
                            self.event_type = value
                            self.event_type.value_namespace = name_space
                            self.event_type.value_namespace_prefix = name_space_prefix
                        if(value_path == "interface-up"):
                            self.interface_up = value
                            self.interface_up.value_namespace = name_space
                            self.interface_up.value_namespace_prefix = name_space_prefix
                        if(value_path == "minimum-active-links"):
                            self.minimum_active_links = value
                            self.minimum_active_links.value_namespace = name_space
                            self.minimum_active_links.value_namespace_prefix = name_space_prefix
                        if(value_path == "minimum-bandwidth"):
                            self.minimum_bandwidth = value
                            self.minimum_bandwidth.value_namespace = name_space
                            self.minimum_bandwidth.value_namespace_prefix = name_space_prefix
                        if(value_path == "registered"):
                            self.registered = value
                            self.registered.value_namespace = name_space
                            self.registered.value_namespace_prefix = name_space_prefix
                        if(value_path == "slow-path-trigger"):
                            self.slow_path_trigger = value
                            self.slow_path_trigger.value_namespace = name_space
                            self.slow_path_trigger.value_namespace_prefix = name_space_prefix
                        if(value_path == "slow-path-up"):
                            self.slow_path_up = value
                            self.slow_path_up.value_namespace = name_space
                            self.slow_path_up.value_namespace_prefix = name_space_prefix
                        if(value_path == "time-stamp"):
                            self.time_stamp = value
                            self.time_stamp.value_namespace = name_space
                            self.time_stamp.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    return (
                        self.bundle_interface.is_set or
                        (self.protect_bundle_item is not None and self.protect_bundle_item.has_data()))

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.bundle_interface.yfilter != YFilter.not_set or
                        (self.protect_bundle_item is not None and self.protect_bundle_item.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "protect-bundle" + "[bundle-interface='" + self.bundle_interface.get() + "']" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-bundlemgr-oper:bundle-information/protect/protect-bundles/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.bundle_interface.is_set or self.bundle_interface.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.bundle_interface.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "protect-bundle-item"):
                        if (self.protect_bundle_item is None):
                            self.protect_bundle_item = BundleInformation.Protect.ProtectBundles.ProtectBundle.ProtectBundleItem()
                            self.protect_bundle_item.parent = self
                            self._children_name_map["protect_bundle_item"] = "protect-bundle-item"
                        return self.protect_bundle_item

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "protect-bundle-item" or name == "bundle-interface"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "bundle-interface"):
                        self.bundle_interface = value
                        self.bundle_interface.value_namespace = name_space
                        self.bundle_interface.value_namespace_prefix = name_space_prefix

            def has_data(self):
                for c in self.protect_bundle:
                    if (c.has_data()):
                        return True
                return False

            def has_operation(self):
                for c in self.protect_bundle:
                    if (c.has_operation()):
                        return True
                return self.yfilter != YFilter.not_set

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "protect-bundles" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-bundlemgr-oper:bundle-information/protect/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "protect-bundle"):
                    for c in self.protect_bundle:
                        segment = c.get_segment_path()
                        if (segment_path == segment):
                            return c
                    c = BundleInformation.Protect.ProtectBundles.ProtectBundle()
                    c.parent = self
                    local_reference_key = "ydk::seg::%s" % segment_path
                    self._local_refs[local_reference_key] = c
                    self.protect_bundle.append(c)
                    return c

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "protect-bundle"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                pass

        def has_data(self):
            return (self.protect_bundles is not None and self.protect_bundles.has_data())

        def has_operation(self):
            return (
                self.yfilter != YFilter.not_set or
                (self.protect_bundles is not None and self.protect_bundles.has_operation()))

        def get_segment_path(self):
            path_buffer = ""
            path_buffer = "protect" + path_buffer

            return path_buffer

        def get_entity_path(self, ancestor):
            path_buffer = ""
            if (ancestor is None):
                path_buffer = "Cisco-IOS-XR-bundlemgr-oper:bundle-information/%s" % self.get_segment_path()
            else:
                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

            leaf_name_data = LeafDataList()

            entity_path = EntityPath(path_buffer, leaf_name_data)
            return entity_path

        def get_child_by_name(self, child_yang_name, segment_path):
            child = self._get_child_by_seg_name([child_yang_name, segment_path])
            if child is not None:
                return child

            if (child_yang_name == "protect-bundles"):
                if (self.protect_bundles is None):
                    self.protect_bundles = BundleInformation.Protect.ProtectBundles()
                    self.protect_bundles.parent = self
                    self._children_name_map["protect_bundles"] = "protect-bundles"
                return self.protect_bundles

            return None

        def has_leaf_or_child_of_name(self, name):
            if(name == "protect-bundles"):
                return True
            return False

        def set_value(self, value_path, value, name_space, name_space_prefix):
            pass


    class MlacpBrief(Entity):
        """
        mLACP Information for Interchassis Groups and
        bundles
        
        .. attribute:: mlacp_brief_iccp_groups
        
        	ICCP Groups with brief mLACP information
        	**type**\:   :py:class:`MlacpBriefIccpGroups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.MlacpBrief.MlacpBriefIccpGroups>`
        
        .. attribute:: mlacp_bundle_briefs
        
        	Bundle interfaces with brief mLACP information
        	**type**\:   :py:class:`MlacpBundleBriefs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.MlacpBrief.MlacpBundleBriefs>`
        
        

        """

        _prefix = 'bundlemgr-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(BundleInformation.MlacpBrief, self).__init__()

            self.yang_name = "mlacp-brief"
            self.yang_parent_name = "bundle-information"

            self.mlacp_brief_iccp_groups = BundleInformation.MlacpBrief.MlacpBriefIccpGroups()
            self.mlacp_brief_iccp_groups.parent = self
            self._children_name_map["mlacp_brief_iccp_groups"] = "mlacp-brief-iccp-groups"
            self._children_yang_names.add("mlacp-brief-iccp-groups")

            self.mlacp_bundle_briefs = BundleInformation.MlacpBrief.MlacpBundleBriefs()
            self.mlacp_bundle_briefs.parent = self
            self._children_name_map["mlacp_bundle_briefs"] = "mlacp-bundle-briefs"
            self._children_yang_names.add("mlacp-bundle-briefs")


        class MlacpBundleBriefs(Entity):
            """
            Bundle interfaces with brief mLACP information
            
            .. attribute:: mlacp_bundle_brief
            
            	Bundle interface
            	**type**\: list of    :py:class:`MlacpBundleBrief <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.MlacpBrief.MlacpBundleBriefs.MlacpBundleBrief>`
            
            

            """

            _prefix = 'bundlemgr-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(BundleInformation.MlacpBrief.MlacpBundleBriefs, self).__init__()

                self.yang_name = "mlacp-bundle-briefs"
                self.yang_parent_name = "mlacp-brief"

                self.mlacp_bundle_brief = YList(self)

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in () and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(BundleInformation.MlacpBrief.MlacpBundleBriefs, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(BundleInformation.MlacpBrief.MlacpBundleBriefs, self).__setattr__(name, value)


            class MlacpBundleBrief(Entity):
                """
                Bundle interface
                
                .. attribute:: bundle_interface  <key>
                
                	Bundle interface
                	**type**\:  str
                
                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                
                .. attribute:: mlacp_bundle_item_brief
                
                	Data for this item
                	**type**\:   :py:class:`MlacpBundleItemBrief <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.MlacpBrief.MlacpBundleBriefs.MlacpBundleBrief.MlacpBundleItemBrief>`
                
                

                """

                _prefix = 'bundlemgr-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(BundleInformation.MlacpBrief.MlacpBundleBriefs.MlacpBundleBrief, self).__init__()

                    self.yang_name = "mlacp-bundle-brief"
                    self.yang_parent_name = "mlacp-bundle-briefs"

                    self.bundle_interface = YLeaf(YType.str, "bundle-interface")

                    self.mlacp_bundle_item_brief = BundleInformation.MlacpBrief.MlacpBundleBriefs.MlacpBundleBrief.MlacpBundleItemBrief()
                    self.mlacp_bundle_item_brief.parent = self
                    self._children_name_map["mlacp_bundle_item_brief"] = "mlacp-bundle-item-brief"
                    self._children_yang_names.add("mlacp-bundle-item-brief")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("bundle_interface") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(BundleInformation.MlacpBrief.MlacpBundleBriefs.MlacpBundleBrief, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(BundleInformation.MlacpBrief.MlacpBundleBriefs.MlacpBundleBrief, self).__setattr__(name, value)


                class MlacpBundleItemBrief(Entity):
                    """
                    Data for this item
                    
                    .. attribute:: mlacp_data
                    
                    	mLACP data for multiple ICCP Groups
                    	**type**\: list of    :py:class:`MlacpData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.MlacpBrief.MlacpBundleBriefs.MlacpBundleBrief.MlacpBundleItemBrief.MlacpData>`
                    
                    

                    """

                    _prefix = 'bundlemgr-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(BundleInformation.MlacpBrief.MlacpBundleBriefs.MlacpBundleBrief.MlacpBundleItemBrief, self).__init__()

                        self.yang_name = "mlacp-bundle-item-brief"
                        self.yang_parent_name = "mlacp-bundle-brief"

                        self.mlacp_data = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(BundleInformation.MlacpBrief.MlacpBundleBriefs.MlacpBundleBrief.MlacpBundleItemBrief, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(BundleInformation.MlacpBrief.MlacpBundleBriefs.MlacpBundleBrief.MlacpBundleItemBrief, self).__setattr__(name, value)


                    class MlacpData(Entity):
                        """
                        mLACP data for multiple ICCP Groups
                        
                        .. attribute:: bundle_data
                        
                        	Bundle information
                        	**type**\: list of    :py:class:`BundleData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.MlacpBrief.MlacpBundleBriefs.MlacpBundleBrief.MlacpBundleItemBrief.MlacpData.BundleData>`
                        
                        .. attribute:: iccp_group_data
                        
                        	ICCP Group information
                        	**type**\:   :py:class:`IccpGroupData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.MlacpBrief.MlacpBundleBriefs.MlacpBundleBrief.MlacpBundleItemBrief.MlacpData.IccpGroupData>`
                        
                        

                        """

                        _prefix = 'bundlemgr-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(BundleInformation.MlacpBrief.MlacpBundleBriefs.MlacpBundleBrief.MlacpBundleItemBrief.MlacpData, self).__init__()

                            self.yang_name = "mlacp-data"
                            self.yang_parent_name = "mlacp-bundle-item-brief"

                            self.iccp_group_data = BundleInformation.MlacpBrief.MlacpBundleBriefs.MlacpBundleBrief.MlacpBundleItemBrief.MlacpData.IccpGroupData()
                            self.iccp_group_data.parent = self
                            self._children_name_map["iccp_group_data"] = "iccp-group-data"
                            self._children_yang_names.add("iccp-group-data")

                            self.bundle_data = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(BundleInformation.MlacpBrief.MlacpBundleBriefs.MlacpBundleBrief.MlacpBundleItemBrief.MlacpData, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(BundleInformation.MlacpBrief.MlacpBundleBriefs.MlacpBundleBrief.MlacpBundleItemBrief.MlacpData, self).__setattr__(name, value)


                        class IccpGroupData(Entity):
                            """
                            ICCP Group information
                            
                            .. attribute:: connect_timer_running
                            
                            	Time remaining on connect timer innsecs
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: nanosecond
                            
                            .. attribute:: iccp_group_id
                            
                            	ICCP Group that the mLACP information is for
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: node_data
                            
                            	Information for the IG from the local and peer devices
                            	**type**\: list of    :py:class:`NodeData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.MlacpBrief.MlacpBundleBriefs.MlacpBundleBrief.MlacpBundleItemBrief.MlacpData.IccpGroupData.NodeData>`
                            
                            .. attribute:: singleton
                            
                            	Is the ICCP group in singleton mode (1 = singleton; 0 = not singleton)
                            	**type**\:  bool
                            
                            

                            """

                            _prefix = 'bundlemgr-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(BundleInformation.MlacpBrief.MlacpBundleBriefs.MlacpBundleBrief.MlacpBundleItemBrief.MlacpData.IccpGroupData, self).__init__()

                                self.yang_name = "iccp-group-data"
                                self.yang_parent_name = "mlacp-data"

                                self.connect_timer_running = YLeaf(YType.uint64, "connect-timer-running")

                                self.iccp_group_id = YLeaf(YType.uint32, "iccp-group-id")

                                self.singleton = YLeaf(YType.boolean, "singleton")

                                self.node_data = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("connect_timer_running",
                                                "iccp_group_id",
                                                "singleton") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(BundleInformation.MlacpBrief.MlacpBundleBriefs.MlacpBundleBrief.MlacpBundleItemBrief.MlacpData.IccpGroupData, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(BundleInformation.MlacpBrief.MlacpBundleBriefs.MlacpBundleBrief.MlacpBundleItemBrief.MlacpData.IccpGroupData, self).__setattr__(name, value)


                            class NodeData(Entity):
                                """
                                Information for the IG from the local and peer
                                devices
                                
                                .. attribute:: iccp_group_state
                                
                                	Node synchronization state
                                	**type**\:   :py:class:`BmdMlacpNodeSyncEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmdMlacpNodeSyncEnum>`
                                
                                .. attribute:: ldp_id
                                
                                	LDP ID of the device
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: mlacp_node_id
                                
                                	mLACP Device ID
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: node_state
                                
                                	Node state
                                	**type**\:   :py:class:`BmdMlacpNodeStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmdMlacpNodeStateEnum>`
                                
                                .. attribute:: system_id
                                
                                	System ID for the ICCP Group
                                	**type**\:   :py:class:`SystemId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.MlacpBrief.MlacpBundleBriefs.MlacpBundleBrief.MlacpBundleItemBrief.MlacpData.IccpGroupData.NodeData.SystemId>`
                                
                                .. attribute:: version_number
                                
                                	Version of the protocol being used
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'bundlemgr-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(BundleInformation.MlacpBrief.MlacpBundleBriefs.MlacpBundleBrief.MlacpBundleItemBrief.MlacpData.IccpGroupData.NodeData, self).__init__()

                                    self.yang_name = "node-data"
                                    self.yang_parent_name = "iccp-group-data"

                                    self.iccp_group_state = YLeaf(YType.enumeration, "iccp-group-state")

                                    self.ldp_id = YLeaf(YType.str, "ldp-id")

                                    self.mlacp_node_id = YLeaf(YType.uint8, "mlacp-node-id")

                                    self.node_state = YLeaf(YType.enumeration, "node-state")

                                    self.version_number = YLeaf(YType.uint32, "version-number")

                                    self.system_id = BundleInformation.MlacpBrief.MlacpBundleBriefs.MlacpBundleBrief.MlacpBundleItemBrief.MlacpData.IccpGroupData.NodeData.SystemId()
                                    self.system_id.parent = self
                                    self._children_name_map["system_id"] = "system-id"
                                    self._children_yang_names.add("system-id")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("iccp_group_state",
                                                    "ldp_id",
                                                    "mlacp_node_id",
                                                    "node_state",
                                                    "version_number") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(BundleInformation.MlacpBrief.MlacpBundleBriefs.MlacpBundleBrief.MlacpBundleItemBrief.MlacpData.IccpGroupData.NodeData, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(BundleInformation.MlacpBrief.MlacpBundleBriefs.MlacpBundleBrief.MlacpBundleItemBrief.MlacpData.IccpGroupData.NodeData, self).__setattr__(name, value)


                                class SystemId(Entity):
                                    """
                                    System ID for the ICCP Group
                                    
                                    .. attribute:: system_mac_addr
                                    
                                    	MAC Address used to identify the system
                                    	**type**\:   :py:class:`SystemMacAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.MlacpBrief.MlacpBundleBriefs.MlacpBundleBrief.MlacpBundleItemBrief.MlacpData.IccpGroupData.NodeData.SystemId.SystemMacAddr>`
                                    
                                    .. attribute:: system_prio
                                    
                                    	Priority of the system
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'bundlemgr-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(BundleInformation.MlacpBrief.MlacpBundleBriefs.MlacpBundleBrief.MlacpBundleItemBrief.MlacpData.IccpGroupData.NodeData.SystemId, self).__init__()

                                        self.yang_name = "system-id"
                                        self.yang_parent_name = "node-data"

                                        self.system_prio = YLeaf(YType.uint16, "system-prio")

                                        self.system_mac_addr = BundleInformation.MlacpBrief.MlacpBundleBriefs.MlacpBundleBrief.MlacpBundleItemBrief.MlacpData.IccpGroupData.NodeData.SystemId.SystemMacAddr()
                                        self.system_mac_addr.parent = self
                                        self._children_name_map["system_mac_addr"] = "system-mac-addr"
                                        self._children_yang_names.add("system-mac-addr")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("system_prio") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(BundleInformation.MlacpBrief.MlacpBundleBriefs.MlacpBundleBrief.MlacpBundleItemBrief.MlacpData.IccpGroupData.NodeData.SystemId, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(BundleInformation.MlacpBrief.MlacpBundleBriefs.MlacpBundleBrief.MlacpBundleItemBrief.MlacpData.IccpGroupData.NodeData.SystemId, self).__setattr__(name, value)


                                    class SystemMacAddr(Entity):
                                        """
                                        MAC Address used to identify the system
                                        
                                        .. attribute:: macaddr
                                        
                                        	macaddr
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'bundlemgr-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(BundleInformation.MlacpBrief.MlacpBundleBriefs.MlacpBundleBrief.MlacpBundleItemBrief.MlacpData.IccpGroupData.NodeData.SystemId.SystemMacAddr, self).__init__()

                                            self.yang_name = "system-mac-addr"
                                            self.yang_parent_name = "system-id"

                                            self.macaddr = YLeaf(YType.str, "macaddr")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("macaddr") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(BundleInformation.MlacpBrief.MlacpBundleBriefs.MlacpBundleBrief.MlacpBundleItemBrief.MlacpData.IccpGroupData.NodeData.SystemId.SystemMacAddr, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(BundleInformation.MlacpBrief.MlacpBundleBriefs.MlacpBundleBrief.MlacpBundleItemBrief.MlacpData.IccpGroupData.NodeData.SystemId.SystemMacAddr, self).__setattr__(name, value)

                                        def has_data(self):
                                            return self.macaddr.is_set

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.macaddr.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "system-mac-addr" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.macaddr.is_set or self.macaddr.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.macaddr.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "macaddr"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "macaddr"):
                                                self.macaddr = value
                                                self.macaddr.value_namespace = name_space
                                                self.macaddr.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.system_prio.is_set or
                                            (self.system_mac_addr is not None and self.system_mac_addr.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.system_prio.yfilter != YFilter.not_set or
                                            (self.system_mac_addr is not None and self.system_mac_addr.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "system-id" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.system_prio.is_set or self.system_prio.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.system_prio.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "system-mac-addr"):
                                            if (self.system_mac_addr is None):
                                                self.system_mac_addr = BundleInformation.MlacpBrief.MlacpBundleBriefs.MlacpBundleBrief.MlacpBundleItemBrief.MlacpData.IccpGroupData.NodeData.SystemId.SystemMacAddr()
                                                self.system_mac_addr.parent = self
                                                self._children_name_map["system_mac_addr"] = "system-mac-addr"
                                            return self.system_mac_addr

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "system-mac-addr" or name == "system-prio"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "system-prio"):
                                            self.system_prio = value
                                            self.system_prio.value_namespace = name_space
                                            self.system_prio.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.iccp_group_state.is_set or
                                        self.ldp_id.is_set or
                                        self.mlacp_node_id.is_set or
                                        self.node_state.is_set or
                                        self.version_number.is_set or
                                        (self.system_id is not None and self.system_id.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.iccp_group_state.yfilter != YFilter.not_set or
                                        self.ldp_id.yfilter != YFilter.not_set or
                                        self.mlacp_node_id.yfilter != YFilter.not_set or
                                        self.node_state.yfilter != YFilter.not_set or
                                        self.version_number.yfilter != YFilter.not_set or
                                        (self.system_id is not None and self.system_id.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "node-data" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.iccp_group_state.is_set or self.iccp_group_state.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.iccp_group_state.get_name_leafdata())
                                    if (self.ldp_id.is_set or self.ldp_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ldp_id.get_name_leafdata())
                                    if (self.mlacp_node_id.is_set or self.mlacp_node_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.mlacp_node_id.get_name_leafdata())
                                    if (self.node_state.is_set or self.node_state.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.node_state.get_name_leafdata())
                                    if (self.version_number.is_set or self.version_number.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.version_number.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "system-id"):
                                        if (self.system_id is None):
                                            self.system_id = BundleInformation.MlacpBrief.MlacpBundleBriefs.MlacpBundleBrief.MlacpBundleItemBrief.MlacpData.IccpGroupData.NodeData.SystemId()
                                            self.system_id.parent = self
                                            self._children_name_map["system_id"] = "system-id"
                                        return self.system_id

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "system-id" or name == "iccp-group-state" or name == "ldp-id" or name == "mlacp-node-id" or name == "node-state" or name == "version-number"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "iccp-group-state"):
                                        self.iccp_group_state = value
                                        self.iccp_group_state.value_namespace = name_space
                                        self.iccp_group_state.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ldp-id"):
                                        self.ldp_id = value
                                        self.ldp_id.value_namespace = name_space
                                        self.ldp_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "mlacp-node-id"):
                                        self.mlacp_node_id = value
                                        self.mlacp_node_id.value_namespace = name_space
                                        self.mlacp_node_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "node-state"):
                                        self.node_state = value
                                        self.node_state.value_namespace = name_space
                                        self.node_state.value_namespace_prefix = name_space_prefix
                                    if(value_path == "version-number"):
                                        self.version_number = value
                                        self.version_number.value_namespace = name_space
                                        self.version_number.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.node_data:
                                    if (c.has_data()):
                                        return True
                                return (
                                    self.connect_timer_running.is_set or
                                    self.iccp_group_id.is_set or
                                    self.singleton.is_set)

                            def has_operation(self):
                                for c in self.node_data:
                                    if (c.has_operation()):
                                        return True
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.connect_timer_running.yfilter != YFilter.not_set or
                                    self.iccp_group_id.yfilter != YFilter.not_set or
                                    self.singleton.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "iccp-group-data" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.connect_timer_running.is_set or self.connect_timer_running.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.connect_timer_running.get_name_leafdata())
                                if (self.iccp_group_id.is_set or self.iccp_group_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.iccp_group_id.get_name_leafdata())
                                if (self.singleton.is_set or self.singleton.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.singleton.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "node-data"):
                                    for c in self.node_data:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = BundleInformation.MlacpBrief.MlacpBundleBriefs.MlacpBundleBrief.MlacpBundleItemBrief.MlacpData.IccpGroupData.NodeData()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.node_data.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "node-data" or name == "connect-timer-running" or name == "iccp-group-id" or name == "singleton"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "connect-timer-running"):
                                    self.connect_timer_running = value
                                    self.connect_timer_running.value_namespace = name_space
                                    self.connect_timer_running.value_namespace_prefix = name_space_prefix
                                if(value_path == "iccp-group-id"):
                                    self.iccp_group_id = value
                                    self.iccp_group_id.value_namespace = name_space
                                    self.iccp_group_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "singleton"):
                                    self.singleton = value
                                    self.singleton.value_namespace = name_space
                                    self.singleton.value_namespace_prefix = name_space_prefix


                        class BundleData(Entity):
                            """
                            Bundle information
                            
                            .. attribute:: bundle_interface_key
                            
                            	Bundle interface key
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: media_type
                            
                            	The media type of the bundle interface
                            	**type**\:   :py:class:`BundleMedia <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleMedia>`
                            
                            .. attribute:: mlacp_bundle_data
                            
                            	mLACP information for the bundle
                            	**type**\: list of    :py:class:`MlacpBundleData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.MlacpBrief.MlacpBundleBriefs.MlacpBundleBrief.MlacpBundleItemBrief.MlacpData.BundleData.MlacpBundleData>`
                            
                            .. attribute:: mlacp_member_data
                            
                            	mLACP information for the member
                            	**type**\: list of    :py:class:`MlacpMemberData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.MlacpBrief.MlacpBundleBriefs.MlacpBundleBrief.MlacpBundleItemBrief.MlacpData.BundleData.MlacpMemberData>`
                            
                            .. attribute:: redundancy_object_id
                            
                            	Redundancy Object ID of the bundle
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            

                            """

                            _prefix = 'bundlemgr-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(BundleInformation.MlacpBrief.MlacpBundleBriefs.MlacpBundleBrief.MlacpBundleItemBrief.MlacpData.BundleData, self).__init__()

                                self.yang_name = "bundle-data"
                                self.yang_parent_name = "mlacp-data"

                                self.bundle_interface_key = YLeaf(YType.uint16, "bundle-interface-key")

                                self.media_type = YLeaf(YType.enumeration, "media-type")

                                self.redundancy_object_id = YLeaf(YType.uint64, "redundancy-object-id")

                                self.mlacp_bundle_data = YList(self)
                                self.mlacp_member_data = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("bundle_interface_key",
                                                "media_type",
                                                "redundancy_object_id") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(BundleInformation.MlacpBrief.MlacpBundleBriefs.MlacpBundleBrief.MlacpBundleItemBrief.MlacpData.BundleData, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(BundleInformation.MlacpBrief.MlacpBundleBriefs.MlacpBundleBrief.MlacpBundleItemBrief.MlacpData.BundleData, self).__setattr__(name, value)


                            class MlacpBundleData(Entity):
                                """
                                mLACP information for the bundle
                                
                                .. attribute:: aggregator_id
                                
                                	Bundle aggregrator ID
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: bundle_name
                                
                                	Bundle name
                                	**type**\:  str
                                
                                .. attribute:: bundle_state
                                
                                	Bundle state
                                	**type**\:   :py:class:`BmdMlacpBdlStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmdMlacpBdlStateEnum>`
                                
                                .. attribute:: mac_address
                                
                                	Bundle MAC address
                                	**type**\:   :py:class:`MacAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.MlacpBrief.MlacpBundleBriefs.MlacpBundleBrief.MlacpBundleItemBrief.MlacpData.BundleData.MlacpBundleData.MacAddress>`
                                
                                .. attribute:: mlacp_node_id
                                
                                	mLACP Device ID
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: port_priority
                                
                                	Bundle port priority
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'bundlemgr-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(BundleInformation.MlacpBrief.MlacpBundleBriefs.MlacpBundleBrief.MlacpBundleItemBrief.MlacpData.BundleData.MlacpBundleData, self).__init__()

                                    self.yang_name = "mlacp-bundle-data"
                                    self.yang_parent_name = "bundle-data"

                                    self.aggregator_id = YLeaf(YType.uint16, "aggregator-id")

                                    self.bundle_name = YLeaf(YType.str, "bundle-name")

                                    self.bundle_state = YLeaf(YType.enumeration, "bundle-state")

                                    self.mlacp_node_id = YLeaf(YType.uint8, "mlacp-node-id")

                                    self.port_priority = YLeaf(YType.uint16, "port-priority")

                                    self.mac_address = BundleInformation.MlacpBrief.MlacpBundleBriefs.MlacpBundleBrief.MlacpBundleItemBrief.MlacpData.BundleData.MlacpBundleData.MacAddress()
                                    self.mac_address.parent = self
                                    self._children_name_map["mac_address"] = "mac-address"
                                    self._children_yang_names.add("mac-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("aggregator_id",
                                                    "bundle_name",
                                                    "bundle_state",
                                                    "mlacp_node_id",
                                                    "port_priority") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(BundleInformation.MlacpBrief.MlacpBundleBriefs.MlacpBundleBrief.MlacpBundleItemBrief.MlacpData.BundleData.MlacpBundleData, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(BundleInformation.MlacpBrief.MlacpBundleBriefs.MlacpBundleBrief.MlacpBundleItemBrief.MlacpData.BundleData.MlacpBundleData, self).__setattr__(name, value)


                                class MacAddress(Entity):
                                    """
                                    Bundle MAC address
                                    
                                    .. attribute:: address
                                    
                                    	MAC address
                                    	**type**\:  str
                                    
                                    	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                    
                                    

                                    """

                                    _prefix = 'bundlemgr-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(BundleInformation.MlacpBrief.MlacpBundleBriefs.MlacpBundleBrief.MlacpBundleItemBrief.MlacpData.BundleData.MlacpBundleData.MacAddress, self).__init__()

                                        self.yang_name = "mac-address"
                                        self.yang_parent_name = "mlacp-bundle-data"

                                        self.address = YLeaf(YType.str, "address")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("address") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(BundleInformation.MlacpBrief.MlacpBundleBriefs.MlacpBundleBrief.MlacpBundleItemBrief.MlacpData.BundleData.MlacpBundleData.MacAddress, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(BundleInformation.MlacpBrief.MlacpBundleBriefs.MlacpBundleBrief.MlacpBundleItemBrief.MlacpData.BundleData.MlacpBundleData.MacAddress, self).__setattr__(name, value)

                                    def has_data(self):
                                        return self.address.is_set

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.address.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "mac-address" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.address.is_set or self.address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.address.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "address"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "address"):
                                            self.address = value
                                            self.address.value_namespace = name_space
                                            self.address.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.aggregator_id.is_set or
                                        self.bundle_name.is_set or
                                        self.bundle_state.is_set or
                                        self.mlacp_node_id.is_set or
                                        self.port_priority.is_set or
                                        (self.mac_address is not None and self.mac_address.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.aggregator_id.yfilter != YFilter.not_set or
                                        self.bundle_name.yfilter != YFilter.not_set or
                                        self.bundle_state.yfilter != YFilter.not_set or
                                        self.mlacp_node_id.yfilter != YFilter.not_set or
                                        self.port_priority.yfilter != YFilter.not_set or
                                        (self.mac_address is not None and self.mac_address.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "mlacp-bundle-data" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.aggregator_id.is_set or self.aggregator_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.aggregator_id.get_name_leafdata())
                                    if (self.bundle_name.is_set or self.bundle_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.bundle_name.get_name_leafdata())
                                    if (self.bundle_state.is_set or self.bundle_state.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.bundle_state.get_name_leafdata())
                                    if (self.mlacp_node_id.is_set or self.mlacp_node_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.mlacp_node_id.get_name_leafdata())
                                    if (self.port_priority.is_set or self.port_priority.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.port_priority.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "mac-address"):
                                        if (self.mac_address is None):
                                            self.mac_address = BundleInformation.MlacpBrief.MlacpBundleBriefs.MlacpBundleBrief.MlacpBundleItemBrief.MlacpData.BundleData.MlacpBundleData.MacAddress()
                                            self.mac_address.parent = self
                                            self._children_name_map["mac_address"] = "mac-address"
                                        return self.mac_address

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "mac-address" or name == "aggregator-id" or name == "bundle-name" or name == "bundle-state" or name == "mlacp-node-id" or name == "port-priority"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "aggregator-id"):
                                        self.aggregator_id = value
                                        self.aggregator_id.value_namespace = name_space
                                        self.aggregator_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "bundle-name"):
                                        self.bundle_name = value
                                        self.bundle_name.value_namespace = name_space
                                        self.bundle_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "bundle-state"):
                                        self.bundle_state = value
                                        self.bundle_state.value_namespace = name_space
                                        self.bundle_state.value_namespace_prefix = name_space_prefix
                                    if(value_path == "mlacp-node-id"):
                                        self.mlacp_node_id = value
                                        self.mlacp_node_id.value_namespace = name_space
                                        self.mlacp_node_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "port-priority"):
                                        self.port_priority = value
                                        self.port_priority.value_namespace = name_space
                                        self.port_priority.value_namespace_prefix = name_space_prefix


                            class MlacpMemberData(Entity):
                                """
                                mLACP information for the member
                                
                                .. attribute:: configured_priority
                                
                                	Configured priority of the member in the bundle
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: interface_handle
                                
                                	Member's interface handle (local device's members only)
                                	**type**\:  str
                                
                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                
                                .. attribute:: member_state
                                
                                	Member state
                                	**type**\:   :py:class:`BmdMlacpMbrStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmdMlacpMbrStateEnum>`
                                
                                .. attribute:: mlacp_node_id
                                
                                	mLACP Device ID
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: operational_priority
                                
                                	Operational priority of the member in the bundle
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: port_name
                                
                                	Port Name
                                	**type**\:  str
                                
                                .. attribute:: port_number
                                
                                	Port number of the member
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'bundlemgr-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(BundleInformation.MlacpBrief.MlacpBundleBriefs.MlacpBundleBrief.MlacpBundleItemBrief.MlacpData.BundleData.MlacpMemberData, self).__init__()

                                    self.yang_name = "mlacp-member-data"
                                    self.yang_parent_name = "bundle-data"

                                    self.configured_priority = YLeaf(YType.uint16, "configured-priority")

                                    self.interface_handle = YLeaf(YType.str, "interface-handle")

                                    self.member_state = YLeaf(YType.enumeration, "member-state")

                                    self.mlacp_node_id = YLeaf(YType.uint8, "mlacp-node-id")

                                    self.operational_priority = YLeaf(YType.uint16, "operational-priority")

                                    self.port_name = YLeaf(YType.str, "port-name")

                                    self.port_number = YLeaf(YType.uint16, "port-number")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("configured_priority",
                                                    "interface_handle",
                                                    "member_state",
                                                    "mlacp_node_id",
                                                    "operational_priority",
                                                    "port_name",
                                                    "port_number") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(BundleInformation.MlacpBrief.MlacpBundleBriefs.MlacpBundleBrief.MlacpBundleItemBrief.MlacpData.BundleData.MlacpMemberData, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(BundleInformation.MlacpBrief.MlacpBundleBriefs.MlacpBundleBrief.MlacpBundleItemBrief.MlacpData.BundleData.MlacpMemberData, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.configured_priority.is_set or
                                        self.interface_handle.is_set or
                                        self.member_state.is_set or
                                        self.mlacp_node_id.is_set or
                                        self.operational_priority.is_set or
                                        self.port_name.is_set or
                                        self.port_number.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.configured_priority.yfilter != YFilter.not_set or
                                        self.interface_handle.yfilter != YFilter.not_set or
                                        self.member_state.yfilter != YFilter.not_set or
                                        self.mlacp_node_id.yfilter != YFilter.not_set or
                                        self.operational_priority.yfilter != YFilter.not_set or
                                        self.port_name.yfilter != YFilter.not_set or
                                        self.port_number.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "mlacp-member-data" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.configured_priority.is_set or self.configured_priority.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.configured_priority.get_name_leafdata())
                                    if (self.interface_handle.is_set or self.interface_handle.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.interface_handle.get_name_leafdata())
                                    if (self.member_state.is_set or self.member_state.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.member_state.get_name_leafdata())
                                    if (self.mlacp_node_id.is_set or self.mlacp_node_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.mlacp_node_id.get_name_leafdata())
                                    if (self.operational_priority.is_set or self.operational_priority.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.operational_priority.get_name_leafdata())
                                    if (self.port_name.is_set or self.port_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.port_name.get_name_leafdata())
                                    if (self.port_number.is_set or self.port_number.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.port_number.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "configured-priority" or name == "interface-handle" or name == "member-state" or name == "mlacp-node-id" or name == "operational-priority" or name == "port-name" or name == "port-number"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "configured-priority"):
                                        self.configured_priority = value
                                        self.configured_priority.value_namespace = name_space
                                        self.configured_priority.value_namespace_prefix = name_space_prefix
                                    if(value_path == "interface-handle"):
                                        self.interface_handle = value
                                        self.interface_handle.value_namespace = name_space
                                        self.interface_handle.value_namespace_prefix = name_space_prefix
                                    if(value_path == "member-state"):
                                        self.member_state = value
                                        self.member_state.value_namespace = name_space
                                        self.member_state.value_namespace_prefix = name_space_prefix
                                    if(value_path == "mlacp-node-id"):
                                        self.mlacp_node_id = value
                                        self.mlacp_node_id.value_namespace = name_space
                                        self.mlacp_node_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "operational-priority"):
                                        self.operational_priority = value
                                        self.operational_priority.value_namespace = name_space
                                        self.operational_priority.value_namespace_prefix = name_space_prefix
                                    if(value_path == "port-name"):
                                        self.port_name = value
                                        self.port_name.value_namespace = name_space
                                        self.port_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "port-number"):
                                        self.port_number = value
                                        self.port_number.value_namespace = name_space
                                        self.port_number.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.mlacp_bundle_data:
                                    if (c.has_data()):
                                        return True
                                for c in self.mlacp_member_data:
                                    if (c.has_data()):
                                        return True
                                return (
                                    self.bundle_interface_key.is_set or
                                    self.media_type.is_set or
                                    self.redundancy_object_id.is_set)

                            def has_operation(self):
                                for c in self.mlacp_bundle_data:
                                    if (c.has_operation()):
                                        return True
                                for c in self.mlacp_member_data:
                                    if (c.has_operation()):
                                        return True
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.bundle_interface_key.yfilter != YFilter.not_set or
                                    self.media_type.yfilter != YFilter.not_set or
                                    self.redundancy_object_id.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "bundle-data" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.bundle_interface_key.is_set or self.bundle_interface_key.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.bundle_interface_key.get_name_leafdata())
                                if (self.media_type.is_set or self.media_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.media_type.get_name_leafdata())
                                if (self.redundancy_object_id.is_set or self.redundancy_object_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.redundancy_object_id.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "mlacp-bundle-data"):
                                    for c in self.mlacp_bundle_data:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = BundleInformation.MlacpBrief.MlacpBundleBriefs.MlacpBundleBrief.MlacpBundleItemBrief.MlacpData.BundleData.MlacpBundleData()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.mlacp_bundle_data.append(c)
                                    return c

                                if (child_yang_name == "mlacp-member-data"):
                                    for c in self.mlacp_member_data:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = BundleInformation.MlacpBrief.MlacpBundleBriefs.MlacpBundleBrief.MlacpBundleItemBrief.MlacpData.BundleData.MlacpMemberData()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.mlacp_member_data.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "mlacp-bundle-data" or name == "mlacp-member-data" or name == "bundle-interface-key" or name == "media-type" or name == "redundancy-object-id"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "bundle-interface-key"):
                                    self.bundle_interface_key = value
                                    self.bundle_interface_key.value_namespace = name_space
                                    self.bundle_interface_key.value_namespace_prefix = name_space_prefix
                                if(value_path == "media-type"):
                                    self.media_type = value
                                    self.media_type.value_namespace = name_space
                                    self.media_type.value_namespace_prefix = name_space_prefix
                                if(value_path == "redundancy-object-id"):
                                    self.redundancy_object_id = value
                                    self.redundancy_object_id.value_namespace = name_space
                                    self.redundancy_object_id.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.bundle_data:
                                if (c.has_data()):
                                    return True
                            return (self.iccp_group_data is not None and self.iccp_group_data.has_data())

                        def has_operation(self):
                            for c in self.bundle_data:
                                if (c.has_operation()):
                                    return True
                            return (
                                self.yfilter != YFilter.not_set or
                                (self.iccp_group_data is not None and self.iccp_group_data.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "mlacp-data" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "bundle-data"):
                                for c in self.bundle_data:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = BundleInformation.MlacpBrief.MlacpBundleBriefs.MlacpBundleBrief.MlacpBundleItemBrief.MlacpData.BundleData()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.bundle_data.append(c)
                                return c

                            if (child_yang_name == "iccp-group-data"):
                                if (self.iccp_group_data is None):
                                    self.iccp_group_data = BundleInformation.MlacpBrief.MlacpBundleBriefs.MlacpBundleBrief.MlacpBundleItemBrief.MlacpData.IccpGroupData()
                                    self.iccp_group_data.parent = self
                                    self._children_name_map["iccp_group_data"] = "iccp-group-data"
                                return self.iccp_group_data

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "bundle-data" or name == "iccp-group-data"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass

                    def has_data(self):
                        for c in self.mlacp_data:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.mlacp_data:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "mlacp-bundle-item-brief" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "mlacp-data"):
                            for c in self.mlacp_data:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = BundleInformation.MlacpBrief.MlacpBundleBriefs.MlacpBundleBrief.MlacpBundleItemBrief.MlacpData()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.mlacp_data.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "mlacp-data"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass

                def has_data(self):
                    return (
                        self.bundle_interface.is_set or
                        (self.mlacp_bundle_item_brief is not None and self.mlacp_bundle_item_brief.has_data()))

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.bundle_interface.yfilter != YFilter.not_set or
                        (self.mlacp_bundle_item_brief is not None and self.mlacp_bundle_item_brief.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "mlacp-bundle-brief" + "[bundle-interface='" + self.bundle_interface.get() + "']" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-bundlemgr-oper:bundle-information/mlacp-brief/mlacp-bundle-briefs/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.bundle_interface.is_set or self.bundle_interface.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.bundle_interface.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "mlacp-bundle-item-brief"):
                        if (self.mlacp_bundle_item_brief is None):
                            self.mlacp_bundle_item_brief = BundleInformation.MlacpBrief.MlacpBundleBriefs.MlacpBundleBrief.MlacpBundleItemBrief()
                            self.mlacp_bundle_item_brief.parent = self
                            self._children_name_map["mlacp_bundle_item_brief"] = "mlacp-bundle-item-brief"
                        return self.mlacp_bundle_item_brief

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "mlacp-bundle-item-brief" or name == "bundle-interface"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "bundle-interface"):
                        self.bundle_interface = value
                        self.bundle_interface.value_namespace = name_space
                        self.bundle_interface.value_namespace_prefix = name_space_prefix

            def has_data(self):
                for c in self.mlacp_bundle_brief:
                    if (c.has_data()):
                        return True
                return False

            def has_operation(self):
                for c in self.mlacp_bundle_brief:
                    if (c.has_operation()):
                        return True
                return self.yfilter != YFilter.not_set

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "mlacp-bundle-briefs" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-bundlemgr-oper:bundle-information/mlacp-brief/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "mlacp-bundle-brief"):
                    for c in self.mlacp_bundle_brief:
                        segment = c.get_segment_path()
                        if (segment_path == segment):
                            return c
                    c = BundleInformation.MlacpBrief.MlacpBundleBriefs.MlacpBundleBrief()
                    c.parent = self
                    local_reference_key = "ydk::seg::%s" % segment_path
                    self._local_refs[local_reference_key] = c
                    self.mlacp_bundle_brief.append(c)
                    return c

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "mlacp-bundle-brief"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                pass


        class MlacpBriefIccpGroups(Entity):
            """
            ICCP Groups with brief mLACP information
            
            .. attribute:: mlacp_brief_iccp_group
            
            	ICCP Group ID
            	**type**\: list of    :py:class:`MlacpBriefIccpGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.MlacpBrief.MlacpBriefIccpGroups.MlacpBriefIccpGroup>`
            
            

            """

            _prefix = 'bundlemgr-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(BundleInformation.MlacpBrief.MlacpBriefIccpGroups, self).__init__()

                self.yang_name = "mlacp-brief-iccp-groups"
                self.yang_parent_name = "mlacp-brief"

                self.mlacp_brief_iccp_group = YList(self)

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in () and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(BundleInformation.MlacpBrief.MlacpBriefIccpGroups, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(BundleInformation.MlacpBrief.MlacpBriefIccpGroups, self).__setattr__(name, value)


            class MlacpBriefIccpGroup(Entity):
                """
                ICCP Group ID
                
                .. attribute:: iccp_group  <key>
                
                	ICCP Group ID
                	**type**\:  int
                
                	**range:** 1..4294967295
                
                .. attribute:: mlacp_brief_iccp_group_item
                
                	Data for this item
                	**type**\:   :py:class:`MlacpBriefIccpGroupItem <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.MlacpBrief.MlacpBriefIccpGroups.MlacpBriefIccpGroup.MlacpBriefIccpGroupItem>`
                
                

                """

                _prefix = 'bundlemgr-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(BundleInformation.MlacpBrief.MlacpBriefIccpGroups.MlacpBriefIccpGroup, self).__init__()

                    self.yang_name = "mlacp-brief-iccp-group"
                    self.yang_parent_name = "mlacp-brief-iccp-groups"

                    self.iccp_group = YLeaf(YType.uint32, "iccp-group")

                    self.mlacp_brief_iccp_group_item = BundleInformation.MlacpBrief.MlacpBriefIccpGroups.MlacpBriefIccpGroup.MlacpBriefIccpGroupItem()
                    self.mlacp_brief_iccp_group_item.parent = self
                    self._children_name_map["mlacp_brief_iccp_group_item"] = "mlacp-brief-iccp-group-item"
                    self._children_yang_names.add("mlacp-brief-iccp-group-item")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("iccp_group") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(BundleInformation.MlacpBrief.MlacpBriefIccpGroups.MlacpBriefIccpGroup, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(BundleInformation.MlacpBrief.MlacpBriefIccpGroups.MlacpBriefIccpGroup, self).__setattr__(name, value)


                class MlacpBriefIccpGroupItem(Entity):
                    """
                    Data for this item
                    
                    .. attribute:: bundle_data
                    
                    	Bundle information
                    	**type**\: list of    :py:class:`BundleData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.MlacpBrief.MlacpBriefIccpGroups.MlacpBriefIccpGroup.MlacpBriefIccpGroupItem.BundleData>`
                    
                    .. attribute:: iccp_group_data
                    
                    	ICCP Group information
                    	**type**\:   :py:class:`IccpGroupData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.MlacpBrief.MlacpBriefIccpGroups.MlacpBriefIccpGroup.MlacpBriefIccpGroupItem.IccpGroupData>`
                    
                    

                    """

                    _prefix = 'bundlemgr-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(BundleInformation.MlacpBrief.MlacpBriefIccpGroups.MlacpBriefIccpGroup.MlacpBriefIccpGroupItem, self).__init__()

                        self.yang_name = "mlacp-brief-iccp-group-item"
                        self.yang_parent_name = "mlacp-brief-iccp-group"

                        self.iccp_group_data = BundleInformation.MlacpBrief.MlacpBriefIccpGroups.MlacpBriefIccpGroup.MlacpBriefIccpGroupItem.IccpGroupData()
                        self.iccp_group_data.parent = self
                        self._children_name_map["iccp_group_data"] = "iccp-group-data"
                        self._children_yang_names.add("iccp-group-data")

                        self.bundle_data = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(BundleInformation.MlacpBrief.MlacpBriefIccpGroups.MlacpBriefIccpGroup.MlacpBriefIccpGroupItem, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(BundleInformation.MlacpBrief.MlacpBriefIccpGroups.MlacpBriefIccpGroup.MlacpBriefIccpGroupItem, self).__setattr__(name, value)


                    class IccpGroupData(Entity):
                        """
                        ICCP Group information
                        
                        .. attribute:: connect_timer_running
                        
                        	Time remaining on connect timer innsecs
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: nanosecond
                        
                        .. attribute:: iccp_group_id
                        
                        	ICCP Group that the mLACP information is for
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: node_data
                        
                        	Information for the IG from the local and peer devices
                        	**type**\: list of    :py:class:`NodeData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.MlacpBrief.MlacpBriefIccpGroups.MlacpBriefIccpGroup.MlacpBriefIccpGroupItem.IccpGroupData.NodeData>`
                        
                        .. attribute:: singleton
                        
                        	Is the ICCP group in singleton mode (1 = singleton; 0 = not singleton)
                        	**type**\:  bool
                        
                        

                        """

                        _prefix = 'bundlemgr-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(BundleInformation.MlacpBrief.MlacpBriefIccpGroups.MlacpBriefIccpGroup.MlacpBriefIccpGroupItem.IccpGroupData, self).__init__()

                            self.yang_name = "iccp-group-data"
                            self.yang_parent_name = "mlacp-brief-iccp-group-item"

                            self.connect_timer_running = YLeaf(YType.uint64, "connect-timer-running")

                            self.iccp_group_id = YLeaf(YType.uint32, "iccp-group-id")

                            self.singleton = YLeaf(YType.boolean, "singleton")

                            self.node_data = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("connect_timer_running",
                                            "iccp_group_id",
                                            "singleton") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(BundleInformation.MlacpBrief.MlacpBriefIccpGroups.MlacpBriefIccpGroup.MlacpBriefIccpGroupItem.IccpGroupData, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(BundleInformation.MlacpBrief.MlacpBriefIccpGroups.MlacpBriefIccpGroup.MlacpBriefIccpGroupItem.IccpGroupData, self).__setattr__(name, value)


                        class NodeData(Entity):
                            """
                            Information for the IG from the local and peer
                            devices
                            
                            .. attribute:: iccp_group_state
                            
                            	Node synchronization state
                            	**type**\:   :py:class:`BmdMlacpNodeSyncEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmdMlacpNodeSyncEnum>`
                            
                            .. attribute:: ldp_id
                            
                            	LDP ID of the device
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: mlacp_node_id
                            
                            	mLACP Device ID
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: node_state
                            
                            	Node state
                            	**type**\:   :py:class:`BmdMlacpNodeStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmdMlacpNodeStateEnum>`
                            
                            .. attribute:: system_id
                            
                            	System ID for the ICCP Group
                            	**type**\:   :py:class:`SystemId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.MlacpBrief.MlacpBriefIccpGroups.MlacpBriefIccpGroup.MlacpBriefIccpGroupItem.IccpGroupData.NodeData.SystemId>`
                            
                            .. attribute:: version_number
                            
                            	Version of the protocol being used
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'bundlemgr-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(BundleInformation.MlacpBrief.MlacpBriefIccpGroups.MlacpBriefIccpGroup.MlacpBriefIccpGroupItem.IccpGroupData.NodeData, self).__init__()

                                self.yang_name = "node-data"
                                self.yang_parent_name = "iccp-group-data"

                                self.iccp_group_state = YLeaf(YType.enumeration, "iccp-group-state")

                                self.ldp_id = YLeaf(YType.str, "ldp-id")

                                self.mlacp_node_id = YLeaf(YType.uint8, "mlacp-node-id")

                                self.node_state = YLeaf(YType.enumeration, "node-state")

                                self.version_number = YLeaf(YType.uint32, "version-number")

                                self.system_id = BundleInformation.MlacpBrief.MlacpBriefIccpGroups.MlacpBriefIccpGroup.MlacpBriefIccpGroupItem.IccpGroupData.NodeData.SystemId()
                                self.system_id.parent = self
                                self._children_name_map["system_id"] = "system-id"
                                self._children_yang_names.add("system-id")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("iccp_group_state",
                                                "ldp_id",
                                                "mlacp_node_id",
                                                "node_state",
                                                "version_number") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(BundleInformation.MlacpBrief.MlacpBriefIccpGroups.MlacpBriefIccpGroup.MlacpBriefIccpGroupItem.IccpGroupData.NodeData, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(BundleInformation.MlacpBrief.MlacpBriefIccpGroups.MlacpBriefIccpGroup.MlacpBriefIccpGroupItem.IccpGroupData.NodeData, self).__setattr__(name, value)


                            class SystemId(Entity):
                                """
                                System ID for the ICCP Group
                                
                                .. attribute:: system_mac_addr
                                
                                	MAC Address used to identify the system
                                	**type**\:   :py:class:`SystemMacAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.MlacpBrief.MlacpBriefIccpGroups.MlacpBriefIccpGroup.MlacpBriefIccpGroupItem.IccpGroupData.NodeData.SystemId.SystemMacAddr>`
                                
                                .. attribute:: system_prio
                                
                                	Priority of the system
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'bundlemgr-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(BundleInformation.MlacpBrief.MlacpBriefIccpGroups.MlacpBriefIccpGroup.MlacpBriefIccpGroupItem.IccpGroupData.NodeData.SystemId, self).__init__()

                                    self.yang_name = "system-id"
                                    self.yang_parent_name = "node-data"

                                    self.system_prio = YLeaf(YType.uint16, "system-prio")

                                    self.system_mac_addr = BundleInformation.MlacpBrief.MlacpBriefIccpGroups.MlacpBriefIccpGroup.MlacpBriefIccpGroupItem.IccpGroupData.NodeData.SystemId.SystemMacAddr()
                                    self.system_mac_addr.parent = self
                                    self._children_name_map["system_mac_addr"] = "system-mac-addr"
                                    self._children_yang_names.add("system-mac-addr")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("system_prio") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(BundleInformation.MlacpBrief.MlacpBriefIccpGroups.MlacpBriefIccpGroup.MlacpBriefIccpGroupItem.IccpGroupData.NodeData.SystemId, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(BundleInformation.MlacpBrief.MlacpBriefIccpGroups.MlacpBriefIccpGroup.MlacpBriefIccpGroupItem.IccpGroupData.NodeData.SystemId, self).__setattr__(name, value)


                                class SystemMacAddr(Entity):
                                    """
                                    MAC Address used to identify the system
                                    
                                    .. attribute:: macaddr
                                    
                                    	macaddr
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'bundlemgr-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(BundleInformation.MlacpBrief.MlacpBriefIccpGroups.MlacpBriefIccpGroup.MlacpBriefIccpGroupItem.IccpGroupData.NodeData.SystemId.SystemMacAddr, self).__init__()

                                        self.yang_name = "system-mac-addr"
                                        self.yang_parent_name = "system-id"

                                        self.macaddr = YLeaf(YType.str, "macaddr")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("macaddr") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(BundleInformation.MlacpBrief.MlacpBriefIccpGroups.MlacpBriefIccpGroup.MlacpBriefIccpGroupItem.IccpGroupData.NodeData.SystemId.SystemMacAddr, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(BundleInformation.MlacpBrief.MlacpBriefIccpGroups.MlacpBriefIccpGroup.MlacpBriefIccpGroupItem.IccpGroupData.NodeData.SystemId.SystemMacAddr, self).__setattr__(name, value)

                                    def has_data(self):
                                        return self.macaddr.is_set

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.macaddr.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "system-mac-addr" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.macaddr.is_set or self.macaddr.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.macaddr.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "macaddr"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "macaddr"):
                                            self.macaddr = value
                                            self.macaddr.value_namespace = name_space
                                            self.macaddr.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.system_prio.is_set or
                                        (self.system_mac_addr is not None and self.system_mac_addr.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.system_prio.yfilter != YFilter.not_set or
                                        (self.system_mac_addr is not None and self.system_mac_addr.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "system-id" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.system_prio.is_set or self.system_prio.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.system_prio.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "system-mac-addr"):
                                        if (self.system_mac_addr is None):
                                            self.system_mac_addr = BundleInformation.MlacpBrief.MlacpBriefIccpGroups.MlacpBriefIccpGroup.MlacpBriefIccpGroupItem.IccpGroupData.NodeData.SystemId.SystemMacAddr()
                                            self.system_mac_addr.parent = self
                                            self._children_name_map["system_mac_addr"] = "system-mac-addr"
                                        return self.system_mac_addr

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "system-mac-addr" or name == "system-prio"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "system-prio"):
                                        self.system_prio = value
                                        self.system_prio.value_namespace = name_space
                                        self.system_prio.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.iccp_group_state.is_set or
                                    self.ldp_id.is_set or
                                    self.mlacp_node_id.is_set or
                                    self.node_state.is_set or
                                    self.version_number.is_set or
                                    (self.system_id is not None and self.system_id.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.iccp_group_state.yfilter != YFilter.not_set or
                                    self.ldp_id.yfilter != YFilter.not_set or
                                    self.mlacp_node_id.yfilter != YFilter.not_set or
                                    self.node_state.yfilter != YFilter.not_set or
                                    self.version_number.yfilter != YFilter.not_set or
                                    (self.system_id is not None and self.system_id.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "node-data" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.iccp_group_state.is_set or self.iccp_group_state.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.iccp_group_state.get_name_leafdata())
                                if (self.ldp_id.is_set or self.ldp_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ldp_id.get_name_leafdata())
                                if (self.mlacp_node_id.is_set or self.mlacp_node_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mlacp_node_id.get_name_leafdata())
                                if (self.node_state.is_set or self.node_state.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.node_state.get_name_leafdata())
                                if (self.version_number.is_set or self.version_number.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.version_number.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "system-id"):
                                    if (self.system_id is None):
                                        self.system_id = BundleInformation.MlacpBrief.MlacpBriefIccpGroups.MlacpBriefIccpGroup.MlacpBriefIccpGroupItem.IccpGroupData.NodeData.SystemId()
                                        self.system_id.parent = self
                                        self._children_name_map["system_id"] = "system-id"
                                    return self.system_id

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "system-id" or name == "iccp-group-state" or name == "ldp-id" or name == "mlacp-node-id" or name == "node-state" or name == "version-number"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "iccp-group-state"):
                                    self.iccp_group_state = value
                                    self.iccp_group_state.value_namespace = name_space
                                    self.iccp_group_state.value_namespace_prefix = name_space_prefix
                                if(value_path == "ldp-id"):
                                    self.ldp_id = value
                                    self.ldp_id.value_namespace = name_space
                                    self.ldp_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "mlacp-node-id"):
                                    self.mlacp_node_id = value
                                    self.mlacp_node_id.value_namespace = name_space
                                    self.mlacp_node_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "node-state"):
                                    self.node_state = value
                                    self.node_state.value_namespace = name_space
                                    self.node_state.value_namespace_prefix = name_space_prefix
                                if(value_path == "version-number"):
                                    self.version_number = value
                                    self.version_number.value_namespace = name_space
                                    self.version_number.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.node_data:
                                if (c.has_data()):
                                    return True
                            return (
                                self.connect_timer_running.is_set or
                                self.iccp_group_id.is_set or
                                self.singleton.is_set)

                        def has_operation(self):
                            for c in self.node_data:
                                if (c.has_operation()):
                                    return True
                            return (
                                self.yfilter != YFilter.not_set or
                                self.connect_timer_running.yfilter != YFilter.not_set or
                                self.iccp_group_id.yfilter != YFilter.not_set or
                                self.singleton.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "iccp-group-data" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.connect_timer_running.is_set or self.connect_timer_running.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.connect_timer_running.get_name_leafdata())
                            if (self.iccp_group_id.is_set or self.iccp_group_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.iccp_group_id.get_name_leafdata())
                            if (self.singleton.is_set or self.singleton.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.singleton.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "node-data"):
                                for c in self.node_data:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = BundleInformation.MlacpBrief.MlacpBriefIccpGroups.MlacpBriefIccpGroup.MlacpBriefIccpGroupItem.IccpGroupData.NodeData()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.node_data.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "node-data" or name == "connect-timer-running" or name == "iccp-group-id" or name == "singleton"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "connect-timer-running"):
                                self.connect_timer_running = value
                                self.connect_timer_running.value_namespace = name_space
                                self.connect_timer_running.value_namespace_prefix = name_space_prefix
                            if(value_path == "iccp-group-id"):
                                self.iccp_group_id = value
                                self.iccp_group_id.value_namespace = name_space
                                self.iccp_group_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "singleton"):
                                self.singleton = value
                                self.singleton.value_namespace = name_space
                                self.singleton.value_namespace_prefix = name_space_prefix


                    class BundleData(Entity):
                        """
                        Bundle information
                        
                        .. attribute:: bundle_interface_key
                        
                        	Bundle interface key
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: media_type
                        
                        	The media type of the bundle interface
                        	**type**\:   :py:class:`BundleMedia <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleMedia>`
                        
                        .. attribute:: mlacp_bundle_data
                        
                        	mLACP information for the bundle
                        	**type**\: list of    :py:class:`MlacpBundleData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.MlacpBrief.MlacpBriefIccpGroups.MlacpBriefIccpGroup.MlacpBriefIccpGroupItem.BundleData.MlacpBundleData>`
                        
                        .. attribute:: mlacp_member_data
                        
                        	mLACP information for the member
                        	**type**\: list of    :py:class:`MlacpMemberData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.MlacpBrief.MlacpBriefIccpGroups.MlacpBriefIccpGroup.MlacpBriefIccpGroupItem.BundleData.MlacpMemberData>`
                        
                        .. attribute:: redundancy_object_id
                        
                        	Redundancy Object ID of the bundle
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        

                        """

                        _prefix = 'bundlemgr-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(BundleInformation.MlacpBrief.MlacpBriefIccpGroups.MlacpBriefIccpGroup.MlacpBriefIccpGroupItem.BundleData, self).__init__()

                            self.yang_name = "bundle-data"
                            self.yang_parent_name = "mlacp-brief-iccp-group-item"

                            self.bundle_interface_key = YLeaf(YType.uint16, "bundle-interface-key")

                            self.media_type = YLeaf(YType.enumeration, "media-type")

                            self.redundancy_object_id = YLeaf(YType.uint64, "redundancy-object-id")

                            self.mlacp_bundle_data = YList(self)
                            self.mlacp_member_data = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("bundle_interface_key",
                                            "media_type",
                                            "redundancy_object_id") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(BundleInformation.MlacpBrief.MlacpBriefIccpGroups.MlacpBriefIccpGroup.MlacpBriefIccpGroupItem.BundleData, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(BundleInformation.MlacpBrief.MlacpBriefIccpGroups.MlacpBriefIccpGroup.MlacpBriefIccpGroupItem.BundleData, self).__setattr__(name, value)


                        class MlacpBundleData(Entity):
                            """
                            mLACP information for the bundle
                            
                            .. attribute:: aggregator_id
                            
                            	Bundle aggregrator ID
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: bundle_name
                            
                            	Bundle name
                            	**type**\:  str
                            
                            .. attribute:: bundle_state
                            
                            	Bundle state
                            	**type**\:   :py:class:`BmdMlacpBdlStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmdMlacpBdlStateEnum>`
                            
                            .. attribute:: mac_address
                            
                            	Bundle MAC address
                            	**type**\:   :py:class:`MacAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.MlacpBrief.MlacpBriefIccpGroups.MlacpBriefIccpGroup.MlacpBriefIccpGroupItem.BundleData.MlacpBundleData.MacAddress>`
                            
                            .. attribute:: mlacp_node_id
                            
                            	mLACP Device ID
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: port_priority
                            
                            	Bundle port priority
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'bundlemgr-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(BundleInformation.MlacpBrief.MlacpBriefIccpGroups.MlacpBriefIccpGroup.MlacpBriefIccpGroupItem.BundleData.MlacpBundleData, self).__init__()

                                self.yang_name = "mlacp-bundle-data"
                                self.yang_parent_name = "bundle-data"

                                self.aggregator_id = YLeaf(YType.uint16, "aggregator-id")

                                self.bundle_name = YLeaf(YType.str, "bundle-name")

                                self.bundle_state = YLeaf(YType.enumeration, "bundle-state")

                                self.mlacp_node_id = YLeaf(YType.uint8, "mlacp-node-id")

                                self.port_priority = YLeaf(YType.uint16, "port-priority")

                                self.mac_address = BundleInformation.MlacpBrief.MlacpBriefIccpGroups.MlacpBriefIccpGroup.MlacpBriefIccpGroupItem.BundleData.MlacpBundleData.MacAddress()
                                self.mac_address.parent = self
                                self._children_name_map["mac_address"] = "mac-address"
                                self._children_yang_names.add("mac-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("aggregator_id",
                                                "bundle_name",
                                                "bundle_state",
                                                "mlacp_node_id",
                                                "port_priority") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(BundleInformation.MlacpBrief.MlacpBriefIccpGroups.MlacpBriefIccpGroup.MlacpBriefIccpGroupItem.BundleData.MlacpBundleData, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(BundleInformation.MlacpBrief.MlacpBriefIccpGroups.MlacpBriefIccpGroup.MlacpBriefIccpGroupItem.BundleData.MlacpBundleData, self).__setattr__(name, value)


                            class MacAddress(Entity):
                                """
                                Bundle MAC address
                                
                                .. attribute:: address
                                
                                	MAC address
                                	**type**\:  str
                                
                                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                
                                

                                """

                                _prefix = 'bundlemgr-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(BundleInformation.MlacpBrief.MlacpBriefIccpGroups.MlacpBriefIccpGroup.MlacpBriefIccpGroupItem.BundleData.MlacpBundleData.MacAddress, self).__init__()

                                    self.yang_name = "mac-address"
                                    self.yang_parent_name = "mlacp-bundle-data"

                                    self.address = YLeaf(YType.str, "address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(BundleInformation.MlacpBrief.MlacpBriefIccpGroups.MlacpBriefIccpGroup.MlacpBriefIccpGroupItem.BundleData.MlacpBundleData.MacAddress, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(BundleInformation.MlacpBrief.MlacpBriefIccpGroups.MlacpBriefIccpGroup.MlacpBriefIccpGroupItem.BundleData.MlacpBundleData.MacAddress, self).__setattr__(name, value)

                                def has_data(self):
                                    return self.address.is_set

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "mac-address" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.address.is_set or self.address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "address"):
                                        self.address = value
                                        self.address.value_namespace = name_space
                                        self.address.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.aggregator_id.is_set or
                                    self.bundle_name.is_set or
                                    self.bundle_state.is_set or
                                    self.mlacp_node_id.is_set or
                                    self.port_priority.is_set or
                                    (self.mac_address is not None and self.mac_address.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.aggregator_id.yfilter != YFilter.not_set or
                                    self.bundle_name.yfilter != YFilter.not_set or
                                    self.bundle_state.yfilter != YFilter.not_set or
                                    self.mlacp_node_id.yfilter != YFilter.not_set or
                                    self.port_priority.yfilter != YFilter.not_set or
                                    (self.mac_address is not None and self.mac_address.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "mlacp-bundle-data" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.aggregator_id.is_set or self.aggregator_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.aggregator_id.get_name_leafdata())
                                if (self.bundle_name.is_set or self.bundle_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.bundle_name.get_name_leafdata())
                                if (self.bundle_state.is_set or self.bundle_state.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.bundle_state.get_name_leafdata())
                                if (self.mlacp_node_id.is_set or self.mlacp_node_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mlacp_node_id.get_name_leafdata())
                                if (self.port_priority.is_set or self.port_priority.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.port_priority.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "mac-address"):
                                    if (self.mac_address is None):
                                        self.mac_address = BundleInformation.MlacpBrief.MlacpBriefIccpGroups.MlacpBriefIccpGroup.MlacpBriefIccpGroupItem.BundleData.MlacpBundleData.MacAddress()
                                        self.mac_address.parent = self
                                        self._children_name_map["mac_address"] = "mac-address"
                                    return self.mac_address

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "mac-address" or name == "aggregator-id" or name == "bundle-name" or name == "bundle-state" or name == "mlacp-node-id" or name == "port-priority"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "aggregator-id"):
                                    self.aggregator_id = value
                                    self.aggregator_id.value_namespace = name_space
                                    self.aggregator_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "bundle-name"):
                                    self.bundle_name = value
                                    self.bundle_name.value_namespace = name_space
                                    self.bundle_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "bundle-state"):
                                    self.bundle_state = value
                                    self.bundle_state.value_namespace = name_space
                                    self.bundle_state.value_namespace_prefix = name_space_prefix
                                if(value_path == "mlacp-node-id"):
                                    self.mlacp_node_id = value
                                    self.mlacp_node_id.value_namespace = name_space
                                    self.mlacp_node_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "port-priority"):
                                    self.port_priority = value
                                    self.port_priority.value_namespace = name_space
                                    self.port_priority.value_namespace_prefix = name_space_prefix


                        class MlacpMemberData(Entity):
                            """
                            mLACP information for the member
                            
                            .. attribute:: configured_priority
                            
                            	Configured priority of the member in the bundle
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: interface_handle
                            
                            	Member's interface handle (local device's members only)
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: member_state
                            
                            	Member state
                            	**type**\:   :py:class:`BmdMlacpMbrStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmdMlacpMbrStateEnum>`
                            
                            .. attribute:: mlacp_node_id
                            
                            	mLACP Device ID
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: operational_priority
                            
                            	Operational priority of the member in the bundle
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: port_name
                            
                            	Port Name
                            	**type**\:  str
                            
                            .. attribute:: port_number
                            
                            	Port number of the member
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'bundlemgr-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(BundleInformation.MlacpBrief.MlacpBriefIccpGroups.MlacpBriefIccpGroup.MlacpBriefIccpGroupItem.BundleData.MlacpMemberData, self).__init__()

                                self.yang_name = "mlacp-member-data"
                                self.yang_parent_name = "bundle-data"

                                self.configured_priority = YLeaf(YType.uint16, "configured-priority")

                                self.interface_handle = YLeaf(YType.str, "interface-handle")

                                self.member_state = YLeaf(YType.enumeration, "member-state")

                                self.mlacp_node_id = YLeaf(YType.uint8, "mlacp-node-id")

                                self.operational_priority = YLeaf(YType.uint16, "operational-priority")

                                self.port_name = YLeaf(YType.str, "port-name")

                                self.port_number = YLeaf(YType.uint16, "port-number")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("configured_priority",
                                                "interface_handle",
                                                "member_state",
                                                "mlacp_node_id",
                                                "operational_priority",
                                                "port_name",
                                                "port_number") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(BundleInformation.MlacpBrief.MlacpBriefIccpGroups.MlacpBriefIccpGroup.MlacpBriefIccpGroupItem.BundleData.MlacpMemberData, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(BundleInformation.MlacpBrief.MlacpBriefIccpGroups.MlacpBriefIccpGroup.MlacpBriefIccpGroupItem.BundleData.MlacpMemberData, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.configured_priority.is_set or
                                    self.interface_handle.is_set or
                                    self.member_state.is_set or
                                    self.mlacp_node_id.is_set or
                                    self.operational_priority.is_set or
                                    self.port_name.is_set or
                                    self.port_number.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.configured_priority.yfilter != YFilter.not_set or
                                    self.interface_handle.yfilter != YFilter.not_set or
                                    self.member_state.yfilter != YFilter.not_set or
                                    self.mlacp_node_id.yfilter != YFilter.not_set or
                                    self.operational_priority.yfilter != YFilter.not_set or
                                    self.port_name.yfilter != YFilter.not_set or
                                    self.port_number.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "mlacp-member-data" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.configured_priority.is_set or self.configured_priority.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.configured_priority.get_name_leafdata())
                                if (self.interface_handle.is_set or self.interface_handle.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.interface_handle.get_name_leafdata())
                                if (self.member_state.is_set or self.member_state.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.member_state.get_name_leafdata())
                                if (self.mlacp_node_id.is_set or self.mlacp_node_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mlacp_node_id.get_name_leafdata())
                                if (self.operational_priority.is_set or self.operational_priority.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.operational_priority.get_name_leafdata())
                                if (self.port_name.is_set or self.port_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.port_name.get_name_leafdata())
                                if (self.port_number.is_set or self.port_number.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.port_number.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "configured-priority" or name == "interface-handle" or name == "member-state" or name == "mlacp-node-id" or name == "operational-priority" or name == "port-name" or name == "port-number"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "configured-priority"):
                                    self.configured_priority = value
                                    self.configured_priority.value_namespace = name_space
                                    self.configured_priority.value_namespace_prefix = name_space_prefix
                                if(value_path == "interface-handle"):
                                    self.interface_handle = value
                                    self.interface_handle.value_namespace = name_space
                                    self.interface_handle.value_namespace_prefix = name_space_prefix
                                if(value_path == "member-state"):
                                    self.member_state = value
                                    self.member_state.value_namespace = name_space
                                    self.member_state.value_namespace_prefix = name_space_prefix
                                if(value_path == "mlacp-node-id"):
                                    self.mlacp_node_id = value
                                    self.mlacp_node_id.value_namespace = name_space
                                    self.mlacp_node_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "operational-priority"):
                                    self.operational_priority = value
                                    self.operational_priority.value_namespace = name_space
                                    self.operational_priority.value_namespace_prefix = name_space_prefix
                                if(value_path == "port-name"):
                                    self.port_name = value
                                    self.port_name.value_namespace = name_space
                                    self.port_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "port-number"):
                                    self.port_number = value
                                    self.port_number.value_namespace = name_space
                                    self.port_number.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.mlacp_bundle_data:
                                if (c.has_data()):
                                    return True
                            for c in self.mlacp_member_data:
                                if (c.has_data()):
                                    return True
                            return (
                                self.bundle_interface_key.is_set or
                                self.media_type.is_set or
                                self.redundancy_object_id.is_set)

                        def has_operation(self):
                            for c in self.mlacp_bundle_data:
                                if (c.has_operation()):
                                    return True
                            for c in self.mlacp_member_data:
                                if (c.has_operation()):
                                    return True
                            return (
                                self.yfilter != YFilter.not_set or
                                self.bundle_interface_key.yfilter != YFilter.not_set or
                                self.media_type.yfilter != YFilter.not_set or
                                self.redundancy_object_id.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "bundle-data" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.bundle_interface_key.is_set or self.bundle_interface_key.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.bundle_interface_key.get_name_leafdata())
                            if (self.media_type.is_set or self.media_type.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.media_type.get_name_leafdata())
                            if (self.redundancy_object_id.is_set or self.redundancy_object_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.redundancy_object_id.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "mlacp-bundle-data"):
                                for c in self.mlacp_bundle_data:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = BundleInformation.MlacpBrief.MlacpBriefIccpGroups.MlacpBriefIccpGroup.MlacpBriefIccpGroupItem.BundleData.MlacpBundleData()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.mlacp_bundle_data.append(c)
                                return c

                            if (child_yang_name == "mlacp-member-data"):
                                for c in self.mlacp_member_data:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = BundleInformation.MlacpBrief.MlacpBriefIccpGroups.MlacpBriefIccpGroup.MlacpBriefIccpGroupItem.BundleData.MlacpMemberData()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.mlacp_member_data.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "mlacp-bundle-data" or name == "mlacp-member-data" or name == "bundle-interface-key" or name == "media-type" or name == "redundancy-object-id"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "bundle-interface-key"):
                                self.bundle_interface_key = value
                                self.bundle_interface_key.value_namespace = name_space
                                self.bundle_interface_key.value_namespace_prefix = name_space_prefix
                            if(value_path == "media-type"):
                                self.media_type = value
                                self.media_type.value_namespace = name_space
                                self.media_type.value_namespace_prefix = name_space_prefix
                            if(value_path == "redundancy-object-id"):
                                self.redundancy_object_id = value
                                self.redundancy_object_id.value_namespace = name_space
                                self.redundancy_object_id.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.bundle_data:
                            if (c.has_data()):
                                return True
                        return (self.iccp_group_data is not None and self.iccp_group_data.has_data())

                    def has_operation(self):
                        for c in self.bundle_data:
                            if (c.has_operation()):
                                return True
                        return (
                            self.yfilter != YFilter.not_set or
                            (self.iccp_group_data is not None and self.iccp_group_data.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "mlacp-brief-iccp-group-item" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "bundle-data"):
                            for c in self.bundle_data:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = BundleInformation.MlacpBrief.MlacpBriefIccpGroups.MlacpBriefIccpGroup.MlacpBriefIccpGroupItem.BundleData()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.bundle_data.append(c)
                            return c

                        if (child_yang_name == "iccp-group-data"):
                            if (self.iccp_group_data is None):
                                self.iccp_group_data = BundleInformation.MlacpBrief.MlacpBriefIccpGroups.MlacpBriefIccpGroup.MlacpBriefIccpGroupItem.IccpGroupData()
                                self.iccp_group_data.parent = self
                                self._children_name_map["iccp_group_data"] = "iccp-group-data"
                            return self.iccp_group_data

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "bundle-data" or name == "iccp-group-data"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass

                def has_data(self):
                    return (
                        self.iccp_group.is_set or
                        (self.mlacp_brief_iccp_group_item is not None and self.mlacp_brief_iccp_group_item.has_data()))

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.iccp_group.yfilter != YFilter.not_set or
                        (self.mlacp_brief_iccp_group_item is not None and self.mlacp_brief_iccp_group_item.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "mlacp-brief-iccp-group" + "[iccp-group='" + self.iccp_group.get() + "']" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-bundlemgr-oper:bundle-information/mlacp-brief/mlacp-brief-iccp-groups/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.iccp_group.is_set or self.iccp_group.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.iccp_group.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "mlacp-brief-iccp-group-item"):
                        if (self.mlacp_brief_iccp_group_item is None):
                            self.mlacp_brief_iccp_group_item = BundleInformation.MlacpBrief.MlacpBriefIccpGroups.MlacpBriefIccpGroup.MlacpBriefIccpGroupItem()
                            self.mlacp_brief_iccp_group_item.parent = self
                            self._children_name_map["mlacp_brief_iccp_group_item"] = "mlacp-brief-iccp-group-item"
                        return self.mlacp_brief_iccp_group_item

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "mlacp-brief-iccp-group-item" or name == "iccp-group"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "iccp-group"):
                        self.iccp_group = value
                        self.iccp_group.value_namespace = name_space
                        self.iccp_group.value_namespace_prefix = name_space_prefix

            def has_data(self):
                for c in self.mlacp_brief_iccp_group:
                    if (c.has_data()):
                        return True
                return False

            def has_operation(self):
                for c in self.mlacp_brief_iccp_group:
                    if (c.has_operation()):
                        return True
                return self.yfilter != YFilter.not_set

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "mlacp-brief-iccp-groups" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-bundlemgr-oper:bundle-information/mlacp-brief/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "mlacp-brief-iccp-group"):
                    for c in self.mlacp_brief_iccp_group:
                        segment = c.get_segment_path()
                        if (segment_path == segment):
                            return c
                    c = BundleInformation.MlacpBrief.MlacpBriefIccpGroups.MlacpBriefIccpGroup()
                    c.parent = self
                    local_reference_key = "ydk::seg::%s" % segment_path
                    self._local_refs[local_reference_key] = c
                    self.mlacp_brief_iccp_group.append(c)
                    return c

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "mlacp-brief-iccp-group"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                pass

        def has_data(self):
            return (
                (self.mlacp_brief_iccp_groups is not None and self.mlacp_brief_iccp_groups.has_data()) or
                (self.mlacp_bundle_briefs is not None and self.mlacp_bundle_briefs.has_data()))

        def has_operation(self):
            return (
                self.yfilter != YFilter.not_set or
                (self.mlacp_brief_iccp_groups is not None and self.mlacp_brief_iccp_groups.has_operation()) or
                (self.mlacp_bundle_briefs is not None and self.mlacp_bundle_briefs.has_operation()))

        def get_segment_path(self):
            path_buffer = ""
            path_buffer = "mlacp-brief" + path_buffer

            return path_buffer

        def get_entity_path(self, ancestor):
            path_buffer = ""
            if (ancestor is None):
                path_buffer = "Cisco-IOS-XR-bundlemgr-oper:bundle-information/%s" % self.get_segment_path()
            else:
                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

            leaf_name_data = LeafDataList()

            entity_path = EntityPath(path_buffer, leaf_name_data)
            return entity_path

        def get_child_by_name(self, child_yang_name, segment_path):
            child = self._get_child_by_seg_name([child_yang_name, segment_path])
            if child is not None:
                return child

            if (child_yang_name == "mlacp-brief-iccp-groups"):
                if (self.mlacp_brief_iccp_groups is None):
                    self.mlacp_brief_iccp_groups = BundleInformation.MlacpBrief.MlacpBriefIccpGroups()
                    self.mlacp_brief_iccp_groups.parent = self
                    self._children_name_map["mlacp_brief_iccp_groups"] = "mlacp-brief-iccp-groups"
                return self.mlacp_brief_iccp_groups

            if (child_yang_name == "mlacp-bundle-briefs"):
                if (self.mlacp_bundle_briefs is None):
                    self.mlacp_bundle_briefs = BundleInformation.MlacpBrief.MlacpBundleBriefs()
                    self.mlacp_bundle_briefs.parent = self
                    self._children_name_map["mlacp_bundle_briefs"] = "mlacp-bundle-briefs"
                return self.mlacp_bundle_briefs

            return None

        def has_leaf_or_child_of_name(self, name):
            if(name == "mlacp-brief-iccp-groups" or name == "mlacp-bundle-briefs"):
                return True
            return False

        def set_value(self, value_path, value, name_space, name_space_prefix):
            pass


    class Mlacp(Entity):
        """
        mLACP Information for Interchassis Groups and
        bundles
        
        .. attribute:: mlacp_bundles
        
        	Bundle interfaces with mLACP information
        	**type**\:   :py:class:`MlacpBundles <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.Mlacp.MlacpBundles>`
        
        .. attribute:: mlacp_iccp_groups
        
        	ICCP Groups with mLACP information
        	**type**\:   :py:class:`MlacpIccpGroups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.Mlacp.MlacpIccpGroups>`
        
        

        """

        _prefix = 'bundlemgr-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(BundleInformation.Mlacp, self).__init__()

            self.yang_name = "mlacp"
            self.yang_parent_name = "bundle-information"

            self.mlacp_bundles = BundleInformation.Mlacp.MlacpBundles()
            self.mlacp_bundles.parent = self
            self._children_name_map["mlacp_bundles"] = "mlacp-bundles"
            self._children_yang_names.add("mlacp-bundles")

            self.mlacp_iccp_groups = BundleInformation.Mlacp.MlacpIccpGroups()
            self.mlacp_iccp_groups.parent = self
            self._children_name_map["mlacp_iccp_groups"] = "mlacp-iccp-groups"
            self._children_yang_names.add("mlacp-iccp-groups")


        class MlacpBundles(Entity):
            """
            Bundle interfaces with mLACP information
            
            .. attribute:: mlacp_bundle
            
            	Bundle interface
            	**type**\: list of    :py:class:`MlacpBundle <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.Mlacp.MlacpBundles.MlacpBundle>`
            
            

            """

            _prefix = 'bundlemgr-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(BundleInformation.Mlacp.MlacpBundles, self).__init__()

                self.yang_name = "mlacp-bundles"
                self.yang_parent_name = "mlacp"

                self.mlacp_bundle = YList(self)

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in () and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(BundleInformation.Mlacp.MlacpBundles, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(BundleInformation.Mlacp.MlacpBundles, self).__setattr__(name, value)


            class MlacpBundle(Entity):
                """
                Bundle interface
                
                .. attribute:: bundle_interface  <key>
                
                	Bundle interface
                	**type**\:  str
                
                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                
                .. attribute:: mlacp_bundle_item
                
                	Data for this item
                	**type**\:   :py:class:`MlacpBundleItem <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.Mlacp.MlacpBundles.MlacpBundle.MlacpBundleItem>`
                
                

                """

                _prefix = 'bundlemgr-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(BundleInformation.Mlacp.MlacpBundles.MlacpBundle, self).__init__()

                    self.yang_name = "mlacp-bundle"
                    self.yang_parent_name = "mlacp-bundles"

                    self.bundle_interface = YLeaf(YType.str, "bundle-interface")

                    self.mlacp_bundle_item = BundleInformation.Mlacp.MlacpBundles.MlacpBundle.MlacpBundleItem()
                    self.mlacp_bundle_item.parent = self
                    self._children_name_map["mlacp_bundle_item"] = "mlacp-bundle-item"
                    self._children_yang_names.add("mlacp-bundle-item")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("bundle_interface") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(BundleInformation.Mlacp.MlacpBundles.MlacpBundle, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(BundleInformation.Mlacp.MlacpBundles.MlacpBundle, self).__setattr__(name, value)


                class MlacpBundleItem(Entity):
                    """
                    Data for this item
                    
                    .. attribute:: mlacp_data
                    
                    	mLACP data for multiple ICCP Groups
                    	**type**\: list of    :py:class:`MlacpData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.Mlacp.MlacpBundles.MlacpBundle.MlacpBundleItem.MlacpData>`
                    
                    

                    """

                    _prefix = 'bundlemgr-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(BundleInformation.Mlacp.MlacpBundles.MlacpBundle.MlacpBundleItem, self).__init__()

                        self.yang_name = "mlacp-bundle-item"
                        self.yang_parent_name = "mlacp-bundle"

                        self.mlacp_data = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(BundleInformation.Mlacp.MlacpBundles.MlacpBundle.MlacpBundleItem, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(BundleInformation.Mlacp.MlacpBundles.MlacpBundle.MlacpBundleItem, self).__setattr__(name, value)


                    class MlacpData(Entity):
                        """
                        mLACP data for multiple ICCP Groups
                        
                        .. attribute:: bundle_data
                        
                        	Bundle information
                        	**type**\: list of    :py:class:`BundleData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.Mlacp.MlacpBundles.MlacpBundle.MlacpBundleItem.MlacpData.BundleData>`
                        
                        .. attribute:: iccp_group_data
                        
                        	ICCP Group information
                        	**type**\:   :py:class:`IccpGroupData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.Mlacp.MlacpBundles.MlacpBundle.MlacpBundleItem.MlacpData.IccpGroupData>`
                        
                        

                        """

                        _prefix = 'bundlemgr-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(BundleInformation.Mlacp.MlacpBundles.MlacpBundle.MlacpBundleItem.MlacpData, self).__init__()

                            self.yang_name = "mlacp-data"
                            self.yang_parent_name = "mlacp-bundle-item"

                            self.iccp_group_data = BundleInformation.Mlacp.MlacpBundles.MlacpBundle.MlacpBundleItem.MlacpData.IccpGroupData()
                            self.iccp_group_data.parent = self
                            self._children_name_map["iccp_group_data"] = "iccp-group-data"
                            self._children_yang_names.add("iccp-group-data")

                            self.bundle_data = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(BundleInformation.Mlacp.MlacpBundles.MlacpBundle.MlacpBundleItem.MlacpData, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(BundleInformation.Mlacp.MlacpBundles.MlacpBundle.MlacpBundleItem.MlacpData, self).__setattr__(name, value)


                        class IccpGroupData(Entity):
                            """
                            ICCP Group information
                            
                            .. attribute:: connect_timer_running
                            
                            	Time remaining on connect timer innsecs
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: nanosecond
                            
                            .. attribute:: iccp_group_id
                            
                            	ICCP Group that the mLACP information is for
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: node_data
                            
                            	Information for the IG from the local and peer devices
                            	**type**\: list of    :py:class:`NodeData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.Mlacp.MlacpBundles.MlacpBundle.MlacpBundleItem.MlacpData.IccpGroupData.NodeData>`
                            
                            .. attribute:: singleton
                            
                            	Is the ICCP group in singleton mode (1 = singleton; 0 = not singleton)
                            	**type**\:  bool
                            
                            

                            """

                            _prefix = 'bundlemgr-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(BundleInformation.Mlacp.MlacpBundles.MlacpBundle.MlacpBundleItem.MlacpData.IccpGroupData, self).__init__()

                                self.yang_name = "iccp-group-data"
                                self.yang_parent_name = "mlacp-data"

                                self.connect_timer_running = YLeaf(YType.uint64, "connect-timer-running")

                                self.iccp_group_id = YLeaf(YType.uint32, "iccp-group-id")

                                self.singleton = YLeaf(YType.boolean, "singleton")

                                self.node_data = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("connect_timer_running",
                                                "iccp_group_id",
                                                "singleton") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(BundleInformation.Mlacp.MlacpBundles.MlacpBundle.MlacpBundleItem.MlacpData.IccpGroupData, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(BundleInformation.Mlacp.MlacpBundles.MlacpBundle.MlacpBundleItem.MlacpData.IccpGroupData, self).__setattr__(name, value)


                            class NodeData(Entity):
                                """
                                Information for the IG from the local and peer
                                devices
                                
                                .. attribute:: iccp_group_state
                                
                                	Node synchronization state
                                	**type**\:   :py:class:`BmdMlacpNodeSyncEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmdMlacpNodeSyncEnum>`
                                
                                .. attribute:: ldp_id
                                
                                	LDP ID of the device
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: mlacp_node_id
                                
                                	mLACP Device ID
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: node_state
                                
                                	Node state
                                	**type**\:   :py:class:`BmdMlacpNodeStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmdMlacpNodeStateEnum>`
                                
                                .. attribute:: system_id
                                
                                	System ID for the ICCP Group
                                	**type**\:   :py:class:`SystemId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.Mlacp.MlacpBundles.MlacpBundle.MlacpBundleItem.MlacpData.IccpGroupData.NodeData.SystemId>`
                                
                                .. attribute:: version_number
                                
                                	Version of the protocol being used
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'bundlemgr-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(BundleInformation.Mlacp.MlacpBundles.MlacpBundle.MlacpBundleItem.MlacpData.IccpGroupData.NodeData, self).__init__()

                                    self.yang_name = "node-data"
                                    self.yang_parent_name = "iccp-group-data"

                                    self.iccp_group_state = YLeaf(YType.enumeration, "iccp-group-state")

                                    self.ldp_id = YLeaf(YType.str, "ldp-id")

                                    self.mlacp_node_id = YLeaf(YType.uint8, "mlacp-node-id")

                                    self.node_state = YLeaf(YType.enumeration, "node-state")

                                    self.version_number = YLeaf(YType.uint32, "version-number")

                                    self.system_id = BundleInformation.Mlacp.MlacpBundles.MlacpBundle.MlacpBundleItem.MlacpData.IccpGroupData.NodeData.SystemId()
                                    self.system_id.parent = self
                                    self._children_name_map["system_id"] = "system-id"
                                    self._children_yang_names.add("system-id")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("iccp_group_state",
                                                    "ldp_id",
                                                    "mlacp_node_id",
                                                    "node_state",
                                                    "version_number") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(BundleInformation.Mlacp.MlacpBundles.MlacpBundle.MlacpBundleItem.MlacpData.IccpGroupData.NodeData, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(BundleInformation.Mlacp.MlacpBundles.MlacpBundle.MlacpBundleItem.MlacpData.IccpGroupData.NodeData, self).__setattr__(name, value)


                                class SystemId(Entity):
                                    """
                                    System ID for the ICCP Group
                                    
                                    .. attribute:: system_mac_addr
                                    
                                    	MAC Address used to identify the system
                                    	**type**\:   :py:class:`SystemMacAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.Mlacp.MlacpBundles.MlacpBundle.MlacpBundleItem.MlacpData.IccpGroupData.NodeData.SystemId.SystemMacAddr>`
                                    
                                    .. attribute:: system_prio
                                    
                                    	Priority of the system
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'bundlemgr-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(BundleInformation.Mlacp.MlacpBundles.MlacpBundle.MlacpBundleItem.MlacpData.IccpGroupData.NodeData.SystemId, self).__init__()

                                        self.yang_name = "system-id"
                                        self.yang_parent_name = "node-data"

                                        self.system_prio = YLeaf(YType.uint16, "system-prio")

                                        self.system_mac_addr = BundleInformation.Mlacp.MlacpBundles.MlacpBundle.MlacpBundleItem.MlacpData.IccpGroupData.NodeData.SystemId.SystemMacAddr()
                                        self.system_mac_addr.parent = self
                                        self._children_name_map["system_mac_addr"] = "system-mac-addr"
                                        self._children_yang_names.add("system-mac-addr")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("system_prio") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(BundleInformation.Mlacp.MlacpBundles.MlacpBundle.MlacpBundleItem.MlacpData.IccpGroupData.NodeData.SystemId, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(BundleInformation.Mlacp.MlacpBundles.MlacpBundle.MlacpBundleItem.MlacpData.IccpGroupData.NodeData.SystemId, self).__setattr__(name, value)


                                    class SystemMacAddr(Entity):
                                        """
                                        MAC Address used to identify the system
                                        
                                        .. attribute:: macaddr
                                        
                                        	macaddr
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'bundlemgr-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(BundleInformation.Mlacp.MlacpBundles.MlacpBundle.MlacpBundleItem.MlacpData.IccpGroupData.NodeData.SystemId.SystemMacAddr, self).__init__()

                                            self.yang_name = "system-mac-addr"
                                            self.yang_parent_name = "system-id"

                                            self.macaddr = YLeaf(YType.str, "macaddr")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("macaddr") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(BundleInformation.Mlacp.MlacpBundles.MlacpBundle.MlacpBundleItem.MlacpData.IccpGroupData.NodeData.SystemId.SystemMacAddr, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(BundleInformation.Mlacp.MlacpBundles.MlacpBundle.MlacpBundleItem.MlacpData.IccpGroupData.NodeData.SystemId.SystemMacAddr, self).__setattr__(name, value)

                                        def has_data(self):
                                            return self.macaddr.is_set

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.macaddr.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "system-mac-addr" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.macaddr.is_set or self.macaddr.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.macaddr.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "macaddr"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "macaddr"):
                                                self.macaddr = value
                                                self.macaddr.value_namespace = name_space
                                                self.macaddr.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.system_prio.is_set or
                                            (self.system_mac_addr is not None and self.system_mac_addr.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.system_prio.yfilter != YFilter.not_set or
                                            (self.system_mac_addr is not None and self.system_mac_addr.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "system-id" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.system_prio.is_set or self.system_prio.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.system_prio.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "system-mac-addr"):
                                            if (self.system_mac_addr is None):
                                                self.system_mac_addr = BundleInformation.Mlacp.MlacpBundles.MlacpBundle.MlacpBundleItem.MlacpData.IccpGroupData.NodeData.SystemId.SystemMacAddr()
                                                self.system_mac_addr.parent = self
                                                self._children_name_map["system_mac_addr"] = "system-mac-addr"
                                            return self.system_mac_addr

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "system-mac-addr" or name == "system-prio"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "system-prio"):
                                            self.system_prio = value
                                            self.system_prio.value_namespace = name_space
                                            self.system_prio.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.iccp_group_state.is_set or
                                        self.ldp_id.is_set or
                                        self.mlacp_node_id.is_set or
                                        self.node_state.is_set or
                                        self.version_number.is_set or
                                        (self.system_id is not None and self.system_id.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.iccp_group_state.yfilter != YFilter.not_set or
                                        self.ldp_id.yfilter != YFilter.not_set or
                                        self.mlacp_node_id.yfilter != YFilter.not_set or
                                        self.node_state.yfilter != YFilter.not_set or
                                        self.version_number.yfilter != YFilter.not_set or
                                        (self.system_id is not None and self.system_id.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "node-data" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.iccp_group_state.is_set or self.iccp_group_state.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.iccp_group_state.get_name_leafdata())
                                    if (self.ldp_id.is_set or self.ldp_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ldp_id.get_name_leafdata())
                                    if (self.mlacp_node_id.is_set or self.mlacp_node_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.mlacp_node_id.get_name_leafdata())
                                    if (self.node_state.is_set or self.node_state.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.node_state.get_name_leafdata())
                                    if (self.version_number.is_set or self.version_number.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.version_number.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "system-id"):
                                        if (self.system_id is None):
                                            self.system_id = BundleInformation.Mlacp.MlacpBundles.MlacpBundle.MlacpBundleItem.MlacpData.IccpGroupData.NodeData.SystemId()
                                            self.system_id.parent = self
                                            self._children_name_map["system_id"] = "system-id"
                                        return self.system_id

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "system-id" or name == "iccp-group-state" or name == "ldp-id" or name == "mlacp-node-id" or name == "node-state" or name == "version-number"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "iccp-group-state"):
                                        self.iccp_group_state = value
                                        self.iccp_group_state.value_namespace = name_space
                                        self.iccp_group_state.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ldp-id"):
                                        self.ldp_id = value
                                        self.ldp_id.value_namespace = name_space
                                        self.ldp_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "mlacp-node-id"):
                                        self.mlacp_node_id = value
                                        self.mlacp_node_id.value_namespace = name_space
                                        self.mlacp_node_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "node-state"):
                                        self.node_state = value
                                        self.node_state.value_namespace = name_space
                                        self.node_state.value_namespace_prefix = name_space_prefix
                                    if(value_path == "version-number"):
                                        self.version_number = value
                                        self.version_number.value_namespace = name_space
                                        self.version_number.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.node_data:
                                    if (c.has_data()):
                                        return True
                                return (
                                    self.connect_timer_running.is_set or
                                    self.iccp_group_id.is_set or
                                    self.singleton.is_set)

                            def has_operation(self):
                                for c in self.node_data:
                                    if (c.has_operation()):
                                        return True
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.connect_timer_running.yfilter != YFilter.not_set or
                                    self.iccp_group_id.yfilter != YFilter.not_set or
                                    self.singleton.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "iccp-group-data" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.connect_timer_running.is_set or self.connect_timer_running.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.connect_timer_running.get_name_leafdata())
                                if (self.iccp_group_id.is_set or self.iccp_group_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.iccp_group_id.get_name_leafdata())
                                if (self.singleton.is_set or self.singleton.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.singleton.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "node-data"):
                                    for c in self.node_data:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = BundleInformation.Mlacp.MlacpBundles.MlacpBundle.MlacpBundleItem.MlacpData.IccpGroupData.NodeData()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.node_data.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "node-data" or name == "connect-timer-running" or name == "iccp-group-id" or name == "singleton"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "connect-timer-running"):
                                    self.connect_timer_running = value
                                    self.connect_timer_running.value_namespace = name_space
                                    self.connect_timer_running.value_namespace_prefix = name_space_prefix
                                if(value_path == "iccp-group-id"):
                                    self.iccp_group_id = value
                                    self.iccp_group_id.value_namespace = name_space
                                    self.iccp_group_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "singleton"):
                                    self.singleton = value
                                    self.singleton.value_namespace = name_space
                                    self.singleton.value_namespace_prefix = name_space_prefix


                        class BundleData(Entity):
                            """
                            Bundle information
                            
                            .. attribute:: bundle_interface_key
                            
                            	Bundle interface key
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: media_type
                            
                            	The media type of the bundle interface
                            	**type**\:   :py:class:`BundleMedia <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleMedia>`
                            
                            .. attribute:: mlacp_bundle_data
                            
                            	mLACP information for the bundle
                            	**type**\: list of    :py:class:`MlacpBundleData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.Mlacp.MlacpBundles.MlacpBundle.MlacpBundleItem.MlacpData.BundleData.MlacpBundleData>`
                            
                            .. attribute:: mlacp_member_data
                            
                            	mLACP information for the member
                            	**type**\: list of    :py:class:`MlacpMemberData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.Mlacp.MlacpBundles.MlacpBundle.MlacpBundleItem.MlacpData.BundleData.MlacpMemberData>`
                            
                            .. attribute:: redundancy_object_id
                            
                            	Redundancy Object ID of the bundle
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            

                            """

                            _prefix = 'bundlemgr-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(BundleInformation.Mlacp.MlacpBundles.MlacpBundle.MlacpBundleItem.MlacpData.BundleData, self).__init__()

                                self.yang_name = "bundle-data"
                                self.yang_parent_name = "mlacp-data"

                                self.bundle_interface_key = YLeaf(YType.uint16, "bundle-interface-key")

                                self.media_type = YLeaf(YType.enumeration, "media-type")

                                self.redundancy_object_id = YLeaf(YType.uint64, "redundancy-object-id")

                                self.mlacp_bundle_data = YList(self)
                                self.mlacp_member_data = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("bundle_interface_key",
                                                "media_type",
                                                "redundancy_object_id") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(BundleInformation.Mlacp.MlacpBundles.MlacpBundle.MlacpBundleItem.MlacpData.BundleData, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(BundleInformation.Mlacp.MlacpBundles.MlacpBundle.MlacpBundleItem.MlacpData.BundleData, self).__setattr__(name, value)


                            class MlacpBundleData(Entity):
                                """
                                mLACP information for the bundle
                                
                                .. attribute:: aggregator_id
                                
                                	Bundle aggregrator ID
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: bundle_name
                                
                                	Bundle name
                                	**type**\:  str
                                
                                .. attribute:: bundle_state
                                
                                	Bundle state
                                	**type**\:   :py:class:`BmdMlacpBdlStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmdMlacpBdlStateEnum>`
                                
                                .. attribute:: mac_address
                                
                                	Bundle MAC address
                                	**type**\:   :py:class:`MacAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.Mlacp.MlacpBundles.MlacpBundle.MlacpBundleItem.MlacpData.BundleData.MlacpBundleData.MacAddress>`
                                
                                .. attribute:: mlacp_node_id
                                
                                	mLACP Device ID
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: port_priority
                                
                                	Bundle port priority
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'bundlemgr-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(BundleInformation.Mlacp.MlacpBundles.MlacpBundle.MlacpBundleItem.MlacpData.BundleData.MlacpBundleData, self).__init__()

                                    self.yang_name = "mlacp-bundle-data"
                                    self.yang_parent_name = "bundle-data"

                                    self.aggregator_id = YLeaf(YType.uint16, "aggregator-id")

                                    self.bundle_name = YLeaf(YType.str, "bundle-name")

                                    self.bundle_state = YLeaf(YType.enumeration, "bundle-state")

                                    self.mlacp_node_id = YLeaf(YType.uint8, "mlacp-node-id")

                                    self.port_priority = YLeaf(YType.uint16, "port-priority")

                                    self.mac_address = BundleInformation.Mlacp.MlacpBundles.MlacpBundle.MlacpBundleItem.MlacpData.BundleData.MlacpBundleData.MacAddress()
                                    self.mac_address.parent = self
                                    self._children_name_map["mac_address"] = "mac-address"
                                    self._children_yang_names.add("mac-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("aggregator_id",
                                                    "bundle_name",
                                                    "bundle_state",
                                                    "mlacp_node_id",
                                                    "port_priority") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(BundleInformation.Mlacp.MlacpBundles.MlacpBundle.MlacpBundleItem.MlacpData.BundleData.MlacpBundleData, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(BundleInformation.Mlacp.MlacpBundles.MlacpBundle.MlacpBundleItem.MlacpData.BundleData.MlacpBundleData, self).__setattr__(name, value)


                                class MacAddress(Entity):
                                    """
                                    Bundle MAC address
                                    
                                    .. attribute:: address
                                    
                                    	MAC address
                                    	**type**\:  str
                                    
                                    	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                    
                                    

                                    """

                                    _prefix = 'bundlemgr-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(BundleInformation.Mlacp.MlacpBundles.MlacpBundle.MlacpBundleItem.MlacpData.BundleData.MlacpBundleData.MacAddress, self).__init__()

                                        self.yang_name = "mac-address"
                                        self.yang_parent_name = "mlacp-bundle-data"

                                        self.address = YLeaf(YType.str, "address")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("address") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(BundleInformation.Mlacp.MlacpBundles.MlacpBundle.MlacpBundleItem.MlacpData.BundleData.MlacpBundleData.MacAddress, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(BundleInformation.Mlacp.MlacpBundles.MlacpBundle.MlacpBundleItem.MlacpData.BundleData.MlacpBundleData.MacAddress, self).__setattr__(name, value)

                                    def has_data(self):
                                        return self.address.is_set

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.address.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "mac-address" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.address.is_set or self.address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.address.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "address"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "address"):
                                            self.address = value
                                            self.address.value_namespace = name_space
                                            self.address.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.aggregator_id.is_set or
                                        self.bundle_name.is_set or
                                        self.bundle_state.is_set or
                                        self.mlacp_node_id.is_set or
                                        self.port_priority.is_set or
                                        (self.mac_address is not None and self.mac_address.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.aggregator_id.yfilter != YFilter.not_set or
                                        self.bundle_name.yfilter != YFilter.not_set or
                                        self.bundle_state.yfilter != YFilter.not_set or
                                        self.mlacp_node_id.yfilter != YFilter.not_set or
                                        self.port_priority.yfilter != YFilter.not_set or
                                        (self.mac_address is not None and self.mac_address.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "mlacp-bundle-data" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.aggregator_id.is_set or self.aggregator_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.aggregator_id.get_name_leafdata())
                                    if (self.bundle_name.is_set or self.bundle_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.bundle_name.get_name_leafdata())
                                    if (self.bundle_state.is_set or self.bundle_state.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.bundle_state.get_name_leafdata())
                                    if (self.mlacp_node_id.is_set or self.mlacp_node_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.mlacp_node_id.get_name_leafdata())
                                    if (self.port_priority.is_set or self.port_priority.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.port_priority.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "mac-address"):
                                        if (self.mac_address is None):
                                            self.mac_address = BundleInformation.Mlacp.MlacpBundles.MlacpBundle.MlacpBundleItem.MlacpData.BundleData.MlacpBundleData.MacAddress()
                                            self.mac_address.parent = self
                                            self._children_name_map["mac_address"] = "mac-address"
                                        return self.mac_address

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "mac-address" or name == "aggregator-id" or name == "bundle-name" or name == "bundle-state" or name == "mlacp-node-id" or name == "port-priority"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "aggregator-id"):
                                        self.aggregator_id = value
                                        self.aggregator_id.value_namespace = name_space
                                        self.aggregator_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "bundle-name"):
                                        self.bundle_name = value
                                        self.bundle_name.value_namespace = name_space
                                        self.bundle_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "bundle-state"):
                                        self.bundle_state = value
                                        self.bundle_state.value_namespace = name_space
                                        self.bundle_state.value_namespace_prefix = name_space_prefix
                                    if(value_path == "mlacp-node-id"):
                                        self.mlacp_node_id = value
                                        self.mlacp_node_id.value_namespace = name_space
                                        self.mlacp_node_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "port-priority"):
                                        self.port_priority = value
                                        self.port_priority.value_namespace = name_space
                                        self.port_priority.value_namespace_prefix = name_space_prefix


                            class MlacpMemberData(Entity):
                                """
                                mLACP information for the member
                                
                                .. attribute:: configured_priority
                                
                                	Configured priority of the member in the bundle
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: interface_handle
                                
                                	Member's interface handle (local device's members only)
                                	**type**\:  str
                                
                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                
                                .. attribute:: member_state
                                
                                	Member state
                                	**type**\:   :py:class:`BmdMlacpMbrStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmdMlacpMbrStateEnum>`
                                
                                .. attribute:: mlacp_node_id
                                
                                	mLACP Device ID
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: operational_priority
                                
                                	Operational priority of the member in the bundle
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: port_name
                                
                                	Port Name
                                	**type**\:  str
                                
                                .. attribute:: port_number
                                
                                	Port number of the member
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'bundlemgr-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(BundleInformation.Mlacp.MlacpBundles.MlacpBundle.MlacpBundleItem.MlacpData.BundleData.MlacpMemberData, self).__init__()

                                    self.yang_name = "mlacp-member-data"
                                    self.yang_parent_name = "bundle-data"

                                    self.configured_priority = YLeaf(YType.uint16, "configured-priority")

                                    self.interface_handle = YLeaf(YType.str, "interface-handle")

                                    self.member_state = YLeaf(YType.enumeration, "member-state")

                                    self.mlacp_node_id = YLeaf(YType.uint8, "mlacp-node-id")

                                    self.operational_priority = YLeaf(YType.uint16, "operational-priority")

                                    self.port_name = YLeaf(YType.str, "port-name")

                                    self.port_number = YLeaf(YType.uint16, "port-number")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("configured_priority",
                                                    "interface_handle",
                                                    "member_state",
                                                    "mlacp_node_id",
                                                    "operational_priority",
                                                    "port_name",
                                                    "port_number") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(BundleInformation.Mlacp.MlacpBundles.MlacpBundle.MlacpBundleItem.MlacpData.BundleData.MlacpMemberData, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(BundleInformation.Mlacp.MlacpBundles.MlacpBundle.MlacpBundleItem.MlacpData.BundleData.MlacpMemberData, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.configured_priority.is_set or
                                        self.interface_handle.is_set or
                                        self.member_state.is_set or
                                        self.mlacp_node_id.is_set or
                                        self.operational_priority.is_set or
                                        self.port_name.is_set or
                                        self.port_number.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.configured_priority.yfilter != YFilter.not_set or
                                        self.interface_handle.yfilter != YFilter.not_set or
                                        self.member_state.yfilter != YFilter.not_set or
                                        self.mlacp_node_id.yfilter != YFilter.not_set or
                                        self.operational_priority.yfilter != YFilter.not_set or
                                        self.port_name.yfilter != YFilter.not_set or
                                        self.port_number.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "mlacp-member-data" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.configured_priority.is_set or self.configured_priority.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.configured_priority.get_name_leafdata())
                                    if (self.interface_handle.is_set or self.interface_handle.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.interface_handle.get_name_leafdata())
                                    if (self.member_state.is_set or self.member_state.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.member_state.get_name_leafdata())
                                    if (self.mlacp_node_id.is_set or self.mlacp_node_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.mlacp_node_id.get_name_leafdata())
                                    if (self.operational_priority.is_set or self.operational_priority.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.operational_priority.get_name_leafdata())
                                    if (self.port_name.is_set or self.port_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.port_name.get_name_leafdata())
                                    if (self.port_number.is_set or self.port_number.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.port_number.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "configured-priority" or name == "interface-handle" or name == "member-state" or name == "mlacp-node-id" or name == "operational-priority" or name == "port-name" or name == "port-number"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "configured-priority"):
                                        self.configured_priority = value
                                        self.configured_priority.value_namespace = name_space
                                        self.configured_priority.value_namespace_prefix = name_space_prefix
                                    if(value_path == "interface-handle"):
                                        self.interface_handle = value
                                        self.interface_handle.value_namespace = name_space
                                        self.interface_handle.value_namespace_prefix = name_space_prefix
                                    if(value_path == "member-state"):
                                        self.member_state = value
                                        self.member_state.value_namespace = name_space
                                        self.member_state.value_namespace_prefix = name_space_prefix
                                    if(value_path == "mlacp-node-id"):
                                        self.mlacp_node_id = value
                                        self.mlacp_node_id.value_namespace = name_space
                                        self.mlacp_node_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "operational-priority"):
                                        self.operational_priority = value
                                        self.operational_priority.value_namespace = name_space
                                        self.operational_priority.value_namespace_prefix = name_space_prefix
                                    if(value_path == "port-name"):
                                        self.port_name = value
                                        self.port_name.value_namespace = name_space
                                        self.port_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "port-number"):
                                        self.port_number = value
                                        self.port_number.value_namespace = name_space
                                        self.port_number.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.mlacp_bundle_data:
                                    if (c.has_data()):
                                        return True
                                for c in self.mlacp_member_data:
                                    if (c.has_data()):
                                        return True
                                return (
                                    self.bundle_interface_key.is_set or
                                    self.media_type.is_set or
                                    self.redundancy_object_id.is_set)

                            def has_operation(self):
                                for c in self.mlacp_bundle_data:
                                    if (c.has_operation()):
                                        return True
                                for c in self.mlacp_member_data:
                                    if (c.has_operation()):
                                        return True
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.bundle_interface_key.yfilter != YFilter.not_set or
                                    self.media_type.yfilter != YFilter.not_set or
                                    self.redundancy_object_id.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "bundle-data" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.bundle_interface_key.is_set or self.bundle_interface_key.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.bundle_interface_key.get_name_leafdata())
                                if (self.media_type.is_set or self.media_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.media_type.get_name_leafdata())
                                if (self.redundancy_object_id.is_set or self.redundancy_object_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.redundancy_object_id.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "mlacp-bundle-data"):
                                    for c in self.mlacp_bundle_data:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = BundleInformation.Mlacp.MlacpBundles.MlacpBundle.MlacpBundleItem.MlacpData.BundleData.MlacpBundleData()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.mlacp_bundle_data.append(c)
                                    return c

                                if (child_yang_name == "mlacp-member-data"):
                                    for c in self.mlacp_member_data:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = BundleInformation.Mlacp.MlacpBundles.MlacpBundle.MlacpBundleItem.MlacpData.BundleData.MlacpMemberData()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.mlacp_member_data.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "mlacp-bundle-data" or name == "mlacp-member-data" or name == "bundle-interface-key" or name == "media-type" or name == "redundancy-object-id"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "bundle-interface-key"):
                                    self.bundle_interface_key = value
                                    self.bundle_interface_key.value_namespace = name_space
                                    self.bundle_interface_key.value_namespace_prefix = name_space_prefix
                                if(value_path == "media-type"):
                                    self.media_type = value
                                    self.media_type.value_namespace = name_space
                                    self.media_type.value_namespace_prefix = name_space_prefix
                                if(value_path == "redundancy-object-id"):
                                    self.redundancy_object_id = value
                                    self.redundancy_object_id.value_namespace = name_space
                                    self.redundancy_object_id.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.bundle_data:
                                if (c.has_data()):
                                    return True
                            return (self.iccp_group_data is not None and self.iccp_group_data.has_data())

                        def has_operation(self):
                            for c in self.bundle_data:
                                if (c.has_operation()):
                                    return True
                            return (
                                self.yfilter != YFilter.not_set or
                                (self.iccp_group_data is not None and self.iccp_group_data.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "mlacp-data" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "bundle-data"):
                                for c in self.bundle_data:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = BundleInformation.Mlacp.MlacpBundles.MlacpBundle.MlacpBundleItem.MlacpData.BundleData()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.bundle_data.append(c)
                                return c

                            if (child_yang_name == "iccp-group-data"):
                                if (self.iccp_group_data is None):
                                    self.iccp_group_data = BundleInformation.Mlacp.MlacpBundles.MlacpBundle.MlacpBundleItem.MlacpData.IccpGroupData()
                                    self.iccp_group_data.parent = self
                                    self._children_name_map["iccp_group_data"] = "iccp-group-data"
                                return self.iccp_group_data

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "bundle-data" or name == "iccp-group-data"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass

                    def has_data(self):
                        for c in self.mlacp_data:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.mlacp_data:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "mlacp-bundle-item" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "mlacp-data"):
                            for c in self.mlacp_data:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = BundleInformation.Mlacp.MlacpBundles.MlacpBundle.MlacpBundleItem.MlacpData()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.mlacp_data.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "mlacp-data"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass

                def has_data(self):
                    return (
                        self.bundle_interface.is_set or
                        (self.mlacp_bundle_item is not None and self.mlacp_bundle_item.has_data()))

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.bundle_interface.yfilter != YFilter.not_set or
                        (self.mlacp_bundle_item is not None and self.mlacp_bundle_item.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "mlacp-bundle" + "[bundle-interface='" + self.bundle_interface.get() + "']" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-bundlemgr-oper:bundle-information/mlacp/mlacp-bundles/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.bundle_interface.is_set or self.bundle_interface.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.bundle_interface.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "mlacp-bundle-item"):
                        if (self.mlacp_bundle_item is None):
                            self.mlacp_bundle_item = BundleInformation.Mlacp.MlacpBundles.MlacpBundle.MlacpBundleItem()
                            self.mlacp_bundle_item.parent = self
                            self._children_name_map["mlacp_bundle_item"] = "mlacp-bundle-item"
                        return self.mlacp_bundle_item

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "mlacp-bundle-item" or name == "bundle-interface"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "bundle-interface"):
                        self.bundle_interface = value
                        self.bundle_interface.value_namespace = name_space
                        self.bundle_interface.value_namespace_prefix = name_space_prefix

            def has_data(self):
                for c in self.mlacp_bundle:
                    if (c.has_data()):
                        return True
                return False

            def has_operation(self):
                for c in self.mlacp_bundle:
                    if (c.has_operation()):
                        return True
                return self.yfilter != YFilter.not_set

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "mlacp-bundles" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-bundlemgr-oper:bundle-information/mlacp/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "mlacp-bundle"):
                    for c in self.mlacp_bundle:
                        segment = c.get_segment_path()
                        if (segment_path == segment):
                            return c
                    c = BundleInformation.Mlacp.MlacpBundles.MlacpBundle()
                    c.parent = self
                    local_reference_key = "ydk::seg::%s" % segment_path
                    self._local_refs[local_reference_key] = c
                    self.mlacp_bundle.append(c)
                    return c

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "mlacp-bundle"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                pass


        class MlacpIccpGroups(Entity):
            """
            ICCP Groups with mLACP information
            
            .. attribute:: mlacp_iccp_group
            
            	ICCP Group ID
            	**type**\: list of    :py:class:`MlacpIccpGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.Mlacp.MlacpIccpGroups.MlacpIccpGroup>`
            
            

            """

            _prefix = 'bundlemgr-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(BundleInformation.Mlacp.MlacpIccpGroups, self).__init__()

                self.yang_name = "mlacp-iccp-groups"
                self.yang_parent_name = "mlacp"

                self.mlacp_iccp_group = YList(self)

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in () and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(BundleInformation.Mlacp.MlacpIccpGroups, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(BundleInformation.Mlacp.MlacpIccpGroups, self).__setattr__(name, value)


            class MlacpIccpGroup(Entity):
                """
                ICCP Group ID
                
                .. attribute:: iccp_group  <key>
                
                	ICCP Group ID
                	**type**\:  int
                
                	**range:** 1..4294967295
                
                .. attribute:: mlacp_iccp_group_item
                
                	Data for this item
                	**type**\:   :py:class:`MlacpIccpGroupItem <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.Mlacp.MlacpIccpGroups.MlacpIccpGroup.MlacpIccpGroupItem>`
                
                

                """

                _prefix = 'bundlemgr-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(BundleInformation.Mlacp.MlacpIccpGroups.MlacpIccpGroup, self).__init__()

                    self.yang_name = "mlacp-iccp-group"
                    self.yang_parent_name = "mlacp-iccp-groups"

                    self.iccp_group = YLeaf(YType.uint32, "iccp-group")

                    self.mlacp_iccp_group_item = BundleInformation.Mlacp.MlacpIccpGroups.MlacpIccpGroup.MlacpIccpGroupItem()
                    self.mlacp_iccp_group_item.parent = self
                    self._children_name_map["mlacp_iccp_group_item"] = "mlacp-iccp-group-item"
                    self._children_yang_names.add("mlacp-iccp-group-item")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("iccp_group") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(BundleInformation.Mlacp.MlacpIccpGroups.MlacpIccpGroup, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(BundleInformation.Mlacp.MlacpIccpGroups.MlacpIccpGroup, self).__setattr__(name, value)


                class MlacpIccpGroupItem(Entity):
                    """
                    Data for this item
                    
                    .. attribute:: bundle_data
                    
                    	Bundle information
                    	**type**\: list of    :py:class:`BundleData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.Mlacp.MlacpIccpGroups.MlacpIccpGroup.MlacpIccpGroupItem.BundleData>`
                    
                    .. attribute:: iccp_group_data
                    
                    	ICCP Group information
                    	**type**\:   :py:class:`IccpGroupData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.Mlacp.MlacpIccpGroups.MlacpIccpGroup.MlacpIccpGroupItem.IccpGroupData>`
                    
                    

                    """

                    _prefix = 'bundlemgr-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(BundleInformation.Mlacp.MlacpIccpGroups.MlacpIccpGroup.MlacpIccpGroupItem, self).__init__()

                        self.yang_name = "mlacp-iccp-group-item"
                        self.yang_parent_name = "mlacp-iccp-group"

                        self.iccp_group_data = BundleInformation.Mlacp.MlacpIccpGroups.MlacpIccpGroup.MlacpIccpGroupItem.IccpGroupData()
                        self.iccp_group_data.parent = self
                        self._children_name_map["iccp_group_data"] = "iccp-group-data"
                        self._children_yang_names.add("iccp-group-data")

                        self.bundle_data = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(BundleInformation.Mlacp.MlacpIccpGroups.MlacpIccpGroup.MlacpIccpGroupItem, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(BundleInformation.Mlacp.MlacpIccpGroups.MlacpIccpGroup.MlacpIccpGroupItem, self).__setattr__(name, value)


                    class IccpGroupData(Entity):
                        """
                        ICCP Group information
                        
                        .. attribute:: connect_timer_running
                        
                        	Time remaining on connect timer innsecs
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: nanosecond
                        
                        .. attribute:: iccp_group_id
                        
                        	ICCP Group that the mLACP information is for
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: node_data
                        
                        	Information for the IG from the local and peer devices
                        	**type**\: list of    :py:class:`NodeData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.Mlacp.MlacpIccpGroups.MlacpIccpGroup.MlacpIccpGroupItem.IccpGroupData.NodeData>`
                        
                        .. attribute:: singleton
                        
                        	Is the ICCP group in singleton mode (1 = singleton; 0 = not singleton)
                        	**type**\:  bool
                        
                        

                        """

                        _prefix = 'bundlemgr-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(BundleInformation.Mlacp.MlacpIccpGroups.MlacpIccpGroup.MlacpIccpGroupItem.IccpGroupData, self).__init__()

                            self.yang_name = "iccp-group-data"
                            self.yang_parent_name = "mlacp-iccp-group-item"

                            self.connect_timer_running = YLeaf(YType.uint64, "connect-timer-running")

                            self.iccp_group_id = YLeaf(YType.uint32, "iccp-group-id")

                            self.singleton = YLeaf(YType.boolean, "singleton")

                            self.node_data = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("connect_timer_running",
                                            "iccp_group_id",
                                            "singleton") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(BundleInformation.Mlacp.MlacpIccpGroups.MlacpIccpGroup.MlacpIccpGroupItem.IccpGroupData, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(BundleInformation.Mlacp.MlacpIccpGroups.MlacpIccpGroup.MlacpIccpGroupItem.IccpGroupData, self).__setattr__(name, value)


                        class NodeData(Entity):
                            """
                            Information for the IG from the local and peer
                            devices
                            
                            .. attribute:: iccp_group_state
                            
                            	Node synchronization state
                            	**type**\:   :py:class:`BmdMlacpNodeSyncEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmdMlacpNodeSyncEnum>`
                            
                            .. attribute:: ldp_id
                            
                            	LDP ID of the device
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: mlacp_node_id
                            
                            	mLACP Device ID
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: node_state
                            
                            	Node state
                            	**type**\:   :py:class:`BmdMlacpNodeStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmdMlacpNodeStateEnum>`
                            
                            .. attribute:: system_id
                            
                            	System ID for the ICCP Group
                            	**type**\:   :py:class:`SystemId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.Mlacp.MlacpIccpGroups.MlacpIccpGroup.MlacpIccpGroupItem.IccpGroupData.NodeData.SystemId>`
                            
                            .. attribute:: version_number
                            
                            	Version of the protocol being used
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'bundlemgr-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(BundleInformation.Mlacp.MlacpIccpGroups.MlacpIccpGroup.MlacpIccpGroupItem.IccpGroupData.NodeData, self).__init__()

                                self.yang_name = "node-data"
                                self.yang_parent_name = "iccp-group-data"

                                self.iccp_group_state = YLeaf(YType.enumeration, "iccp-group-state")

                                self.ldp_id = YLeaf(YType.str, "ldp-id")

                                self.mlacp_node_id = YLeaf(YType.uint8, "mlacp-node-id")

                                self.node_state = YLeaf(YType.enumeration, "node-state")

                                self.version_number = YLeaf(YType.uint32, "version-number")

                                self.system_id = BundleInformation.Mlacp.MlacpIccpGroups.MlacpIccpGroup.MlacpIccpGroupItem.IccpGroupData.NodeData.SystemId()
                                self.system_id.parent = self
                                self._children_name_map["system_id"] = "system-id"
                                self._children_yang_names.add("system-id")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("iccp_group_state",
                                                "ldp_id",
                                                "mlacp_node_id",
                                                "node_state",
                                                "version_number") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(BundleInformation.Mlacp.MlacpIccpGroups.MlacpIccpGroup.MlacpIccpGroupItem.IccpGroupData.NodeData, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(BundleInformation.Mlacp.MlacpIccpGroups.MlacpIccpGroup.MlacpIccpGroupItem.IccpGroupData.NodeData, self).__setattr__(name, value)


                            class SystemId(Entity):
                                """
                                System ID for the ICCP Group
                                
                                .. attribute:: system_mac_addr
                                
                                	MAC Address used to identify the system
                                	**type**\:   :py:class:`SystemMacAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.Mlacp.MlacpIccpGroups.MlacpIccpGroup.MlacpIccpGroupItem.IccpGroupData.NodeData.SystemId.SystemMacAddr>`
                                
                                .. attribute:: system_prio
                                
                                	Priority of the system
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'bundlemgr-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(BundleInformation.Mlacp.MlacpIccpGroups.MlacpIccpGroup.MlacpIccpGroupItem.IccpGroupData.NodeData.SystemId, self).__init__()

                                    self.yang_name = "system-id"
                                    self.yang_parent_name = "node-data"

                                    self.system_prio = YLeaf(YType.uint16, "system-prio")

                                    self.system_mac_addr = BundleInformation.Mlacp.MlacpIccpGroups.MlacpIccpGroup.MlacpIccpGroupItem.IccpGroupData.NodeData.SystemId.SystemMacAddr()
                                    self.system_mac_addr.parent = self
                                    self._children_name_map["system_mac_addr"] = "system-mac-addr"
                                    self._children_yang_names.add("system-mac-addr")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("system_prio") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(BundleInformation.Mlacp.MlacpIccpGroups.MlacpIccpGroup.MlacpIccpGroupItem.IccpGroupData.NodeData.SystemId, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(BundleInformation.Mlacp.MlacpIccpGroups.MlacpIccpGroup.MlacpIccpGroupItem.IccpGroupData.NodeData.SystemId, self).__setattr__(name, value)


                                class SystemMacAddr(Entity):
                                    """
                                    MAC Address used to identify the system
                                    
                                    .. attribute:: macaddr
                                    
                                    	macaddr
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'bundlemgr-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(BundleInformation.Mlacp.MlacpIccpGroups.MlacpIccpGroup.MlacpIccpGroupItem.IccpGroupData.NodeData.SystemId.SystemMacAddr, self).__init__()

                                        self.yang_name = "system-mac-addr"
                                        self.yang_parent_name = "system-id"

                                        self.macaddr = YLeaf(YType.str, "macaddr")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("macaddr") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(BundleInformation.Mlacp.MlacpIccpGroups.MlacpIccpGroup.MlacpIccpGroupItem.IccpGroupData.NodeData.SystemId.SystemMacAddr, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(BundleInformation.Mlacp.MlacpIccpGroups.MlacpIccpGroup.MlacpIccpGroupItem.IccpGroupData.NodeData.SystemId.SystemMacAddr, self).__setattr__(name, value)

                                    def has_data(self):
                                        return self.macaddr.is_set

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.macaddr.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "system-mac-addr" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.macaddr.is_set or self.macaddr.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.macaddr.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "macaddr"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "macaddr"):
                                            self.macaddr = value
                                            self.macaddr.value_namespace = name_space
                                            self.macaddr.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.system_prio.is_set or
                                        (self.system_mac_addr is not None and self.system_mac_addr.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.system_prio.yfilter != YFilter.not_set or
                                        (self.system_mac_addr is not None and self.system_mac_addr.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "system-id" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.system_prio.is_set or self.system_prio.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.system_prio.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "system-mac-addr"):
                                        if (self.system_mac_addr is None):
                                            self.system_mac_addr = BundleInformation.Mlacp.MlacpIccpGroups.MlacpIccpGroup.MlacpIccpGroupItem.IccpGroupData.NodeData.SystemId.SystemMacAddr()
                                            self.system_mac_addr.parent = self
                                            self._children_name_map["system_mac_addr"] = "system-mac-addr"
                                        return self.system_mac_addr

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "system-mac-addr" or name == "system-prio"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "system-prio"):
                                        self.system_prio = value
                                        self.system_prio.value_namespace = name_space
                                        self.system_prio.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.iccp_group_state.is_set or
                                    self.ldp_id.is_set or
                                    self.mlacp_node_id.is_set or
                                    self.node_state.is_set or
                                    self.version_number.is_set or
                                    (self.system_id is not None and self.system_id.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.iccp_group_state.yfilter != YFilter.not_set or
                                    self.ldp_id.yfilter != YFilter.not_set or
                                    self.mlacp_node_id.yfilter != YFilter.not_set or
                                    self.node_state.yfilter != YFilter.not_set or
                                    self.version_number.yfilter != YFilter.not_set or
                                    (self.system_id is not None and self.system_id.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "node-data" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.iccp_group_state.is_set or self.iccp_group_state.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.iccp_group_state.get_name_leafdata())
                                if (self.ldp_id.is_set or self.ldp_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ldp_id.get_name_leafdata())
                                if (self.mlacp_node_id.is_set or self.mlacp_node_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mlacp_node_id.get_name_leafdata())
                                if (self.node_state.is_set or self.node_state.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.node_state.get_name_leafdata())
                                if (self.version_number.is_set or self.version_number.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.version_number.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "system-id"):
                                    if (self.system_id is None):
                                        self.system_id = BundleInformation.Mlacp.MlacpIccpGroups.MlacpIccpGroup.MlacpIccpGroupItem.IccpGroupData.NodeData.SystemId()
                                        self.system_id.parent = self
                                        self._children_name_map["system_id"] = "system-id"
                                    return self.system_id

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "system-id" or name == "iccp-group-state" or name == "ldp-id" or name == "mlacp-node-id" or name == "node-state" or name == "version-number"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "iccp-group-state"):
                                    self.iccp_group_state = value
                                    self.iccp_group_state.value_namespace = name_space
                                    self.iccp_group_state.value_namespace_prefix = name_space_prefix
                                if(value_path == "ldp-id"):
                                    self.ldp_id = value
                                    self.ldp_id.value_namespace = name_space
                                    self.ldp_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "mlacp-node-id"):
                                    self.mlacp_node_id = value
                                    self.mlacp_node_id.value_namespace = name_space
                                    self.mlacp_node_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "node-state"):
                                    self.node_state = value
                                    self.node_state.value_namespace = name_space
                                    self.node_state.value_namespace_prefix = name_space_prefix
                                if(value_path == "version-number"):
                                    self.version_number = value
                                    self.version_number.value_namespace = name_space
                                    self.version_number.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.node_data:
                                if (c.has_data()):
                                    return True
                            return (
                                self.connect_timer_running.is_set or
                                self.iccp_group_id.is_set or
                                self.singleton.is_set)

                        def has_operation(self):
                            for c in self.node_data:
                                if (c.has_operation()):
                                    return True
                            return (
                                self.yfilter != YFilter.not_set or
                                self.connect_timer_running.yfilter != YFilter.not_set or
                                self.iccp_group_id.yfilter != YFilter.not_set or
                                self.singleton.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "iccp-group-data" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.connect_timer_running.is_set or self.connect_timer_running.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.connect_timer_running.get_name_leafdata())
                            if (self.iccp_group_id.is_set or self.iccp_group_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.iccp_group_id.get_name_leafdata())
                            if (self.singleton.is_set or self.singleton.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.singleton.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "node-data"):
                                for c in self.node_data:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = BundleInformation.Mlacp.MlacpIccpGroups.MlacpIccpGroup.MlacpIccpGroupItem.IccpGroupData.NodeData()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.node_data.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "node-data" or name == "connect-timer-running" or name == "iccp-group-id" or name == "singleton"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "connect-timer-running"):
                                self.connect_timer_running = value
                                self.connect_timer_running.value_namespace = name_space
                                self.connect_timer_running.value_namespace_prefix = name_space_prefix
                            if(value_path == "iccp-group-id"):
                                self.iccp_group_id = value
                                self.iccp_group_id.value_namespace = name_space
                                self.iccp_group_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "singleton"):
                                self.singleton = value
                                self.singleton.value_namespace = name_space
                                self.singleton.value_namespace_prefix = name_space_prefix


                    class BundleData(Entity):
                        """
                        Bundle information
                        
                        .. attribute:: bundle_interface_key
                        
                        	Bundle interface key
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: media_type
                        
                        	The media type of the bundle interface
                        	**type**\:   :py:class:`BundleMedia <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleMedia>`
                        
                        .. attribute:: mlacp_bundle_data
                        
                        	mLACP information for the bundle
                        	**type**\: list of    :py:class:`MlacpBundleData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.Mlacp.MlacpIccpGroups.MlacpIccpGroup.MlacpIccpGroupItem.BundleData.MlacpBundleData>`
                        
                        .. attribute:: mlacp_member_data
                        
                        	mLACP information for the member
                        	**type**\: list of    :py:class:`MlacpMemberData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.Mlacp.MlacpIccpGroups.MlacpIccpGroup.MlacpIccpGroupItem.BundleData.MlacpMemberData>`
                        
                        .. attribute:: redundancy_object_id
                        
                        	Redundancy Object ID of the bundle
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        

                        """

                        _prefix = 'bundlemgr-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(BundleInformation.Mlacp.MlacpIccpGroups.MlacpIccpGroup.MlacpIccpGroupItem.BundleData, self).__init__()

                            self.yang_name = "bundle-data"
                            self.yang_parent_name = "mlacp-iccp-group-item"

                            self.bundle_interface_key = YLeaf(YType.uint16, "bundle-interface-key")

                            self.media_type = YLeaf(YType.enumeration, "media-type")

                            self.redundancy_object_id = YLeaf(YType.uint64, "redundancy-object-id")

                            self.mlacp_bundle_data = YList(self)
                            self.mlacp_member_data = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("bundle_interface_key",
                                            "media_type",
                                            "redundancy_object_id") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(BundleInformation.Mlacp.MlacpIccpGroups.MlacpIccpGroup.MlacpIccpGroupItem.BundleData, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(BundleInformation.Mlacp.MlacpIccpGroups.MlacpIccpGroup.MlacpIccpGroupItem.BundleData, self).__setattr__(name, value)


                        class MlacpBundleData(Entity):
                            """
                            mLACP information for the bundle
                            
                            .. attribute:: aggregator_id
                            
                            	Bundle aggregrator ID
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: bundle_name
                            
                            	Bundle name
                            	**type**\:  str
                            
                            .. attribute:: bundle_state
                            
                            	Bundle state
                            	**type**\:   :py:class:`BmdMlacpBdlStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmdMlacpBdlStateEnum>`
                            
                            .. attribute:: mac_address
                            
                            	Bundle MAC address
                            	**type**\:   :py:class:`MacAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.Mlacp.MlacpIccpGroups.MlacpIccpGroup.MlacpIccpGroupItem.BundleData.MlacpBundleData.MacAddress>`
                            
                            .. attribute:: mlacp_node_id
                            
                            	mLACP Device ID
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: port_priority
                            
                            	Bundle port priority
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'bundlemgr-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(BundleInformation.Mlacp.MlacpIccpGroups.MlacpIccpGroup.MlacpIccpGroupItem.BundleData.MlacpBundleData, self).__init__()

                                self.yang_name = "mlacp-bundle-data"
                                self.yang_parent_name = "bundle-data"

                                self.aggregator_id = YLeaf(YType.uint16, "aggregator-id")

                                self.bundle_name = YLeaf(YType.str, "bundle-name")

                                self.bundle_state = YLeaf(YType.enumeration, "bundle-state")

                                self.mlacp_node_id = YLeaf(YType.uint8, "mlacp-node-id")

                                self.port_priority = YLeaf(YType.uint16, "port-priority")

                                self.mac_address = BundleInformation.Mlacp.MlacpIccpGroups.MlacpIccpGroup.MlacpIccpGroupItem.BundleData.MlacpBundleData.MacAddress()
                                self.mac_address.parent = self
                                self._children_name_map["mac_address"] = "mac-address"
                                self._children_yang_names.add("mac-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("aggregator_id",
                                                "bundle_name",
                                                "bundle_state",
                                                "mlacp_node_id",
                                                "port_priority") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(BundleInformation.Mlacp.MlacpIccpGroups.MlacpIccpGroup.MlacpIccpGroupItem.BundleData.MlacpBundleData, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(BundleInformation.Mlacp.MlacpIccpGroups.MlacpIccpGroup.MlacpIccpGroupItem.BundleData.MlacpBundleData, self).__setattr__(name, value)


                            class MacAddress(Entity):
                                """
                                Bundle MAC address
                                
                                .. attribute:: address
                                
                                	MAC address
                                	**type**\:  str
                                
                                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                
                                

                                """

                                _prefix = 'bundlemgr-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(BundleInformation.Mlacp.MlacpIccpGroups.MlacpIccpGroup.MlacpIccpGroupItem.BundleData.MlacpBundleData.MacAddress, self).__init__()

                                    self.yang_name = "mac-address"
                                    self.yang_parent_name = "mlacp-bundle-data"

                                    self.address = YLeaf(YType.str, "address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(BundleInformation.Mlacp.MlacpIccpGroups.MlacpIccpGroup.MlacpIccpGroupItem.BundleData.MlacpBundleData.MacAddress, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(BundleInformation.Mlacp.MlacpIccpGroups.MlacpIccpGroup.MlacpIccpGroupItem.BundleData.MlacpBundleData.MacAddress, self).__setattr__(name, value)

                                def has_data(self):
                                    return self.address.is_set

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "mac-address" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.address.is_set or self.address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "address"):
                                        self.address = value
                                        self.address.value_namespace = name_space
                                        self.address.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.aggregator_id.is_set or
                                    self.bundle_name.is_set or
                                    self.bundle_state.is_set or
                                    self.mlacp_node_id.is_set or
                                    self.port_priority.is_set or
                                    (self.mac_address is not None and self.mac_address.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.aggregator_id.yfilter != YFilter.not_set or
                                    self.bundle_name.yfilter != YFilter.not_set or
                                    self.bundle_state.yfilter != YFilter.not_set or
                                    self.mlacp_node_id.yfilter != YFilter.not_set or
                                    self.port_priority.yfilter != YFilter.not_set or
                                    (self.mac_address is not None and self.mac_address.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "mlacp-bundle-data" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.aggregator_id.is_set or self.aggregator_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.aggregator_id.get_name_leafdata())
                                if (self.bundle_name.is_set or self.bundle_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.bundle_name.get_name_leafdata())
                                if (self.bundle_state.is_set or self.bundle_state.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.bundle_state.get_name_leafdata())
                                if (self.mlacp_node_id.is_set or self.mlacp_node_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mlacp_node_id.get_name_leafdata())
                                if (self.port_priority.is_set or self.port_priority.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.port_priority.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "mac-address"):
                                    if (self.mac_address is None):
                                        self.mac_address = BundleInformation.Mlacp.MlacpIccpGroups.MlacpIccpGroup.MlacpIccpGroupItem.BundleData.MlacpBundleData.MacAddress()
                                        self.mac_address.parent = self
                                        self._children_name_map["mac_address"] = "mac-address"
                                    return self.mac_address

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "mac-address" or name == "aggregator-id" or name == "bundle-name" or name == "bundle-state" or name == "mlacp-node-id" or name == "port-priority"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "aggregator-id"):
                                    self.aggregator_id = value
                                    self.aggregator_id.value_namespace = name_space
                                    self.aggregator_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "bundle-name"):
                                    self.bundle_name = value
                                    self.bundle_name.value_namespace = name_space
                                    self.bundle_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "bundle-state"):
                                    self.bundle_state = value
                                    self.bundle_state.value_namespace = name_space
                                    self.bundle_state.value_namespace_prefix = name_space_prefix
                                if(value_path == "mlacp-node-id"):
                                    self.mlacp_node_id = value
                                    self.mlacp_node_id.value_namespace = name_space
                                    self.mlacp_node_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "port-priority"):
                                    self.port_priority = value
                                    self.port_priority.value_namespace = name_space
                                    self.port_priority.value_namespace_prefix = name_space_prefix


                        class MlacpMemberData(Entity):
                            """
                            mLACP information for the member
                            
                            .. attribute:: configured_priority
                            
                            	Configured priority of the member in the bundle
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: interface_handle
                            
                            	Member's interface handle (local device's members only)
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: member_state
                            
                            	Member state
                            	**type**\:   :py:class:`BmdMlacpMbrStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmdMlacpMbrStateEnum>`
                            
                            .. attribute:: mlacp_node_id
                            
                            	mLACP Device ID
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: operational_priority
                            
                            	Operational priority of the member in the bundle
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: port_name
                            
                            	Port Name
                            	**type**\:  str
                            
                            .. attribute:: port_number
                            
                            	Port number of the member
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'bundlemgr-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(BundleInformation.Mlacp.MlacpIccpGroups.MlacpIccpGroup.MlacpIccpGroupItem.BundleData.MlacpMemberData, self).__init__()

                                self.yang_name = "mlacp-member-data"
                                self.yang_parent_name = "bundle-data"

                                self.configured_priority = YLeaf(YType.uint16, "configured-priority")

                                self.interface_handle = YLeaf(YType.str, "interface-handle")

                                self.member_state = YLeaf(YType.enumeration, "member-state")

                                self.mlacp_node_id = YLeaf(YType.uint8, "mlacp-node-id")

                                self.operational_priority = YLeaf(YType.uint16, "operational-priority")

                                self.port_name = YLeaf(YType.str, "port-name")

                                self.port_number = YLeaf(YType.uint16, "port-number")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("configured_priority",
                                                "interface_handle",
                                                "member_state",
                                                "mlacp_node_id",
                                                "operational_priority",
                                                "port_name",
                                                "port_number") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(BundleInformation.Mlacp.MlacpIccpGroups.MlacpIccpGroup.MlacpIccpGroupItem.BundleData.MlacpMemberData, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(BundleInformation.Mlacp.MlacpIccpGroups.MlacpIccpGroup.MlacpIccpGroupItem.BundleData.MlacpMemberData, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.configured_priority.is_set or
                                    self.interface_handle.is_set or
                                    self.member_state.is_set or
                                    self.mlacp_node_id.is_set or
                                    self.operational_priority.is_set or
                                    self.port_name.is_set or
                                    self.port_number.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.configured_priority.yfilter != YFilter.not_set or
                                    self.interface_handle.yfilter != YFilter.not_set or
                                    self.member_state.yfilter != YFilter.not_set or
                                    self.mlacp_node_id.yfilter != YFilter.not_set or
                                    self.operational_priority.yfilter != YFilter.not_set or
                                    self.port_name.yfilter != YFilter.not_set or
                                    self.port_number.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "mlacp-member-data" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.configured_priority.is_set or self.configured_priority.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.configured_priority.get_name_leafdata())
                                if (self.interface_handle.is_set or self.interface_handle.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.interface_handle.get_name_leafdata())
                                if (self.member_state.is_set or self.member_state.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.member_state.get_name_leafdata())
                                if (self.mlacp_node_id.is_set or self.mlacp_node_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mlacp_node_id.get_name_leafdata())
                                if (self.operational_priority.is_set or self.operational_priority.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.operational_priority.get_name_leafdata())
                                if (self.port_name.is_set or self.port_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.port_name.get_name_leafdata())
                                if (self.port_number.is_set or self.port_number.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.port_number.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "configured-priority" or name == "interface-handle" or name == "member-state" or name == "mlacp-node-id" or name == "operational-priority" or name == "port-name" or name == "port-number"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "configured-priority"):
                                    self.configured_priority = value
                                    self.configured_priority.value_namespace = name_space
                                    self.configured_priority.value_namespace_prefix = name_space_prefix
                                if(value_path == "interface-handle"):
                                    self.interface_handle = value
                                    self.interface_handle.value_namespace = name_space
                                    self.interface_handle.value_namespace_prefix = name_space_prefix
                                if(value_path == "member-state"):
                                    self.member_state = value
                                    self.member_state.value_namespace = name_space
                                    self.member_state.value_namespace_prefix = name_space_prefix
                                if(value_path == "mlacp-node-id"):
                                    self.mlacp_node_id = value
                                    self.mlacp_node_id.value_namespace = name_space
                                    self.mlacp_node_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "operational-priority"):
                                    self.operational_priority = value
                                    self.operational_priority.value_namespace = name_space
                                    self.operational_priority.value_namespace_prefix = name_space_prefix
                                if(value_path == "port-name"):
                                    self.port_name = value
                                    self.port_name.value_namespace = name_space
                                    self.port_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "port-number"):
                                    self.port_number = value
                                    self.port_number.value_namespace = name_space
                                    self.port_number.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.mlacp_bundle_data:
                                if (c.has_data()):
                                    return True
                            for c in self.mlacp_member_data:
                                if (c.has_data()):
                                    return True
                            return (
                                self.bundle_interface_key.is_set or
                                self.media_type.is_set or
                                self.redundancy_object_id.is_set)

                        def has_operation(self):
                            for c in self.mlacp_bundle_data:
                                if (c.has_operation()):
                                    return True
                            for c in self.mlacp_member_data:
                                if (c.has_operation()):
                                    return True
                            return (
                                self.yfilter != YFilter.not_set or
                                self.bundle_interface_key.yfilter != YFilter.not_set or
                                self.media_type.yfilter != YFilter.not_set or
                                self.redundancy_object_id.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "bundle-data" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.bundle_interface_key.is_set or self.bundle_interface_key.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.bundle_interface_key.get_name_leafdata())
                            if (self.media_type.is_set or self.media_type.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.media_type.get_name_leafdata())
                            if (self.redundancy_object_id.is_set or self.redundancy_object_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.redundancy_object_id.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "mlacp-bundle-data"):
                                for c in self.mlacp_bundle_data:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = BundleInformation.Mlacp.MlacpIccpGroups.MlacpIccpGroup.MlacpIccpGroupItem.BundleData.MlacpBundleData()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.mlacp_bundle_data.append(c)
                                return c

                            if (child_yang_name == "mlacp-member-data"):
                                for c in self.mlacp_member_data:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = BundleInformation.Mlacp.MlacpIccpGroups.MlacpIccpGroup.MlacpIccpGroupItem.BundleData.MlacpMemberData()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.mlacp_member_data.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "mlacp-bundle-data" or name == "mlacp-member-data" or name == "bundle-interface-key" or name == "media-type" or name == "redundancy-object-id"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "bundle-interface-key"):
                                self.bundle_interface_key = value
                                self.bundle_interface_key.value_namespace = name_space
                                self.bundle_interface_key.value_namespace_prefix = name_space_prefix
                            if(value_path == "media-type"):
                                self.media_type = value
                                self.media_type.value_namespace = name_space
                                self.media_type.value_namespace_prefix = name_space_prefix
                            if(value_path == "redundancy-object-id"):
                                self.redundancy_object_id = value
                                self.redundancy_object_id.value_namespace = name_space
                                self.redundancy_object_id.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.bundle_data:
                            if (c.has_data()):
                                return True
                        return (self.iccp_group_data is not None and self.iccp_group_data.has_data())

                    def has_operation(self):
                        for c in self.bundle_data:
                            if (c.has_operation()):
                                return True
                        return (
                            self.yfilter != YFilter.not_set or
                            (self.iccp_group_data is not None and self.iccp_group_data.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "mlacp-iccp-group-item" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "bundle-data"):
                            for c in self.bundle_data:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = BundleInformation.Mlacp.MlacpIccpGroups.MlacpIccpGroup.MlacpIccpGroupItem.BundleData()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.bundle_data.append(c)
                            return c

                        if (child_yang_name == "iccp-group-data"):
                            if (self.iccp_group_data is None):
                                self.iccp_group_data = BundleInformation.Mlacp.MlacpIccpGroups.MlacpIccpGroup.MlacpIccpGroupItem.IccpGroupData()
                                self.iccp_group_data.parent = self
                                self._children_name_map["iccp_group_data"] = "iccp-group-data"
                            return self.iccp_group_data

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "bundle-data" or name == "iccp-group-data"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass

                def has_data(self):
                    return (
                        self.iccp_group.is_set or
                        (self.mlacp_iccp_group_item is not None and self.mlacp_iccp_group_item.has_data()))

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.iccp_group.yfilter != YFilter.not_set or
                        (self.mlacp_iccp_group_item is not None and self.mlacp_iccp_group_item.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "mlacp-iccp-group" + "[iccp-group='" + self.iccp_group.get() + "']" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-bundlemgr-oper:bundle-information/mlacp/mlacp-iccp-groups/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.iccp_group.is_set or self.iccp_group.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.iccp_group.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "mlacp-iccp-group-item"):
                        if (self.mlacp_iccp_group_item is None):
                            self.mlacp_iccp_group_item = BundleInformation.Mlacp.MlacpIccpGroups.MlacpIccpGroup.MlacpIccpGroupItem()
                            self.mlacp_iccp_group_item.parent = self
                            self._children_name_map["mlacp_iccp_group_item"] = "mlacp-iccp-group-item"
                        return self.mlacp_iccp_group_item

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "mlacp-iccp-group-item" or name == "iccp-group"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "iccp-group"):
                        self.iccp_group = value
                        self.iccp_group.value_namespace = name_space
                        self.iccp_group.value_namespace_prefix = name_space_prefix

            def has_data(self):
                for c in self.mlacp_iccp_group:
                    if (c.has_data()):
                        return True
                return False

            def has_operation(self):
                for c in self.mlacp_iccp_group:
                    if (c.has_operation()):
                        return True
                return self.yfilter != YFilter.not_set

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "mlacp-iccp-groups" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-bundlemgr-oper:bundle-information/mlacp/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "mlacp-iccp-group"):
                    for c in self.mlacp_iccp_group:
                        segment = c.get_segment_path()
                        if (segment_path == segment):
                            return c
                    c = BundleInformation.Mlacp.MlacpIccpGroups.MlacpIccpGroup()
                    c.parent = self
                    local_reference_key = "ydk::seg::%s" % segment_path
                    self._local_refs[local_reference_key] = c
                    self.mlacp_iccp_group.append(c)
                    return c

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "mlacp-iccp-group"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                pass

        def has_data(self):
            return (
                (self.mlacp_bundles is not None and self.mlacp_bundles.has_data()) or
                (self.mlacp_iccp_groups is not None and self.mlacp_iccp_groups.has_data()))

        def has_operation(self):
            return (
                self.yfilter != YFilter.not_set or
                (self.mlacp_bundles is not None and self.mlacp_bundles.has_operation()) or
                (self.mlacp_iccp_groups is not None and self.mlacp_iccp_groups.has_operation()))

        def get_segment_path(self):
            path_buffer = ""
            path_buffer = "mlacp" + path_buffer

            return path_buffer

        def get_entity_path(self, ancestor):
            path_buffer = ""
            if (ancestor is None):
                path_buffer = "Cisco-IOS-XR-bundlemgr-oper:bundle-information/%s" % self.get_segment_path()
            else:
                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

            leaf_name_data = LeafDataList()

            entity_path = EntityPath(path_buffer, leaf_name_data)
            return entity_path

        def get_child_by_name(self, child_yang_name, segment_path):
            child = self._get_child_by_seg_name([child_yang_name, segment_path])
            if child is not None:
                return child

            if (child_yang_name == "mlacp-bundles"):
                if (self.mlacp_bundles is None):
                    self.mlacp_bundles = BundleInformation.Mlacp.MlacpBundles()
                    self.mlacp_bundles.parent = self
                    self._children_name_map["mlacp_bundles"] = "mlacp-bundles"
                return self.mlacp_bundles

            if (child_yang_name == "mlacp-iccp-groups"):
                if (self.mlacp_iccp_groups is None):
                    self.mlacp_iccp_groups = BundleInformation.Mlacp.MlacpIccpGroups()
                    self.mlacp_iccp_groups.parent = self
                    self._children_name_map["mlacp_iccp_groups"] = "mlacp-iccp-groups"
                return self.mlacp_iccp_groups

            return None

        def has_leaf_or_child_of_name(self, name):
            if(name == "mlacp-bundles" or name == "mlacp-iccp-groups"):
                return True
            return False

        def set_value(self, value_path, value, name_space, name_space_prefix):
            pass


    class MacAllocation(Entity):
        """
        Information about allocated MAC addresses that
        are not in use
        
        .. attribute:: mac_allocation_global
        
        	All MAC addresses that are allocated but currently not in use
        	**type**\:   :py:class:`MacAllocationGlobal <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.MacAllocation.MacAllocationGlobal>`
        
        

        """

        _prefix = 'bundlemgr-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(BundleInformation.MacAllocation, self).__init__()

            self.yang_name = "mac-allocation"
            self.yang_parent_name = "bundle-information"

            self.mac_allocation_global = BundleInformation.MacAllocation.MacAllocationGlobal()
            self.mac_allocation_global.parent = self
            self._children_name_map["mac_allocation_global"] = "mac-allocation-global"
            self._children_yang_names.add("mac-allocation-global")


        class MacAllocationGlobal(Entity):
            """
            All MAC addresses that are allocated but
            currently not in use
            
            .. attribute:: mac_allocation_global_item
            
            	Data for this item
            	**type**\:   :py:class:`MacAllocationGlobalItem <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.MacAllocation.MacAllocationGlobal.MacAllocationGlobalItem>`
            
            

            """

            _prefix = 'bundlemgr-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(BundleInformation.MacAllocation.MacAllocationGlobal, self).__init__()

                self.yang_name = "mac-allocation-global"
                self.yang_parent_name = "mac-allocation"

                self.mac_allocation_global_item = BundleInformation.MacAllocation.MacAllocationGlobal.MacAllocationGlobalItem()
                self.mac_allocation_global_item.parent = self
                self._children_name_map["mac_allocation_global_item"] = "mac-allocation-global-item"
                self._children_yang_names.add("mac-allocation-global-item")


            class MacAllocationGlobalItem(Entity):
                """
                Data for this item
                
                .. attribute:: mac_address
                
                	MAC addresses allocated but unused
                	**type**\: list of    :py:class:`MacAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.MacAllocation.MacAllocationGlobal.MacAllocationGlobalItem.MacAddress>`
                
                

                """

                _prefix = 'bundlemgr-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(BundleInformation.MacAllocation.MacAllocationGlobal.MacAllocationGlobalItem, self).__init__()

                    self.yang_name = "mac-allocation-global-item"
                    self.yang_parent_name = "mac-allocation-global"

                    self.mac_address = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(BundleInformation.MacAllocation.MacAllocationGlobal.MacAllocationGlobalItem, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(BundleInformation.MacAllocation.MacAllocationGlobal.MacAllocationGlobalItem, self).__setattr__(name, value)


                class MacAddress(Entity):
                    """
                    MAC addresses allocated but unused
                    
                    .. attribute:: address
                    
                    	MAC address
                    	**type**\:  str
                    
                    	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                    
                    

                    """

                    _prefix = 'bundlemgr-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(BundleInformation.MacAllocation.MacAllocationGlobal.MacAllocationGlobalItem.MacAddress, self).__init__()

                        self.yang_name = "mac-address"
                        self.yang_parent_name = "mac-allocation-global-item"

                        self.address = YLeaf(YType.str, "address")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("address") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(BundleInformation.MacAllocation.MacAllocationGlobal.MacAllocationGlobalItem.MacAddress, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(BundleInformation.MacAllocation.MacAllocationGlobal.MacAllocationGlobalItem.MacAddress, self).__setattr__(name, value)

                    def has_data(self):
                        return self.address.is_set

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.address.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "mac-address" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-bundlemgr-oper:bundle-information/mac-allocation/mac-allocation-global/mac-allocation-global-item/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.address.is_set or self.address.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.address.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "address"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "address"):
                            self.address = value
                            self.address.value_namespace = name_space
                            self.address.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.mac_address:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.mac_address:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "mac-allocation-global-item" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-bundlemgr-oper:bundle-information/mac-allocation/mac-allocation-global/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "mac-address"):
                        for c in self.mac_address:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = BundleInformation.MacAllocation.MacAllocationGlobal.MacAllocationGlobalItem.MacAddress()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.mac_address.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "mac-address"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass

            def has_data(self):
                return (self.mac_allocation_global_item is not None and self.mac_allocation_global_item.has_data())

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    (self.mac_allocation_global_item is not None and self.mac_allocation_global_item.has_operation()))

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "mac-allocation-global" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-bundlemgr-oper:bundle-information/mac-allocation/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "mac-allocation-global-item"):
                    if (self.mac_allocation_global_item is None):
                        self.mac_allocation_global_item = BundleInformation.MacAllocation.MacAllocationGlobal.MacAllocationGlobalItem()
                        self.mac_allocation_global_item.parent = self
                        self._children_name_map["mac_allocation_global_item"] = "mac-allocation-global-item"
                    return self.mac_allocation_global_item

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "mac-allocation-global-item"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                pass

        def has_data(self):
            return (self.mac_allocation_global is not None and self.mac_allocation_global.has_data())

        def has_operation(self):
            return (
                self.yfilter != YFilter.not_set or
                (self.mac_allocation_global is not None and self.mac_allocation_global.has_operation()))

        def get_segment_path(self):
            path_buffer = ""
            path_buffer = "mac-allocation" + path_buffer

            return path_buffer

        def get_entity_path(self, ancestor):
            path_buffer = ""
            if (ancestor is None):
                path_buffer = "Cisco-IOS-XR-bundlemgr-oper:bundle-information/%s" % self.get_segment_path()
            else:
                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

            leaf_name_data = LeafDataList()

            entity_path = EntityPath(path_buffer, leaf_name_data)
            return entity_path

        def get_child_by_name(self, child_yang_name, segment_path):
            child = self._get_child_by_seg_name([child_yang_name, segment_path])
            if child is not None:
                return child

            if (child_yang_name == "mac-allocation-global"):
                if (self.mac_allocation_global is None):
                    self.mac_allocation_global = BundleInformation.MacAllocation.MacAllocationGlobal()
                    self.mac_allocation_global.parent = self
                    self._children_name_map["mac_allocation_global"] = "mac-allocation-global"
                return self.mac_allocation_global

            return None

        def has_leaf_or_child_of_name(self, name):
            if(name == "mac-allocation-global"):
                return True
            return False

        def set_value(self, value_path, value, name_space, name_space_prefix):
            pass


    class Events(Entity):
        """
        Events information for bundles and members
        
        .. attribute:: events_bundles
        
        	Bundle interfaces with events information
        	**type**\:   :py:class:`EventsBundles <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.Events.EventsBundles>`
        
        .. attribute:: events_members
        
        	Member interfaces with events information
        	**type**\:   :py:class:`EventsMembers <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.Events.EventsMembers>`
        
        

        """

        _prefix = 'bundlemgr-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(BundleInformation.Events, self).__init__()

            self.yang_name = "events"
            self.yang_parent_name = "bundle-information"

            self.events_bundles = BundleInformation.Events.EventsBundles()
            self.events_bundles.parent = self
            self._children_name_map["events_bundles"] = "events-bundles"
            self._children_yang_names.add("events-bundles")

            self.events_members = BundleInformation.Events.EventsMembers()
            self.events_members.parent = self
            self._children_name_map["events_members"] = "events-members"
            self._children_yang_names.add("events-members")


        class EventsMembers(Entity):
            """
            Member interfaces with events information
            
            .. attribute:: events_member
            
            	Member interface
            	**type**\: list of    :py:class:`EventsMember <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.Events.EventsMembers.EventsMember>`
            
            

            """

            _prefix = 'bundlemgr-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(BundleInformation.Events.EventsMembers, self).__init__()

                self.yang_name = "events-members"
                self.yang_parent_name = "events"

                self.events_member = YList(self)

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in () and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(BundleInformation.Events.EventsMembers, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(BundleInformation.Events.EventsMembers, self).__setattr__(name, value)


            class EventsMember(Entity):
                """
                Member interface
                
                .. attribute:: member_interface  <key>
                
                	Member interface
                	**type**\:  str
                
                .. attribute:: events_member_ancestor
                
                	Data for this item and its parent bundle
                	**type**\:   :py:class:`EventsMemberAncestor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.Events.EventsMembers.EventsMember.EventsMemberAncestor>`
                
                .. attribute:: events_member_item
                
                	Data for this item
                	**type**\:   :py:class:`EventsMemberItem <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.Events.EventsMembers.EventsMember.EventsMemberItem>`
                
                

                """

                _prefix = 'bundlemgr-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(BundleInformation.Events.EventsMembers.EventsMember, self).__init__()

                    self.yang_name = "events-member"
                    self.yang_parent_name = "events-members"

                    self.member_interface = YLeaf(YType.str, "member-interface")

                    self.events_member_ancestor = BundleInformation.Events.EventsMembers.EventsMember.EventsMemberAncestor()
                    self.events_member_ancestor.parent = self
                    self._children_name_map["events_member_ancestor"] = "events-member-ancestor"
                    self._children_yang_names.add("events-member-ancestor")

                    self.events_member_item = BundleInformation.Events.EventsMembers.EventsMember.EventsMemberItem()
                    self.events_member_item.parent = self
                    self._children_name_map["events_member_item"] = "events-member-item"
                    self._children_yang_names.add("events-member-item")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("member_interface") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(BundleInformation.Events.EventsMembers.EventsMember, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(BundleInformation.Events.EventsMembers.EventsMember, self).__setattr__(name, value)


                class EventsMemberItem(Entity):
                    """
                    Data for this item
                    
                    .. attribute:: item_name
                    
                    	Name for the current item to use
                    	**type**\:  str
                    
                    .. attribute:: items
                    
                    	Event items
                    	**type**\: list of    :py:class:`Items <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.Events.EventsMembers.EventsMember.EventsMemberItem.Items>`
                    
                    

                    """

                    _prefix = 'bundlemgr-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(BundleInformation.Events.EventsMembers.EventsMember.EventsMemberItem, self).__init__()

                        self.yang_name = "events-member-item"
                        self.yang_parent_name = "events-member"

                        self.item_name = YLeaf(YType.str, "item-name")

                        self.items = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("item_name") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(BundleInformation.Events.EventsMembers.EventsMember.EventsMemberItem, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(BundleInformation.Events.EventsMembers.EventsMember.EventsMemberItem, self).__setattr__(name, value)


                    class Items(Entity):
                        """
                        Event items
                        
                        .. attribute:: bundle_evt_info
                        
                        	Event information for a bundle
                        	**type**\:   :py:class:`BundleEvtInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.Events.EventsMembers.EventsMember.EventsMemberItem.Items.BundleEvtInfo>`
                        
                        .. attribute:: event_type
                        
                        	EventType
                        	**type**\:   :py:class:`BmdBagTarget <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmdBagTarget>`
                        
                        .. attribute:: member_evt_info
                        
                        	Event information for a member
                        	**type**\:   :py:class:`MemberEvtInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.Events.EventsMembers.EventsMember.EventsMemberItem.Items.MemberEvtInfo>`
                        
                        .. attribute:: rg_evt_info
                        
                        	Event information for an RG
                        	**type**\:   :py:class:`RgEvtInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.Events.EventsMembers.EventsMember.EventsMemberItem.Items.RgEvtInfo>`
                        
                        

                        """

                        _prefix = 'bundlemgr-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(BundleInformation.Events.EventsMembers.EventsMember.EventsMemberItem.Items, self).__init__()

                            self.yang_name = "items"
                            self.yang_parent_name = "events-member-item"

                            self.event_type = YLeaf(YType.enumeration, "event-type")

                            self.bundle_evt_info = BundleInformation.Events.EventsMembers.EventsMember.EventsMemberItem.Items.BundleEvtInfo()
                            self.bundle_evt_info.parent = self
                            self._children_name_map["bundle_evt_info"] = "bundle-evt-info"
                            self._children_yang_names.add("bundle-evt-info")

                            self.member_evt_info = BundleInformation.Events.EventsMembers.EventsMember.EventsMemberItem.Items.MemberEvtInfo()
                            self.member_evt_info.parent = self
                            self._children_name_map["member_evt_info"] = "member-evt-info"
                            self._children_yang_names.add("member-evt-info")

                            self.rg_evt_info = BundleInformation.Events.EventsMembers.EventsMember.EventsMemberItem.Items.RgEvtInfo()
                            self.rg_evt_info.parent = self
                            self._children_name_map["rg_evt_info"] = "rg-evt-info"
                            self._children_yang_names.add("rg-evt-info")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("event_type") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(BundleInformation.Events.EventsMembers.EventsMember.EventsMemberItem.Items, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(BundleInformation.Events.EventsMembers.EventsMember.EventsMemberItem.Items, self).__setattr__(name, value)


                        class MemberEvtInfo(Entity):
                            """
                            Event information for a member
                            
                            .. attribute:: data
                            
                            	Additional data for the event
                            	**type**\:   :py:class:`Data <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.Events.EventsMembers.EventsMember.EventsMemberItem.Items.MemberEvtInfo.Data>`
                            
                            .. attribute:: member_event_type
                            
                            	Type of event for member
                            	**type**\:   :py:class:`BmdBagEventMbrItem <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmdBagEventMbrItem>`
                            
                            .. attribute:: time_stamp
                            
                            	Time stamp of the event
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            

                            """

                            _prefix = 'bundlemgr-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(BundleInformation.Events.EventsMembers.EventsMember.EventsMemberItem.Items.MemberEvtInfo, self).__init__()

                                self.yang_name = "member-evt-info"
                                self.yang_parent_name = "items"

                                self.member_event_type = YLeaf(YType.enumeration, "member-event-type")

                                self.time_stamp = YLeaf(YType.uint64, "time-stamp")

                                self.data = BundleInformation.Events.EventsMembers.EventsMember.EventsMemberItem.Items.MemberEvtInfo.Data()
                                self.data.parent = self
                                self._children_name_map["data"] = "data"
                                self._children_yang_names.add("data")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("member_event_type",
                                                "time_stamp") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(BundleInformation.Events.EventsMembers.EventsMember.EventsMemberItem.Items.MemberEvtInfo, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(BundleInformation.Events.EventsMembers.EventsMember.EventsMemberItem.Items.MemberEvtInfo, self).__setattr__(name, value)


                            class Data(Entity):
                                """
                                Additional data for the event
                                
                                .. attribute:: data_type
                                
                                	DataType
                                	**type**\:   :py:class:`BmdBagEventData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmdBagEventData>`
                                
                                .. attribute:: error
                                
                                	Error
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: no_data
                                
                                	NoData
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: string_data
                                
                                	StringData
                                	**type**\:  str
                                
                                

                                """

                                _prefix = 'bundlemgr-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(BundleInformation.Events.EventsMembers.EventsMember.EventsMemberItem.Items.MemberEvtInfo.Data, self).__init__()

                                    self.yang_name = "data"
                                    self.yang_parent_name = "member-evt-info"

                                    self.data_type = YLeaf(YType.enumeration, "data-type")

                                    self.error = YLeaf(YType.uint32, "error")

                                    self.no_data = YLeaf(YType.uint8, "no-data")

                                    self.string_data = YLeaf(YType.str, "string-data")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("data_type",
                                                    "error",
                                                    "no_data",
                                                    "string_data") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(BundleInformation.Events.EventsMembers.EventsMember.EventsMemberItem.Items.MemberEvtInfo.Data, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(BundleInformation.Events.EventsMembers.EventsMember.EventsMemberItem.Items.MemberEvtInfo.Data, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.data_type.is_set or
                                        self.error.is_set or
                                        self.no_data.is_set or
                                        self.string_data.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.data_type.yfilter != YFilter.not_set or
                                        self.error.yfilter != YFilter.not_set or
                                        self.no_data.yfilter != YFilter.not_set or
                                        self.string_data.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "data" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.data_type.is_set or self.data_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.data_type.get_name_leafdata())
                                    if (self.error.is_set or self.error.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.error.get_name_leafdata())
                                    if (self.no_data.is_set or self.no_data.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.no_data.get_name_leafdata())
                                    if (self.string_data.is_set or self.string_data.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.string_data.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "data-type" or name == "error" or name == "no-data" or name == "string-data"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "data-type"):
                                        self.data_type = value
                                        self.data_type.value_namespace = name_space
                                        self.data_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "error"):
                                        self.error = value
                                        self.error.value_namespace = name_space
                                        self.error.value_namespace_prefix = name_space_prefix
                                    if(value_path == "no-data"):
                                        self.no_data = value
                                        self.no_data.value_namespace = name_space
                                        self.no_data.value_namespace_prefix = name_space_prefix
                                    if(value_path == "string-data"):
                                        self.string_data = value
                                        self.string_data.value_namespace = name_space
                                        self.string_data.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.member_event_type.is_set or
                                    self.time_stamp.is_set or
                                    (self.data is not None and self.data.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.member_event_type.yfilter != YFilter.not_set or
                                    self.time_stamp.yfilter != YFilter.not_set or
                                    (self.data is not None and self.data.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "member-evt-info" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.member_event_type.is_set or self.member_event_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.member_event_type.get_name_leafdata())
                                if (self.time_stamp.is_set or self.time_stamp.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.time_stamp.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "data"):
                                    if (self.data is None):
                                        self.data = BundleInformation.Events.EventsMembers.EventsMember.EventsMemberItem.Items.MemberEvtInfo.Data()
                                        self.data.parent = self
                                        self._children_name_map["data"] = "data"
                                    return self.data

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "data" or name == "member-event-type" or name == "time-stamp"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "member-event-type"):
                                    self.member_event_type = value
                                    self.member_event_type.value_namespace = name_space
                                    self.member_event_type.value_namespace_prefix = name_space_prefix
                                if(value_path == "time-stamp"):
                                    self.time_stamp = value
                                    self.time_stamp.value_namespace = name_space
                                    self.time_stamp.value_namespace_prefix = name_space_prefix


                        class BundleEvtInfo(Entity):
                            """
                            Event information for a bundle
                            
                            .. attribute:: bundle_event_type
                            
                            	Type of event for bundle
                            	**type**\:   :py:class:`BmdBagEventBdlItem <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmdBagEventBdlItem>`
                            
                            .. attribute:: data
                            
                            	Additional data for the event
                            	**type**\:   :py:class:`Data <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.Events.EventsMembers.EventsMember.EventsMemberItem.Items.BundleEvtInfo.Data>`
                            
                            .. attribute:: time_stamp
                            
                            	Time stamp of the event
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            

                            """

                            _prefix = 'bundlemgr-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(BundleInformation.Events.EventsMembers.EventsMember.EventsMemberItem.Items.BundleEvtInfo, self).__init__()

                                self.yang_name = "bundle-evt-info"
                                self.yang_parent_name = "items"

                                self.bundle_event_type = YLeaf(YType.enumeration, "bundle-event-type")

                                self.time_stamp = YLeaf(YType.uint64, "time-stamp")

                                self.data = BundleInformation.Events.EventsMembers.EventsMember.EventsMemberItem.Items.BundleEvtInfo.Data()
                                self.data.parent = self
                                self._children_name_map["data"] = "data"
                                self._children_yang_names.add("data")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("bundle_event_type",
                                                "time_stamp") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(BundleInformation.Events.EventsMembers.EventsMember.EventsMemberItem.Items.BundleEvtInfo, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(BundleInformation.Events.EventsMembers.EventsMember.EventsMemberItem.Items.BundleEvtInfo, self).__setattr__(name, value)


                            class Data(Entity):
                                """
                                Additional data for the event
                                
                                .. attribute:: data_type
                                
                                	DataType
                                	**type**\:   :py:class:`BmdBagEventData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmdBagEventData>`
                                
                                .. attribute:: error
                                
                                	Error
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: no_data
                                
                                	NoData
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: string_data
                                
                                	StringData
                                	**type**\:  str
                                
                                

                                """

                                _prefix = 'bundlemgr-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(BundleInformation.Events.EventsMembers.EventsMember.EventsMemberItem.Items.BundleEvtInfo.Data, self).__init__()

                                    self.yang_name = "data"
                                    self.yang_parent_name = "bundle-evt-info"

                                    self.data_type = YLeaf(YType.enumeration, "data-type")

                                    self.error = YLeaf(YType.uint32, "error")

                                    self.no_data = YLeaf(YType.uint8, "no-data")

                                    self.string_data = YLeaf(YType.str, "string-data")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("data_type",
                                                    "error",
                                                    "no_data",
                                                    "string_data") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(BundleInformation.Events.EventsMembers.EventsMember.EventsMemberItem.Items.BundleEvtInfo.Data, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(BundleInformation.Events.EventsMembers.EventsMember.EventsMemberItem.Items.BundleEvtInfo.Data, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.data_type.is_set or
                                        self.error.is_set or
                                        self.no_data.is_set or
                                        self.string_data.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.data_type.yfilter != YFilter.not_set or
                                        self.error.yfilter != YFilter.not_set or
                                        self.no_data.yfilter != YFilter.not_set or
                                        self.string_data.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "data" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.data_type.is_set or self.data_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.data_type.get_name_leafdata())
                                    if (self.error.is_set or self.error.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.error.get_name_leafdata())
                                    if (self.no_data.is_set or self.no_data.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.no_data.get_name_leafdata())
                                    if (self.string_data.is_set or self.string_data.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.string_data.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "data-type" or name == "error" or name == "no-data" or name == "string-data"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "data-type"):
                                        self.data_type = value
                                        self.data_type.value_namespace = name_space
                                        self.data_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "error"):
                                        self.error = value
                                        self.error.value_namespace = name_space
                                        self.error.value_namespace_prefix = name_space_prefix
                                    if(value_path == "no-data"):
                                        self.no_data = value
                                        self.no_data.value_namespace = name_space
                                        self.no_data.value_namespace_prefix = name_space_prefix
                                    if(value_path == "string-data"):
                                        self.string_data = value
                                        self.string_data.value_namespace = name_space
                                        self.string_data.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.bundle_event_type.is_set or
                                    self.time_stamp.is_set or
                                    (self.data is not None and self.data.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.bundle_event_type.yfilter != YFilter.not_set or
                                    self.time_stamp.yfilter != YFilter.not_set or
                                    (self.data is not None and self.data.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "bundle-evt-info" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.bundle_event_type.is_set or self.bundle_event_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.bundle_event_type.get_name_leafdata())
                                if (self.time_stamp.is_set or self.time_stamp.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.time_stamp.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "data"):
                                    if (self.data is None):
                                        self.data = BundleInformation.Events.EventsMembers.EventsMember.EventsMemberItem.Items.BundleEvtInfo.Data()
                                        self.data.parent = self
                                        self._children_name_map["data"] = "data"
                                    return self.data

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "data" or name == "bundle-event-type" or name == "time-stamp"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "bundle-event-type"):
                                    self.bundle_event_type = value
                                    self.bundle_event_type.value_namespace = name_space
                                    self.bundle_event_type.value_namespace_prefix = name_space_prefix
                                if(value_path == "time-stamp"):
                                    self.time_stamp = value
                                    self.time_stamp.value_namespace = name_space
                                    self.time_stamp.value_namespace_prefix = name_space_prefix


                        class RgEvtInfo(Entity):
                            """
                            Event information for an RG
                            
                            .. attribute:: data
                            
                            	Additional data for the event
                            	**type**\:   :py:class:`Data <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.Events.EventsMembers.EventsMember.EventsMemberItem.Items.RgEvtInfo.Data>`
                            
                            .. attribute:: rg_event_type
                            
                            	Type of event for RG
                            	**type**\:   :py:class:`BmdBagEventRgItem <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmdBagEventRgItem>`
                            
                            .. attribute:: time_stamp
                            
                            	Time stamp of the event
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            

                            """

                            _prefix = 'bundlemgr-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(BundleInformation.Events.EventsMembers.EventsMember.EventsMemberItem.Items.RgEvtInfo, self).__init__()

                                self.yang_name = "rg-evt-info"
                                self.yang_parent_name = "items"

                                self.rg_event_type = YLeaf(YType.enumeration, "rg-event-type")

                                self.time_stamp = YLeaf(YType.uint64, "time-stamp")

                                self.data = BundleInformation.Events.EventsMembers.EventsMember.EventsMemberItem.Items.RgEvtInfo.Data()
                                self.data.parent = self
                                self._children_name_map["data"] = "data"
                                self._children_yang_names.add("data")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("rg_event_type",
                                                "time_stamp") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(BundleInformation.Events.EventsMembers.EventsMember.EventsMemberItem.Items.RgEvtInfo, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(BundleInformation.Events.EventsMembers.EventsMember.EventsMemberItem.Items.RgEvtInfo, self).__setattr__(name, value)


                            class Data(Entity):
                                """
                                Additional data for the event
                                
                                .. attribute:: data_type
                                
                                	DataType
                                	**type**\:   :py:class:`BmdBagEventData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmdBagEventData>`
                                
                                .. attribute:: error
                                
                                	Error
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: no_data
                                
                                	NoData
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: string_data
                                
                                	StringData
                                	**type**\:  str
                                
                                

                                """

                                _prefix = 'bundlemgr-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(BundleInformation.Events.EventsMembers.EventsMember.EventsMemberItem.Items.RgEvtInfo.Data, self).__init__()

                                    self.yang_name = "data"
                                    self.yang_parent_name = "rg-evt-info"

                                    self.data_type = YLeaf(YType.enumeration, "data-type")

                                    self.error = YLeaf(YType.uint32, "error")

                                    self.no_data = YLeaf(YType.uint8, "no-data")

                                    self.string_data = YLeaf(YType.str, "string-data")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("data_type",
                                                    "error",
                                                    "no_data",
                                                    "string_data") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(BundleInformation.Events.EventsMembers.EventsMember.EventsMemberItem.Items.RgEvtInfo.Data, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(BundleInformation.Events.EventsMembers.EventsMember.EventsMemberItem.Items.RgEvtInfo.Data, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.data_type.is_set or
                                        self.error.is_set or
                                        self.no_data.is_set or
                                        self.string_data.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.data_type.yfilter != YFilter.not_set or
                                        self.error.yfilter != YFilter.not_set or
                                        self.no_data.yfilter != YFilter.not_set or
                                        self.string_data.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "data" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.data_type.is_set or self.data_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.data_type.get_name_leafdata())
                                    if (self.error.is_set or self.error.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.error.get_name_leafdata())
                                    if (self.no_data.is_set or self.no_data.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.no_data.get_name_leafdata())
                                    if (self.string_data.is_set or self.string_data.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.string_data.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "data-type" or name == "error" or name == "no-data" or name == "string-data"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "data-type"):
                                        self.data_type = value
                                        self.data_type.value_namespace = name_space
                                        self.data_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "error"):
                                        self.error = value
                                        self.error.value_namespace = name_space
                                        self.error.value_namespace_prefix = name_space_prefix
                                    if(value_path == "no-data"):
                                        self.no_data = value
                                        self.no_data.value_namespace = name_space
                                        self.no_data.value_namespace_prefix = name_space_prefix
                                    if(value_path == "string-data"):
                                        self.string_data = value
                                        self.string_data.value_namespace = name_space
                                        self.string_data.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.rg_event_type.is_set or
                                    self.time_stamp.is_set or
                                    (self.data is not None and self.data.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.rg_event_type.yfilter != YFilter.not_set or
                                    self.time_stamp.yfilter != YFilter.not_set or
                                    (self.data is not None and self.data.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "rg-evt-info" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.rg_event_type.is_set or self.rg_event_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.rg_event_type.get_name_leafdata())
                                if (self.time_stamp.is_set or self.time_stamp.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.time_stamp.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "data"):
                                    if (self.data is None):
                                        self.data = BundleInformation.Events.EventsMembers.EventsMember.EventsMemberItem.Items.RgEvtInfo.Data()
                                        self.data.parent = self
                                        self._children_name_map["data"] = "data"
                                    return self.data

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "data" or name == "rg-event-type" or name == "time-stamp"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "rg-event-type"):
                                    self.rg_event_type = value
                                    self.rg_event_type.value_namespace = name_space
                                    self.rg_event_type.value_namespace_prefix = name_space_prefix
                                if(value_path == "time-stamp"):
                                    self.time_stamp = value
                                    self.time_stamp.value_namespace = name_space
                                    self.time_stamp.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.event_type.is_set or
                                (self.bundle_evt_info is not None and self.bundle_evt_info.has_data()) or
                                (self.member_evt_info is not None and self.member_evt_info.has_data()) or
                                (self.rg_evt_info is not None and self.rg_evt_info.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.event_type.yfilter != YFilter.not_set or
                                (self.bundle_evt_info is not None and self.bundle_evt_info.has_operation()) or
                                (self.member_evt_info is not None and self.member_evt_info.has_operation()) or
                                (self.rg_evt_info is not None and self.rg_evt_info.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "items" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.event_type.is_set or self.event_type.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.event_type.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "bundle-evt-info"):
                                if (self.bundle_evt_info is None):
                                    self.bundle_evt_info = BundleInformation.Events.EventsMembers.EventsMember.EventsMemberItem.Items.BundleEvtInfo()
                                    self.bundle_evt_info.parent = self
                                    self._children_name_map["bundle_evt_info"] = "bundle-evt-info"
                                return self.bundle_evt_info

                            if (child_yang_name == "member-evt-info"):
                                if (self.member_evt_info is None):
                                    self.member_evt_info = BundleInformation.Events.EventsMembers.EventsMember.EventsMemberItem.Items.MemberEvtInfo()
                                    self.member_evt_info.parent = self
                                    self._children_name_map["member_evt_info"] = "member-evt-info"
                                return self.member_evt_info

                            if (child_yang_name == "rg-evt-info"):
                                if (self.rg_evt_info is None):
                                    self.rg_evt_info = BundleInformation.Events.EventsMembers.EventsMember.EventsMemberItem.Items.RgEvtInfo()
                                    self.rg_evt_info.parent = self
                                    self._children_name_map["rg_evt_info"] = "rg-evt-info"
                                return self.rg_evt_info

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "bundle-evt-info" or name == "member-evt-info" or name == "rg-evt-info" or name == "event-type"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "event-type"):
                                self.event_type = value
                                self.event_type.value_namespace = name_space
                                self.event_type.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.items:
                            if (c.has_data()):
                                return True
                        return self.item_name.is_set

                    def has_operation(self):
                        for c in self.items:
                            if (c.has_operation()):
                                return True
                        return (
                            self.yfilter != YFilter.not_set or
                            self.item_name.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "events-member-item" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.item_name.is_set or self.item_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.item_name.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "items"):
                            for c in self.items:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = BundleInformation.Events.EventsMembers.EventsMember.EventsMemberItem.Items()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.items.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "items" or name == "item-name"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "item-name"):
                            self.item_name = value
                            self.item_name.value_namespace = name_space
                            self.item_name.value_namespace_prefix = name_space_prefix


                class EventsMemberAncestor(Entity):
                    """
                    Data for this item and its parent bundle
                    
                    .. attribute:: item_name
                    
                    	Name for the current item to use
                    	**type**\:  str
                    
                    .. attribute:: items
                    
                    	Event items
                    	**type**\: list of    :py:class:`Items <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.Events.EventsMembers.EventsMember.EventsMemberAncestor.Items>`
                    
                    

                    """

                    _prefix = 'bundlemgr-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(BundleInformation.Events.EventsMembers.EventsMember.EventsMemberAncestor, self).__init__()

                        self.yang_name = "events-member-ancestor"
                        self.yang_parent_name = "events-member"

                        self.item_name = YLeaf(YType.str, "item-name")

                        self.items = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("item_name") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(BundleInformation.Events.EventsMembers.EventsMember.EventsMemberAncestor, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(BundleInformation.Events.EventsMembers.EventsMember.EventsMemberAncestor, self).__setattr__(name, value)


                    class Items(Entity):
                        """
                        Event items
                        
                        .. attribute:: bundle_evt_info
                        
                        	Event information for a bundle
                        	**type**\:   :py:class:`BundleEvtInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.Events.EventsMembers.EventsMember.EventsMemberAncestor.Items.BundleEvtInfo>`
                        
                        .. attribute:: event_type
                        
                        	EventType
                        	**type**\:   :py:class:`BmdBagTarget <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmdBagTarget>`
                        
                        .. attribute:: member_evt_info
                        
                        	Event information for a member
                        	**type**\:   :py:class:`MemberEvtInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.Events.EventsMembers.EventsMember.EventsMemberAncestor.Items.MemberEvtInfo>`
                        
                        .. attribute:: rg_evt_info
                        
                        	Event information for an RG
                        	**type**\:   :py:class:`RgEvtInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.Events.EventsMembers.EventsMember.EventsMemberAncestor.Items.RgEvtInfo>`
                        
                        

                        """

                        _prefix = 'bundlemgr-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(BundleInformation.Events.EventsMembers.EventsMember.EventsMemberAncestor.Items, self).__init__()

                            self.yang_name = "items"
                            self.yang_parent_name = "events-member-ancestor"

                            self.event_type = YLeaf(YType.enumeration, "event-type")

                            self.bundle_evt_info = BundleInformation.Events.EventsMembers.EventsMember.EventsMemberAncestor.Items.BundleEvtInfo()
                            self.bundle_evt_info.parent = self
                            self._children_name_map["bundle_evt_info"] = "bundle-evt-info"
                            self._children_yang_names.add("bundle-evt-info")

                            self.member_evt_info = BundleInformation.Events.EventsMembers.EventsMember.EventsMemberAncestor.Items.MemberEvtInfo()
                            self.member_evt_info.parent = self
                            self._children_name_map["member_evt_info"] = "member-evt-info"
                            self._children_yang_names.add("member-evt-info")

                            self.rg_evt_info = BundleInformation.Events.EventsMembers.EventsMember.EventsMemberAncestor.Items.RgEvtInfo()
                            self.rg_evt_info.parent = self
                            self._children_name_map["rg_evt_info"] = "rg-evt-info"
                            self._children_yang_names.add("rg-evt-info")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("event_type") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(BundleInformation.Events.EventsMembers.EventsMember.EventsMemberAncestor.Items, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(BundleInformation.Events.EventsMembers.EventsMember.EventsMemberAncestor.Items, self).__setattr__(name, value)


                        class MemberEvtInfo(Entity):
                            """
                            Event information for a member
                            
                            .. attribute:: data
                            
                            	Additional data for the event
                            	**type**\:   :py:class:`Data <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.Events.EventsMembers.EventsMember.EventsMemberAncestor.Items.MemberEvtInfo.Data>`
                            
                            .. attribute:: member_event_type
                            
                            	Type of event for member
                            	**type**\:   :py:class:`BmdBagEventMbrItem <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmdBagEventMbrItem>`
                            
                            .. attribute:: time_stamp
                            
                            	Time stamp of the event
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            

                            """

                            _prefix = 'bundlemgr-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(BundleInformation.Events.EventsMembers.EventsMember.EventsMemberAncestor.Items.MemberEvtInfo, self).__init__()

                                self.yang_name = "member-evt-info"
                                self.yang_parent_name = "items"

                                self.member_event_type = YLeaf(YType.enumeration, "member-event-type")

                                self.time_stamp = YLeaf(YType.uint64, "time-stamp")

                                self.data = BundleInformation.Events.EventsMembers.EventsMember.EventsMemberAncestor.Items.MemberEvtInfo.Data()
                                self.data.parent = self
                                self._children_name_map["data"] = "data"
                                self._children_yang_names.add("data")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("member_event_type",
                                                "time_stamp") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(BundleInformation.Events.EventsMembers.EventsMember.EventsMemberAncestor.Items.MemberEvtInfo, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(BundleInformation.Events.EventsMembers.EventsMember.EventsMemberAncestor.Items.MemberEvtInfo, self).__setattr__(name, value)


                            class Data(Entity):
                                """
                                Additional data for the event
                                
                                .. attribute:: data_type
                                
                                	DataType
                                	**type**\:   :py:class:`BmdBagEventData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmdBagEventData>`
                                
                                .. attribute:: error
                                
                                	Error
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: no_data
                                
                                	NoData
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: string_data
                                
                                	StringData
                                	**type**\:  str
                                
                                

                                """

                                _prefix = 'bundlemgr-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(BundleInformation.Events.EventsMembers.EventsMember.EventsMemberAncestor.Items.MemberEvtInfo.Data, self).__init__()

                                    self.yang_name = "data"
                                    self.yang_parent_name = "member-evt-info"

                                    self.data_type = YLeaf(YType.enumeration, "data-type")

                                    self.error = YLeaf(YType.uint32, "error")

                                    self.no_data = YLeaf(YType.uint8, "no-data")

                                    self.string_data = YLeaf(YType.str, "string-data")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("data_type",
                                                    "error",
                                                    "no_data",
                                                    "string_data") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(BundleInformation.Events.EventsMembers.EventsMember.EventsMemberAncestor.Items.MemberEvtInfo.Data, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(BundleInformation.Events.EventsMembers.EventsMember.EventsMemberAncestor.Items.MemberEvtInfo.Data, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.data_type.is_set or
                                        self.error.is_set or
                                        self.no_data.is_set or
                                        self.string_data.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.data_type.yfilter != YFilter.not_set or
                                        self.error.yfilter != YFilter.not_set or
                                        self.no_data.yfilter != YFilter.not_set or
                                        self.string_data.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "data" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.data_type.is_set or self.data_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.data_type.get_name_leafdata())
                                    if (self.error.is_set or self.error.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.error.get_name_leafdata())
                                    if (self.no_data.is_set or self.no_data.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.no_data.get_name_leafdata())
                                    if (self.string_data.is_set or self.string_data.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.string_data.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "data-type" or name == "error" or name == "no-data" or name == "string-data"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "data-type"):
                                        self.data_type = value
                                        self.data_type.value_namespace = name_space
                                        self.data_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "error"):
                                        self.error = value
                                        self.error.value_namespace = name_space
                                        self.error.value_namespace_prefix = name_space_prefix
                                    if(value_path == "no-data"):
                                        self.no_data = value
                                        self.no_data.value_namespace = name_space
                                        self.no_data.value_namespace_prefix = name_space_prefix
                                    if(value_path == "string-data"):
                                        self.string_data = value
                                        self.string_data.value_namespace = name_space
                                        self.string_data.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.member_event_type.is_set or
                                    self.time_stamp.is_set or
                                    (self.data is not None and self.data.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.member_event_type.yfilter != YFilter.not_set or
                                    self.time_stamp.yfilter != YFilter.not_set or
                                    (self.data is not None and self.data.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "member-evt-info" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.member_event_type.is_set or self.member_event_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.member_event_type.get_name_leafdata())
                                if (self.time_stamp.is_set or self.time_stamp.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.time_stamp.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "data"):
                                    if (self.data is None):
                                        self.data = BundleInformation.Events.EventsMembers.EventsMember.EventsMemberAncestor.Items.MemberEvtInfo.Data()
                                        self.data.parent = self
                                        self._children_name_map["data"] = "data"
                                    return self.data

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "data" or name == "member-event-type" or name == "time-stamp"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "member-event-type"):
                                    self.member_event_type = value
                                    self.member_event_type.value_namespace = name_space
                                    self.member_event_type.value_namespace_prefix = name_space_prefix
                                if(value_path == "time-stamp"):
                                    self.time_stamp = value
                                    self.time_stamp.value_namespace = name_space
                                    self.time_stamp.value_namespace_prefix = name_space_prefix


                        class BundleEvtInfo(Entity):
                            """
                            Event information for a bundle
                            
                            .. attribute:: bundle_event_type
                            
                            	Type of event for bundle
                            	**type**\:   :py:class:`BmdBagEventBdlItem <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmdBagEventBdlItem>`
                            
                            .. attribute:: data
                            
                            	Additional data for the event
                            	**type**\:   :py:class:`Data <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.Events.EventsMembers.EventsMember.EventsMemberAncestor.Items.BundleEvtInfo.Data>`
                            
                            .. attribute:: time_stamp
                            
                            	Time stamp of the event
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            

                            """

                            _prefix = 'bundlemgr-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(BundleInformation.Events.EventsMembers.EventsMember.EventsMemberAncestor.Items.BundleEvtInfo, self).__init__()

                                self.yang_name = "bundle-evt-info"
                                self.yang_parent_name = "items"

                                self.bundle_event_type = YLeaf(YType.enumeration, "bundle-event-type")

                                self.time_stamp = YLeaf(YType.uint64, "time-stamp")

                                self.data = BundleInformation.Events.EventsMembers.EventsMember.EventsMemberAncestor.Items.BundleEvtInfo.Data()
                                self.data.parent = self
                                self._children_name_map["data"] = "data"
                                self._children_yang_names.add("data")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("bundle_event_type",
                                                "time_stamp") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(BundleInformation.Events.EventsMembers.EventsMember.EventsMemberAncestor.Items.BundleEvtInfo, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(BundleInformation.Events.EventsMembers.EventsMember.EventsMemberAncestor.Items.BundleEvtInfo, self).__setattr__(name, value)


                            class Data(Entity):
                                """
                                Additional data for the event
                                
                                .. attribute:: data_type
                                
                                	DataType
                                	**type**\:   :py:class:`BmdBagEventData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmdBagEventData>`
                                
                                .. attribute:: error
                                
                                	Error
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: no_data
                                
                                	NoData
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: string_data
                                
                                	StringData
                                	**type**\:  str
                                
                                

                                """

                                _prefix = 'bundlemgr-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(BundleInformation.Events.EventsMembers.EventsMember.EventsMemberAncestor.Items.BundleEvtInfo.Data, self).__init__()

                                    self.yang_name = "data"
                                    self.yang_parent_name = "bundle-evt-info"

                                    self.data_type = YLeaf(YType.enumeration, "data-type")

                                    self.error = YLeaf(YType.uint32, "error")

                                    self.no_data = YLeaf(YType.uint8, "no-data")

                                    self.string_data = YLeaf(YType.str, "string-data")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("data_type",
                                                    "error",
                                                    "no_data",
                                                    "string_data") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(BundleInformation.Events.EventsMembers.EventsMember.EventsMemberAncestor.Items.BundleEvtInfo.Data, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(BundleInformation.Events.EventsMembers.EventsMember.EventsMemberAncestor.Items.BundleEvtInfo.Data, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.data_type.is_set or
                                        self.error.is_set or
                                        self.no_data.is_set or
                                        self.string_data.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.data_type.yfilter != YFilter.not_set or
                                        self.error.yfilter != YFilter.not_set or
                                        self.no_data.yfilter != YFilter.not_set or
                                        self.string_data.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "data" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.data_type.is_set or self.data_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.data_type.get_name_leafdata())
                                    if (self.error.is_set or self.error.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.error.get_name_leafdata())
                                    if (self.no_data.is_set or self.no_data.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.no_data.get_name_leafdata())
                                    if (self.string_data.is_set or self.string_data.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.string_data.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "data-type" or name == "error" or name == "no-data" or name == "string-data"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "data-type"):
                                        self.data_type = value
                                        self.data_type.value_namespace = name_space
                                        self.data_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "error"):
                                        self.error = value
                                        self.error.value_namespace = name_space
                                        self.error.value_namespace_prefix = name_space_prefix
                                    if(value_path == "no-data"):
                                        self.no_data = value
                                        self.no_data.value_namespace = name_space
                                        self.no_data.value_namespace_prefix = name_space_prefix
                                    if(value_path == "string-data"):
                                        self.string_data = value
                                        self.string_data.value_namespace = name_space
                                        self.string_data.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.bundle_event_type.is_set or
                                    self.time_stamp.is_set or
                                    (self.data is not None and self.data.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.bundle_event_type.yfilter != YFilter.not_set or
                                    self.time_stamp.yfilter != YFilter.not_set or
                                    (self.data is not None and self.data.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "bundle-evt-info" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.bundle_event_type.is_set or self.bundle_event_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.bundle_event_type.get_name_leafdata())
                                if (self.time_stamp.is_set or self.time_stamp.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.time_stamp.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "data"):
                                    if (self.data is None):
                                        self.data = BundleInformation.Events.EventsMembers.EventsMember.EventsMemberAncestor.Items.BundleEvtInfo.Data()
                                        self.data.parent = self
                                        self._children_name_map["data"] = "data"
                                    return self.data

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "data" or name == "bundle-event-type" or name == "time-stamp"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "bundle-event-type"):
                                    self.bundle_event_type = value
                                    self.bundle_event_type.value_namespace = name_space
                                    self.bundle_event_type.value_namespace_prefix = name_space_prefix
                                if(value_path == "time-stamp"):
                                    self.time_stamp = value
                                    self.time_stamp.value_namespace = name_space
                                    self.time_stamp.value_namespace_prefix = name_space_prefix


                        class RgEvtInfo(Entity):
                            """
                            Event information for an RG
                            
                            .. attribute:: data
                            
                            	Additional data for the event
                            	**type**\:   :py:class:`Data <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.Events.EventsMembers.EventsMember.EventsMemberAncestor.Items.RgEvtInfo.Data>`
                            
                            .. attribute:: rg_event_type
                            
                            	Type of event for RG
                            	**type**\:   :py:class:`BmdBagEventRgItem <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmdBagEventRgItem>`
                            
                            .. attribute:: time_stamp
                            
                            	Time stamp of the event
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            

                            """

                            _prefix = 'bundlemgr-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(BundleInformation.Events.EventsMembers.EventsMember.EventsMemberAncestor.Items.RgEvtInfo, self).__init__()

                                self.yang_name = "rg-evt-info"
                                self.yang_parent_name = "items"

                                self.rg_event_type = YLeaf(YType.enumeration, "rg-event-type")

                                self.time_stamp = YLeaf(YType.uint64, "time-stamp")

                                self.data = BundleInformation.Events.EventsMembers.EventsMember.EventsMemberAncestor.Items.RgEvtInfo.Data()
                                self.data.parent = self
                                self._children_name_map["data"] = "data"
                                self._children_yang_names.add("data")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("rg_event_type",
                                                "time_stamp") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(BundleInformation.Events.EventsMembers.EventsMember.EventsMemberAncestor.Items.RgEvtInfo, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(BundleInformation.Events.EventsMembers.EventsMember.EventsMemberAncestor.Items.RgEvtInfo, self).__setattr__(name, value)


                            class Data(Entity):
                                """
                                Additional data for the event
                                
                                .. attribute:: data_type
                                
                                	DataType
                                	**type**\:   :py:class:`BmdBagEventData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmdBagEventData>`
                                
                                .. attribute:: error
                                
                                	Error
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: no_data
                                
                                	NoData
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: string_data
                                
                                	StringData
                                	**type**\:  str
                                
                                

                                """

                                _prefix = 'bundlemgr-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(BundleInformation.Events.EventsMembers.EventsMember.EventsMemberAncestor.Items.RgEvtInfo.Data, self).__init__()

                                    self.yang_name = "data"
                                    self.yang_parent_name = "rg-evt-info"

                                    self.data_type = YLeaf(YType.enumeration, "data-type")

                                    self.error = YLeaf(YType.uint32, "error")

                                    self.no_data = YLeaf(YType.uint8, "no-data")

                                    self.string_data = YLeaf(YType.str, "string-data")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("data_type",
                                                    "error",
                                                    "no_data",
                                                    "string_data") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(BundleInformation.Events.EventsMembers.EventsMember.EventsMemberAncestor.Items.RgEvtInfo.Data, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(BundleInformation.Events.EventsMembers.EventsMember.EventsMemberAncestor.Items.RgEvtInfo.Data, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.data_type.is_set or
                                        self.error.is_set or
                                        self.no_data.is_set or
                                        self.string_data.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.data_type.yfilter != YFilter.not_set or
                                        self.error.yfilter != YFilter.not_set or
                                        self.no_data.yfilter != YFilter.not_set or
                                        self.string_data.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "data" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.data_type.is_set or self.data_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.data_type.get_name_leafdata())
                                    if (self.error.is_set or self.error.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.error.get_name_leafdata())
                                    if (self.no_data.is_set or self.no_data.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.no_data.get_name_leafdata())
                                    if (self.string_data.is_set or self.string_data.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.string_data.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "data-type" or name == "error" or name == "no-data" or name == "string-data"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "data-type"):
                                        self.data_type = value
                                        self.data_type.value_namespace = name_space
                                        self.data_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "error"):
                                        self.error = value
                                        self.error.value_namespace = name_space
                                        self.error.value_namespace_prefix = name_space_prefix
                                    if(value_path == "no-data"):
                                        self.no_data = value
                                        self.no_data.value_namespace = name_space
                                        self.no_data.value_namespace_prefix = name_space_prefix
                                    if(value_path == "string-data"):
                                        self.string_data = value
                                        self.string_data.value_namespace = name_space
                                        self.string_data.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.rg_event_type.is_set or
                                    self.time_stamp.is_set or
                                    (self.data is not None and self.data.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.rg_event_type.yfilter != YFilter.not_set or
                                    self.time_stamp.yfilter != YFilter.not_set or
                                    (self.data is not None and self.data.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "rg-evt-info" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.rg_event_type.is_set or self.rg_event_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.rg_event_type.get_name_leafdata())
                                if (self.time_stamp.is_set or self.time_stamp.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.time_stamp.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "data"):
                                    if (self.data is None):
                                        self.data = BundleInformation.Events.EventsMembers.EventsMember.EventsMemberAncestor.Items.RgEvtInfo.Data()
                                        self.data.parent = self
                                        self._children_name_map["data"] = "data"
                                    return self.data

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "data" or name == "rg-event-type" or name == "time-stamp"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "rg-event-type"):
                                    self.rg_event_type = value
                                    self.rg_event_type.value_namespace = name_space
                                    self.rg_event_type.value_namespace_prefix = name_space_prefix
                                if(value_path == "time-stamp"):
                                    self.time_stamp = value
                                    self.time_stamp.value_namespace = name_space
                                    self.time_stamp.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.event_type.is_set or
                                (self.bundle_evt_info is not None and self.bundle_evt_info.has_data()) or
                                (self.member_evt_info is not None and self.member_evt_info.has_data()) or
                                (self.rg_evt_info is not None and self.rg_evt_info.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.event_type.yfilter != YFilter.not_set or
                                (self.bundle_evt_info is not None and self.bundle_evt_info.has_operation()) or
                                (self.member_evt_info is not None and self.member_evt_info.has_operation()) or
                                (self.rg_evt_info is not None and self.rg_evt_info.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "items" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.event_type.is_set or self.event_type.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.event_type.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "bundle-evt-info"):
                                if (self.bundle_evt_info is None):
                                    self.bundle_evt_info = BundleInformation.Events.EventsMembers.EventsMember.EventsMemberAncestor.Items.BundleEvtInfo()
                                    self.bundle_evt_info.parent = self
                                    self._children_name_map["bundle_evt_info"] = "bundle-evt-info"
                                return self.bundle_evt_info

                            if (child_yang_name == "member-evt-info"):
                                if (self.member_evt_info is None):
                                    self.member_evt_info = BundleInformation.Events.EventsMembers.EventsMember.EventsMemberAncestor.Items.MemberEvtInfo()
                                    self.member_evt_info.parent = self
                                    self._children_name_map["member_evt_info"] = "member-evt-info"
                                return self.member_evt_info

                            if (child_yang_name == "rg-evt-info"):
                                if (self.rg_evt_info is None):
                                    self.rg_evt_info = BundleInformation.Events.EventsMembers.EventsMember.EventsMemberAncestor.Items.RgEvtInfo()
                                    self.rg_evt_info.parent = self
                                    self._children_name_map["rg_evt_info"] = "rg-evt-info"
                                return self.rg_evt_info

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "bundle-evt-info" or name == "member-evt-info" or name == "rg-evt-info" or name == "event-type"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "event-type"):
                                self.event_type = value
                                self.event_type.value_namespace = name_space
                                self.event_type.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.items:
                            if (c.has_data()):
                                return True
                        return self.item_name.is_set

                    def has_operation(self):
                        for c in self.items:
                            if (c.has_operation()):
                                return True
                        return (
                            self.yfilter != YFilter.not_set or
                            self.item_name.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "events-member-ancestor" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.item_name.is_set or self.item_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.item_name.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "items"):
                            for c in self.items:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = BundleInformation.Events.EventsMembers.EventsMember.EventsMemberAncestor.Items()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.items.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "items" or name == "item-name"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "item-name"):
                            self.item_name = value
                            self.item_name.value_namespace = name_space
                            self.item_name.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    return (
                        self.member_interface.is_set or
                        (self.events_member_ancestor is not None and self.events_member_ancestor.has_data()) or
                        (self.events_member_item is not None and self.events_member_item.has_data()))

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.member_interface.yfilter != YFilter.not_set or
                        (self.events_member_ancestor is not None and self.events_member_ancestor.has_operation()) or
                        (self.events_member_item is not None and self.events_member_item.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "events-member" + "[member-interface='" + self.member_interface.get() + "']" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-bundlemgr-oper:bundle-information/events/events-members/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.member_interface.is_set or self.member_interface.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.member_interface.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "events-member-ancestor"):
                        if (self.events_member_ancestor is None):
                            self.events_member_ancestor = BundleInformation.Events.EventsMembers.EventsMember.EventsMemberAncestor()
                            self.events_member_ancestor.parent = self
                            self._children_name_map["events_member_ancestor"] = "events-member-ancestor"
                        return self.events_member_ancestor

                    if (child_yang_name == "events-member-item"):
                        if (self.events_member_item is None):
                            self.events_member_item = BundleInformation.Events.EventsMembers.EventsMember.EventsMemberItem()
                            self.events_member_item.parent = self
                            self._children_name_map["events_member_item"] = "events-member-item"
                        return self.events_member_item

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "events-member-ancestor" or name == "events-member-item" or name == "member-interface"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "member-interface"):
                        self.member_interface = value
                        self.member_interface.value_namespace = name_space
                        self.member_interface.value_namespace_prefix = name_space_prefix

            def has_data(self):
                for c in self.events_member:
                    if (c.has_data()):
                        return True
                return False

            def has_operation(self):
                for c in self.events_member:
                    if (c.has_operation()):
                        return True
                return self.yfilter != YFilter.not_set

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "events-members" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-bundlemgr-oper:bundle-information/events/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "events-member"):
                    for c in self.events_member:
                        segment = c.get_segment_path()
                        if (segment_path == segment):
                            return c
                    c = BundleInformation.Events.EventsMembers.EventsMember()
                    c.parent = self
                    local_reference_key = "ydk::seg::%s" % segment_path
                    self._local_refs[local_reference_key] = c
                    self.events_member.append(c)
                    return c

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "events-member"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                pass


        class EventsBundles(Entity):
            """
            Bundle interfaces with events information
            
            .. attribute:: events_bundle
            
            	Bundle interface
            	**type**\: list of    :py:class:`EventsBundle <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.Events.EventsBundles.EventsBundle>`
            
            

            """

            _prefix = 'bundlemgr-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(BundleInformation.Events.EventsBundles, self).__init__()

                self.yang_name = "events-bundles"
                self.yang_parent_name = "events"

                self.events_bundle = YList(self)

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in () and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(BundleInformation.Events.EventsBundles, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(BundleInformation.Events.EventsBundles, self).__setattr__(name, value)


            class EventsBundle(Entity):
                """
                Bundle interface
                
                .. attribute:: bundle_interface  <key>
                
                	Bundle interface
                	**type**\:  str
                
                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                
                .. attribute:: events_bundle_ancestor
                
                	Data for this item and its parent bundle
                	**type**\:   :py:class:`EventsBundleAncestor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.Events.EventsBundles.EventsBundle.EventsBundleAncestor>`
                
                .. attribute:: events_bundle_children_members
                
                	Children of bundle with events information
                	**type**\:   :py:class:`EventsBundleChildrenMembers <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.Events.EventsBundles.EventsBundle.EventsBundleChildrenMembers>`
                
                .. attribute:: events_bundle_descendant
                
                	Data for this item and all its members
                	**type**\:   :py:class:`EventsBundleDescendant <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.Events.EventsBundles.EventsBundle.EventsBundleDescendant>`
                
                .. attribute:: events_bundle_item
                
                	Data for this item
                	**type**\:   :py:class:`EventsBundleItem <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.Events.EventsBundles.EventsBundle.EventsBundleItem>`
                
                

                """

                _prefix = 'bundlemgr-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(BundleInformation.Events.EventsBundles.EventsBundle, self).__init__()

                    self.yang_name = "events-bundle"
                    self.yang_parent_name = "events-bundles"

                    self.bundle_interface = YLeaf(YType.str, "bundle-interface")

                    self.events_bundle_ancestor = BundleInformation.Events.EventsBundles.EventsBundle.EventsBundleAncestor()
                    self.events_bundle_ancestor.parent = self
                    self._children_name_map["events_bundle_ancestor"] = "events-bundle-ancestor"
                    self._children_yang_names.add("events-bundle-ancestor")

                    self.events_bundle_children_members = BundleInformation.Events.EventsBundles.EventsBundle.EventsBundleChildrenMembers()
                    self.events_bundle_children_members.parent = self
                    self._children_name_map["events_bundle_children_members"] = "events-bundle-children-members"
                    self._children_yang_names.add("events-bundle-children-members")

                    self.events_bundle_descendant = BundleInformation.Events.EventsBundles.EventsBundle.EventsBundleDescendant()
                    self.events_bundle_descendant.parent = self
                    self._children_name_map["events_bundle_descendant"] = "events-bundle-descendant"
                    self._children_yang_names.add("events-bundle-descendant")

                    self.events_bundle_item = BundleInformation.Events.EventsBundles.EventsBundle.EventsBundleItem()
                    self.events_bundle_item.parent = self
                    self._children_name_map["events_bundle_item"] = "events-bundle-item"
                    self._children_yang_names.add("events-bundle-item")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("bundle_interface") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(BundleInformation.Events.EventsBundles.EventsBundle, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(BundleInformation.Events.EventsBundles.EventsBundle, self).__setattr__(name, value)


                class EventsBundleAncestor(Entity):
                    """
                    Data for this item and its parent bundle
                    
                    .. attribute:: item_name
                    
                    	Name for the current item to use
                    	**type**\:  str
                    
                    .. attribute:: items
                    
                    	Event items
                    	**type**\: list of    :py:class:`Items <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.Events.EventsBundles.EventsBundle.EventsBundleAncestor.Items>`
                    
                    

                    """

                    _prefix = 'bundlemgr-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(BundleInformation.Events.EventsBundles.EventsBundle.EventsBundleAncestor, self).__init__()

                        self.yang_name = "events-bundle-ancestor"
                        self.yang_parent_name = "events-bundle"

                        self.item_name = YLeaf(YType.str, "item-name")

                        self.items = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("item_name") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(BundleInformation.Events.EventsBundles.EventsBundle.EventsBundleAncestor, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(BundleInformation.Events.EventsBundles.EventsBundle.EventsBundleAncestor, self).__setattr__(name, value)


                    class Items(Entity):
                        """
                        Event items
                        
                        .. attribute:: bundle_evt_info
                        
                        	Event information for a bundle
                        	**type**\:   :py:class:`BundleEvtInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.Events.EventsBundles.EventsBundle.EventsBundleAncestor.Items.BundleEvtInfo>`
                        
                        .. attribute:: event_type
                        
                        	EventType
                        	**type**\:   :py:class:`BmdBagTarget <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmdBagTarget>`
                        
                        .. attribute:: member_evt_info
                        
                        	Event information for a member
                        	**type**\:   :py:class:`MemberEvtInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.Events.EventsBundles.EventsBundle.EventsBundleAncestor.Items.MemberEvtInfo>`
                        
                        .. attribute:: rg_evt_info
                        
                        	Event information for an RG
                        	**type**\:   :py:class:`RgEvtInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.Events.EventsBundles.EventsBundle.EventsBundleAncestor.Items.RgEvtInfo>`
                        
                        

                        """

                        _prefix = 'bundlemgr-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(BundleInformation.Events.EventsBundles.EventsBundle.EventsBundleAncestor.Items, self).__init__()

                            self.yang_name = "items"
                            self.yang_parent_name = "events-bundle-ancestor"

                            self.event_type = YLeaf(YType.enumeration, "event-type")

                            self.bundle_evt_info = BundleInformation.Events.EventsBundles.EventsBundle.EventsBundleAncestor.Items.BundleEvtInfo()
                            self.bundle_evt_info.parent = self
                            self._children_name_map["bundle_evt_info"] = "bundle-evt-info"
                            self._children_yang_names.add("bundle-evt-info")

                            self.member_evt_info = BundleInformation.Events.EventsBundles.EventsBundle.EventsBundleAncestor.Items.MemberEvtInfo()
                            self.member_evt_info.parent = self
                            self._children_name_map["member_evt_info"] = "member-evt-info"
                            self._children_yang_names.add("member-evt-info")

                            self.rg_evt_info = BundleInformation.Events.EventsBundles.EventsBundle.EventsBundleAncestor.Items.RgEvtInfo()
                            self.rg_evt_info.parent = self
                            self._children_name_map["rg_evt_info"] = "rg-evt-info"
                            self._children_yang_names.add("rg-evt-info")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("event_type") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(BundleInformation.Events.EventsBundles.EventsBundle.EventsBundleAncestor.Items, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(BundleInformation.Events.EventsBundles.EventsBundle.EventsBundleAncestor.Items, self).__setattr__(name, value)


                        class MemberEvtInfo(Entity):
                            """
                            Event information for a member
                            
                            .. attribute:: data
                            
                            	Additional data for the event
                            	**type**\:   :py:class:`Data <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.Events.EventsBundles.EventsBundle.EventsBundleAncestor.Items.MemberEvtInfo.Data>`
                            
                            .. attribute:: member_event_type
                            
                            	Type of event for member
                            	**type**\:   :py:class:`BmdBagEventMbrItem <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmdBagEventMbrItem>`
                            
                            .. attribute:: time_stamp
                            
                            	Time stamp of the event
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            

                            """

                            _prefix = 'bundlemgr-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(BundleInformation.Events.EventsBundles.EventsBundle.EventsBundleAncestor.Items.MemberEvtInfo, self).__init__()

                                self.yang_name = "member-evt-info"
                                self.yang_parent_name = "items"

                                self.member_event_type = YLeaf(YType.enumeration, "member-event-type")

                                self.time_stamp = YLeaf(YType.uint64, "time-stamp")

                                self.data = BundleInformation.Events.EventsBundles.EventsBundle.EventsBundleAncestor.Items.MemberEvtInfo.Data()
                                self.data.parent = self
                                self._children_name_map["data"] = "data"
                                self._children_yang_names.add("data")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("member_event_type",
                                                "time_stamp") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(BundleInformation.Events.EventsBundles.EventsBundle.EventsBundleAncestor.Items.MemberEvtInfo, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(BundleInformation.Events.EventsBundles.EventsBundle.EventsBundleAncestor.Items.MemberEvtInfo, self).__setattr__(name, value)


                            class Data(Entity):
                                """
                                Additional data for the event
                                
                                .. attribute:: data_type
                                
                                	DataType
                                	**type**\:   :py:class:`BmdBagEventData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmdBagEventData>`
                                
                                .. attribute:: error
                                
                                	Error
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: no_data
                                
                                	NoData
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: string_data
                                
                                	StringData
                                	**type**\:  str
                                
                                

                                """

                                _prefix = 'bundlemgr-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(BundleInformation.Events.EventsBundles.EventsBundle.EventsBundleAncestor.Items.MemberEvtInfo.Data, self).__init__()

                                    self.yang_name = "data"
                                    self.yang_parent_name = "member-evt-info"

                                    self.data_type = YLeaf(YType.enumeration, "data-type")

                                    self.error = YLeaf(YType.uint32, "error")

                                    self.no_data = YLeaf(YType.uint8, "no-data")

                                    self.string_data = YLeaf(YType.str, "string-data")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("data_type",
                                                    "error",
                                                    "no_data",
                                                    "string_data") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(BundleInformation.Events.EventsBundles.EventsBundle.EventsBundleAncestor.Items.MemberEvtInfo.Data, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(BundleInformation.Events.EventsBundles.EventsBundle.EventsBundleAncestor.Items.MemberEvtInfo.Data, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.data_type.is_set or
                                        self.error.is_set or
                                        self.no_data.is_set or
                                        self.string_data.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.data_type.yfilter != YFilter.not_set or
                                        self.error.yfilter != YFilter.not_set or
                                        self.no_data.yfilter != YFilter.not_set or
                                        self.string_data.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "data" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.data_type.is_set or self.data_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.data_type.get_name_leafdata())
                                    if (self.error.is_set or self.error.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.error.get_name_leafdata())
                                    if (self.no_data.is_set or self.no_data.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.no_data.get_name_leafdata())
                                    if (self.string_data.is_set or self.string_data.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.string_data.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "data-type" or name == "error" or name == "no-data" or name == "string-data"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "data-type"):
                                        self.data_type = value
                                        self.data_type.value_namespace = name_space
                                        self.data_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "error"):
                                        self.error = value
                                        self.error.value_namespace = name_space
                                        self.error.value_namespace_prefix = name_space_prefix
                                    if(value_path == "no-data"):
                                        self.no_data = value
                                        self.no_data.value_namespace = name_space
                                        self.no_data.value_namespace_prefix = name_space_prefix
                                    if(value_path == "string-data"):
                                        self.string_data = value
                                        self.string_data.value_namespace = name_space
                                        self.string_data.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.member_event_type.is_set or
                                    self.time_stamp.is_set or
                                    (self.data is not None and self.data.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.member_event_type.yfilter != YFilter.not_set or
                                    self.time_stamp.yfilter != YFilter.not_set or
                                    (self.data is not None and self.data.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "member-evt-info" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.member_event_type.is_set or self.member_event_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.member_event_type.get_name_leafdata())
                                if (self.time_stamp.is_set or self.time_stamp.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.time_stamp.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "data"):
                                    if (self.data is None):
                                        self.data = BundleInformation.Events.EventsBundles.EventsBundle.EventsBundleAncestor.Items.MemberEvtInfo.Data()
                                        self.data.parent = self
                                        self._children_name_map["data"] = "data"
                                    return self.data

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "data" or name == "member-event-type" or name == "time-stamp"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "member-event-type"):
                                    self.member_event_type = value
                                    self.member_event_type.value_namespace = name_space
                                    self.member_event_type.value_namespace_prefix = name_space_prefix
                                if(value_path == "time-stamp"):
                                    self.time_stamp = value
                                    self.time_stamp.value_namespace = name_space
                                    self.time_stamp.value_namespace_prefix = name_space_prefix


                        class BundleEvtInfo(Entity):
                            """
                            Event information for a bundle
                            
                            .. attribute:: bundle_event_type
                            
                            	Type of event for bundle
                            	**type**\:   :py:class:`BmdBagEventBdlItem <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmdBagEventBdlItem>`
                            
                            .. attribute:: data
                            
                            	Additional data for the event
                            	**type**\:   :py:class:`Data <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.Events.EventsBundles.EventsBundle.EventsBundleAncestor.Items.BundleEvtInfo.Data>`
                            
                            .. attribute:: time_stamp
                            
                            	Time stamp of the event
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            

                            """

                            _prefix = 'bundlemgr-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(BundleInformation.Events.EventsBundles.EventsBundle.EventsBundleAncestor.Items.BundleEvtInfo, self).__init__()

                                self.yang_name = "bundle-evt-info"
                                self.yang_parent_name = "items"

                                self.bundle_event_type = YLeaf(YType.enumeration, "bundle-event-type")

                                self.time_stamp = YLeaf(YType.uint64, "time-stamp")

                                self.data = BundleInformation.Events.EventsBundles.EventsBundle.EventsBundleAncestor.Items.BundleEvtInfo.Data()
                                self.data.parent = self
                                self._children_name_map["data"] = "data"
                                self._children_yang_names.add("data")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("bundle_event_type",
                                                "time_stamp") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(BundleInformation.Events.EventsBundles.EventsBundle.EventsBundleAncestor.Items.BundleEvtInfo, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(BundleInformation.Events.EventsBundles.EventsBundle.EventsBundleAncestor.Items.BundleEvtInfo, self).__setattr__(name, value)


                            class Data(Entity):
                                """
                                Additional data for the event
                                
                                .. attribute:: data_type
                                
                                	DataType
                                	**type**\:   :py:class:`BmdBagEventData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmdBagEventData>`
                                
                                .. attribute:: error
                                
                                	Error
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: no_data
                                
                                	NoData
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: string_data
                                
                                	StringData
                                	**type**\:  str
                                
                                

                                """

                                _prefix = 'bundlemgr-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(BundleInformation.Events.EventsBundles.EventsBundle.EventsBundleAncestor.Items.BundleEvtInfo.Data, self).__init__()

                                    self.yang_name = "data"
                                    self.yang_parent_name = "bundle-evt-info"

                                    self.data_type = YLeaf(YType.enumeration, "data-type")

                                    self.error = YLeaf(YType.uint32, "error")

                                    self.no_data = YLeaf(YType.uint8, "no-data")

                                    self.string_data = YLeaf(YType.str, "string-data")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("data_type",
                                                    "error",
                                                    "no_data",
                                                    "string_data") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(BundleInformation.Events.EventsBundles.EventsBundle.EventsBundleAncestor.Items.BundleEvtInfo.Data, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(BundleInformation.Events.EventsBundles.EventsBundle.EventsBundleAncestor.Items.BundleEvtInfo.Data, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.data_type.is_set or
                                        self.error.is_set or
                                        self.no_data.is_set or
                                        self.string_data.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.data_type.yfilter != YFilter.not_set or
                                        self.error.yfilter != YFilter.not_set or
                                        self.no_data.yfilter != YFilter.not_set or
                                        self.string_data.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "data" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.data_type.is_set or self.data_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.data_type.get_name_leafdata())
                                    if (self.error.is_set or self.error.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.error.get_name_leafdata())
                                    if (self.no_data.is_set or self.no_data.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.no_data.get_name_leafdata())
                                    if (self.string_data.is_set or self.string_data.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.string_data.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "data-type" or name == "error" or name == "no-data" or name == "string-data"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "data-type"):
                                        self.data_type = value
                                        self.data_type.value_namespace = name_space
                                        self.data_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "error"):
                                        self.error = value
                                        self.error.value_namespace = name_space
                                        self.error.value_namespace_prefix = name_space_prefix
                                    if(value_path == "no-data"):
                                        self.no_data = value
                                        self.no_data.value_namespace = name_space
                                        self.no_data.value_namespace_prefix = name_space_prefix
                                    if(value_path == "string-data"):
                                        self.string_data = value
                                        self.string_data.value_namespace = name_space
                                        self.string_data.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.bundle_event_type.is_set or
                                    self.time_stamp.is_set or
                                    (self.data is not None and self.data.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.bundle_event_type.yfilter != YFilter.not_set or
                                    self.time_stamp.yfilter != YFilter.not_set or
                                    (self.data is not None and self.data.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "bundle-evt-info" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.bundle_event_type.is_set or self.bundle_event_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.bundle_event_type.get_name_leafdata())
                                if (self.time_stamp.is_set or self.time_stamp.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.time_stamp.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "data"):
                                    if (self.data is None):
                                        self.data = BundleInformation.Events.EventsBundles.EventsBundle.EventsBundleAncestor.Items.BundleEvtInfo.Data()
                                        self.data.parent = self
                                        self._children_name_map["data"] = "data"
                                    return self.data

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "data" or name == "bundle-event-type" or name == "time-stamp"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "bundle-event-type"):
                                    self.bundle_event_type = value
                                    self.bundle_event_type.value_namespace = name_space
                                    self.bundle_event_type.value_namespace_prefix = name_space_prefix
                                if(value_path == "time-stamp"):
                                    self.time_stamp = value
                                    self.time_stamp.value_namespace = name_space
                                    self.time_stamp.value_namespace_prefix = name_space_prefix


                        class RgEvtInfo(Entity):
                            """
                            Event information for an RG
                            
                            .. attribute:: data
                            
                            	Additional data for the event
                            	**type**\:   :py:class:`Data <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.Events.EventsBundles.EventsBundle.EventsBundleAncestor.Items.RgEvtInfo.Data>`
                            
                            .. attribute:: rg_event_type
                            
                            	Type of event for RG
                            	**type**\:   :py:class:`BmdBagEventRgItem <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmdBagEventRgItem>`
                            
                            .. attribute:: time_stamp
                            
                            	Time stamp of the event
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            

                            """

                            _prefix = 'bundlemgr-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(BundleInformation.Events.EventsBundles.EventsBundle.EventsBundleAncestor.Items.RgEvtInfo, self).__init__()

                                self.yang_name = "rg-evt-info"
                                self.yang_parent_name = "items"

                                self.rg_event_type = YLeaf(YType.enumeration, "rg-event-type")

                                self.time_stamp = YLeaf(YType.uint64, "time-stamp")

                                self.data = BundleInformation.Events.EventsBundles.EventsBundle.EventsBundleAncestor.Items.RgEvtInfo.Data()
                                self.data.parent = self
                                self._children_name_map["data"] = "data"
                                self._children_yang_names.add("data")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("rg_event_type",
                                                "time_stamp") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(BundleInformation.Events.EventsBundles.EventsBundle.EventsBundleAncestor.Items.RgEvtInfo, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(BundleInformation.Events.EventsBundles.EventsBundle.EventsBundleAncestor.Items.RgEvtInfo, self).__setattr__(name, value)


                            class Data(Entity):
                                """
                                Additional data for the event
                                
                                .. attribute:: data_type
                                
                                	DataType
                                	**type**\:   :py:class:`BmdBagEventData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmdBagEventData>`
                                
                                .. attribute:: error
                                
                                	Error
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: no_data
                                
                                	NoData
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: string_data
                                
                                	StringData
                                	**type**\:  str
                                
                                

                                """

                                _prefix = 'bundlemgr-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(BundleInformation.Events.EventsBundles.EventsBundle.EventsBundleAncestor.Items.RgEvtInfo.Data, self).__init__()

                                    self.yang_name = "data"
                                    self.yang_parent_name = "rg-evt-info"

                                    self.data_type = YLeaf(YType.enumeration, "data-type")

                                    self.error = YLeaf(YType.uint32, "error")

                                    self.no_data = YLeaf(YType.uint8, "no-data")

                                    self.string_data = YLeaf(YType.str, "string-data")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("data_type",
                                                    "error",
                                                    "no_data",
                                                    "string_data") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(BundleInformation.Events.EventsBundles.EventsBundle.EventsBundleAncestor.Items.RgEvtInfo.Data, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(BundleInformation.Events.EventsBundles.EventsBundle.EventsBundleAncestor.Items.RgEvtInfo.Data, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.data_type.is_set or
                                        self.error.is_set or
                                        self.no_data.is_set or
                                        self.string_data.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.data_type.yfilter != YFilter.not_set or
                                        self.error.yfilter != YFilter.not_set or
                                        self.no_data.yfilter != YFilter.not_set or
                                        self.string_data.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "data" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.data_type.is_set or self.data_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.data_type.get_name_leafdata())
                                    if (self.error.is_set or self.error.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.error.get_name_leafdata())
                                    if (self.no_data.is_set or self.no_data.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.no_data.get_name_leafdata())
                                    if (self.string_data.is_set or self.string_data.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.string_data.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "data-type" or name == "error" or name == "no-data" or name == "string-data"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "data-type"):
                                        self.data_type = value
                                        self.data_type.value_namespace = name_space
                                        self.data_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "error"):
                                        self.error = value
                                        self.error.value_namespace = name_space
                                        self.error.value_namespace_prefix = name_space_prefix
                                    if(value_path == "no-data"):
                                        self.no_data = value
                                        self.no_data.value_namespace = name_space
                                        self.no_data.value_namespace_prefix = name_space_prefix
                                    if(value_path == "string-data"):
                                        self.string_data = value
                                        self.string_data.value_namespace = name_space
                                        self.string_data.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.rg_event_type.is_set or
                                    self.time_stamp.is_set or
                                    (self.data is not None and self.data.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.rg_event_type.yfilter != YFilter.not_set or
                                    self.time_stamp.yfilter != YFilter.not_set or
                                    (self.data is not None and self.data.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "rg-evt-info" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.rg_event_type.is_set or self.rg_event_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.rg_event_type.get_name_leafdata())
                                if (self.time_stamp.is_set or self.time_stamp.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.time_stamp.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "data"):
                                    if (self.data is None):
                                        self.data = BundleInformation.Events.EventsBundles.EventsBundle.EventsBundleAncestor.Items.RgEvtInfo.Data()
                                        self.data.parent = self
                                        self._children_name_map["data"] = "data"
                                    return self.data

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "data" or name == "rg-event-type" or name == "time-stamp"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "rg-event-type"):
                                    self.rg_event_type = value
                                    self.rg_event_type.value_namespace = name_space
                                    self.rg_event_type.value_namespace_prefix = name_space_prefix
                                if(value_path == "time-stamp"):
                                    self.time_stamp = value
                                    self.time_stamp.value_namespace = name_space
                                    self.time_stamp.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.event_type.is_set or
                                (self.bundle_evt_info is not None and self.bundle_evt_info.has_data()) or
                                (self.member_evt_info is not None and self.member_evt_info.has_data()) or
                                (self.rg_evt_info is not None and self.rg_evt_info.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.event_type.yfilter != YFilter.not_set or
                                (self.bundle_evt_info is not None and self.bundle_evt_info.has_operation()) or
                                (self.member_evt_info is not None and self.member_evt_info.has_operation()) or
                                (self.rg_evt_info is not None and self.rg_evt_info.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "items" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.event_type.is_set or self.event_type.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.event_type.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "bundle-evt-info"):
                                if (self.bundle_evt_info is None):
                                    self.bundle_evt_info = BundleInformation.Events.EventsBundles.EventsBundle.EventsBundleAncestor.Items.BundleEvtInfo()
                                    self.bundle_evt_info.parent = self
                                    self._children_name_map["bundle_evt_info"] = "bundle-evt-info"
                                return self.bundle_evt_info

                            if (child_yang_name == "member-evt-info"):
                                if (self.member_evt_info is None):
                                    self.member_evt_info = BundleInformation.Events.EventsBundles.EventsBundle.EventsBundleAncestor.Items.MemberEvtInfo()
                                    self.member_evt_info.parent = self
                                    self._children_name_map["member_evt_info"] = "member-evt-info"
                                return self.member_evt_info

                            if (child_yang_name == "rg-evt-info"):
                                if (self.rg_evt_info is None):
                                    self.rg_evt_info = BundleInformation.Events.EventsBundles.EventsBundle.EventsBundleAncestor.Items.RgEvtInfo()
                                    self.rg_evt_info.parent = self
                                    self._children_name_map["rg_evt_info"] = "rg-evt-info"
                                return self.rg_evt_info

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "bundle-evt-info" or name == "member-evt-info" or name == "rg-evt-info" or name == "event-type"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "event-type"):
                                self.event_type = value
                                self.event_type.value_namespace = name_space
                                self.event_type.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.items:
                            if (c.has_data()):
                                return True
                        return self.item_name.is_set

                    def has_operation(self):
                        for c in self.items:
                            if (c.has_operation()):
                                return True
                        return (
                            self.yfilter != YFilter.not_set or
                            self.item_name.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "events-bundle-ancestor" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.item_name.is_set or self.item_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.item_name.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "items"):
                            for c in self.items:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = BundleInformation.Events.EventsBundles.EventsBundle.EventsBundleAncestor.Items()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.items.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "items" or name == "item-name"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "item-name"):
                            self.item_name = value
                            self.item_name.value_namespace = name_space
                            self.item_name.value_namespace_prefix = name_space_prefix


                class EventsBundleItem(Entity):
                    """
                    Data for this item
                    
                    .. attribute:: item_name
                    
                    	Name for the current item to use
                    	**type**\:  str
                    
                    .. attribute:: items
                    
                    	Event items
                    	**type**\: list of    :py:class:`Items <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.Events.EventsBundles.EventsBundle.EventsBundleItem.Items>`
                    
                    

                    """

                    _prefix = 'bundlemgr-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(BundleInformation.Events.EventsBundles.EventsBundle.EventsBundleItem, self).__init__()

                        self.yang_name = "events-bundle-item"
                        self.yang_parent_name = "events-bundle"

                        self.item_name = YLeaf(YType.str, "item-name")

                        self.items = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("item_name") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(BundleInformation.Events.EventsBundles.EventsBundle.EventsBundleItem, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(BundleInformation.Events.EventsBundles.EventsBundle.EventsBundleItem, self).__setattr__(name, value)


                    class Items(Entity):
                        """
                        Event items
                        
                        .. attribute:: bundle_evt_info
                        
                        	Event information for a bundle
                        	**type**\:   :py:class:`BundleEvtInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.Events.EventsBundles.EventsBundle.EventsBundleItem.Items.BundleEvtInfo>`
                        
                        .. attribute:: event_type
                        
                        	EventType
                        	**type**\:   :py:class:`BmdBagTarget <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmdBagTarget>`
                        
                        .. attribute:: member_evt_info
                        
                        	Event information for a member
                        	**type**\:   :py:class:`MemberEvtInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.Events.EventsBundles.EventsBundle.EventsBundleItem.Items.MemberEvtInfo>`
                        
                        .. attribute:: rg_evt_info
                        
                        	Event information for an RG
                        	**type**\:   :py:class:`RgEvtInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.Events.EventsBundles.EventsBundle.EventsBundleItem.Items.RgEvtInfo>`
                        
                        

                        """

                        _prefix = 'bundlemgr-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(BundleInformation.Events.EventsBundles.EventsBundle.EventsBundleItem.Items, self).__init__()

                            self.yang_name = "items"
                            self.yang_parent_name = "events-bundle-item"

                            self.event_type = YLeaf(YType.enumeration, "event-type")

                            self.bundle_evt_info = BundleInformation.Events.EventsBundles.EventsBundle.EventsBundleItem.Items.BundleEvtInfo()
                            self.bundle_evt_info.parent = self
                            self._children_name_map["bundle_evt_info"] = "bundle-evt-info"
                            self._children_yang_names.add("bundle-evt-info")

                            self.member_evt_info = BundleInformation.Events.EventsBundles.EventsBundle.EventsBundleItem.Items.MemberEvtInfo()
                            self.member_evt_info.parent = self
                            self._children_name_map["member_evt_info"] = "member-evt-info"
                            self._children_yang_names.add("member-evt-info")

                            self.rg_evt_info = BundleInformation.Events.EventsBundles.EventsBundle.EventsBundleItem.Items.RgEvtInfo()
                            self.rg_evt_info.parent = self
                            self._children_name_map["rg_evt_info"] = "rg-evt-info"
                            self._children_yang_names.add("rg-evt-info")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("event_type") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(BundleInformation.Events.EventsBundles.EventsBundle.EventsBundleItem.Items, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(BundleInformation.Events.EventsBundles.EventsBundle.EventsBundleItem.Items, self).__setattr__(name, value)


                        class MemberEvtInfo(Entity):
                            """
                            Event information for a member
                            
                            .. attribute:: data
                            
                            	Additional data for the event
                            	**type**\:   :py:class:`Data <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.Events.EventsBundles.EventsBundle.EventsBundleItem.Items.MemberEvtInfo.Data>`
                            
                            .. attribute:: member_event_type
                            
                            	Type of event for member
                            	**type**\:   :py:class:`BmdBagEventMbrItem <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmdBagEventMbrItem>`
                            
                            .. attribute:: time_stamp
                            
                            	Time stamp of the event
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            

                            """

                            _prefix = 'bundlemgr-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(BundleInformation.Events.EventsBundles.EventsBundle.EventsBundleItem.Items.MemberEvtInfo, self).__init__()

                                self.yang_name = "member-evt-info"
                                self.yang_parent_name = "items"

                                self.member_event_type = YLeaf(YType.enumeration, "member-event-type")

                                self.time_stamp = YLeaf(YType.uint64, "time-stamp")

                                self.data = BundleInformation.Events.EventsBundles.EventsBundle.EventsBundleItem.Items.MemberEvtInfo.Data()
                                self.data.parent = self
                                self._children_name_map["data"] = "data"
                                self._children_yang_names.add("data")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("member_event_type",
                                                "time_stamp") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(BundleInformation.Events.EventsBundles.EventsBundle.EventsBundleItem.Items.MemberEvtInfo, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(BundleInformation.Events.EventsBundles.EventsBundle.EventsBundleItem.Items.MemberEvtInfo, self).__setattr__(name, value)


                            class Data(Entity):
                                """
                                Additional data for the event
                                
                                .. attribute:: data_type
                                
                                	DataType
                                	**type**\:   :py:class:`BmdBagEventData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmdBagEventData>`
                                
                                .. attribute:: error
                                
                                	Error
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: no_data
                                
                                	NoData
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: string_data
                                
                                	StringData
                                	**type**\:  str
                                
                                

                                """

                                _prefix = 'bundlemgr-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(BundleInformation.Events.EventsBundles.EventsBundle.EventsBundleItem.Items.MemberEvtInfo.Data, self).__init__()

                                    self.yang_name = "data"
                                    self.yang_parent_name = "member-evt-info"

                                    self.data_type = YLeaf(YType.enumeration, "data-type")

                                    self.error = YLeaf(YType.uint32, "error")

                                    self.no_data = YLeaf(YType.uint8, "no-data")

                                    self.string_data = YLeaf(YType.str, "string-data")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("data_type",
                                                    "error",
                                                    "no_data",
                                                    "string_data") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(BundleInformation.Events.EventsBundles.EventsBundle.EventsBundleItem.Items.MemberEvtInfo.Data, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(BundleInformation.Events.EventsBundles.EventsBundle.EventsBundleItem.Items.MemberEvtInfo.Data, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.data_type.is_set or
                                        self.error.is_set or
                                        self.no_data.is_set or
                                        self.string_data.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.data_type.yfilter != YFilter.not_set or
                                        self.error.yfilter != YFilter.not_set or
                                        self.no_data.yfilter != YFilter.not_set or
                                        self.string_data.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "data" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.data_type.is_set or self.data_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.data_type.get_name_leafdata())
                                    if (self.error.is_set or self.error.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.error.get_name_leafdata())
                                    if (self.no_data.is_set or self.no_data.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.no_data.get_name_leafdata())
                                    if (self.string_data.is_set or self.string_data.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.string_data.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "data-type" or name == "error" or name == "no-data" or name == "string-data"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "data-type"):
                                        self.data_type = value
                                        self.data_type.value_namespace = name_space
                                        self.data_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "error"):
                                        self.error = value
                                        self.error.value_namespace = name_space
                                        self.error.value_namespace_prefix = name_space_prefix
                                    if(value_path == "no-data"):
                                        self.no_data = value
                                        self.no_data.value_namespace = name_space
                                        self.no_data.value_namespace_prefix = name_space_prefix
                                    if(value_path == "string-data"):
                                        self.string_data = value
                                        self.string_data.value_namespace = name_space
                                        self.string_data.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.member_event_type.is_set or
                                    self.time_stamp.is_set or
                                    (self.data is not None and self.data.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.member_event_type.yfilter != YFilter.not_set or
                                    self.time_stamp.yfilter != YFilter.not_set or
                                    (self.data is not None and self.data.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "member-evt-info" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.member_event_type.is_set or self.member_event_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.member_event_type.get_name_leafdata())
                                if (self.time_stamp.is_set or self.time_stamp.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.time_stamp.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "data"):
                                    if (self.data is None):
                                        self.data = BundleInformation.Events.EventsBundles.EventsBundle.EventsBundleItem.Items.MemberEvtInfo.Data()
                                        self.data.parent = self
                                        self._children_name_map["data"] = "data"
                                    return self.data

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "data" or name == "member-event-type" or name == "time-stamp"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "member-event-type"):
                                    self.member_event_type = value
                                    self.member_event_type.value_namespace = name_space
                                    self.member_event_type.value_namespace_prefix = name_space_prefix
                                if(value_path == "time-stamp"):
                                    self.time_stamp = value
                                    self.time_stamp.value_namespace = name_space
                                    self.time_stamp.value_namespace_prefix = name_space_prefix


                        class BundleEvtInfo(Entity):
                            """
                            Event information for a bundle
                            
                            .. attribute:: bundle_event_type
                            
                            	Type of event for bundle
                            	**type**\:   :py:class:`BmdBagEventBdlItem <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmdBagEventBdlItem>`
                            
                            .. attribute:: data
                            
                            	Additional data for the event
                            	**type**\:   :py:class:`Data <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.Events.EventsBundles.EventsBundle.EventsBundleItem.Items.BundleEvtInfo.Data>`
                            
                            .. attribute:: time_stamp
                            
                            	Time stamp of the event
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            

                            """

                            _prefix = 'bundlemgr-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(BundleInformation.Events.EventsBundles.EventsBundle.EventsBundleItem.Items.BundleEvtInfo, self).__init__()

                                self.yang_name = "bundle-evt-info"
                                self.yang_parent_name = "items"

                                self.bundle_event_type = YLeaf(YType.enumeration, "bundle-event-type")

                                self.time_stamp = YLeaf(YType.uint64, "time-stamp")

                                self.data = BundleInformation.Events.EventsBundles.EventsBundle.EventsBundleItem.Items.BundleEvtInfo.Data()
                                self.data.parent = self
                                self._children_name_map["data"] = "data"
                                self._children_yang_names.add("data")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("bundle_event_type",
                                                "time_stamp") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(BundleInformation.Events.EventsBundles.EventsBundle.EventsBundleItem.Items.BundleEvtInfo, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(BundleInformation.Events.EventsBundles.EventsBundle.EventsBundleItem.Items.BundleEvtInfo, self).__setattr__(name, value)


                            class Data(Entity):
                                """
                                Additional data for the event
                                
                                .. attribute:: data_type
                                
                                	DataType
                                	**type**\:   :py:class:`BmdBagEventData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmdBagEventData>`
                                
                                .. attribute:: error
                                
                                	Error
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: no_data
                                
                                	NoData
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: string_data
                                
                                	StringData
                                	**type**\:  str
                                
                                

                                """

                                _prefix = 'bundlemgr-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(BundleInformation.Events.EventsBundles.EventsBundle.EventsBundleItem.Items.BundleEvtInfo.Data, self).__init__()

                                    self.yang_name = "data"
                                    self.yang_parent_name = "bundle-evt-info"

                                    self.data_type = YLeaf(YType.enumeration, "data-type")

                                    self.error = YLeaf(YType.uint32, "error")

                                    self.no_data = YLeaf(YType.uint8, "no-data")

                                    self.string_data = YLeaf(YType.str, "string-data")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("data_type",
                                                    "error",
                                                    "no_data",
                                                    "string_data") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(BundleInformation.Events.EventsBundles.EventsBundle.EventsBundleItem.Items.BundleEvtInfo.Data, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(BundleInformation.Events.EventsBundles.EventsBundle.EventsBundleItem.Items.BundleEvtInfo.Data, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.data_type.is_set or
                                        self.error.is_set or
                                        self.no_data.is_set or
                                        self.string_data.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.data_type.yfilter != YFilter.not_set or
                                        self.error.yfilter != YFilter.not_set or
                                        self.no_data.yfilter != YFilter.not_set or
                                        self.string_data.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "data" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.data_type.is_set or self.data_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.data_type.get_name_leafdata())
                                    if (self.error.is_set or self.error.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.error.get_name_leafdata())
                                    if (self.no_data.is_set or self.no_data.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.no_data.get_name_leafdata())
                                    if (self.string_data.is_set or self.string_data.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.string_data.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "data-type" or name == "error" or name == "no-data" or name == "string-data"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "data-type"):
                                        self.data_type = value
                                        self.data_type.value_namespace = name_space
                                        self.data_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "error"):
                                        self.error = value
                                        self.error.value_namespace = name_space
                                        self.error.value_namespace_prefix = name_space_prefix
                                    if(value_path == "no-data"):
                                        self.no_data = value
                                        self.no_data.value_namespace = name_space
                                        self.no_data.value_namespace_prefix = name_space_prefix
                                    if(value_path == "string-data"):
                                        self.string_data = value
                                        self.string_data.value_namespace = name_space
                                        self.string_data.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.bundle_event_type.is_set or
                                    self.time_stamp.is_set or
                                    (self.data is not None and self.data.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.bundle_event_type.yfilter != YFilter.not_set or
                                    self.time_stamp.yfilter != YFilter.not_set or
                                    (self.data is not None and self.data.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "bundle-evt-info" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.bundle_event_type.is_set or self.bundle_event_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.bundle_event_type.get_name_leafdata())
                                if (self.time_stamp.is_set or self.time_stamp.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.time_stamp.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "data"):
                                    if (self.data is None):
                                        self.data = BundleInformation.Events.EventsBundles.EventsBundle.EventsBundleItem.Items.BundleEvtInfo.Data()
                                        self.data.parent = self
                                        self._children_name_map["data"] = "data"
                                    return self.data

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "data" or name == "bundle-event-type" or name == "time-stamp"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "bundle-event-type"):
                                    self.bundle_event_type = value
                                    self.bundle_event_type.value_namespace = name_space
                                    self.bundle_event_type.value_namespace_prefix = name_space_prefix
                                if(value_path == "time-stamp"):
                                    self.time_stamp = value
                                    self.time_stamp.value_namespace = name_space
                                    self.time_stamp.value_namespace_prefix = name_space_prefix


                        class RgEvtInfo(Entity):
                            """
                            Event information for an RG
                            
                            .. attribute:: data
                            
                            	Additional data for the event
                            	**type**\:   :py:class:`Data <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.Events.EventsBundles.EventsBundle.EventsBundleItem.Items.RgEvtInfo.Data>`
                            
                            .. attribute:: rg_event_type
                            
                            	Type of event for RG
                            	**type**\:   :py:class:`BmdBagEventRgItem <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmdBagEventRgItem>`
                            
                            .. attribute:: time_stamp
                            
                            	Time stamp of the event
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            

                            """

                            _prefix = 'bundlemgr-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(BundleInformation.Events.EventsBundles.EventsBundle.EventsBundleItem.Items.RgEvtInfo, self).__init__()

                                self.yang_name = "rg-evt-info"
                                self.yang_parent_name = "items"

                                self.rg_event_type = YLeaf(YType.enumeration, "rg-event-type")

                                self.time_stamp = YLeaf(YType.uint64, "time-stamp")

                                self.data = BundleInformation.Events.EventsBundles.EventsBundle.EventsBundleItem.Items.RgEvtInfo.Data()
                                self.data.parent = self
                                self._children_name_map["data"] = "data"
                                self._children_yang_names.add("data")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("rg_event_type",
                                                "time_stamp") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(BundleInformation.Events.EventsBundles.EventsBundle.EventsBundleItem.Items.RgEvtInfo, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(BundleInformation.Events.EventsBundles.EventsBundle.EventsBundleItem.Items.RgEvtInfo, self).__setattr__(name, value)


                            class Data(Entity):
                                """
                                Additional data for the event
                                
                                .. attribute:: data_type
                                
                                	DataType
                                	**type**\:   :py:class:`BmdBagEventData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmdBagEventData>`
                                
                                .. attribute:: error
                                
                                	Error
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: no_data
                                
                                	NoData
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: string_data
                                
                                	StringData
                                	**type**\:  str
                                
                                

                                """

                                _prefix = 'bundlemgr-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(BundleInformation.Events.EventsBundles.EventsBundle.EventsBundleItem.Items.RgEvtInfo.Data, self).__init__()

                                    self.yang_name = "data"
                                    self.yang_parent_name = "rg-evt-info"

                                    self.data_type = YLeaf(YType.enumeration, "data-type")

                                    self.error = YLeaf(YType.uint32, "error")

                                    self.no_data = YLeaf(YType.uint8, "no-data")

                                    self.string_data = YLeaf(YType.str, "string-data")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("data_type",
                                                    "error",
                                                    "no_data",
                                                    "string_data") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(BundleInformation.Events.EventsBundles.EventsBundle.EventsBundleItem.Items.RgEvtInfo.Data, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(BundleInformation.Events.EventsBundles.EventsBundle.EventsBundleItem.Items.RgEvtInfo.Data, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.data_type.is_set or
                                        self.error.is_set or
                                        self.no_data.is_set or
                                        self.string_data.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.data_type.yfilter != YFilter.not_set or
                                        self.error.yfilter != YFilter.not_set or
                                        self.no_data.yfilter != YFilter.not_set or
                                        self.string_data.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "data" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.data_type.is_set or self.data_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.data_type.get_name_leafdata())
                                    if (self.error.is_set or self.error.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.error.get_name_leafdata())
                                    if (self.no_data.is_set or self.no_data.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.no_data.get_name_leafdata())
                                    if (self.string_data.is_set or self.string_data.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.string_data.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "data-type" or name == "error" or name == "no-data" or name == "string-data"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "data-type"):
                                        self.data_type = value
                                        self.data_type.value_namespace = name_space
                                        self.data_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "error"):
                                        self.error = value
                                        self.error.value_namespace = name_space
                                        self.error.value_namespace_prefix = name_space_prefix
                                    if(value_path == "no-data"):
                                        self.no_data = value
                                        self.no_data.value_namespace = name_space
                                        self.no_data.value_namespace_prefix = name_space_prefix
                                    if(value_path == "string-data"):
                                        self.string_data = value
                                        self.string_data.value_namespace = name_space
                                        self.string_data.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.rg_event_type.is_set or
                                    self.time_stamp.is_set or
                                    (self.data is not None and self.data.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.rg_event_type.yfilter != YFilter.not_set or
                                    self.time_stamp.yfilter != YFilter.not_set or
                                    (self.data is not None and self.data.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "rg-evt-info" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.rg_event_type.is_set or self.rg_event_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.rg_event_type.get_name_leafdata())
                                if (self.time_stamp.is_set or self.time_stamp.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.time_stamp.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "data"):
                                    if (self.data is None):
                                        self.data = BundleInformation.Events.EventsBundles.EventsBundle.EventsBundleItem.Items.RgEvtInfo.Data()
                                        self.data.parent = self
                                        self._children_name_map["data"] = "data"
                                    return self.data

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "data" or name == "rg-event-type" or name == "time-stamp"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "rg-event-type"):
                                    self.rg_event_type = value
                                    self.rg_event_type.value_namespace = name_space
                                    self.rg_event_type.value_namespace_prefix = name_space_prefix
                                if(value_path == "time-stamp"):
                                    self.time_stamp = value
                                    self.time_stamp.value_namespace = name_space
                                    self.time_stamp.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.event_type.is_set or
                                (self.bundle_evt_info is not None and self.bundle_evt_info.has_data()) or
                                (self.member_evt_info is not None and self.member_evt_info.has_data()) or
                                (self.rg_evt_info is not None and self.rg_evt_info.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.event_type.yfilter != YFilter.not_set or
                                (self.bundle_evt_info is not None and self.bundle_evt_info.has_operation()) or
                                (self.member_evt_info is not None and self.member_evt_info.has_operation()) or
                                (self.rg_evt_info is not None and self.rg_evt_info.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "items" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.event_type.is_set or self.event_type.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.event_type.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "bundle-evt-info"):
                                if (self.bundle_evt_info is None):
                                    self.bundle_evt_info = BundleInformation.Events.EventsBundles.EventsBundle.EventsBundleItem.Items.BundleEvtInfo()
                                    self.bundle_evt_info.parent = self
                                    self._children_name_map["bundle_evt_info"] = "bundle-evt-info"
                                return self.bundle_evt_info

                            if (child_yang_name == "member-evt-info"):
                                if (self.member_evt_info is None):
                                    self.member_evt_info = BundleInformation.Events.EventsBundles.EventsBundle.EventsBundleItem.Items.MemberEvtInfo()
                                    self.member_evt_info.parent = self
                                    self._children_name_map["member_evt_info"] = "member-evt-info"
                                return self.member_evt_info

                            if (child_yang_name == "rg-evt-info"):
                                if (self.rg_evt_info is None):
                                    self.rg_evt_info = BundleInformation.Events.EventsBundles.EventsBundle.EventsBundleItem.Items.RgEvtInfo()
                                    self.rg_evt_info.parent = self
                                    self._children_name_map["rg_evt_info"] = "rg-evt-info"
                                return self.rg_evt_info

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "bundle-evt-info" or name == "member-evt-info" or name == "rg-evt-info" or name == "event-type"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "event-type"):
                                self.event_type = value
                                self.event_type.value_namespace = name_space
                                self.event_type.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.items:
                            if (c.has_data()):
                                return True
                        return self.item_name.is_set

                    def has_operation(self):
                        for c in self.items:
                            if (c.has_operation()):
                                return True
                        return (
                            self.yfilter != YFilter.not_set or
                            self.item_name.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "events-bundle-item" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.item_name.is_set or self.item_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.item_name.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "items"):
                            for c in self.items:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = BundleInformation.Events.EventsBundles.EventsBundle.EventsBundleItem.Items()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.items.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "items" or name == "item-name"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "item-name"):
                            self.item_name = value
                            self.item_name.value_namespace = name_space
                            self.item_name.value_namespace_prefix = name_space_prefix


                class EventsBundleDescendant(Entity):
                    """
                    Data for this item and all its members
                    
                    .. attribute:: events_item
                    
                    	Event items
                    	**type**\: list of    :py:class:`EventsItem <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.Events.EventsBundles.EventsBundle.EventsBundleDescendant.EventsItem>`
                    
                    

                    """

                    _prefix = 'bundlemgr-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(BundleInformation.Events.EventsBundles.EventsBundle.EventsBundleDescendant, self).__init__()

                        self.yang_name = "events-bundle-descendant"
                        self.yang_parent_name = "events-bundle"

                        self.events_item = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(BundleInformation.Events.EventsBundles.EventsBundle.EventsBundleDescendant, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(BundleInformation.Events.EventsBundles.EventsBundle.EventsBundleDescendant, self).__setattr__(name, value)


                    class EventsItem(Entity):
                        """
                        Event items
                        
                        .. attribute:: item_name
                        
                        	Name for the current item to use
                        	**type**\:  str
                        
                        .. attribute:: items
                        
                        	Event items
                        	**type**\: list of    :py:class:`Items <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.Events.EventsBundles.EventsBundle.EventsBundleDescendant.EventsItem.Items>`
                        
                        

                        """

                        _prefix = 'bundlemgr-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(BundleInformation.Events.EventsBundles.EventsBundle.EventsBundleDescendant.EventsItem, self).__init__()

                            self.yang_name = "events-item"
                            self.yang_parent_name = "events-bundle-descendant"

                            self.item_name = YLeaf(YType.str, "item-name")

                            self.items = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("item_name") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(BundleInformation.Events.EventsBundles.EventsBundle.EventsBundleDescendant.EventsItem, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(BundleInformation.Events.EventsBundles.EventsBundle.EventsBundleDescendant.EventsItem, self).__setattr__(name, value)


                        class Items(Entity):
                            """
                            Event items
                            
                            .. attribute:: bundle_evt_info
                            
                            	Event information for a bundle
                            	**type**\:   :py:class:`BundleEvtInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.Events.EventsBundles.EventsBundle.EventsBundleDescendant.EventsItem.Items.BundleEvtInfo>`
                            
                            .. attribute:: event_type
                            
                            	EventType
                            	**type**\:   :py:class:`BmdBagTarget <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmdBagTarget>`
                            
                            .. attribute:: member_evt_info
                            
                            	Event information for a member
                            	**type**\:   :py:class:`MemberEvtInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.Events.EventsBundles.EventsBundle.EventsBundleDescendant.EventsItem.Items.MemberEvtInfo>`
                            
                            .. attribute:: rg_evt_info
                            
                            	Event information for an RG
                            	**type**\:   :py:class:`RgEvtInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.Events.EventsBundles.EventsBundle.EventsBundleDescendant.EventsItem.Items.RgEvtInfo>`
                            
                            

                            """

                            _prefix = 'bundlemgr-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(BundleInformation.Events.EventsBundles.EventsBundle.EventsBundleDescendant.EventsItem.Items, self).__init__()

                                self.yang_name = "items"
                                self.yang_parent_name = "events-item"

                                self.event_type = YLeaf(YType.enumeration, "event-type")

                                self.bundle_evt_info = BundleInformation.Events.EventsBundles.EventsBundle.EventsBundleDescendant.EventsItem.Items.BundleEvtInfo()
                                self.bundle_evt_info.parent = self
                                self._children_name_map["bundle_evt_info"] = "bundle-evt-info"
                                self._children_yang_names.add("bundle-evt-info")

                                self.member_evt_info = BundleInformation.Events.EventsBundles.EventsBundle.EventsBundleDescendant.EventsItem.Items.MemberEvtInfo()
                                self.member_evt_info.parent = self
                                self._children_name_map["member_evt_info"] = "member-evt-info"
                                self._children_yang_names.add("member-evt-info")

                                self.rg_evt_info = BundleInformation.Events.EventsBundles.EventsBundle.EventsBundleDescendant.EventsItem.Items.RgEvtInfo()
                                self.rg_evt_info.parent = self
                                self._children_name_map["rg_evt_info"] = "rg-evt-info"
                                self._children_yang_names.add("rg-evt-info")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("event_type") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(BundleInformation.Events.EventsBundles.EventsBundle.EventsBundleDescendant.EventsItem.Items, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(BundleInformation.Events.EventsBundles.EventsBundle.EventsBundleDescendant.EventsItem.Items, self).__setattr__(name, value)


                            class MemberEvtInfo(Entity):
                                """
                                Event information for a member
                                
                                .. attribute:: data
                                
                                	Additional data for the event
                                	**type**\:   :py:class:`Data <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.Events.EventsBundles.EventsBundle.EventsBundleDescendant.EventsItem.Items.MemberEvtInfo.Data>`
                                
                                .. attribute:: member_event_type
                                
                                	Type of event for member
                                	**type**\:   :py:class:`BmdBagEventMbrItem <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmdBagEventMbrItem>`
                                
                                .. attribute:: time_stamp
                                
                                	Time stamp of the event
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'bundlemgr-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(BundleInformation.Events.EventsBundles.EventsBundle.EventsBundleDescendant.EventsItem.Items.MemberEvtInfo, self).__init__()

                                    self.yang_name = "member-evt-info"
                                    self.yang_parent_name = "items"

                                    self.member_event_type = YLeaf(YType.enumeration, "member-event-type")

                                    self.time_stamp = YLeaf(YType.uint64, "time-stamp")

                                    self.data = BundleInformation.Events.EventsBundles.EventsBundle.EventsBundleDescendant.EventsItem.Items.MemberEvtInfo.Data()
                                    self.data.parent = self
                                    self._children_name_map["data"] = "data"
                                    self._children_yang_names.add("data")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("member_event_type",
                                                    "time_stamp") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(BundleInformation.Events.EventsBundles.EventsBundle.EventsBundleDescendant.EventsItem.Items.MemberEvtInfo, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(BundleInformation.Events.EventsBundles.EventsBundle.EventsBundleDescendant.EventsItem.Items.MemberEvtInfo, self).__setattr__(name, value)


                                class Data(Entity):
                                    """
                                    Additional data for the event
                                    
                                    .. attribute:: data_type
                                    
                                    	DataType
                                    	**type**\:   :py:class:`BmdBagEventData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmdBagEventData>`
                                    
                                    .. attribute:: error
                                    
                                    	Error
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: no_data
                                    
                                    	NoData
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: string_data
                                    
                                    	StringData
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'bundlemgr-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(BundleInformation.Events.EventsBundles.EventsBundle.EventsBundleDescendant.EventsItem.Items.MemberEvtInfo.Data, self).__init__()

                                        self.yang_name = "data"
                                        self.yang_parent_name = "member-evt-info"

                                        self.data_type = YLeaf(YType.enumeration, "data-type")

                                        self.error = YLeaf(YType.uint32, "error")

                                        self.no_data = YLeaf(YType.uint8, "no-data")

                                        self.string_data = YLeaf(YType.str, "string-data")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data_type",
                                                        "error",
                                                        "no_data",
                                                        "string_data") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(BundleInformation.Events.EventsBundles.EventsBundle.EventsBundleDescendant.EventsItem.Items.MemberEvtInfo.Data, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(BundleInformation.Events.EventsBundles.EventsBundle.EventsBundleDescendant.EventsItem.Items.MemberEvtInfo.Data, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data_type.is_set or
                                            self.error.is_set or
                                            self.no_data.is_set or
                                            self.string_data.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data_type.yfilter != YFilter.not_set or
                                            self.error.yfilter != YFilter.not_set or
                                            self.no_data.yfilter != YFilter.not_set or
                                            self.string_data.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "data" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data_type.is_set or self.data_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data_type.get_name_leafdata())
                                        if (self.error.is_set or self.error.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.error.get_name_leafdata())
                                        if (self.no_data.is_set or self.no_data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.no_data.get_name_leafdata())
                                        if (self.string_data.is_set or self.string_data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.string_data.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data-type" or name == "error" or name == "no-data" or name == "string-data"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data-type"):
                                            self.data_type = value
                                            self.data_type.value_namespace = name_space
                                            self.data_type.value_namespace_prefix = name_space_prefix
                                        if(value_path == "error"):
                                            self.error = value
                                            self.error.value_namespace = name_space
                                            self.error.value_namespace_prefix = name_space_prefix
                                        if(value_path == "no-data"):
                                            self.no_data = value
                                            self.no_data.value_namespace = name_space
                                            self.no_data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "string-data"):
                                            self.string_data = value
                                            self.string_data.value_namespace = name_space
                                            self.string_data.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.member_event_type.is_set or
                                        self.time_stamp.is_set or
                                        (self.data is not None and self.data.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.member_event_type.yfilter != YFilter.not_set or
                                        self.time_stamp.yfilter != YFilter.not_set or
                                        (self.data is not None and self.data.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "member-evt-info" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.member_event_type.is_set or self.member_event_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.member_event_type.get_name_leafdata())
                                    if (self.time_stamp.is_set or self.time_stamp.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.time_stamp.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "data"):
                                        if (self.data is None):
                                            self.data = BundleInformation.Events.EventsBundles.EventsBundle.EventsBundleDescendant.EventsItem.Items.MemberEvtInfo.Data()
                                            self.data.parent = self
                                            self._children_name_map["data"] = "data"
                                        return self.data

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "data" or name == "member-event-type" or name == "time-stamp"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "member-event-type"):
                                        self.member_event_type = value
                                        self.member_event_type.value_namespace = name_space
                                        self.member_event_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "time-stamp"):
                                        self.time_stamp = value
                                        self.time_stamp.value_namespace = name_space
                                        self.time_stamp.value_namespace_prefix = name_space_prefix


                            class BundleEvtInfo(Entity):
                                """
                                Event information for a bundle
                                
                                .. attribute:: bundle_event_type
                                
                                	Type of event for bundle
                                	**type**\:   :py:class:`BmdBagEventBdlItem <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmdBagEventBdlItem>`
                                
                                .. attribute:: data
                                
                                	Additional data for the event
                                	**type**\:   :py:class:`Data <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.Events.EventsBundles.EventsBundle.EventsBundleDescendant.EventsItem.Items.BundleEvtInfo.Data>`
                                
                                .. attribute:: time_stamp
                                
                                	Time stamp of the event
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'bundlemgr-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(BundleInformation.Events.EventsBundles.EventsBundle.EventsBundleDescendant.EventsItem.Items.BundleEvtInfo, self).__init__()

                                    self.yang_name = "bundle-evt-info"
                                    self.yang_parent_name = "items"

                                    self.bundle_event_type = YLeaf(YType.enumeration, "bundle-event-type")

                                    self.time_stamp = YLeaf(YType.uint64, "time-stamp")

                                    self.data = BundleInformation.Events.EventsBundles.EventsBundle.EventsBundleDescendant.EventsItem.Items.BundleEvtInfo.Data()
                                    self.data.parent = self
                                    self._children_name_map["data"] = "data"
                                    self._children_yang_names.add("data")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("bundle_event_type",
                                                    "time_stamp") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(BundleInformation.Events.EventsBundles.EventsBundle.EventsBundleDescendant.EventsItem.Items.BundleEvtInfo, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(BundleInformation.Events.EventsBundles.EventsBundle.EventsBundleDescendant.EventsItem.Items.BundleEvtInfo, self).__setattr__(name, value)


                                class Data(Entity):
                                    """
                                    Additional data for the event
                                    
                                    .. attribute:: data_type
                                    
                                    	DataType
                                    	**type**\:   :py:class:`BmdBagEventData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmdBagEventData>`
                                    
                                    .. attribute:: error
                                    
                                    	Error
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: no_data
                                    
                                    	NoData
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: string_data
                                    
                                    	StringData
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'bundlemgr-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(BundleInformation.Events.EventsBundles.EventsBundle.EventsBundleDescendant.EventsItem.Items.BundleEvtInfo.Data, self).__init__()

                                        self.yang_name = "data"
                                        self.yang_parent_name = "bundle-evt-info"

                                        self.data_type = YLeaf(YType.enumeration, "data-type")

                                        self.error = YLeaf(YType.uint32, "error")

                                        self.no_data = YLeaf(YType.uint8, "no-data")

                                        self.string_data = YLeaf(YType.str, "string-data")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data_type",
                                                        "error",
                                                        "no_data",
                                                        "string_data") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(BundleInformation.Events.EventsBundles.EventsBundle.EventsBundleDescendant.EventsItem.Items.BundleEvtInfo.Data, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(BundleInformation.Events.EventsBundles.EventsBundle.EventsBundleDescendant.EventsItem.Items.BundleEvtInfo.Data, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data_type.is_set or
                                            self.error.is_set or
                                            self.no_data.is_set or
                                            self.string_data.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data_type.yfilter != YFilter.not_set or
                                            self.error.yfilter != YFilter.not_set or
                                            self.no_data.yfilter != YFilter.not_set or
                                            self.string_data.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "data" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data_type.is_set or self.data_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data_type.get_name_leafdata())
                                        if (self.error.is_set or self.error.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.error.get_name_leafdata())
                                        if (self.no_data.is_set or self.no_data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.no_data.get_name_leafdata())
                                        if (self.string_data.is_set or self.string_data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.string_data.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data-type" or name == "error" or name == "no-data" or name == "string-data"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data-type"):
                                            self.data_type = value
                                            self.data_type.value_namespace = name_space
                                            self.data_type.value_namespace_prefix = name_space_prefix
                                        if(value_path == "error"):
                                            self.error = value
                                            self.error.value_namespace = name_space
                                            self.error.value_namespace_prefix = name_space_prefix
                                        if(value_path == "no-data"):
                                            self.no_data = value
                                            self.no_data.value_namespace = name_space
                                            self.no_data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "string-data"):
                                            self.string_data = value
                                            self.string_data.value_namespace = name_space
                                            self.string_data.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.bundle_event_type.is_set or
                                        self.time_stamp.is_set or
                                        (self.data is not None and self.data.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.bundle_event_type.yfilter != YFilter.not_set or
                                        self.time_stamp.yfilter != YFilter.not_set or
                                        (self.data is not None and self.data.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "bundle-evt-info" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.bundle_event_type.is_set or self.bundle_event_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.bundle_event_type.get_name_leafdata())
                                    if (self.time_stamp.is_set or self.time_stamp.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.time_stamp.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "data"):
                                        if (self.data is None):
                                            self.data = BundleInformation.Events.EventsBundles.EventsBundle.EventsBundleDescendant.EventsItem.Items.BundleEvtInfo.Data()
                                            self.data.parent = self
                                            self._children_name_map["data"] = "data"
                                        return self.data

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "data" or name == "bundle-event-type" or name == "time-stamp"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "bundle-event-type"):
                                        self.bundle_event_type = value
                                        self.bundle_event_type.value_namespace = name_space
                                        self.bundle_event_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "time-stamp"):
                                        self.time_stamp = value
                                        self.time_stamp.value_namespace = name_space
                                        self.time_stamp.value_namespace_prefix = name_space_prefix


                            class RgEvtInfo(Entity):
                                """
                                Event information for an RG
                                
                                .. attribute:: data
                                
                                	Additional data for the event
                                	**type**\:   :py:class:`Data <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.Events.EventsBundles.EventsBundle.EventsBundleDescendant.EventsItem.Items.RgEvtInfo.Data>`
                                
                                .. attribute:: rg_event_type
                                
                                	Type of event for RG
                                	**type**\:   :py:class:`BmdBagEventRgItem <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmdBagEventRgItem>`
                                
                                .. attribute:: time_stamp
                                
                                	Time stamp of the event
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'bundlemgr-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(BundleInformation.Events.EventsBundles.EventsBundle.EventsBundleDescendant.EventsItem.Items.RgEvtInfo, self).__init__()

                                    self.yang_name = "rg-evt-info"
                                    self.yang_parent_name = "items"

                                    self.rg_event_type = YLeaf(YType.enumeration, "rg-event-type")

                                    self.time_stamp = YLeaf(YType.uint64, "time-stamp")

                                    self.data = BundleInformation.Events.EventsBundles.EventsBundle.EventsBundleDescendant.EventsItem.Items.RgEvtInfo.Data()
                                    self.data.parent = self
                                    self._children_name_map["data"] = "data"
                                    self._children_yang_names.add("data")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("rg_event_type",
                                                    "time_stamp") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(BundleInformation.Events.EventsBundles.EventsBundle.EventsBundleDescendant.EventsItem.Items.RgEvtInfo, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(BundleInformation.Events.EventsBundles.EventsBundle.EventsBundleDescendant.EventsItem.Items.RgEvtInfo, self).__setattr__(name, value)


                                class Data(Entity):
                                    """
                                    Additional data for the event
                                    
                                    .. attribute:: data_type
                                    
                                    	DataType
                                    	**type**\:   :py:class:`BmdBagEventData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmdBagEventData>`
                                    
                                    .. attribute:: error
                                    
                                    	Error
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: no_data
                                    
                                    	NoData
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: string_data
                                    
                                    	StringData
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'bundlemgr-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(BundleInformation.Events.EventsBundles.EventsBundle.EventsBundleDescendant.EventsItem.Items.RgEvtInfo.Data, self).__init__()

                                        self.yang_name = "data"
                                        self.yang_parent_name = "rg-evt-info"

                                        self.data_type = YLeaf(YType.enumeration, "data-type")

                                        self.error = YLeaf(YType.uint32, "error")

                                        self.no_data = YLeaf(YType.uint8, "no-data")

                                        self.string_data = YLeaf(YType.str, "string-data")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data_type",
                                                        "error",
                                                        "no_data",
                                                        "string_data") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(BundleInformation.Events.EventsBundles.EventsBundle.EventsBundleDescendant.EventsItem.Items.RgEvtInfo.Data, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(BundleInformation.Events.EventsBundles.EventsBundle.EventsBundleDescendant.EventsItem.Items.RgEvtInfo.Data, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data_type.is_set or
                                            self.error.is_set or
                                            self.no_data.is_set or
                                            self.string_data.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data_type.yfilter != YFilter.not_set or
                                            self.error.yfilter != YFilter.not_set or
                                            self.no_data.yfilter != YFilter.not_set or
                                            self.string_data.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "data" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data_type.is_set or self.data_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data_type.get_name_leafdata())
                                        if (self.error.is_set or self.error.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.error.get_name_leafdata())
                                        if (self.no_data.is_set or self.no_data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.no_data.get_name_leafdata())
                                        if (self.string_data.is_set or self.string_data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.string_data.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data-type" or name == "error" or name == "no-data" or name == "string-data"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data-type"):
                                            self.data_type = value
                                            self.data_type.value_namespace = name_space
                                            self.data_type.value_namespace_prefix = name_space_prefix
                                        if(value_path == "error"):
                                            self.error = value
                                            self.error.value_namespace = name_space
                                            self.error.value_namespace_prefix = name_space_prefix
                                        if(value_path == "no-data"):
                                            self.no_data = value
                                            self.no_data.value_namespace = name_space
                                            self.no_data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "string-data"):
                                            self.string_data = value
                                            self.string_data.value_namespace = name_space
                                            self.string_data.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.rg_event_type.is_set or
                                        self.time_stamp.is_set or
                                        (self.data is not None and self.data.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.rg_event_type.yfilter != YFilter.not_set or
                                        self.time_stamp.yfilter != YFilter.not_set or
                                        (self.data is not None and self.data.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "rg-evt-info" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.rg_event_type.is_set or self.rg_event_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.rg_event_type.get_name_leafdata())
                                    if (self.time_stamp.is_set or self.time_stamp.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.time_stamp.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "data"):
                                        if (self.data is None):
                                            self.data = BundleInformation.Events.EventsBundles.EventsBundle.EventsBundleDescendant.EventsItem.Items.RgEvtInfo.Data()
                                            self.data.parent = self
                                            self._children_name_map["data"] = "data"
                                        return self.data

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "data" or name == "rg-event-type" or name == "time-stamp"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "rg-event-type"):
                                        self.rg_event_type = value
                                        self.rg_event_type.value_namespace = name_space
                                        self.rg_event_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "time-stamp"):
                                        self.time_stamp = value
                                        self.time_stamp.value_namespace = name_space
                                        self.time_stamp.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.event_type.is_set or
                                    (self.bundle_evt_info is not None and self.bundle_evt_info.has_data()) or
                                    (self.member_evt_info is not None and self.member_evt_info.has_data()) or
                                    (self.rg_evt_info is not None and self.rg_evt_info.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.event_type.yfilter != YFilter.not_set or
                                    (self.bundle_evt_info is not None and self.bundle_evt_info.has_operation()) or
                                    (self.member_evt_info is not None and self.member_evt_info.has_operation()) or
                                    (self.rg_evt_info is not None and self.rg_evt_info.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "items" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.event_type.is_set or self.event_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.event_type.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "bundle-evt-info"):
                                    if (self.bundle_evt_info is None):
                                        self.bundle_evt_info = BundleInformation.Events.EventsBundles.EventsBundle.EventsBundleDescendant.EventsItem.Items.BundleEvtInfo()
                                        self.bundle_evt_info.parent = self
                                        self._children_name_map["bundle_evt_info"] = "bundle-evt-info"
                                    return self.bundle_evt_info

                                if (child_yang_name == "member-evt-info"):
                                    if (self.member_evt_info is None):
                                        self.member_evt_info = BundleInformation.Events.EventsBundles.EventsBundle.EventsBundleDescendant.EventsItem.Items.MemberEvtInfo()
                                        self.member_evt_info.parent = self
                                        self._children_name_map["member_evt_info"] = "member-evt-info"
                                    return self.member_evt_info

                                if (child_yang_name == "rg-evt-info"):
                                    if (self.rg_evt_info is None):
                                        self.rg_evt_info = BundleInformation.Events.EventsBundles.EventsBundle.EventsBundleDescendant.EventsItem.Items.RgEvtInfo()
                                        self.rg_evt_info.parent = self
                                        self._children_name_map["rg_evt_info"] = "rg-evt-info"
                                    return self.rg_evt_info

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "bundle-evt-info" or name == "member-evt-info" or name == "rg-evt-info" or name == "event-type"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "event-type"):
                                    self.event_type = value
                                    self.event_type.value_namespace = name_space
                                    self.event_type.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.items:
                                if (c.has_data()):
                                    return True
                            return self.item_name.is_set

                        def has_operation(self):
                            for c in self.items:
                                if (c.has_operation()):
                                    return True
                            return (
                                self.yfilter != YFilter.not_set or
                                self.item_name.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "events-item" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.item_name.is_set or self.item_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.item_name.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "items"):
                                for c in self.items:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = BundleInformation.Events.EventsBundles.EventsBundle.EventsBundleDescendant.EventsItem.Items()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.items.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "items" or name == "item-name"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "item-name"):
                                self.item_name = value
                                self.item_name.value_namespace = name_space
                                self.item_name.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.events_item:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.events_item:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "events-bundle-descendant" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "events-item"):
                            for c in self.events_item:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = BundleInformation.Events.EventsBundles.EventsBundle.EventsBundleDescendant.EventsItem()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.events_item.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "events-item"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class EventsBundleChildrenMembers(Entity):
                    """
                    Children of bundle with events information
                    
                    .. attribute:: events_bundle_children_member
                    
                    	Bundle member item with events information
                    	**type**\: list of    :py:class:`EventsBundleChildrenMember <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.Events.EventsBundles.EventsBundle.EventsBundleChildrenMembers.EventsBundleChildrenMember>`
                    
                    

                    """

                    _prefix = 'bundlemgr-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(BundleInformation.Events.EventsBundles.EventsBundle.EventsBundleChildrenMembers, self).__init__()

                        self.yang_name = "events-bundle-children-members"
                        self.yang_parent_name = "events-bundle"

                        self.events_bundle_children_member = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(BundleInformation.Events.EventsBundles.EventsBundle.EventsBundleChildrenMembers, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(BundleInformation.Events.EventsBundles.EventsBundle.EventsBundleChildrenMembers, self).__setattr__(name, value)


                    class EventsBundleChildrenMember(Entity):
                        """
                        Bundle member item with events information
                        
                        .. attribute:: member_interface  <key>
                        
                        	Member interface
                        	**type**\:  str
                        
                        .. attribute:: item_name
                        
                        	Name for the current item to use
                        	**type**\:  str
                        
                        .. attribute:: items
                        
                        	Event items
                        	**type**\: list of    :py:class:`Items <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.Events.EventsBundles.EventsBundle.EventsBundleChildrenMembers.EventsBundleChildrenMember.Items>`
                        
                        

                        """

                        _prefix = 'bundlemgr-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(BundleInformation.Events.EventsBundles.EventsBundle.EventsBundleChildrenMembers.EventsBundleChildrenMember, self).__init__()

                            self.yang_name = "events-bundle-children-member"
                            self.yang_parent_name = "events-bundle-children-members"

                            self.member_interface = YLeaf(YType.str, "member-interface")

                            self.item_name = YLeaf(YType.str, "item-name")

                            self.items = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("member_interface",
                                            "item_name") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(BundleInformation.Events.EventsBundles.EventsBundle.EventsBundleChildrenMembers.EventsBundleChildrenMember, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(BundleInformation.Events.EventsBundles.EventsBundle.EventsBundleChildrenMembers.EventsBundleChildrenMember, self).__setattr__(name, value)


                        class Items(Entity):
                            """
                            Event items
                            
                            .. attribute:: bundle_evt_info
                            
                            	Event information for a bundle
                            	**type**\:   :py:class:`BundleEvtInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.Events.EventsBundles.EventsBundle.EventsBundleChildrenMembers.EventsBundleChildrenMember.Items.BundleEvtInfo>`
                            
                            .. attribute:: event_type
                            
                            	EventType
                            	**type**\:   :py:class:`BmdBagTarget <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmdBagTarget>`
                            
                            .. attribute:: member_evt_info
                            
                            	Event information for a member
                            	**type**\:   :py:class:`MemberEvtInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.Events.EventsBundles.EventsBundle.EventsBundleChildrenMembers.EventsBundleChildrenMember.Items.MemberEvtInfo>`
                            
                            .. attribute:: rg_evt_info
                            
                            	Event information for an RG
                            	**type**\:   :py:class:`RgEvtInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.Events.EventsBundles.EventsBundle.EventsBundleChildrenMembers.EventsBundleChildrenMember.Items.RgEvtInfo>`
                            
                            

                            """

                            _prefix = 'bundlemgr-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(BundleInformation.Events.EventsBundles.EventsBundle.EventsBundleChildrenMembers.EventsBundleChildrenMember.Items, self).__init__()

                                self.yang_name = "items"
                                self.yang_parent_name = "events-bundle-children-member"

                                self.event_type = YLeaf(YType.enumeration, "event-type")

                                self.bundle_evt_info = BundleInformation.Events.EventsBundles.EventsBundle.EventsBundleChildrenMembers.EventsBundleChildrenMember.Items.BundleEvtInfo()
                                self.bundle_evt_info.parent = self
                                self._children_name_map["bundle_evt_info"] = "bundle-evt-info"
                                self._children_yang_names.add("bundle-evt-info")

                                self.member_evt_info = BundleInformation.Events.EventsBundles.EventsBundle.EventsBundleChildrenMembers.EventsBundleChildrenMember.Items.MemberEvtInfo()
                                self.member_evt_info.parent = self
                                self._children_name_map["member_evt_info"] = "member-evt-info"
                                self._children_yang_names.add("member-evt-info")

                                self.rg_evt_info = BundleInformation.Events.EventsBundles.EventsBundle.EventsBundleChildrenMembers.EventsBundleChildrenMember.Items.RgEvtInfo()
                                self.rg_evt_info.parent = self
                                self._children_name_map["rg_evt_info"] = "rg-evt-info"
                                self._children_yang_names.add("rg-evt-info")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("event_type") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(BundleInformation.Events.EventsBundles.EventsBundle.EventsBundleChildrenMembers.EventsBundleChildrenMember.Items, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(BundleInformation.Events.EventsBundles.EventsBundle.EventsBundleChildrenMembers.EventsBundleChildrenMember.Items, self).__setattr__(name, value)


                            class MemberEvtInfo(Entity):
                                """
                                Event information for a member
                                
                                .. attribute:: data
                                
                                	Additional data for the event
                                	**type**\:   :py:class:`Data <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.Events.EventsBundles.EventsBundle.EventsBundleChildrenMembers.EventsBundleChildrenMember.Items.MemberEvtInfo.Data>`
                                
                                .. attribute:: member_event_type
                                
                                	Type of event for member
                                	**type**\:   :py:class:`BmdBagEventMbrItem <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmdBagEventMbrItem>`
                                
                                .. attribute:: time_stamp
                                
                                	Time stamp of the event
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'bundlemgr-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(BundleInformation.Events.EventsBundles.EventsBundle.EventsBundleChildrenMembers.EventsBundleChildrenMember.Items.MemberEvtInfo, self).__init__()

                                    self.yang_name = "member-evt-info"
                                    self.yang_parent_name = "items"

                                    self.member_event_type = YLeaf(YType.enumeration, "member-event-type")

                                    self.time_stamp = YLeaf(YType.uint64, "time-stamp")

                                    self.data = BundleInformation.Events.EventsBundles.EventsBundle.EventsBundleChildrenMembers.EventsBundleChildrenMember.Items.MemberEvtInfo.Data()
                                    self.data.parent = self
                                    self._children_name_map["data"] = "data"
                                    self._children_yang_names.add("data")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("member_event_type",
                                                    "time_stamp") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(BundleInformation.Events.EventsBundles.EventsBundle.EventsBundleChildrenMembers.EventsBundleChildrenMember.Items.MemberEvtInfo, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(BundleInformation.Events.EventsBundles.EventsBundle.EventsBundleChildrenMembers.EventsBundleChildrenMember.Items.MemberEvtInfo, self).__setattr__(name, value)


                                class Data(Entity):
                                    """
                                    Additional data for the event
                                    
                                    .. attribute:: data_type
                                    
                                    	DataType
                                    	**type**\:   :py:class:`BmdBagEventData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmdBagEventData>`
                                    
                                    .. attribute:: error
                                    
                                    	Error
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: no_data
                                    
                                    	NoData
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: string_data
                                    
                                    	StringData
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'bundlemgr-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(BundleInformation.Events.EventsBundles.EventsBundle.EventsBundleChildrenMembers.EventsBundleChildrenMember.Items.MemberEvtInfo.Data, self).__init__()

                                        self.yang_name = "data"
                                        self.yang_parent_name = "member-evt-info"

                                        self.data_type = YLeaf(YType.enumeration, "data-type")

                                        self.error = YLeaf(YType.uint32, "error")

                                        self.no_data = YLeaf(YType.uint8, "no-data")

                                        self.string_data = YLeaf(YType.str, "string-data")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data_type",
                                                        "error",
                                                        "no_data",
                                                        "string_data") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(BundleInformation.Events.EventsBundles.EventsBundle.EventsBundleChildrenMembers.EventsBundleChildrenMember.Items.MemberEvtInfo.Data, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(BundleInformation.Events.EventsBundles.EventsBundle.EventsBundleChildrenMembers.EventsBundleChildrenMember.Items.MemberEvtInfo.Data, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data_type.is_set or
                                            self.error.is_set or
                                            self.no_data.is_set or
                                            self.string_data.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data_type.yfilter != YFilter.not_set or
                                            self.error.yfilter != YFilter.not_set or
                                            self.no_data.yfilter != YFilter.not_set or
                                            self.string_data.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "data" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data_type.is_set or self.data_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data_type.get_name_leafdata())
                                        if (self.error.is_set or self.error.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.error.get_name_leafdata())
                                        if (self.no_data.is_set or self.no_data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.no_data.get_name_leafdata())
                                        if (self.string_data.is_set or self.string_data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.string_data.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data-type" or name == "error" or name == "no-data" or name == "string-data"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data-type"):
                                            self.data_type = value
                                            self.data_type.value_namespace = name_space
                                            self.data_type.value_namespace_prefix = name_space_prefix
                                        if(value_path == "error"):
                                            self.error = value
                                            self.error.value_namespace = name_space
                                            self.error.value_namespace_prefix = name_space_prefix
                                        if(value_path == "no-data"):
                                            self.no_data = value
                                            self.no_data.value_namespace = name_space
                                            self.no_data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "string-data"):
                                            self.string_data = value
                                            self.string_data.value_namespace = name_space
                                            self.string_data.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.member_event_type.is_set or
                                        self.time_stamp.is_set or
                                        (self.data is not None and self.data.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.member_event_type.yfilter != YFilter.not_set or
                                        self.time_stamp.yfilter != YFilter.not_set or
                                        (self.data is not None and self.data.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "member-evt-info" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.member_event_type.is_set or self.member_event_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.member_event_type.get_name_leafdata())
                                    if (self.time_stamp.is_set or self.time_stamp.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.time_stamp.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "data"):
                                        if (self.data is None):
                                            self.data = BundleInformation.Events.EventsBundles.EventsBundle.EventsBundleChildrenMembers.EventsBundleChildrenMember.Items.MemberEvtInfo.Data()
                                            self.data.parent = self
                                            self._children_name_map["data"] = "data"
                                        return self.data

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "data" or name == "member-event-type" or name == "time-stamp"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "member-event-type"):
                                        self.member_event_type = value
                                        self.member_event_type.value_namespace = name_space
                                        self.member_event_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "time-stamp"):
                                        self.time_stamp = value
                                        self.time_stamp.value_namespace = name_space
                                        self.time_stamp.value_namespace_prefix = name_space_prefix


                            class BundleEvtInfo(Entity):
                                """
                                Event information for a bundle
                                
                                .. attribute:: bundle_event_type
                                
                                	Type of event for bundle
                                	**type**\:   :py:class:`BmdBagEventBdlItem <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmdBagEventBdlItem>`
                                
                                .. attribute:: data
                                
                                	Additional data for the event
                                	**type**\:   :py:class:`Data <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.Events.EventsBundles.EventsBundle.EventsBundleChildrenMembers.EventsBundleChildrenMember.Items.BundleEvtInfo.Data>`
                                
                                .. attribute:: time_stamp
                                
                                	Time stamp of the event
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'bundlemgr-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(BundleInformation.Events.EventsBundles.EventsBundle.EventsBundleChildrenMembers.EventsBundleChildrenMember.Items.BundleEvtInfo, self).__init__()

                                    self.yang_name = "bundle-evt-info"
                                    self.yang_parent_name = "items"

                                    self.bundle_event_type = YLeaf(YType.enumeration, "bundle-event-type")

                                    self.time_stamp = YLeaf(YType.uint64, "time-stamp")

                                    self.data = BundleInformation.Events.EventsBundles.EventsBundle.EventsBundleChildrenMembers.EventsBundleChildrenMember.Items.BundleEvtInfo.Data()
                                    self.data.parent = self
                                    self._children_name_map["data"] = "data"
                                    self._children_yang_names.add("data")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("bundle_event_type",
                                                    "time_stamp") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(BundleInformation.Events.EventsBundles.EventsBundle.EventsBundleChildrenMembers.EventsBundleChildrenMember.Items.BundleEvtInfo, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(BundleInformation.Events.EventsBundles.EventsBundle.EventsBundleChildrenMembers.EventsBundleChildrenMember.Items.BundleEvtInfo, self).__setattr__(name, value)


                                class Data(Entity):
                                    """
                                    Additional data for the event
                                    
                                    .. attribute:: data_type
                                    
                                    	DataType
                                    	**type**\:   :py:class:`BmdBagEventData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmdBagEventData>`
                                    
                                    .. attribute:: error
                                    
                                    	Error
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: no_data
                                    
                                    	NoData
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: string_data
                                    
                                    	StringData
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'bundlemgr-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(BundleInformation.Events.EventsBundles.EventsBundle.EventsBundleChildrenMembers.EventsBundleChildrenMember.Items.BundleEvtInfo.Data, self).__init__()

                                        self.yang_name = "data"
                                        self.yang_parent_name = "bundle-evt-info"

                                        self.data_type = YLeaf(YType.enumeration, "data-type")

                                        self.error = YLeaf(YType.uint32, "error")

                                        self.no_data = YLeaf(YType.uint8, "no-data")

                                        self.string_data = YLeaf(YType.str, "string-data")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data_type",
                                                        "error",
                                                        "no_data",
                                                        "string_data") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(BundleInformation.Events.EventsBundles.EventsBundle.EventsBundleChildrenMembers.EventsBundleChildrenMember.Items.BundleEvtInfo.Data, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(BundleInformation.Events.EventsBundles.EventsBundle.EventsBundleChildrenMembers.EventsBundleChildrenMember.Items.BundleEvtInfo.Data, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data_type.is_set or
                                            self.error.is_set or
                                            self.no_data.is_set or
                                            self.string_data.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data_type.yfilter != YFilter.not_set or
                                            self.error.yfilter != YFilter.not_set or
                                            self.no_data.yfilter != YFilter.not_set or
                                            self.string_data.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "data" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data_type.is_set or self.data_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data_type.get_name_leafdata())
                                        if (self.error.is_set or self.error.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.error.get_name_leafdata())
                                        if (self.no_data.is_set or self.no_data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.no_data.get_name_leafdata())
                                        if (self.string_data.is_set or self.string_data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.string_data.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data-type" or name == "error" or name == "no-data" or name == "string-data"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data-type"):
                                            self.data_type = value
                                            self.data_type.value_namespace = name_space
                                            self.data_type.value_namespace_prefix = name_space_prefix
                                        if(value_path == "error"):
                                            self.error = value
                                            self.error.value_namespace = name_space
                                            self.error.value_namespace_prefix = name_space_prefix
                                        if(value_path == "no-data"):
                                            self.no_data = value
                                            self.no_data.value_namespace = name_space
                                            self.no_data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "string-data"):
                                            self.string_data = value
                                            self.string_data.value_namespace = name_space
                                            self.string_data.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.bundle_event_type.is_set or
                                        self.time_stamp.is_set or
                                        (self.data is not None and self.data.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.bundle_event_type.yfilter != YFilter.not_set or
                                        self.time_stamp.yfilter != YFilter.not_set or
                                        (self.data is not None and self.data.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "bundle-evt-info" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.bundle_event_type.is_set or self.bundle_event_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.bundle_event_type.get_name_leafdata())
                                    if (self.time_stamp.is_set or self.time_stamp.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.time_stamp.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "data"):
                                        if (self.data is None):
                                            self.data = BundleInformation.Events.EventsBundles.EventsBundle.EventsBundleChildrenMembers.EventsBundleChildrenMember.Items.BundleEvtInfo.Data()
                                            self.data.parent = self
                                            self._children_name_map["data"] = "data"
                                        return self.data

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "data" or name == "bundle-event-type" or name == "time-stamp"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "bundle-event-type"):
                                        self.bundle_event_type = value
                                        self.bundle_event_type.value_namespace = name_space
                                        self.bundle_event_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "time-stamp"):
                                        self.time_stamp = value
                                        self.time_stamp.value_namespace = name_space
                                        self.time_stamp.value_namespace_prefix = name_space_prefix


                            class RgEvtInfo(Entity):
                                """
                                Event information for an RG
                                
                                .. attribute:: data
                                
                                	Additional data for the event
                                	**type**\:   :py:class:`Data <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.Events.EventsBundles.EventsBundle.EventsBundleChildrenMembers.EventsBundleChildrenMember.Items.RgEvtInfo.Data>`
                                
                                .. attribute:: rg_event_type
                                
                                	Type of event for RG
                                	**type**\:   :py:class:`BmdBagEventRgItem <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmdBagEventRgItem>`
                                
                                .. attribute:: time_stamp
                                
                                	Time stamp of the event
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'bundlemgr-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(BundleInformation.Events.EventsBundles.EventsBundle.EventsBundleChildrenMembers.EventsBundleChildrenMember.Items.RgEvtInfo, self).__init__()

                                    self.yang_name = "rg-evt-info"
                                    self.yang_parent_name = "items"

                                    self.rg_event_type = YLeaf(YType.enumeration, "rg-event-type")

                                    self.time_stamp = YLeaf(YType.uint64, "time-stamp")

                                    self.data = BundleInformation.Events.EventsBundles.EventsBundle.EventsBundleChildrenMembers.EventsBundleChildrenMember.Items.RgEvtInfo.Data()
                                    self.data.parent = self
                                    self._children_name_map["data"] = "data"
                                    self._children_yang_names.add("data")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("rg_event_type",
                                                    "time_stamp") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(BundleInformation.Events.EventsBundles.EventsBundle.EventsBundleChildrenMembers.EventsBundleChildrenMember.Items.RgEvtInfo, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(BundleInformation.Events.EventsBundles.EventsBundle.EventsBundleChildrenMembers.EventsBundleChildrenMember.Items.RgEvtInfo, self).__setattr__(name, value)


                                class Data(Entity):
                                    """
                                    Additional data for the event
                                    
                                    .. attribute:: data_type
                                    
                                    	DataType
                                    	**type**\:   :py:class:`BmdBagEventData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmdBagEventData>`
                                    
                                    .. attribute:: error
                                    
                                    	Error
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: no_data
                                    
                                    	NoData
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: string_data
                                    
                                    	StringData
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'bundlemgr-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(BundleInformation.Events.EventsBundles.EventsBundle.EventsBundleChildrenMembers.EventsBundleChildrenMember.Items.RgEvtInfo.Data, self).__init__()

                                        self.yang_name = "data"
                                        self.yang_parent_name = "rg-evt-info"

                                        self.data_type = YLeaf(YType.enumeration, "data-type")

                                        self.error = YLeaf(YType.uint32, "error")

                                        self.no_data = YLeaf(YType.uint8, "no-data")

                                        self.string_data = YLeaf(YType.str, "string-data")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data_type",
                                                        "error",
                                                        "no_data",
                                                        "string_data") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(BundleInformation.Events.EventsBundles.EventsBundle.EventsBundleChildrenMembers.EventsBundleChildrenMember.Items.RgEvtInfo.Data, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(BundleInformation.Events.EventsBundles.EventsBundle.EventsBundleChildrenMembers.EventsBundleChildrenMember.Items.RgEvtInfo.Data, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data_type.is_set or
                                            self.error.is_set or
                                            self.no_data.is_set or
                                            self.string_data.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data_type.yfilter != YFilter.not_set or
                                            self.error.yfilter != YFilter.not_set or
                                            self.no_data.yfilter != YFilter.not_set or
                                            self.string_data.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "data" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data_type.is_set or self.data_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data_type.get_name_leafdata())
                                        if (self.error.is_set or self.error.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.error.get_name_leafdata())
                                        if (self.no_data.is_set or self.no_data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.no_data.get_name_leafdata())
                                        if (self.string_data.is_set or self.string_data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.string_data.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data-type" or name == "error" or name == "no-data" or name == "string-data"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data-type"):
                                            self.data_type = value
                                            self.data_type.value_namespace = name_space
                                            self.data_type.value_namespace_prefix = name_space_prefix
                                        if(value_path == "error"):
                                            self.error = value
                                            self.error.value_namespace = name_space
                                            self.error.value_namespace_prefix = name_space_prefix
                                        if(value_path == "no-data"):
                                            self.no_data = value
                                            self.no_data.value_namespace = name_space
                                            self.no_data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "string-data"):
                                            self.string_data = value
                                            self.string_data.value_namespace = name_space
                                            self.string_data.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.rg_event_type.is_set or
                                        self.time_stamp.is_set or
                                        (self.data is not None and self.data.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.rg_event_type.yfilter != YFilter.not_set or
                                        self.time_stamp.yfilter != YFilter.not_set or
                                        (self.data is not None and self.data.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "rg-evt-info" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.rg_event_type.is_set or self.rg_event_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.rg_event_type.get_name_leafdata())
                                    if (self.time_stamp.is_set or self.time_stamp.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.time_stamp.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "data"):
                                        if (self.data is None):
                                            self.data = BundleInformation.Events.EventsBundles.EventsBundle.EventsBundleChildrenMembers.EventsBundleChildrenMember.Items.RgEvtInfo.Data()
                                            self.data.parent = self
                                            self._children_name_map["data"] = "data"
                                        return self.data

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "data" or name == "rg-event-type" or name == "time-stamp"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "rg-event-type"):
                                        self.rg_event_type = value
                                        self.rg_event_type.value_namespace = name_space
                                        self.rg_event_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "time-stamp"):
                                        self.time_stamp = value
                                        self.time_stamp.value_namespace = name_space
                                        self.time_stamp.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.event_type.is_set or
                                    (self.bundle_evt_info is not None and self.bundle_evt_info.has_data()) or
                                    (self.member_evt_info is not None and self.member_evt_info.has_data()) or
                                    (self.rg_evt_info is not None and self.rg_evt_info.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.event_type.yfilter != YFilter.not_set or
                                    (self.bundle_evt_info is not None and self.bundle_evt_info.has_operation()) or
                                    (self.member_evt_info is not None and self.member_evt_info.has_operation()) or
                                    (self.rg_evt_info is not None and self.rg_evt_info.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "items" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.event_type.is_set or self.event_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.event_type.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "bundle-evt-info"):
                                    if (self.bundle_evt_info is None):
                                        self.bundle_evt_info = BundleInformation.Events.EventsBundles.EventsBundle.EventsBundleChildrenMembers.EventsBundleChildrenMember.Items.BundleEvtInfo()
                                        self.bundle_evt_info.parent = self
                                        self._children_name_map["bundle_evt_info"] = "bundle-evt-info"
                                    return self.bundle_evt_info

                                if (child_yang_name == "member-evt-info"):
                                    if (self.member_evt_info is None):
                                        self.member_evt_info = BundleInformation.Events.EventsBundles.EventsBundle.EventsBundleChildrenMembers.EventsBundleChildrenMember.Items.MemberEvtInfo()
                                        self.member_evt_info.parent = self
                                        self._children_name_map["member_evt_info"] = "member-evt-info"
                                    return self.member_evt_info

                                if (child_yang_name == "rg-evt-info"):
                                    if (self.rg_evt_info is None):
                                        self.rg_evt_info = BundleInformation.Events.EventsBundles.EventsBundle.EventsBundleChildrenMembers.EventsBundleChildrenMember.Items.RgEvtInfo()
                                        self.rg_evt_info.parent = self
                                        self._children_name_map["rg_evt_info"] = "rg-evt-info"
                                    return self.rg_evt_info

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "bundle-evt-info" or name == "member-evt-info" or name == "rg-evt-info" or name == "event-type"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "event-type"):
                                    self.event_type = value
                                    self.event_type.value_namespace = name_space
                                    self.event_type.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.items:
                                if (c.has_data()):
                                    return True
                            return (
                                self.member_interface.is_set or
                                self.item_name.is_set)

                        def has_operation(self):
                            for c in self.items:
                                if (c.has_operation()):
                                    return True
                            return (
                                self.yfilter != YFilter.not_set or
                                self.member_interface.yfilter != YFilter.not_set or
                                self.item_name.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "events-bundle-children-member" + "[member-interface='" + self.member_interface.get() + "']" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.member_interface.is_set or self.member_interface.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.member_interface.get_name_leafdata())
                            if (self.item_name.is_set or self.item_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.item_name.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "items"):
                                for c in self.items:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = BundleInformation.Events.EventsBundles.EventsBundle.EventsBundleChildrenMembers.EventsBundleChildrenMember.Items()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.items.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "items" or name == "member-interface" or name == "item-name"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "member-interface"):
                                self.member_interface = value
                                self.member_interface.value_namespace = name_space
                                self.member_interface.value_namespace_prefix = name_space_prefix
                            if(value_path == "item-name"):
                                self.item_name = value
                                self.item_name.value_namespace = name_space
                                self.item_name.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.events_bundle_children_member:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.events_bundle_children_member:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "events-bundle-children-members" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "events-bundle-children-member"):
                            for c in self.events_bundle_children_member:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = BundleInformation.Events.EventsBundles.EventsBundle.EventsBundleChildrenMembers.EventsBundleChildrenMember()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.events_bundle_children_member.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "events-bundle-children-member"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass

                def has_data(self):
                    return (
                        self.bundle_interface.is_set or
                        (self.events_bundle_ancestor is not None and self.events_bundle_ancestor.has_data()) or
                        (self.events_bundle_children_members is not None and self.events_bundle_children_members.has_data()) or
                        (self.events_bundle_descendant is not None and self.events_bundle_descendant.has_data()) or
                        (self.events_bundle_item is not None and self.events_bundle_item.has_data()))

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.bundle_interface.yfilter != YFilter.not_set or
                        (self.events_bundle_ancestor is not None and self.events_bundle_ancestor.has_operation()) or
                        (self.events_bundle_children_members is not None and self.events_bundle_children_members.has_operation()) or
                        (self.events_bundle_descendant is not None and self.events_bundle_descendant.has_operation()) or
                        (self.events_bundle_item is not None and self.events_bundle_item.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "events-bundle" + "[bundle-interface='" + self.bundle_interface.get() + "']" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-bundlemgr-oper:bundle-information/events/events-bundles/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.bundle_interface.is_set or self.bundle_interface.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.bundle_interface.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "events-bundle-ancestor"):
                        if (self.events_bundle_ancestor is None):
                            self.events_bundle_ancestor = BundleInformation.Events.EventsBundles.EventsBundle.EventsBundleAncestor()
                            self.events_bundle_ancestor.parent = self
                            self._children_name_map["events_bundle_ancestor"] = "events-bundle-ancestor"
                        return self.events_bundle_ancestor

                    if (child_yang_name == "events-bundle-children-members"):
                        if (self.events_bundle_children_members is None):
                            self.events_bundle_children_members = BundleInformation.Events.EventsBundles.EventsBundle.EventsBundleChildrenMembers()
                            self.events_bundle_children_members.parent = self
                            self._children_name_map["events_bundle_children_members"] = "events-bundle-children-members"
                        return self.events_bundle_children_members

                    if (child_yang_name == "events-bundle-descendant"):
                        if (self.events_bundle_descendant is None):
                            self.events_bundle_descendant = BundleInformation.Events.EventsBundles.EventsBundle.EventsBundleDescendant()
                            self.events_bundle_descendant.parent = self
                            self._children_name_map["events_bundle_descendant"] = "events-bundle-descendant"
                        return self.events_bundle_descendant

                    if (child_yang_name == "events-bundle-item"):
                        if (self.events_bundle_item is None):
                            self.events_bundle_item = BundleInformation.Events.EventsBundles.EventsBundle.EventsBundleItem()
                            self.events_bundle_item.parent = self
                            self._children_name_map["events_bundle_item"] = "events-bundle-item"
                        return self.events_bundle_item

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "events-bundle-ancestor" or name == "events-bundle-children-members" or name == "events-bundle-descendant" or name == "events-bundle-item" or name == "bundle-interface"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "bundle-interface"):
                        self.bundle_interface = value
                        self.bundle_interface.value_namespace = name_space
                        self.bundle_interface.value_namespace_prefix = name_space_prefix

            def has_data(self):
                for c in self.events_bundle:
                    if (c.has_data()):
                        return True
                return False

            def has_operation(self):
                for c in self.events_bundle:
                    if (c.has_operation()):
                        return True
                return self.yfilter != YFilter.not_set

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "events-bundles" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-bundlemgr-oper:bundle-information/events/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "events-bundle"):
                    for c in self.events_bundle:
                        segment = c.get_segment_path()
                        if (segment_path == segment):
                            return c
                    c = BundleInformation.Events.EventsBundles.EventsBundle()
                    c.parent = self
                    local_reference_key = "ydk::seg::%s" % segment_path
                    self._local_refs[local_reference_key] = c
                    self.events_bundle.append(c)
                    return c

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "events-bundle"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                pass

        def has_data(self):
            return (
                (self.events_bundles is not None and self.events_bundles.has_data()) or
                (self.events_members is not None and self.events_members.has_data()))

        def has_operation(self):
            return (
                self.yfilter != YFilter.not_set or
                (self.events_bundles is not None and self.events_bundles.has_operation()) or
                (self.events_members is not None and self.events_members.has_operation()))

        def get_segment_path(self):
            path_buffer = ""
            path_buffer = "events" + path_buffer

            return path_buffer

        def get_entity_path(self, ancestor):
            path_buffer = ""
            if (ancestor is None):
                path_buffer = "Cisco-IOS-XR-bundlemgr-oper:bundle-information/%s" % self.get_segment_path()
            else:
                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

            leaf_name_data = LeafDataList()

            entity_path = EntityPath(path_buffer, leaf_name_data)
            return entity_path

        def get_child_by_name(self, child_yang_name, segment_path):
            child = self._get_child_by_seg_name([child_yang_name, segment_path])
            if child is not None:
                return child

            if (child_yang_name == "events-bundles"):
                if (self.events_bundles is None):
                    self.events_bundles = BundleInformation.Events.EventsBundles()
                    self.events_bundles.parent = self
                    self._children_name_map["events_bundles"] = "events-bundles"
                return self.events_bundles

            if (child_yang_name == "events-members"):
                if (self.events_members is None):
                    self.events_members = BundleInformation.Events.EventsMembers()
                    self.events_members.parent = self
                    self._children_name_map["events_members"] = "events-members"
                return self.events_members

            return None

        def has_leaf_or_child_of_name(self, name):
            if(name == "events-bundles" or name == "events-members"):
                return True
            return False

        def set_value(self, value_path, value, name_space, name_space_prefix):
            pass


    class EventsBdl(Entity):
        """
        Bundle events information for bundles and
        members
        
        .. attribute:: events_bdl_bundles
        
        	Bundle interfaces with bundle events information
        	**type**\:   :py:class:`EventsBdlBundles <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.EventsBdl.EventsBdlBundles>`
        
        .. attribute:: events_bdl_iccp_groups
        
        	Bundle events for all ICCP Groups
        	**type**\:   :py:class:`EventsBdlIccpGroups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.EventsBdl.EventsBdlIccpGroups>`
        
        .. attribute:: events_bdl_members
        
        	Member interfaces with bundle events information
        	**type**\:   :py:class:`EventsBdlMembers <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.EventsBdl.EventsBdlMembers>`
        
        

        """

        _prefix = 'bundlemgr-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(BundleInformation.EventsBdl, self).__init__()

            self.yang_name = "events-bdl"
            self.yang_parent_name = "bundle-information"

            self.events_bdl_bundles = BundleInformation.EventsBdl.EventsBdlBundles()
            self.events_bdl_bundles.parent = self
            self._children_name_map["events_bdl_bundles"] = "events-bdl-bundles"
            self._children_yang_names.add("events-bdl-bundles")

            self.events_bdl_iccp_groups = BundleInformation.EventsBdl.EventsBdlIccpGroups()
            self.events_bdl_iccp_groups.parent = self
            self._children_name_map["events_bdl_iccp_groups"] = "events-bdl-iccp-groups"
            self._children_yang_names.add("events-bdl-iccp-groups")

            self.events_bdl_members = BundleInformation.EventsBdl.EventsBdlMembers()
            self.events_bdl_members.parent = self
            self._children_name_map["events_bdl_members"] = "events-bdl-members"
            self._children_yang_names.add("events-bdl-members")


        class EventsBdlMembers(Entity):
            """
            Member interfaces with bundle events
            information
            
            .. attribute:: events_bdl_member
            
            	Member interface
            	**type**\: list of    :py:class:`EventsBdlMember <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.EventsBdl.EventsBdlMembers.EventsBdlMember>`
            
            

            """

            _prefix = 'bundlemgr-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(BundleInformation.EventsBdl.EventsBdlMembers, self).__init__()

                self.yang_name = "events-bdl-members"
                self.yang_parent_name = "events-bdl"

                self.events_bdl_member = YList(self)

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in () and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(BundleInformation.EventsBdl.EventsBdlMembers, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(BundleInformation.EventsBdl.EventsBdlMembers, self).__setattr__(name, value)


            class EventsBdlMember(Entity):
                """
                Member interface
                
                .. attribute:: member_interface  <key>
                
                	Member interface
                	**type**\:  str
                
                .. attribute:: events_bdl_member_ancestor
                
                	Data for this item and its parent bundle
                	**type**\:   :py:class:`EventsBdlMemberAncestor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.EventsBdl.EventsBdlMembers.EventsBdlMember.EventsBdlMemberAncestor>`
                
                

                """

                _prefix = 'bundlemgr-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(BundleInformation.EventsBdl.EventsBdlMembers.EventsBdlMember, self).__init__()

                    self.yang_name = "events-bdl-member"
                    self.yang_parent_name = "events-bdl-members"

                    self.member_interface = YLeaf(YType.str, "member-interface")

                    self.events_bdl_member_ancestor = BundleInformation.EventsBdl.EventsBdlMembers.EventsBdlMember.EventsBdlMemberAncestor()
                    self.events_bdl_member_ancestor.parent = self
                    self._children_name_map["events_bdl_member_ancestor"] = "events-bdl-member-ancestor"
                    self._children_yang_names.add("events-bdl-member-ancestor")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("member_interface") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(BundleInformation.EventsBdl.EventsBdlMembers.EventsBdlMember, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(BundleInformation.EventsBdl.EventsBdlMembers.EventsBdlMember, self).__setattr__(name, value)


                class EventsBdlMemberAncestor(Entity):
                    """
                    Data for this item and its parent bundle
                    
                    .. attribute:: item_name
                    
                    	Name for the current item to use
                    	**type**\:  str
                    
                    .. attribute:: items
                    
                    	Event items
                    	**type**\: list of    :py:class:`Items <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.EventsBdl.EventsBdlMembers.EventsBdlMember.EventsBdlMemberAncestor.Items>`
                    
                    

                    """

                    _prefix = 'bundlemgr-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(BundleInformation.EventsBdl.EventsBdlMembers.EventsBdlMember.EventsBdlMemberAncestor, self).__init__()

                        self.yang_name = "events-bdl-member-ancestor"
                        self.yang_parent_name = "events-bdl-member"

                        self.item_name = YLeaf(YType.str, "item-name")

                        self.items = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("item_name") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(BundleInformation.EventsBdl.EventsBdlMembers.EventsBdlMember.EventsBdlMemberAncestor, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(BundleInformation.EventsBdl.EventsBdlMembers.EventsBdlMember.EventsBdlMemberAncestor, self).__setattr__(name, value)


                    class Items(Entity):
                        """
                        Event items
                        
                        .. attribute:: bundle_evt_info
                        
                        	Event information for a bundle
                        	**type**\:   :py:class:`BundleEvtInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.EventsBdl.EventsBdlMembers.EventsBdlMember.EventsBdlMemberAncestor.Items.BundleEvtInfo>`
                        
                        .. attribute:: event_type
                        
                        	EventType
                        	**type**\:   :py:class:`BmdBagTarget <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmdBagTarget>`
                        
                        .. attribute:: member_evt_info
                        
                        	Event information for a member
                        	**type**\:   :py:class:`MemberEvtInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.EventsBdl.EventsBdlMembers.EventsBdlMember.EventsBdlMemberAncestor.Items.MemberEvtInfo>`
                        
                        .. attribute:: rg_evt_info
                        
                        	Event information for an RG
                        	**type**\:   :py:class:`RgEvtInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.EventsBdl.EventsBdlMembers.EventsBdlMember.EventsBdlMemberAncestor.Items.RgEvtInfo>`
                        
                        

                        """

                        _prefix = 'bundlemgr-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(BundleInformation.EventsBdl.EventsBdlMembers.EventsBdlMember.EventsBdlMemberAncestor.Items, self).__init__()

                            self.yang_name = "items"
                            self.yang_parent_name = "events-bdl-member-ancestor"

                            self.event_type = YLeaf(YType.enumeration, "event-type")

                            self.bundle_evt_info = BundleInformation.EventsBdl.EventsBdlMembers.EventsBdlMember.EventsBdlMemberAncestor.Items.BundleEvtInfo()
                            self.bundle_evt_info.parent = self
                            self._children_name_map["bundle_evt_info"] = "bundle-evt-info"
                            self._children_yang_names.add("bundle-evt-info")

                            self.member_evt_info = BundleInformation.EventsBdl.EventsBdlMembers.EventsBdlMember.EventsBdlMemberAncestor.Items.MemberEvtInfo()
                            self.member_evt_info.parent = self
                            self._children_name_map["member_evt_info"] = "member-evt-info"
                            self._children_yang_names.add("member-evt-info")

                            self.rg_evt_info = BundleInformation.EventsBdl.EventsBdlMembers.EventsBdlMember.EventsBdlMemberAncestor.Items.RgEvtInfo()
                            self.rg_evt_info.parent = self
                            self._children_name_map["rg_evt_info"] = "rg-evt-info"
                            self._children_yang_names.add("rg-evt-info")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("event_type") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(BundleInformation.EventsBdl.EventsBdlMembers.EventsBdlMember.EventsBdlMemberAncestor.Items, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(BundleInformation.EventsBdl.EventsBdlMembers.EventsBdlMember.EventsBdlMemberAncestor.Items, self).__setattr__(name, value)


                        class MemberEvtInfo(Entity):
                            """
                            Event information for a member
                            
                            .. attribute:: data
                            
                            	Additional data for the event
                            	**type**\:   :py:class:`Data <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.EventsBdl.EventsBdlMembers.EventsBdlMember.EventsBdlMemberAncestor.Items.MemberEvtInfo.Data>`
                            
                            .. attribute:: member_event_type
                            
                            	Type of event for member
                            	**type**\:   :py:class:`BmdBagEventMbrItem <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmdBagEventMbrItem>`
                            
                            .. attribute:: time_stamp
                            
                            	Time stamp of the event
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            

                            """

                            _prefix = 'bundlemgr-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(BundleInformation.EventsBdl.EventsBdlMembers.EventsBdlMember.EventsBdlMemberAncestor.Items.MemberEvtInfo, self).__init__()

                                self.yang_name = "member-evt-info"
                                self.yang_parent_name = "items"

                                self.member_event_type = YLeaf(YType.enumeration, "member-event-type")

                                self.time_stamp = YLeaf(YType.uint64, "time-stamp")

                                self.data = BundleInformation.EventsBdl.EventsBdlMembers.EventsBdlMember.EventsBdlMemberAncestor.Items.MemberEvtInfo.Data()
                                self.data.parent = self
                                self._children_name_map["data"] = "data"
                                self._children_yang_names.add("data")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("member_event_type",
                                                "time_stamp") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(BundleInformation.EventsBdl.EventsBdlMembers.EventsBdlMember.EventsBdlMemberAncestor.Items.MemberEvtInfo, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(BundleInformation.EventsBdl.EventsBdlMembers.EventsBdlMember.EventsBdlMemberAncestor.Items.MemberEvtInfo, self).__setattr__(name, value)


                            class Data(Entity):
                                """
                                Additional data for the event
                                
                                .. attribute:: data_type
                                
                                	DataType
                                	**type**\:   :py:class:`BmdBagEventData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmdBagEventData>`
                                
                                .. attribute:: error
                                
                                	Error
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: no_data
                                
                                	NoData
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: string_data
                                
                                	StringData
                                	**type**\:  str
                                
                                

                                """

                                _prefix = 'bundlemgr-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(BundleInformation.EventsBdl.EventsBdlMembers.EventsBdlMember.EventsBdlMemberAncestor.Items.MemberEvtInfo.Data, self).__init__()

                                    self.yang_name = "data"
                                    self.yang_parent_name = "member-evt-info"

                                    self.data_type = YLeaf(YType.enumeration, "data-type")

                                    self.error = YLeaf(YType.uint32, "error")

                                    self.no_data = YLeaf(YType.uint8, "no-data")

                                    self.string_data = YLeaf(YType.str, "string-data")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("data_type",
                                                    "error",
                                                    "no_data",
                                                    "string_data") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(BundleInformation.EventsBdl.EventsBdlMembers.EventsBdlMember.EventsBdlMemberAncestor.Items.MemberEvtInfo.Data, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(BundleInformation.EventsBdl.EventsBdlMembers.EventsBdlMember.EventsBdlMemberAncestor.Items.MemberEvtInfo.Data, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.data_type.is_set or
                                        self.error.is_set or
                                        self.no_data.is_set or
                                        self.string_data.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.data_type.yfilter != YFilter.not_set or
                                        self.error.yfilter != YFilter.not_set or
                                        self.no_data.yfilter != YFilter.not_set or
                                        self.string_data.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "data" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.data_type.is_set or self.data_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.data_type.get_name_leafdata())
                                    if (self.error.is_set or self.error.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.error.get_name_leafdata())
                                    if (self.no_data.is_set or self.no_data.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.no_data.get_name_leafdata())
                                    if (self.string_data.is_set or self.string_data.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.string_data.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "data-type" or name == "error" or name == "no-data" or name == "string-data"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "data-type"):
                                        self.data_type = value
                                        self.data_type.value_namespace = name_space
                                        self.data_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "error"):
                                        self.error = value
                                        self.error.value_namespace = name_space
                                        self.error.value_namespace_prefix = name_space_prefix
                                    if(value_path == "no-data"):
                                        self.no_data = value
                                        self.no_data.value_namespace = name_space
                                        self.no_data.value_namespace_prefix = name_space_prefix
                                    if(value_path == "string-data"):
                                        self.string_data = value
                                        self.string_data.value_namespace = name_space
                                        self.string_data.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.member_event_type.is_set or
                                    self.time_stamp.is_set or
                                    (self.data is not None and self.data.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.member_event_type.yfilter != YFilter.not_set or
                                    self.time_stamp.yfilter != YFilter.not_set or
                                    (self.data is not None and self.data.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "member-evt-info" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.member_event_type.is_set or self.member_event_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.member_event_type.get_name_leafdata())
                                if (self.time_stamp.is_set or self.time_stamp.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.time_stamp.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "data"):
                                    if (self.data is None):
                                        self.data = BundleInformation.EventsBdl.EventsBdlMembers.EventsBdlMember.EventsBdlMemberAncestor.Items.MemberEvtInfo.Data()
                                        self.data.parent = self
                                        self._children_name_map["data"] = "data"
                                    return self.data

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "data" or name == "member-event-type" or name == "time-stamp"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "member-event-type"):
                                    self.member_event_type = value
                                    self.member_event_type.value_namespace = name_space
                                    self.member_event_type.value_namespace_prefix = name_space_prefix
                                if(value_path == "time-stamp"):
                                    self.time_stamp = value
                                    self.time_stamp.value_namespace = name_space
                                    self.time_stamp.value_namespace_prefix = name_space_prefix


                        class BundleEvtInfo(Entity):
                            """
                            Event information for a bundle
                            
                            .. attribute:: bundle_event_type
                            
                            	Type of event for bundle
                            	**type**\:   :py:class:`BmdBagEventBdlItem <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmdBagEventBdlItem>`
                            
                            .. attribute:: data
                            
                            	Additional data for the event
                            	**type**\:   :py:class:`Data <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.EventsBdl.EventsBdlMembers.EventsBdlMember.EventsBdlMemberAncestor.Items.BundleEvtInfo.Data>`
                            
                            .. attribute:: time_stamp
                            
                            	Time stamp of the event
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            

                            """

                            _prefix = 'bundlemgr-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(BundleInformation.EventsBdl.EventsBdlMembers.EventsBdlMember.EventsBdlMemberAncestor.Items.BundleEvtInfo, self).__init__()

                                self.yang_name = "bundle-evt-info"
                                self.yang_parent_name = "items"

                                self.bundle_event_type = YLeaf(YType.enumeration, "bundle-event-type")

                                self.time_stamp = YLeaf(YType.uint64, "time-stamp")

                                self.data = BundleInformation.EventsBdl.EventsBdlMembers.EventsBdlMember.EventsBdlMemberAncestor.Items.BundleEvtInfo.Data()
                                self.data.parent = self
                                self._children_name_map["data"] = "data"
                                self._children_yang_names.add("data")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("bundle_event_type",
                                                "time_stamp") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(BundleInformation.EventsBdl.EventsBdlMembers.EventsBdlMember.EventsBdlMemberAncestor.Items.BundleEvtInfo, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(BundleInformation.EventsBdl.EventsBdlMembers.EventsBdlMember.EventsBdlMemberAncestor.Items.BundleEvtInfo, self).__setattr__(name, value)


                            class Data(Entity):
                                """
                                Additional data for the event
                                
                                .. attribute:: data_type
                                
                                	DataType
                                	**type**\:   :py:class:`BmdBagEventData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmdBagEventData>`
                                
                                .. attribute:: error
                                
                                	Error
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: no_data
                                
                                	NoData
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: string_data
                                
                                	StringData
                                	**type**\:  str
                                
                                

                                """

                                _prefix = 'bundlemgr-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(BundleInformation.EventsBdl.EventsBdlMembers.EventsBdlMember.EventsBdlMemberAncestor.Items.BundleEvtInfo.Data, self).__init__()

                                    self.yang_name = "data"
                                    self.yang_parent_name = "bundle-evt-info"

                                    self.data_type = YLeaf(YType.enumeration, "data-type")

                                    self.error = YLeaf(YType.uint32, "error")

                                    self.no_data = YLeaf(YType.uint8, "no-data")

                                    self.string_data = YLeaf(YType.str, "string-data")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("data_type",
                                                    "error",
                                                    "no_data",
                                                    "string_data") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(BundleInformation.EventsBdl.EventsBdlMembers.EventsBdlMember.EventsBdlMemberAncestor.Items.BundleEvtInfo.Data, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(BundleInformation.EventsBdl.EventsBdlMembers.EventsBdlMember.EventsBdlMemberAncestor.Items.BundleEvtInfo.Data, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.data_type.is_set or
                                        self.error.is_set or
                                        self.no_data.is_set or
                                        self.string_data.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.data_type.yfilter != YFilter.not_set or
                                        self.error.yfilter != YFilter.not_set or
                                        self.no_data.yfilter != YFilter.not_set or
                                        self.string_data.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "data" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.data_type.is_set or self.data_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.data_type.get_name_leafdata())
                                    if (self.error.is_set or self.error.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.error.get_name_leafdata())
                                    if (self.no_data.is_set or self.no_data.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.no_data.get_name_leafdata())
                                    if (self.string_data.is_set or self.string_data.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.string_data.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "data-type" or name == "error" or name == "no-data" or name == "string-data"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "data-type"):
                                        self.data_type = value
                                        self.data_type.value_namespace = name_space
                                        self.data_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "error"):
                                        self.error = value
                                        self.error.value_namespace = name_space
                                        self.error.value_namespace_prefix = name_space_prefix
                                    if(value_path == "no-data"):
                                        self.no_data = value
                                        self.no_data.value_namespace = name_space
                                        self.no_data.value_namespace_prefix = name_space_prefix
                                    if(value_path == "string-data"):
                                        self.string_data = value
                                        self.string_data.value_namespace = name_space
                                        self.string_data.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.bundle_event_type.is_set or
                                    self.time_stamp.is_set or
                                    (self.data is not None and self.data.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.bundle_event_type.yfilter != YFilter.not_set or
                                    self.time_stamp.yfilter != YFilter.not_set or
                                    (self.data is not None and self.data.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "bundle-evt-info" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.bundle_event_type.is_set or self.bundle_event_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.bundle_event_type.get_name_leafdata())
                                if (self.time_stamp.is_set or self.time_stamp.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.time_stamp.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "data"):
                                    if (self.data is None):
                                        self.data = BundleInformation.EventsBdl.EventsBdlMembers.EventsBdlMember.EventsBdlMemberAncestor.Items.BundleEvtInfo.Data()
                                        self.data.parent = self
                                        self._children_name_map["data"] = "data"
                                    return self.data

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "data" or name == "bundle-event-type" or name == "time-stamp"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "bundle-event-type"):
                                    self.bundle_event_type = value
                                    self.bundle_event_type.value_namespace = name_space
                                    self.bundle_event_type.value_namespace_prefix = name_space_prefix
                                if(value_path == "time-stamp"):
                                    self.time_stamp = value
                                    self.time_stamp.value_namespace = name_space
                                    self.time_stamp.value_namespace_prefix = name_space_prefix


                        class RgEvtInfo(Entity):
                            """
                            Event information for an RG
                            
                            .. attribute:: data
                            
                            	Additional data for the event
                            	**type**\:   :py:class:`Data <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.EventsBdl.EventsBdlMembers.EventsBdlMember.EventsBdlMemberAncestor.Items.RgEvtInfo.Data>`
                            
                            .. attribute:: rg_event_type
                            
                            	Type of event for RG
                            	**type**\:   :py:class:`BmdBagEventRgItem <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmdBagEventRgItem>`
                            
                            .. attribute:: time_stamp
                            
                            	Time stamp of the event
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            

                            """

                            _prefix = 'bundlemgr-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(BundleInformation.EventsBdl.EventsBdlMembers.EventsBdlMember.EventsBdlMemberAncestor.Items.RgEvtInfo, self).__init__()

                                self.yang_name = "rg-evt-info"
                                self.yang_parent_name = "items"

                                self.rg_event_type = YLeaf(YType.enumeration, "rg-event-type")

                                self.time_stamp = YLeaf(YType.uint64, "time-stamp")

                                self.data = BundleInformation.EventsBdl.EventsBdlMembers.EventsBdlMember.EventsBdlMemberAncestor.Items.RgEvtInfo.Data()
                                self.data.parent = self
                                self._children_name_map["data"] = "data"
                                self._children_yang_names.add("data")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("rg_event_type",
                                                "time_stamp") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(BundleInformation.EventsBdl.EventsBdlMembers.EventsBdlMember.EventsBdlMemberAncestor.Items.RgEvtInfo, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(BundleInformation.EventsBdl.EventsBdlMembers.EventsBdlMember.EventsBdlMemberAncestor.Items.RgEvtInfo, self).__setattr__(name, value)


                            class Data(Entity):
                                """
                                Additional data for the event
                                
                                .. attribute:: data_type
                                
                                	DataType
                                	**type**\:   :py:class:`BmdBagEventData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmdBagEventData>`
                                
                                .. attribute:: error
                                
                                	Error
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: no_data
                                
                                	NoData
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: string_data
                                
                                	StringData
                                	**type**\:  str
                                
                                

                                """

                                _prefix = 'bundlemgr-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(BundleInformation.EventsBdl.EventsBdlMembers.EventsBdlMember.EventsBdlMemberAncestor.Items.RgEvtInfo.Data, self).__init__()

                                    self.yang_name = "data"
                                    self.yang_parent_name = "rg-evt-info"

                                    self.data_type = YLeaf(YType.enumeration, "data-type")

                                    self.error = YLeaf(YType.uint32, "error")

                                    self.no_data = YLeaf(YType.uint8, "no-data")

                                    self.string_data = YLeaf(YType.str, "string-data")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("data_type",
                                                    "error",
                                                    "no_data",
                                                    "string_data") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(BundleInformation.EventsBdl.EventsBdlMembers.EventsBdlMember.EventsBdlMemberAncestor.Items.RgEvtInfo.Data, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(BundleInformation.EventsBdl.EventsBdlMembers.EventsBdlMember.EventsBdlMemberAncestor.Items.RgEvtInfo.Data, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.data_type.is_set or
                                        self.error.is_set or
                                        self.no_data.is_set or
                                        self.string_data.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.data_type.yfilter != YFilter.not_set or
                                        self.error.yfilter != YFilter.not_set or
                                        self.no_data.yfilter != YFilter.not_set or
                                        self.string_data.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "data" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.data_type.is_set or self.data_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.data_type.get_name_leafdata())
                                    if (self.error.is_set or self.error.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.error.get_name_leafdata())
                                    if (self.no_data.is_set or self.no_data.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.no_data.get_name_leafdata())
                                    if (self.string_data.is_set or self.string_data.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.string_data.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "data-type" or name == "error" or name == "no-data" or name == "string-data"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "data-type"):
                                        self.data_type = value
                                        self.data_type.value_namespace = name_space
                                        self.data_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "error"):
                                        self.error = value
                                        self.error.value_namespace = name_space
                                        self.error.value_namespace_prefix = name_space_prefix
                                    if(value_path == "no-data"):
                                        self.no_data = value
                                        self.no_data.value_namespace = name_space
                                        self.no_data.value_namespace_prefix = name_space_prefix
                                    if(value_path == "string-data"):
                                        self.string_data = value
                                        self.string_data.value_namespace = name_space
                                        self.string_data.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.rg_event_type.is_set or
                                    self.time_stamp.is_set or
                                    (self.data is not None and self.data.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.rg_event_type.yfilter != YFilter.not_set or
                                    self.time_stamp.yfilter != YFilter.not_set or
                                    (self.data is not None and self.data.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "rg-evt-info" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.rg_event_type.is_set or self.rg_event_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.rg_event_type.get_name_leafdata())
                                if (self.time_stamp.is_set or self.time_stamp.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.time_stamp.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "data"):
                                    if (self.data is None):
                                        self.data = BundleInformation.EventsBdl.EventsBdlMembers.EventsBdlMember.EventsBdlMemberAncestor.Items.RgEvtInfo.Data()
                                        self.data.parent = self
                                        self._children_name_map["data"] = "data"
                                    return self.data

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "data" or name == "rg-event-type" or name == "time-stamp"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "rg-event-type"):
                                    self.rg_event_type = value
                                    self.rg_event_type.value_namespace = name_space
                                    self.rg_event_type.value_namespace_prefix = name_space_prefix
                                if(value_path == "time-stamp"):
                                    self.time_stamp = value
                                    self.time_stamp.value_namespace = name_space
                                    self.time_stamp.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.event_type.is_set or
                                (self.bundle_evt_info is not None and self.bundle_evt_info.has_data()) or
                                (self.member_evt_info is not None and self.member_evt_info.has_data()) or
                                (self.rg_evt_info is not None and self.rg_evt_info.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.event_type.yfilter != YFilter.not_set or
                                (self.bundle_evt_info is not None and self.bundle_evt_info.has_operation()) or
                                (self.member_evt_info is not None and self.member_evt_info.has_operation()) or
                                (self.rg_evt_info is not None and self.rg_evt_info.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "items" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.event_type.is_set or self.event_type.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.event_type.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "bundle-evt-info"):
                                if (self.bundle_evt_info is None):
                                    self.bundle_evt_info = BundleInformation.EventsBdl.EventsBdlMembers.EventsBdlMember.EventsBdlMemberAncestor.Items.BundleEvtInfo()
                                    self.bundle_evt_info.parent = self
                                    self._children_name_map["bundle_evt_info"] = "bundle-evt-info"
                                return self.bundle_evt_info

                            if (child_yang_name == "member-evt-info"):
                                if (self.member_evt_info is None):
                                    self.member_evt_info = BundleInformation.EventsBdl.EventsBdlMembers.EventsBdlMember.EventsBdlMemberAncestor.Items.MemberEvtInfo()
                                    self.member_evt_info.parent = self
                                    self._children_name_map["member_evt_info"] = "member-evt-info"
                                return self.member_evt_info

                            if (child_yang_name == "rg-evt-info"):
                                if (self.rg_evt_info is None):
                                    self.rg_evt_info = BundleInformation.EventsBdl.EventsBdlMembers.EventsBdlMember.EventsBdlMemberAncestor.Items.RgEvtInfo()
                                    self.rg_evt_info.parent = self
                                    self._children_name_map["rg_evt_info"] = "rg-evt-info"
                                return self.rg_evt_info

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "bundle-evt-info" or name == "member-evt-info" or name == "rg-evt-info" or name == "event-type"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "event-type"):
                                self.event_type = value
                                self.event_type.value_namespace = name_space
                                self.event_type.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.items:
                            if (c.has_data()):
                                return True
                        return self.item_name.is_set

                    def has_operation(self):
                        for c in self.items:
                            if (c.has_operation()):
                                return True
                        return (
                            self.yfilter != YFilter.not_set or
                            self.item_name.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "events-bdl-member-ancestor" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.item_name.is_set or self.item_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.item_name.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "items"):
                            for c in self.items:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = BundleInformation.EventsBdl.EventsBdlMembers.EventsBdlMember.EventsBdlMemberAncestor.Items()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.items.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "items" or name == "item-name"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "item-name"):
                            self.item_name = value
                            self.item_name.value_namespace = name_space
                            self.item_name.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    return (
                        self.member_interface.is_set or
                        (self.events_bdl_member_ancestor is not None and self.events_bdl_member_ancestor.has_data()))

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.member_interface.yfilter != YFilter.not_set or
                        (self.events_bdl_member_ancestor is not None and self.events_bdl_member_ancestor.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "events-bdl-member" + "[member-interface='" + self.member_interface.get() + "']" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-bundlemgr-oper:bundle-information/events-bdl/events-bdl-members/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.member_interface.is_set or self.member_interface.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.member_interface.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "events-bdl-member-ancestor"):
                        if (self.events_bdl_member_ancestor is None):
                            self.events_bdl_member_ancestor = BundleInformation.EventsBdl.EventsBdlMembers.EventsBdlMember.EventsBdlMemberAncestor()
                            self.events_bdl_member_ancestor.parent = self
                            self._children_name_map["events_bdl_member_ancestor"] = "events-bdl-member-ancestor"
                        return self.events_bdl_member_ancestor

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "events-bdl-member-ancestor" or name == "member-interface"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "member-interface"):
                        self.member_interface = value
                        self.member_interface.value_namespace = name_space
                        self.member_interface.value_namespace_prefix = name_space_prefix

            def has_data(self):
                for c in self.events_bdl_member:
                    if (c.has_data()):
                        return True
                return False

            def has_operation(self):
                for c in self.events_bdl_member:
                    if (c.has_operation()):
                        return True
                return self.yfilter != YFilter.not_set

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "events-bdl-members" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-bundlemgr-oper:bundle-information/events-bdl/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "events-bdl-member"):
                    for c in self.events_bdl_member:
                        segment = c.get_segment_path()
                        if (segment_path == segment):
                            return c
                    c = BundleInformation.EventsBdl.EventsBdlMembers.EventsBdlMember()
                    c.parent = self
                    local_reference_key = "ydk::seg::%s" % segment_path
                    self._local_refs[local_reference_key] = c
                    self.events_bdl_member.append(c)
                    return c

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "events-bdl-member"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                pass


        class EventsBdlBundles(Entity):
            """
            Bundle interfaces with bundle events
            information
            
            .. attribute:: events_bdl_bundle
            
            	Bundle interface
            	**type**\: list of    :py:class:`EventsBdlBundle <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.EventsBdl.EventsBdlBundles.EventsBdlBundle>`
            
            

            """

            _prefix = 'bundlemgr-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(BundleInformation.EventsBdl.EventsBdlBundles, self).__init__()

                self.yang_name = "events-bdl-bundles"
                self.yang_parent_name = "events-bdl"

                self.events_bdl_bundle = YList(self)

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in () and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(BundleInformation.EventsBdl.EventsBdlBundles, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(BundleInformation.EventsBdl.EventsBdlBundles, self).__setattr__(name, value)


            class EventsBdlBundle(Entity):
                """
                Bundle interface
                
                .. attribute:: bundle_interface  <key>
                
                	Bundle interface
                	**type**\:  str
                
                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                
                .. attribute:: events_bdl_bundle_item
                
                	Data for this item
                	**type**\:   :py:class:`EventsBdlBundleItem <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.EventsBdl.EventsBdlBundles.EventsBdlBundle.EventsBdlBundleItem>`
                
                

                """

                _prefix = 'bundlemgr-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(BundleInformation.EventsBdl.EventsBdlBundles.EventsBdlBundle, self).__init__()

                    self.yang_name = "events-bdl-bundle"
                    self.yang_parent_name = "events-bdl-bundles"

                    self.bundle_interface = YLeaf(YType.str, "bundle-interface")

                    self.events_bdl_bundle_item = BundleInformation.EventsBdl.EventsBdlBundles.EventsBdlBundle.EventsBdlBundleItem()
                    self.events_bdl_bundle_item.parent = self
                    self._children_name_map["events_bdl_bundle_item"] = "events-bdl-bundle-item"
                    self._children_yang_names.add("events-bdl-bundle-item")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("bundle_interface") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(BundleInformation.EventsBdl.EventsBdlBundles.EventsBdlBundle, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(BundleInformation.EventsBdl.EventsBdlBundles.EventsBdlBundle, self).__setattr__(name, value)


                class EventsBdlBundleItem(Entity):
                    """
                    Data for this item
                    
                    .. attribute:: item_name
                    
                    	Name for the current item to use
                    	**type**\:  str
                    
                    .. attribute:: items
                    
                    	Event items
                    	**type**\: list of    :py:class:`Items <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.EventsBdl.EventsBdlBundles.EventsBdlBundle.EventsBdlBundleItem.Items>`
                    
                    

                    """

                    _prefix = 'bundlemgr-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(BundleInformation.EventsBdl.EventsBdlBundles.EventsBdlBundle.EventsBdlBundleItem, self).__init__()

                        self.yang_name = "events-bdl-bundle-item"
                        self.yang_parent_name = "events-bdl-bundle"

                        self.item_name = YLeaf(YType.str, "item-name")

                        self.items = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("item_name") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(BundleInformation.EventsBdl.EventsBdlBundles.EventsBdlBundle.EventsBdlBundleItem, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(BundleInformation.EventsBdl.EventsBdlBundles.EventsBdlBundle.EventsBdlBundleItem, self).__setattr__(name, value)


                    class Items(Entity):
                        """
                        Event items
                        
                        .. attribute:: bundle_evt_info
                        
                        	Event information for a bundle
                        	**type**\:   :py:class:`BundleEvtInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.EventsBdl.EventsBdlBundles.EventsBdlBundle.EventsBdlBundleItem.Items.BundleEvtInfo>`
                        
                        .. attribute:: event_type
                        
                        	EventType
                        	**type**\:   :py:class:`BmdBagTarget <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmdBagTarget>`
                        
                        .. attribute:: member_evt_info
                        
                        	Event information for a member
                        	**type**\:   :py:class:`MemberEvtInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.EventsBdl.EventsBdlBundles.EventsBdlBundle.EventsBdlBundleItem.Items.MemberEvtInfo>`
                        
                        .. attribute:: rg_evt_info
                        
                        	Event information for an RG
                        	**type**\:   :py:class:`RgEvtInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.EventsBdl.EventsBdlBundles.EventsBdlBundle.EventsBdlBundleItem.Items.RgEvtInfo>`
                        
                        

                        """

                        _prefix = 'bundlemgr-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(BundleInformation.EventsBdl.EventsBdlBundles.EventsBdlBundle.EventsBdlBundleItem.Items, self).__init__()

                            self.yang_name = "items"
                            self.yang_parent_name = "events-bdl-bundle-item"

                            self.event_type = YLeaf(YType.enumeration, "event-type")

                            self.bundle_evt_info = BundleInformation.EventsBdl.EventsBdlBundles.EventsBdlBundle.EventsBdlBundleItem.Items.BundleEvtInfo()
                            self.bundle_evt_info.parent = self
                            self._children_name_map["bundle_evt_info"] = "bundle-evt-info"
                            self._children_yang_names.add("bundle-evt-info")

                            self.member_evt_info = BundleInformation.EventsBdl.EventsBdlBundles.EventsBdlBundle.EventsBdlBundleItem.Items.MemberEvtInfo()
                            self.member_evt_info.parent = self
                            self._children_name_map["member_evt_info"] = "member-evt-info"
                            self._children_yang_names.add("member-evt-info")

                            self.rg_evt_info = BundleInformation.EventsBdl.EventsBdlBundles.EventsBdlBundle.EventsBdlBundleItem.Items.RgEvtInfo()
                            self.rg_evt_info.parent = self
                            self._children_name_map["rg_evt_info"] = "rg-evt-info"
                            self._children_yang_names.add("rg-evt-info")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("event_type") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(BundleInformation.EventsBdl.EventsBdlBundles.EventsBdlBundle.EventsBdlBundleItem.Items, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(BundleInformation.EventsBdl.EventsBdlBundles.EventsBdlBundle.EventsBdlBundleItem.Items, self).__setattr__(name, value)


                        class MemberEvtInfo(Entity):
                            """
                            Event information for a member
                            
                            .. attribute:: data
                            
                            	Additional data for the event
                            	**type**\:   :py:class:`Data <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.EventsBdl.EventsBdlBundles.EventsBdlBundle.EventsBdlBundleItem.Items.MemberEvtInfo.Data>`
                            
                            .. attribute:: member_event_type
                            
                            	Type of event for member
                            	**type**\:   :py:class:`BmdBagEventMbrItem <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmdBagEventMbrItem>`
                            
                            .. attribute:: time_stamp
                            
                            	Time stamp of the event
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            

                            """

                            _prefix = 'bundlemgr-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(BundleInformation.EventsBdl.EventsBdlBundles.EventsBdlBundle.EventsBdlBundleItem.Items.MemberEvtInfo, self).__init__()

                                self.yang_name = "member-evt-info"
                                self.yang_parent_name = "items"

                                self.member_event_type = YLeaf(YType.enumeration, "member-event-type")

                                self.time_stamp = YLeaf(YType.uint64, "time-stamp")

                                self.data = BundleInformation.EventsBdl.EventsBdlBundles.EventsBdlBundle.EventsBdlBundleItem.Items.MemberEvtInfo.Data()
                                self.data.parent = self
                                self._children_name_map["data"] = "data"
                                self._children_yang_names.add("data")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("member_event_type",
                                                "time_stamp") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(BundleInformation.EventsBdl.EventsBdlBundles.EventsBdlBundle.EventsBdlBundleItem.Items.MemberEvtInfo, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(BundleInformation.EventsBdl.EventsBdlBundles.EventsBdlBundle.EventsBdlBundleItem.Items.MemberEvtInfo, self).__setattr__(name, value)


                            class Data(Entity):
                                """
                                Additional data for the event
                                
                                .. attribute:: data_type
                                
                                	DataType
                                	**type**\:   :py:class:`BmdBagEventData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmdBagEventData>`
                                
                                .. attribute:: error
                                
                                	Error
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: no_data
                                
                                	NoData
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: string_data
                                
                                	StringData
                                	**type**\:  str
                                
                                

                                """

                                _prefix = 'bundlemgr-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(BundleInformation.EventsBdl.EventsBdlBundles.EventsBdlBundle.EventsBdlBundleItem.Items.MemberEvtInfo.Data, self).__init__()

                                    self.yang_name = "data"
                                    self.yang_parent_name = "member-evt-info"

                                    self.data_type = YLeaf(YType.enumeration, "data-type")

                                    self.error = YLeaf(YType.uint32, "error")

                                    self.no_data = YLeaf(YType.uint8, "no-data")

                                    self.string_data = YLeaf(YType.str, "string-data")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("data_type",
                                                    "error",
                                                    "no_data",
                                                    "string_data") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(BundleInformation.EventsBdl.EventsBdlBundles.EventsBdlBundle.EventsBdlBundleItem.Items.MemberEvtInfo.Data, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(BundleInformation.EventsBdl.EventsBdlBundles.EventsBdlBundle.EventsBdlBundleItem.Items.MemberEvtInfo.Data, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.data_type.is_set or
                                        self.error.is_set or
                                        self.no_data.is_set or
                                        self.string_data.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.data_type.yfilter != YFilter.not_set or
                                        self.error.yfilter != YFilter.not_set or
                                        self.no_data.yfilter != YFilter.not_set or
                                        self.string_data.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "data" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.data_type.is_set or self.data_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.data_type.get_name_leafdata())
                                    if (self.error.is_set or self.error.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.error.get_name_leafdata())
                                    if (self.no_data.is_set or self.no_data.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.no_data.get_name_leafdata())
                                    if (self.string_data.is_set or self.string_data.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.string_data.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "data-type" or name == "error" or name == "no-data" or name == "string-data"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "data-type"):
                                        self.data_type = value
                                        self.data_type.value_namespace = name_space
                                        self.data_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "error"):
                                        self.error = value
                                        self.error.value_namespace = name_space
                                        self.error.value_namespace_prefix = name_space_prefix
                                    if(value_path == "no-data"):
                                        self.no_data = value
                                        self.no_data.value_namespace = name_space
                                        self.no_data.value_namespace_prefix = name_space_prefix
                                    if(value_path == "string-data"):
                                        self.string_data = value
                                        self.string_data.value_namespace = name_space
                                        self.string_data.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.member_event_type.is_set or
                                    self.time_stamp.is_set or
                                    (self.data is not None and self.data.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.member_event_type.yfilter != YFilter.not_set or
                                    self.time_stamp.yfilter != YFilter.not_set or
                                    (self.data is not None and self.data.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "member-evt-info" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.member_event_type.is_set or self.member_event_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.member_event_type.get_name_leafdata())
                                if (self.time_stamp.is_set or self.time_stamp.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.time_stamp.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "data"):
                                    if (self.data is None):
                                        self.data = BundleInformation.EventsBdl.EventsBdlBundles.EventsBdlBundle.EventsBdlBundleItem.Items.MemberEvtInfo.Data()
                                        self.data.parent = self
                                        self._children_name_map["data"] = "data"
                                    return self.data

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "data" or name == "member-event-type" or name == "time-stamp"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "member-event-type"):
                                    self.member_event_type = value
                                    self.member_event_type.value_namespace = name_space
                                    self.member_event_type.value_namespace_prefix = name_space_prefix
                                if(value_path == "time-stamp"):
                                    self.time_stamp = value
                                    self.time_stamp.value_namespace = name_space
                                    self.time_stamp.value_namespace_prefix = name_space_prefix


                        class BundleEvtInfo(Entity):
                            """
                            Event information for a bundle
                            
                            .. attribute:: bundle_event_type
                            
                            	Type of event for bundle
                            	**type**\:   :py:class:`BmdBagEventBdlItem <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmdBagEventBdlItem>`
                            
                            .. attribute:: data
                            
                            	Additional data for the event
                            	**type**\:   :py:class:`Data <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.EventsBdl.EventsBdlBundles.EventsBdlBundle.EventsBdlBundleItem.Items.BundleEvtInfo.Data>`
                            
                            .. attribute:: time_stamp
                            
                            	Time stamp of the event
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            

                            """

                            _prefix = 'bundlemgr-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(BundleInformation.EventsBdl.EventsBdlBundles.EventsBdlBundle.EventsBdlBundleItem.Items.BundleEvtInfo, self).__init__()

                                self.yang_name = "bundle-evt-info"
                                self.yang_parent_name = "items"

                                self.bundle_event_type = YLeaf(YType.enumeration, "bundle-event-type")

                                self.time_stamp = YLeaf(YType.uint64, "time-stamp")

                                self.data = BundleInformation.EventsBdl.EventsBdlBundles.EventsBdlBundle.EventsBdlBundleItem.Items.BundleEvtInfo.Data()
                                self.data.parent = self
                                self._children_name_map["data"] = "data"
                                self._children_yang_names.add("data")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("bundle_event_type",
                                                "time_stamp") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(BundleInformation.EventsBdl.EventsBdlBundles.EventsBdlBundle.EventsBdlBundleItem.Items.BundleEvtInfo, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(BundleInformation.EventsBdl.EventsBdlBundles.EventsBdlBundle.EventsBdlBundleItem.Items.BundleEvtInfo, self).__setattr__(name, value)


                            class Data(Entity):
                                """
                                Additional data for the event
                                
                                .. attribute:: data_type
                                
                                	DataType
                                	**type**\:   :py:class:`BmdBagEventData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmdBagEventData>`
                                
                                .. attribute:: error
                                
                                	Error
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: no_data
                                
                                	NoData
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: string_data
                                
                                	StringData
                                	**type**\:  str
                                
                                

                                """

                                _prefix = 'bundlemgr-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(BundleInformation.EventsBdl.EventsBdlBundles.EventsBdlBundle.EventsBdlBundleItem.Items.BundleEvtInfo.Data, self).__init__()

                                    self.yang_name = "data"
                                    self.yang_parent_name = "bundle-evt-info"

                                    self.data_type = YLeaf(YType.enumeration, "data-type")

                                    self.error = YLeaf(YType.uint32, "error")

                                    self.no_data = YLeaf(YType.uint8, "no-data")

                                    self.string_data = YLeaf(YType.str, "string-data")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("data_type",
                                                    "error",
                                                    "no_data",
                                                    "string_data") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(BundleInformation.EventsBdl.EventsBdlBundles.EventsBdlBundle.EventsBdlBundleItem.Items.BundleEvtInfo.Data, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(BundleInformation.EventsBdl.EventsBdlBundles.EventsBdlBundle.EventsBdlBundleItem.Items.BundleEvtInfo.Data, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.data_type.is_set or
                                        self.error.is_set or
                                        self.no_data.is_set or
                                        self.string_data.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.data_type.yfilter != YFilter.not_set or
                                        self.error.yfilter != YFilter.not_set or
                                        self.no_data.yfilter != YFilter.not_set or
                                        self.string_data.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "data" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.data_type.is_set or self.data_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.data_type.get_name_leafdata())
                                    if (self.error.is_set or self.error.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.error.get_name_leafdata())
                                    if (self.no_data.is_set or self.no_data.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.no_data.get_name_leafdata())
                                    if (self.string_data.is_set or self.string_data.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.string_data.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "data-type" or name == "error" or name == "no-data" or name == "string-data"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "data-type"):
                                        self.data_type = value
                                        self.data_type.value_namespace = name_space
                                        self.data_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "error"):
                                        self.error = value
                                        self.error.value_namespace = name_space
                                        self.error.value_namespace_prefix = name_space_prefix
                                    if(value_path == "no-data"):
                                        self.no_data = value
                                        self.no_data.value_namespace = name_space
                                        self.no_data.value_namespace_prefix = name_space_prefix
                                    if(value_path == "string-data"):
                                        self.string_data = value
                                        self.string_data.value_namespace = name_space
                                        self.string_data.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.bundle_event_type.is_set or
                                    self.time_stamp.is_set or
                                    (self.data is not None and self.data.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.bundle_event_type.yfilter != YFilter.not_set or
                                    self.time_stamp.yfilter != YFilter.not_set or
                                    (self.data is not None and self.data.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "bundle-evt-info" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.bundle_event_type.is_set or self.bundle_event_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.bundle_event_type.get_name_leafdata())
                                if (self.time_stamp.is_set or self.time_stamp.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.time_stamp.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "data"):
                                    if (self.data is None):
                                        self.data = BundleInformation.EventsBdl.EventsBdlBundles.EventsBdlBundle.EventsBdlBundleItem.Items.BundleEvtInfo.Data()
                                        self.data.parent = self
                                        self._children_name_map["data"] = "data"
                                    return self.data

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "data" or name == "bundle-event-type" or name == "time-stamp"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "bundle-event-type"):
                                    self.bundle_event_type = value
                                    self.bundle_event_type.value_namespace = name_space
                                    self.bundle_event_type.value_namespace_prefix = name_space_prefix
                                if(value_path == "time-stamp"):
                                    self.time_stamp = value
                                    self.time_stamp.value_namespace = name_space
                                    self.time_stamp.value_namespace_prefix = name_space_prefix


                        class RgEvtInfo(Entity):
                            """
                            Event information for an RG
                            
                            .. attribute:: data
                            
                            	Additional data for the event
                            	**type**\:   :py:class:`Data <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.EventsBdl.EventsBdlBundles.EventsBdlBundle.EventsBdlBundleItem.Items.RgEvtInfo.Data>`
                            
                            .. attribute:: rg_event_type
                            
                            	Type of event for RG
                            	**type**\:   :py:class:`BmdBagEventRgItem <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmdBagEventRgItem>`
                            
                            .. attribute:: time_stamp
                            
                            	Time stamp of the event
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            

                            """

                            _prefix = 'bundlemgr-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(BundleInformation.EventsBdl.EventsBdlBundles.EventsBdlBundle.EventsBdlBundleItem.Items.RgEvtInfo, self).__init__()

                                self.yang_name = "rg-evt-info"
                                self.yang_parent_name = "items"

                                self.rg_event_type = YLeaf(YType.enumeration, "rg-event-type")

                                self.time_stamp = YLeaf(YType.uint64, "time-stamp")

                                self.data = BundleInformation.EventsBdl.EventsBdlBundles.EventsBdlBundle.EventsBdlBundleItem.Items.RgEvtInfo.Data()
                                self.data.parent = self
                                self._children_name_map["data"] = "data"
                                self._children_yang_names.add("data")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("rg_event_type",
                                                "time_stamp") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(BundleInformation.EventsBdl.EventsBdlBundles.EventsBdlBundle.EventsBdlBundleItem.Items.RgEvtInfo, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(BundleInformation.EventsBdl.EventsBdlBundles.EventsBdlBundle.EventsBdlBundleItem.Items.RgEvtInfo, self).__setattr__(name, value)


                            class Data(Entity):
                                """
                                Additional data for the event
                                
                                .. attribute:: data_type
                                
                                	DataType
                                	**type**\:   :py:class:`BmdBagEventData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmdBagEventData>`
                                
                                .. attribute:: error
                                
                                	Error
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: no_data
                                
                                	NoData
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: string_data
                                
                                	StringData
                                	**type**\:  str
                                
                                

                                """

                                _prefix = 'bundlemgr-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(BundleInformation.EventsBdl.EventsBdlBundles.EventsBdlBundle.EventsBdlBundleItem.Items.RgEvtInfo.Data, self).__init__()

                                    self.yang_name = "data"
                                    self.yang_parent_name = "rg-evt-info"

                                    self.data_type = YLeaf(YType.enumeration, "data-type")

                                    self.error = YLeaf(YType.uint32, "error")

                                    self.no_data = YLeaf(YType.uint8, "no-data")

                                    self.string_data = YLeaf(YType.str, "string-data")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("data_type",
                                                    "error",
                                                    "no_data",
                                                    "string_data") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(BundleInformation.EventsBdl.EventsBdlBundles.EventsBdlBundle.EventsBdlBundleItem.Items.RgEvtInfo.Data, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(BundleInformation.EventsBdl.EventsBdlBundles.EventsBdlBundle.EventsBdlBundleItem.Items.RgEvtInfo.Data, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.data_type.is_set or
                                        self.error.is_set or
                                        self.no_data.is_set or
                                        self.string_data.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.data_type.yfilter != YFilter.not_set or
                                        self.error.yfilter != YFilter.not_set or
                                        self.no_data.yfilter != YFilter.not_set or
                                        self.string_data.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "data" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.data_type.is_set or self.data_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.data_type.get_name_leafdata())
                                    if (self.error.is_set or self.error.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.error.get_name_leafdata())
                                    if (self.no_data.is_set or self.no_data.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.no_data.get_name_leafdata())
                                    if (self.string_data.is_set or self.string_data.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.string_data.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "data-type" or name == "error" or name == "no-data" or name == "string-data"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "data-type"):
                                        self.data_type = value
                                        self.data_type.value_namespace = name_space
                                        self.data_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "error"):
                                        self.error = value
                                        self.error.value_namespace = name_space
                                        self.error.value_namespace_prefix = name_space_prefix
                                    if(value_path == "no-data"):
                                        self.no_data = value
                                        self.no_data.value_namespace = name_space
                                        self.no_data.value_namespace_prefix = name_space_prefix
                                    if(value_path == "string-data"):
                                        self.string_data = value
                                        self.string_data.value_namespace = name_space
                                        self.string_data.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.rg_event_type.is_set or
                                    self.time_stamp.is_set or
                                    (self.data is not None and self.data.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.rg_event_type.yfilter != YFilter.not_set or
                                    self.time_stamp.yfilter != YFilter.not_set or
                                    (self.data is not None and self.data.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "rg-evt-info" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.rg_event_type.is_set or self.rg_event_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.rg_event_type.get_name_leafdata())
                                if (self.time_stamp.is_set or self.time_stamp.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.time_stamp.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "data"):
                                    if (self.data is None):
                                        self.data = BundleInformation.EventsBdl.EventsBdlBundles.EventsBdlBundle.EventsBdlBundleItem.Items.RgEvtInfo.Data()
                                        self.data.parent = self
                                        self._children_name_map["data"] = "data"
                                    return self.data

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "data" or name == "rg-event-type" or name == "time-stamp"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "rg-event-type"):
                                    self.rg_event_type = value
                                    self.rg_event_type.value_namespace = name_space
                                    self.rg_event_type.value_namespace_prefix = name_space_prefix
                                if(value_path == "time-stamp"):
                                    self.time_stamp = value
                                    self.time_stamp.value_namespace = name_space
                                    self.time_stamp.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.event_type.is_set or
                                (self.bundle_evt_info is not None and self.bundle_evt_info.has_data()) or
                                (self.member_evt_info is not None and self.member_evt_info.has_data()) or
                                (self.rg_evt_info is not None and self.rg_evt_info.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.event_type.yfilter != YFilter.not_set or
                                (self.bundle_evt_info is not None and self.bundle_evt_info.has_operation()) or
                                (self.member_evt_info is not None and self.member_evt_info.has_operation()) or
                                (self.rg_evt_info is not None and self.rg_evt_info.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "items" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.event_type.is_set or self.event_type.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.event_type.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "bundle-evt-info"):
                                if (self.bundle_evt_info is None):
                                    self.bundle_evt_info = BundleInformation.EventsBdl.EventsBdlBundles.EventsBdlBundle.EventsBdlBundleItem.Items.BundleEvtInfo()
                                    self.bundle_evt_info.parent = self
                                    self._children_name_map["bundle_evt_info"] = "bundle-evt-info"
                                return self.bundle_evt_info

                            if (child_yang_name == "member-evt-info"):
                                if (self.member_evt_info is None):
                                    self.member_evt_info = BundleInformation.EventsBdl.EventsBdlBundles.EventsBdlBundle.EventsBdlBundleItem.Items.MemberEvtInfo()
                                    self.member_evt_info.parent = self
                                    self._children_name_map["member_evt_info"] = "member-evt-info"
                                return self.member_evt_info

                            if (child_yang_name == "rg-evt-info"):
                                if (self.rg_evt_info is None):
                                    self.rg_evt_info = BundleInformation.EventsBdl.EventsBdlBundles.EventsBdlBundle.EventsBdlBundleItem.Items.RgEvtInfo()
                                    self.rg_evt_info.parent = self
                                    self._children_name_map["rg_evt_info"] = "rg-evt-info"
                                return self.rg_evt_info

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "bundle-evt-info" or name == "member-evt-info" or name == "rg-evt-info" or name == "event-type"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "event-type"):
                                self.event_type = value
                                self.event_type.value_namespace = name_space
                                self.event_type.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.items:
                            if (c.has_data()):
                                return True
                        return self.item_name.is_set

                    def has_operation(self):
                        for c in self.items:
                            if (c.has_operation()):
                                return True
                        return (
                            self.yfilter != YFilter.not_set or
                            self.item_name.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "events-bdl-bundle-item" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.item_name.is_set or self.item_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.item_name.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "items"):
                            for c in self.items:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = BundleInformation.EventsBdl.EventsBdlBundles.EventsBdlBundle.EventsBdlBundleItem.Items()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.items.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "items" or name == "item-name"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "item-name"):
                            self.item_name = value
                            self.item_name.value_namespace = name_space
                            self.item_name.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    return (
                        self.bundle_interface.is_set or
                        (self.events_bdl_bundle_item is not None and self.events_bdl_bundle_item.has_data()))

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.bundle_interface.yfilter != YFilter.not_set or
                        (self.events_bdl_bundle_item is not None and self.events_bdl_bundle_item.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "events-bdl-bundle" + "[bundle-interface='" + self.bundle_interface.get() + "']" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-bundlemgr-oper:bundle-information/events-bdl/events-bdl-bundles/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.bundle_interface.is_set or self.bundle_interface.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.bundle_interface.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "events-bdl-bundle-item"):
                        if (self.events_bdl_bundle_item is None):
                            self.events_bdl_bundle_item = BundleInformation.EventsBdl.EventsBdlBundles.EventsBdlBundle.EventsBdlBundleItem()
                            self.events_bdl_bundle_item.parent = self
                            self._children_name_map["events_bdl_bundle_item"] = "events-bdl-bundle-item"
                        return self.events_bdl_bundle_item

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "events-bdl-bundle-item" or name == "bundle-interface"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "bundle-interface"):
                        self.bundle_interface = value
                        self.bundle_interface.value_namespace = name_space
                        self.bundle_interface.value_namespace_prefix = name_space_prefix

            def has_data(self):
                for c in self.events_bdl_bundle:
                    if (c.has_data()):
                        return True
                return False

            def has_operation(self):
                for c in self.events_bdl_bundle:
                    if (c.has_operation()):
                        return True
                return self.yfilter != YFilter.not_set

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "events-bdl-bundles" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-bundlemgr-oper:bundle-information/events-bdl/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "events-bdl-bundle"):
                    for c in self.events_bdl_bundle:
                        segment = c.get_segment_path()
                        if (segment_path == segment):
                            return c
                    c = BundleInformation.EventsBdl.EventsBdlBundles.EventsBdlBundle()
                    c.parent = self
                    local_reference_key = "ydk::seg::%s" % segment_path
                    self._local_refs[local_reference_key] = c
                    self.events_bdl_bundle.append(c)
                    return c

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "events-bdl-bundle"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                pass


        class EventsBdlIccpGroups(Entity):
            """
            Bundle events for all ICCP Groups
            
            .. attribute:: events_bdl_iccp_group
            
            	ICCP Group ID
            	**type**\: list of    :py:class:`EventsBdlIccpGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.EventsBdl.EventsBdlIccpGroups.EventsBdlIccpGroup>`
            
            

            """

            _prefix = 'bundlemgr-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(BundleInformation.EventsBdl.EventsBdlIccpGroups, self).__init__()

                self.yang_name = "events-bdl-iccp-groups"
                self.yang_parent_name = "events-bdl"

                self.events_bdl_iccp_group = YList(self)

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in () and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(BundleInformation.EventsBdl.EventsBdlIccpGroups, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(BundleInformation.EventsBdl.EventsBdlIccpGroups, self).__setattr__(name, value)


            class EventsBdlIccpGroup(Entity):
                """
                ICCP Group ID
                
                .. attribute:: iccp_group  <key>
                
                	ICCP Group ID
                	**type**\:  int
                
                	**range:** 1..4294967295
                
                .. attribute:: events_bdl_bundle_descendant_iccp_group
                
                	Data for this item and all its members
                	**type**\:   :py:class:`EventsBdlBundleDescendantIccpGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.EventsBdl.EventsBdlIccpGroups.EventsBdlIccpGroup.EventsBdlBundleDescendantIccpGroup>`
                
                

                """

                _prefix = 'bundlemgr-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(BundleInformation.EventsBdl.EventsBdlIccpGroups.EventsBdlIccpGroup, self).__init__()

                    self.yang_name = "events-bdl-iccp-group"
                    self.yang_parent_name = "events-bdl-iccp-groups"

                    self.iccp_group = YLeaf(YType.uint32, "iccp-group")

                    self.events_bdl_bundle_descendant_iccp_group = BundleInformation.EventsBdl.EventsBdlIccpGroups.EventsBdlIccpGroup.EventsBdlBundleDescendantIccpGroup()
                    self.events_bdl_bundle_descendant_iccp_group.parent = self
                    self._children_name_map["events_bdl_bundle_descendant_iccp_group"] = "events-bdl-bundle-descendant-iccp-group"
                    self._children_yang_names.add("events-bdl-bundle-descendant-iccp-group")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("iccp_group") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(BundleInformation.EventsBdl.EventsBdlIccpGroups.EventsBdlIccpGroup, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(BundleInformation.EventsBdl.EventsBdlIccpGroups.EventsBdlIccpGroup, self).__setattr__(name, value)


                class EventsBdlBundleDescendantIccpGroup(Entity):
                    """
                    Data for this item and all its members
                    
                    .. attribute:: events_item
                    
                    	Event items
                    	**type**\: list of    :py:class:`EventsItem <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.EventsBdl.EventsBdlIccpGroups.EventsBdlIccpGroup.EventsBdlBundleDescendantIccpGroup.EventsItem>`
                    
                    

                    """

                    _prefix = 'bundlemgr-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(BundleInformation.EventsBdl.EventsBdlIccpGroups.EventsBdlIccpGroup.EventsBdlBundleDescendantIccpGroup, self).__init__()

                        self.yang_name = "events-bdl-bundle-descendant-iccp-group"
                        self.yang_parent_name = "events-bdl-iccp-group"

                        self.events_item = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(BundleInformation.EventsBdl.EventsBdlIccpGroups.EventsBdlIccpGroup.EventsBdlBundleDescendantIccpGroup, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(BundleInformation.EventsBdl.EventsBdlIccpGroups.EventsBdlIccpGroup.EventsBdlBundleDescendantIccpGroup, self).__setattr__(name, value)


                    class EventsItem(Entity):
                        """
                        Event items
                        
                        .. attribute:: item_name
                        
                        	Name for the current item to use
                        	**type**\:  str
                        
                        .. attribute:: items
                        
                        	Event items
                        	**type**\: list of    :py:class:`Items <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.EventsBdl.EventsBdlIccpGroups.EventsBdlIccpGroup.EventsBdlBundleDescendantIccpGroup.EventsItem.Items>`
                        
                        

                        """

                        _prefix = 'bundlemgr-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(BundleInformation.EventsBdl.EventsBdlIccpGroups.EventsBdlIccpGroup.EventsBdlBundleDescendantIccpGroup.EventsItem, self).__init__()

                            self.yang_name = "events-item"
                            self.yang_parent_name = "events-bdl-bundle-descendant-iccp-group"

                            self.item_name = YLeaf(YType.str, "item-name")

                            self.items = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("item_name") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(BundleInformation.EventsBdl.EventsBdlIccpGroups.EventsBdlIccpGroup.EventsBdlBundleDescendantIccpGroup.EventsItem, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(BundleInformation.EventsBdl.EventsBdlIccpGroups.EventsBdlIccpGroup.EventsBdlBundleDescendantIccpGroup.EventsItem, self).__setattr__(name, value)


                        class Items(Entity):
                            """
                            Event items
                            
                            .. attribute:: bundle_evt_info
                            
                            	Event information for a bundle
                            	**type**\:   :py:class:`BundleEvtInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.EventsBdl.EventsBdlIccpGroups.EventsBdlIccpGroup.EventsBdlBundleDescendantIccpGroup.EventsItem.Items.BundleEvtInfo>`
                            
                            .. attribute:: event_type
                            
                            	EventType
                            	**type**\:   :py:class:`BmdBagTarget <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmdBagTarget>`
                            
                            .. attribute:: member_evt_info
                            
                            	Event information for a member
                            	**type**\:   :py:class:`MemberEvtInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.EventsBdl.EventsBdlIccpGroups.EventsBdlIccpGroup.EventsBdlBundleDescendantIccpGroup.EventsItem.Items.MemberEvtInfo>`
                            
                            .. attribute:: rg_evt_info
                            
                            	Event information for an RG
                            	**type**\:   :py:class:`RgEvtInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.EventsBdl.EventsBdlIccpGroups.EventsBdlIccpGroup.EventsBdlBundleDescendantIccpGroup.EventsItem.Items.RgEvtInfo>`
                            
                            

                            """

                            _prefix = 'bundlemgr-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(BundleInformation.EventsBdl.EventsBdlIccpGroups.EventsBdlIccpGroup.EventsBdlBundleDescendantIccpGroup.EventsItem.Items, self).__init__()

                                self.yang_name = "items"
                                self.yang_parent_name = "events-item"

                                self.event_type = YLeaf(YType.enumeration, "event-type")

                                self.bundle_evt_info = BundleInformation.EventsBdl.EventsBdlIccpGroups.EventsBdlIccpGroup.EventsBdlBundleDescendantIccpGroup.EventsItem.Items.BundleEvtInfo()
                                self.bundle_evt_info.parent = self
                                self._children_name_map["bundle_evt_info"] = "bundle-evt-info"
                                self._children_yang_names.add("bundle-evt-info")

                                self.member_evt_info = BundleInformation.EventsBdl.EventsBdlIccpGroups.EventsBdlIccpGroup.EventsBdlBundleDescendantIccpGroup.EventsItem.Items.MemberEvtInfo()
                                self.member_evt_info.parent = self
                                self._children_name_map["member_evt_info"] = "member-evt-info"
                                self._children_yang_names.add("member-evt-info")

                                self.rg_evt_info = BundleInformation.EventsBdl.EventsBdlIccpGroups.EventsBdlIccpGroup.EventsBdlBundleDescendantIccpGroup.EventsItem.Items.RgEvtInfo()
                                self.rg_evt_info.parent = self
                                self._children_name_map["rg_evt_info"] = "rg-evt-info"
                                self._children_yang_names.add("rg-evt-info")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("event_type") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(BundleInformation.EventsBdl.EventsBdlIccpGroups.EventsBdlIccpGroup.EventsBdlBundleDescendantIccpGroup.EventsItem.Items, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(BundleInformation.EventsBdl.EventsBdlIccpGroups.EventsBdlIccpGroup.EventsBdlBundleDescendantIccpGroup.EventsItem.Items, self).__setattr__(name, value)


                            class MemberEvtInfo(Entity):
                                """
                                Event information for a member
                                
                                .. attribute:: data
                                
                                	Additional data for the event
                                	**type**\:   :py:class:`Data <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.EventsBdl.EventsBdlIccpGroups.EventsBdlIccpGroup.EventsBdlBundleDescendantIccpGroup.EventsItem.Items.MemberEvtInfo.Data>`
                                
                                .. attribute:: member_event_type
                                
                                	Type of event for member
                                	**type**\:   :py:class:`BmdBagEventMbrItem <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmdBagEventMbrItem>`
                                
                                .. attribute:: time_stamp
                                
                                	Time stamp of the event
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'bundlemgr-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(BundleInformation.EventsBdl.EventsBdlIccpGroups.EventsBdlIccpGroup.EventsBdlBundleDescendantIccpGroup.EventsItem.Items.MemberEvtInfo, self).__init__()

                                    self.yang_name = "member-evt-info"
                                    self.yang_parent_name = "items"

                                    self.member_event_type = YLeaf(YType.enumeration, "member-event-type")

                                    self.time_stamp = YLeaf(YType.uint64, "time-stamp")

                                    self.data = BundleInformation.EventsBdl.EventsBdlIccpGroups.EventsBdlIccpGroup.EventsBdlBundleDescendantIccpGroup.EventsItem.Items.MemberEvtInfo.Data()
                                    self.data.parent = self
                                    self._children_name_map["data"] = "data"
                                    self._children_yang_names.add("data")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("member_event_type",
                                                    "time_stamp") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(BundleInformation.EventsBdl.EventsBdlIccpGroups.EventsBdlIccpGroup.EventsBdlBundleDescendantIccpGroup.EventsItem.Items.MemberEvtInfo, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(BundleInformation.EventsBdl.EventsBdlIccpGroups.EventsBdlIccpGroup.EventsBdlBundleDescendantIccpGroup.EventsItem.Items.MemberEvtInfo, self).__setattr__(name, value)


                                class Data(Entity):
                                    """
                                    Additional data for the event
                                    
                                    .. attribute:: data_type
                                    
                                    	DataType
                                    	**type**\:   :py:class:`BmdBagEventData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmdBagEventData>`
                                    
                                    .. attribute:: error
                                    
                                    	Error
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: no_data
                                    
                                    	NoData
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: string_data
                                    
                                    	StringData
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'bundlemgr-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(BundleInformation.EventsBdl.EventsBdlIccpGroups.EventsBdlIccpGroup.EventsBdlBundleDescendantIccpGroup.EventsItem.Items.MemberEvtInfo.Data, self).__init__()

                                        self.yang_name = "data"
                                        self.yang_parent_name = "member-evt-info"

                                        self.data_type = YLeaf(YType.enumeration, "data-type")

                                        self.error = YLeaf(YType.uint32, "error")

                                        self.no_data = YLeaf(YType.uint8, "no-data")

                                        self.string_data = YLeaf(YType.str, "string-data")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data_type",
                                                        "error",
                                                        "no_data",
                                                        "string_data") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(BundleInformation.EventsBdl.EventsBdlIccpGroups.EventsBdlIccpGroup.EventsBdlBundleDescendantIccpGroup.EventsItem.Items.MemberEvtInfo.Data, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(BundleInformation.EventsBdl.EventsBdlIccpGroups.EventsBdlIccpGroup.EventsBdlBundleDescendantIccpGroup.EventsItem.Items.MemberEvtInfo.Data, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data_type.is_set or
                                            self.error.is_set or
                                            self.no_data.is_set or
                                            self.string_data.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data_type.yfilter != YFilter.not_set or
                                            self.error.yfilter != YFilter.not_set or
                                            self.no_data.yfilter != YFilter.not_set or
                                            self.string_data.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "data" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data_type.is_set or self.data_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data_type.get_name_leafdata())
                                        if (self.error.is_set or self.error.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.error.get_name_leafdata())
                                        if (self.no_data.is_set or self.no_data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.no_data.get_name_leafdata())
                                        if (self.string_data.is_set or self.string_data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.string_data.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data-type" or name == "error" or name == "no-data" or name == "string-data"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data-type"):
                                            self.data_type = value
                                            self.data_type.value_namespace = name_space
                                            self.data_type.value_namespace_prefix = name_space_prefix
                                        if(value_path == "error"):
                                            self.error = value
                                            self.error.value_namespace = name_space
                                            self.error.value_namespace_prefix = name_space_prefix
                                        if(value_path == "no-data"):
                                            self.no_data = value
                                            self.no_data.value_namespace = name_space
                                            self.no_data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "string-data"):
                                            self.string_data = value
                                            self.string_data.value_namespace = name_space
                                            self.string_data.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.member_event_type.is_set or
                                        self.time_stamp.is_set or
                                        (self.data is not None and self.data.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.member_event_type.yfilter != YFilter.not_set or
                                        self.time_stamp.yfilter != YFilter.not_set or
                                        (self.data is not None and self.data.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "member-evt-info" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.member_event_type.is_set or self.member_event_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.member_event_type.get_name_leafdata())
                                    if (self.time_stamp.is_set or self.time_stamp.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.time_stamp.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "data"):
                                        if (self.data is None):
                                            self.data = BundleInformation.EventsBdl.EventsBdlIccpGroups.EventsBdlIccpGroup.EventsBdlBundleDescendantIccpGroup.EventsItem.Items.MemberEvtInfo.Data()
                                            self.data.parent = self
                                            self._children_name_map["data"] = "data"
                                        return self.data

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "data" or name == "member-event-type" or name == "time-stamp"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "member-event-type"):
                                        self.member_event_type = value
                                        self.member_event_type.value_namespace = name_space
                                        self.member_event_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "time-stamp"):
                                        self.time_stamp = value
                                        self.time_stamp.value_namespace = name_space
                                        self.time_stamp.value_namespace_prefix = name_space_prefix


                            class BundleEvtInfo(Entity):
                                """
                                Event information for a bundle
                                
                                .. attribute:: bundle_event_type
                                
                                	Type of event for bundle
                                	**type**\:   :py:class:`BmdBagEventBdlItem <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmdBagEventBdlItem>`
                                
                                .. attribute:: data
                                
                                	Additional data for the event
                                	**type**\:   :py:class:`Data <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.EventsBdl.EventsBdlIccpGroups.EventsBdlIccpGroup.EventsBdlBundleDescendantIccpGroup.EventsItem.Items.BundleEvtInfo.Data>`
                                
                                .. attribute:: time_stamp
                                
                                	Time stamp of the event
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'bundlemgr-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(BundleInformation.EventsBdl.EventsBdlIccpGroups.EventsBdlIccpGroup.EventsBdlBundleDescendantIccpGroup.EventsItem.Items.BundleEvtInfo, self).__init__()

                                    self.yang_name = "bundle-evt-info"
                                    self.yang_parent_name = "items"

                                    self.bundle_event_type = YLeaf(YType.enumeration, "bundle-event-type")

                                    self.time_stamp = YLeaf(YType.uint64, "time-stamp")

                                    self.data = BundleInformation.EventsBdl.EventsBdlIccpGroups.EventsBdlIccpGroup.EventsBdlBundleDescendantIccpGroup.EventsItem.Items.BundleEvtInfo.Data()
                                    self.data.parent = self
                                    self._children_name_map["data"] = "data"
                                    self._children_yang_names.add("data")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("bundle_event_type",
                                                    "time_stamp") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(BundleInformation.EventsBdl.EventsBdlIccpGroups.EventsBdlIccpGroup.EventsBdlBundleDescendantIccpGroup.EventsItem.Items.BundleEvtInfo, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(BundleInformation.EventsBdl.EventsBdlIccpGroups.EventsBdlIccpGroup.EventsBdlBundleDescendantIccpGroup.EventsItem.Items.BundleEvtInfo, self).__setattr__(name, value)


                                class Data(Entity):
                                    """
                                    Additional data for the event
                                    
                                    .. attribute:: data_type
                                    
                                    	DataType
                                    	**type**\:   :py:class:`BmdBagEventData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmdBagEventData>`
                                    
                                    .. attribute:: error
                                    
                                    	Error
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: no_data
                                    
                                    	NoData
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: string_data
                                    
                                    	StringData
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'bundlemgr-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(BundleInformation.EventsBdl.EventsBdlIccpGroups.EventsBdlIccpGroup.EventsBdlBundleDescendantIccpGroup.EventsItem.Items.BundleEvtInfo.Data, self).__init__()

                                        self.yang_name = "data"
                                        self.yang_parent_name = "bundle-evt-info"

                                        self.data_type = YLeaf(YType.enumeration, "data-type")

                                        self.error = YLeaf(YType.uint32, "error")

                                        self.no_data = YLeaf(YType.uint8, "no-data")

                                        self.string_data = YLeaf(YType.str, "string-data")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data_type",
                                                        "error",
                                                        "no_data",
                                                        "string_data") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(BundleInformation.EventsBdl.EventsBdlIccpGroups.EventsBdlIccpGroup.EventsBdlBundleDescendantIccpGroup.EventsItem.Items.BundleEvtInfo.Data, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(BundleInformation.EventsBdl.EventsBdlIccpGroups.EventsBdlIccpGroup.EventsBdlBundleDescendantIccpGroup.EventsItem.Items.BundleEvtInfo.Data, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data_type.is_set or
                                            self.error.is_set or
                                            self.no_data.is_set or
                                            self.string_data.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data_type.yfilter != YFilter.not_set or
                                            self.error.yfilter != YFilter.not_set or
                                            self.no_data.yfilter != YFilter.not_set or
                                            self.string_data.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "data" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data_type.is_set or self.data_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data_type.get_name_leafdata())
                                        if (self.error.is_set or self.error.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.error.get_name_leafdata())
                                        if (self.no_data.is_set or self.no_data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.no_data.get_name_leafdata())
                                        if (self.string_data.is_set or self.string_data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.string_data.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data-type" or name == "error" or name == "no-data" or name == "string-data"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data-type"):
                                            self.data_type = value
                                            self.data_type.value_namespace = name_space
                                            self.data_type.value_namespace_prefix = name_space_prefix
                                        if(value_path == "error"):
                                            self.error = value
                                            self.error.value_namespace = name_space
                                            self.error.value_namespace_prefix = name_space_prefix
                                        if(value_path == "no-data"):
                                            self.no_data = value
                                            self.no_data.value_namespace = name_space
                                            self.no_data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "string-data"):
                                            self.string_data = value
                                            self.string_data.value_namespace = name_space
                                            self.string_data.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.bundle_event_type.is_set or
                                        self.time_stamp.is_set or
                                        (self.data is not None and self.data.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.bundle_event_type.yfilter != YFilter.not_set or
                                        self.time_stamp.yfilter != YFilter.not_set or
                                        (self.data is not None and self.data.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "bundle-evt-info" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.bundle_event_type.is_set or self.bundle_event_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.bundle_event_type.get_name_leafdata())
                                    if (self.time_stamp.is_set or self.time_stamp.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.time_stamp.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "data"):
                                        if (self.data is None):
                                            self.data = BundleInformation.EventsBdl.EventsBdlIccpGroups.EventsBdlIccpGroup.EventsBdlBundleDescendantIccpGroup.EventsItem.Items.BundleEvtInfo.Data()
                                            self.data.parent = self
                                            self._children_name_map["data"] = "data"
                                        return self.data

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "data" or name == "bundle-event-type" or name == "time-stamp"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "bundle-event-type"):
                                        self.bundle_event_type = value
                                        self.bundle_event_type.value_namespace = name_space
                                        self.bundle_event_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "time-stamp"):
                                        self.time_stamp = value
                                        self.time_stamp.value_namespace = name_space
                                        self.time_stamp.value_namespace_prefix = name_space_prefix


                            class RgEvtInfo(Entity):
                                """
                                Event information for an RG
                                
                                .. attribute:: data
                                
                                	Additional data for the event
                                	**type**\:   :py:class:`Data <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.EventsBdl.EventsBdlIccpGroups.EventsBdlIccpGroup.EventsBdlBundleDescendantIccpGroup.EventsItem.Items.RgEvtInfo.Data>`
                                
                                .. attribute:: rg_event_type
                                
                                	Type of event for RG
                                	**type**\:   :py:class:`BmdBagEventRgItem <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmdBagEventRgItem>`
                                
                                .. attribute:: time_stamp
                                
                                	Time stamp of the event
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'bundlemgr-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(BundleInformation.EventsBdl.EventsBdlIccpGroups.EventsBdlIccpGroup.EventsBdlBundleDescendantIccpGroup.EventsItem.Items.RgEvtInfo, self).__init__()

                                    self.yang_name = "rg-evt-info"
                                    self.yang_parent_name = "items"

                                    self.rg_event_type = YLeaf(YType.enumeration, "rg-event-type")

                                    self.time_stamp = YLeaf(YType.uint64, "time-stamp")

                                    self.data = BundleInformation.EventsBdl.EventsBdlIccpGroups.EventsBdlIccpGroup.EventsBdlBundleDescendantIccpGroup.EventsItem.Items.RgEvtInfo.Data()
                                    self.data.parent = self
                                    self._children_name_map["data"] = "data"
                                    self._children_yang_names.add("data")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("rg_event_type",
                                                    "time_stamp") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(BundleInformation.EventsBdl.EventsBdlIccpGroups.EventsBdlIccpGroup.EventsBdlBundleDescendantIccpGroup.EventsItem.Items.RgEvtInfo, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(BundleInformation.EventsBdl.EventsBdlIccpGroups.EventsBdlIccpGroup.EventsBdlBundleDescendantIccpGroup.EventsItem.Items.RgEvtInfo, self).__setattr__(name, value)


                                class Data(Entity):
                                    """
                                    Additional data for the event
                                    
                                    .. attribute:: data_type
                                    
                                    	DataType
                                    	**type**\:   :py:class:`BmdBagEventData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmdBagEventData>`
                                    
                                    .. attribute:: error
                                    
                                    	Error
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: no_data
                                    
                                    	NoData
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: string_data
                                    
                                    	StringData
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'bundlemgr-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(BundleInformation.EventsBdl.EventsBdlIccpGroups.EventsBdlIccpGroup.EventsBdlBundleDescendantIccpGroup.EventsItem.Items.RgEvtInfo.Data, self).__init__()

                                        self.yang_name = "data"
                                        self.yang_parent_name = "rg-evt-info"

                                        self.data_type = YLeaf(YType.enumeration, "data-type")

                                        self.error = YLeaf(YType.uint32, "error")

                                        self.no_data = YLeaf(YType.uint8, "no-data")

                                        self.string_data = YLeaf(YType.str, "string-data")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data_type",
                                                        "error",
                                                        "no_data",
                                                        "string_data") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(BundleInformation.EventsBdl.EventsBdlIccpGroups.EventsBdlIccpGroup.EventsBdlBundleDescendantIccpGroup.EventsItem.Items.RgEvtInfo.Data, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(BundleInformation.EventsBdl.EventsBdlIccpGroups.EventsBdlIccpGroup.EventsBdlBundleDescendantIccpGroup.EventsItem.Items.RgEvtInfo.Data, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data_type.is_set or
                                            self.error.is_set or
                                            self.no_data.is_set or
                                            self.string_data.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data_type.yfilter != YFilter.not_set or
                                            self.error.yfilter != YFilter.not_set or
                                            self.no_data.yfilter != YFilter.not_set or
                                            self.string_data.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "data" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data_type.is_set or self.data_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data_type.get_name_leafdata())
                                        if (self.error.is_set or self.error.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.error.get_name_leafdata())
                                        if (self.no_data.is_set or self.no_data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.no_data.get_name_leafdata())
                                        if (self.string_data.is_set or self.string_data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.string_data.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data-type" or name == "error" or name == "no-data" or name == "string-data"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data-type"):
                                            self.data_type = value
                                            self.data_type.value_namespace = name_space
                                            self.data_type.value_namespace_prefix = name_space_prefix
                                        if(value_path == "error"):
                                            self.error = value
                                            self.error.value_namespace = name_space
                                            self.error.value_namespace_prefix = name_space_prefix
                                        if(value_path == "no-data"):
                                            self.no_data = value
                                            self.no_data.value_namespace = name_space
                                            self.no_data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "string-data"):
                                            self.string_data = value
                                            self.string_data.value_namespace = name_space
                                            self.string_data.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.rg_event_type.is_set or
                                        self.time_stamp.is_set or
                                        (self.data is not None and self.data.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.rg_event_type.yfilter != YFilter.not_set or
                                        self.time_stamp.yfilter != YFilter.not_set or
                                        (self.data is not None and self.data.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "rg-evt-info" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.rg_event_type.is_set or self.rg_event_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.rg_event_type.get_name_leafdata())
                                    if (self.time_stamp.is_set or self.time_stamp.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.time_stamp.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "data"):
                                        if (self.data is None):
                                            self.data = BundleInformation.EventsBdl.EventsBdlIccpGroups.EventsBdlIccpGroup.EventsBdlBundleDescendantIccpGroup.EventsItem.Items.RgEvtInfo.Data()
                                            self.data.parent = self
                                            self._children_name_map["data"] = "data"
                                        return self.data

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "data" or name == "rg-event-type" or name == "time-stamp"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "rg-event-type"):
                                        self.rg_event_type = value
                                        self.rg_event_type.value_namespace = name_space
                                        self.rg_event_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "time-stamp"):
                                        self.time_stamp = value
                                        self.time_stamp.value_namespace = name_space
                                        self.time_stamp.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.event_type.is_set or
                                    (self.bundle_evt_info is not None and self.bundle_evt_info.has_data()) or
                                    (self.member_evt_info is not None and self.member_evt_info.has_data()) or
                                    (self.rg_evt_info is not None and self.rg_evt_info.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.event_type.yfilter != YFilter.not_set or
                                    (self.bundle_evt_info is not None and self.bundle_evt_info.has_operation()) or
                                    (self.member_evt_info is not None and self.member_evt_info.has_operation()) or
                                    (self.rg_evt_info is not None and self.rg_evt_info.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "items" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.event_type.is_set or self.event_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.event_type.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "bundle-evt-info"):
                                    if (self.bundle_evt_info is None):
                                        self.bundle_evt_info = BundleInformation.EventsBdl.EventsBdlIccpGroups.EventsBdlIccpGroup.EventsBdlBundleDescendantIccpGroup.EventsItem.Items.BundleEvtInfo()
                                        self.bundle_evt_info.parent = self
                                        self._children_name_map["bundle_evt_info"] = "bundle-evt-info"
                                    return self.bundle_evt_info

                                if (child_yang_name == "member-evt-info"):
                                    if (self.member_evt_info is None):
                                        self.member_evt_info = BundleInformation.EventsBdl.EventsBdlIccpGroups.EventsBdlIccpGroup.EventsBdlBundleDescendantIccpGroup.EventsItem.Items.MemberEvtInfo()
                                        self.member_evt_info.parent = self
                                        self._children_name_map["member_evt_info"] = "member-evt-info"
                                    return self.member_evt_info

                                if (child_yang_name == "rg-evt-info"):
                                    if (self.rg_evt_info is None):
                                        self.rg_evt_info = BundleInformation.EventsBdl.EventsBdlIccpGroups.EventsBdlIccpGroup.EventsBdlBundleDescendantIccpGroup.EventsItem.Items.RgEvtInfo()
                                        self.rg_evt_info.parent = self
                                        self._children_name_map["rg_evt_info"] = "rg-evt-info"
                                    return self.rg_evt_info

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "bundle-evt-info" or name == "member-evt-info" or name == "rg-evt-info" or name == "event-type"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "event-type"):
                                    self.event_type = value
                                    self.event_type.value_namespace = name_space
                                    self.event_type.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.items:
                                if (c.has_data()):
                                    return True
                            return self.item_name.is_set

                        def has_operation(self):
                            for c in self.items:
                                if (c.has_operation()):
                                    return True
                            return (
                                self.yfilter != YFilter.not_set or
                                self.item_name.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "events-item" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.item_name.is_set or self.item_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.item_name.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "items"):
                                for c in self.items:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = BundleInformation.EventsBdl.EventsBdlIccpGroups.EventsBdlIccpGroup.EventsBdlBundleDescendantIccpGroup.EventsItem.Items()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.items.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "items" or name == "item-name"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "item-name"):
                                self.item_name = value
                                self.item_name.value_namespace = name_space
                                self.item_name.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.events_item:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.events_item:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "events-bdl-bundle-descendant-iccp-group" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "events-item"):
                            for c in self.events_item:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = BundleInformation.EventsBdl.EventsBdlIccpGroups.EventsBdlIccpGroup.EventsBdlBundleDescendantIccpGroup.EventsItem()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.events_item.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "events-item"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass

                def has_data(self):
                    return (
                        self.iccp_group.is_set or
                        (self.events_bdl_bundle_descendant_iccp_group is not None and self.events_bdl_bundle_descendant_iccp_group.has_data()))

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.iccp_group.yfilter != YFilter.not_set or
                        (self.events_bdl_bundle_descendant_iccp_group is not None and self.events_bdl_bundle_descendant_iccp_group.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "events-bdl-iccp-group" + "[iccp-group='" + self.iccp_group.get() + "']" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-bundlemgr-oper:bundle-information/events-bdl/events-bdl-iccp-groups/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.iccp_group.is_set or self.iccp_group.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.iccp_group.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "events-bdl-bundle-descendant-iccp-group"):
                        if (self.events_bdl_bundle_descendant_iccp_group is None):
                            self.events_bdl_bundle_descendant_iccp_group = BundleInformation.EventsBdl.EventsBdlIccpGroups.EventsBdlIccpGroup.EventsBdlBundleDescendantIccpGroup()
                            self.events_bdl_bundle_descendant_iccp_group.parent = self
                            self._children_name_map["events_bdl_bundle_descendant_iccp_group"] = "events-bdl-bundle-descendant-iccp-group"
                        return self.events_bdl_bundle_descendant_iccp_group

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "events-bdl-bundle-descendant-iccp-group" or name == "iccp-group"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "iccp-group"):
                        self.iccp_group = value
                        self.iccp_group.value_namespace = name_space
                        self.iccp_group.value_namespace_prefix = name_space_prefix

            def has_data(self):
                for c in self.events_bdl_iccp_group:
                    if (c.has_data()):
                        return True
                return False

            def has_operation(self):
                for c in self.events_bdl_iccp_group:
                    if (c.has_operation()):
                        return True
                return self.yfilter != YFilter.not_set

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "events-bdl-iccp-groups" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-bundlemgr-oper:bundle-information/events-bdl/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "events-bdl-iccp-group"):
                    for c in self.events_bdl_iccp_group:
                        segment = c.get_segment_path()
                        if (segment_path == segment):
                            return c
                    c = BundleInformation.EventsBdl.EventsBdlIccpGroups.EventsBdlIccpGroup()
                    c.parent = self
                    local_reference_key = "ydk::seg::%s" % segment_path
                    self._local_refs[local_reference_key] = c
                    self.events_bdl_iccp_group.append(c)
                    return c

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "events-bdl-iccp-group"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                pass

        def has_data(self):
            return (
                (self.events_bdl_bundles is not None and self.events_bdl_bundles.has_data()) or
                (self.events_bdl_iccp_groups is not None and self.events_bdl_iccp_groups.has_data()) or
                (self.events_bdl_members is not None and self.events_bdl_members.has_data()))

        def has_operation(self):
            return (
                self.yfilter != YFilter.not_set or
                (self.events_bdl_bundles is not None and self.events_bdl_bundles.has_operation()) or
                (self.events_bdl_iccp_groups is not None and self.events_bdl_iccp_groups.has_operation()) or
                (self.events_bdl_members is not None and self.events_bdl_members.has_operation()))

        def get_segment_path(self):
            path_buffer = ""
            path_buffer = "events-bdl" + path_buffer

            return path_buffer

        def get_entity_path(self, ancestor):
            path_buffer = ""
            if (ancestor is None):
                path_buffer = "Cisco-IOS-XR-bundlemgr-oper:bundle-information/%s" % self.get_segment_path()
            else:
                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

            leaf_name_data = LeafDataList()

            entity_path = EntityPath(path_buffer, leaf_name_data)
            return entity_path

        def get_child_by_name(self, child_yang_name, segment_path):
            child = self._get_child_by_seg_name([child_yang_name, segment_path])
            if child is not None:
                return child

            if (child_yang_name == "events-bdl-bundles"):
                if (self.events_bdl_bundles is None):
                    self.events_bdl_bundles = BundleInformation.EventsBdl.EventsBdlBundles()
                    self.events_bdl_bundles.parent = self
                    self._children_name_map["events_bdl_bundles"] = "events-bdl-bundles"
                return self.events_bdl_bundles

            if (child_yang_name == "events-bdl-iccp-groups"):
                if (self.events_bdl_iccp_groups is None):
                    self.events_bdl_iccp_groups = BundleInformation.EventsBdl.EventsBdlIccpGroups()
                    self.events_bdl_iccp_groups.parent = self
                    self._children_name_map["events_bdl_iccp_groups"] = "events-bdl-iccp-groups"
                return self.events_bdl_iccp_groups

            if (child_yang_name == "events-bdl-members"):
                if (self.events_bdl_members is None):
                    self.events_bdl_members = BundleInformation.EventsBdl.EventsBdlMembers()
                    self.events_bdl_members.parent = self
                    self._children_name_map["events_bdl_members"] = "events-bdl-members"
                return self.events_bdl_members

            return None

        def has_leaf_or_child_of_name(self, name):
            if(name == "events-bdl-bundles" or name == "events-bdl-iccp-groups" or name == "events-bdl-members"):
                return True
            return False

        def set_value(self, value_path, value, name_space, name_space_prefix):
            pass


    class BundleBriefs(Entity):
        """
        Bundle interfaces with common bundle information
        
        .. attribute:: bundle_brief
        
        	Bundle interface
        	**type**\: list of    :py:class:`BundleBrief <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.BundleBriefs.BundleBrief>`
        
        

        """

        _prefix = 'bundlemgr-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(BundleInformation.BundleBriefs, self).__init__()

            self.yang_name = "bundle-briefs"
            self.yang_parent_name = "bundle-information"

            self.bundle_brief = YList(self)

        def __setattr__(self, name, value):
            self._check_monkey_patching_error(name, value)
            with _handle_type_error():
                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                        "Please use list append or extend method."
                                        .format(value))
                if isinstance(value, Enum.YLeaf):
                    value = value.name
                if name in () and name in self.__dict__:
                    if isinstance(value, YLeaf):
                        self.__dict__[name].set(value.get())
                    elif isinstance(value, YLeafList):
                        super(BundleInformation.BundleBriefs, self).__setattr__(name, value)
                    else:
                        self.__dict__[name].set(value)
                else:
                    if hasattr(value, "parent") and name != "parent":
                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                            value.parent = self
                        elif value.parent is None and value.yang_name in self._children_yang_names:
                            value.parent = self
                    super(BundleInformation.BundleBriefs, self).__setattr__(name, value)


        class BundleBrief(Entity):
            """
            Bundle interface
            
            .. attribute:: bundle_interface  <key>
            
            	Bundle interface
            	**type**\:  str
            
            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
            
            .. attribute:: bundle_brief_item
            
            	Data for this item
            	**type**\:   :py:class:`BundleBriefItem <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.BundleBriefs.BundleBrief.BundleBriefItem>`
            
            

            """

            _prefix = 'bundlemgr-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(BundleInformation.BundleBriefs.BundleBrief, self).__init__()

                self.yang_name = "bundle-brief"
                self.yang_parent_name = "bundle-briefs"

                self.bundle_interface = YLeaf(YType.str, "bundle-interface")

                self.bundle_brief_item = BundleInformation.BundleBriefs.BundleBrief.BundleBriefItem()
                self.bundle_brief_item.parent = self
                self._children_name_map["bundle_brief_item"] = "bundle-brief-item"
                self._children_yang_names.add("bundle-brief-item")

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in ("bundle_interface") and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(BundleInformation.BundleBriefs.BundleBrief, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(BundleInformation.BundleBriefs.BundleBrief, self).__setattr__(name, value)


            class BundleBriefItem(Entity):
                """
                Data for this item
                
                .. attribute:: active_foreign_member_count
                
                	The number of active foreign members on the bundle
                	**type**\:  int
                
                	**range:** 0..65535
                
                .. attribute:: active_member_count
                
                	The number of active local members on the bundle
                	**type**\:  int
                
                	**range:** 0..65535
                
                .. attribute:: available_bandwidth
                
                	Bandwidth available to the bundle interface (kbps)
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: kbit/s
                
                .. attribute:: bfd_config
                
                	Configuration values for BFD on bundle members
                	**type**\: list of    :py:class:`BfdConfig <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.BundleBriefs.BundleBrief.BundleBriefItem.BfdConfig>`
                
                .. attribute:: bundle_interface_name
                
                	Bundle interface name
                	**type**\:  str
                
                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                
                .. attribute:: bundle_status
                
                	The state of the bundle
                	**type**\:   :py:class:`BmBdlState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmBdlState>`
                
                .. attribute:: cisco_extensions
                
                	The status of the Cisco Extensions feature (1 = enabled, 0 = not enabled)
                	**type**\:  bool
                
                .. attribute:: collector_max_delay
                
                	Collector Max Delay
                	**type**\:  int
                
                	**range:** 0..65535
                
                .. attribute:: configured_bandwidth
                
                	Bandwidth configured on the bundle interface (kbps)
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: kbit/s
                
                .. attribute:: configured_foreign_member_count
                
                	The number of configured local members on the bundle
                	**type**\:  int
                
                	**range:** 0..65535
                
                .. attribute:: configured_member_count
                
                	The number of configured local members on the bundle
                	**type**\:  int
                
                	**range:** 0..65535
                
                .. attribute:: effective_bandwidth
                
                	Effective bandwidth on the bundle interface (kbps)
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: kbit/s
                
                .. attribute:: iccp_group_id
                
                	ICCP Group that the bundle is configured to
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: inter_chassis
                
                	Indicates if this bundle is operating as an inter\-chassis link (1 = I\-C link, 0 = normal)
                	**type**\:  bool
                
                .. attribute:: ipv4bfd_status
                
                	The status of the BFD (IPv4) feature on the bundle
                	**type**\:   :py:class:`BmFeatureStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmFeatureStatus>`
                
                .. attribute:: ipv6bfd_status
                
                	The status of the BFD (IPv6) feature on the bundle
                	**type**\:   :py:class:`BmFeatureStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmFeatureStatus>`
                
                .. attribute:: is_active
                
                	Indicates the active/standby redundancy state of the device for the bundle
                	**type**\:  bool
                
                .. attribute:: lacp_nonrevertive
                
                	The status of the LACP nonrevertive feature (1 = enable, 0 = not enabled)
                	**type**\:  bool
                
                .. attribute:: lacp_status
                
                	The status of the LACP feature on the bundle
                	**type**\:   :py:class:`BmFeatureStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmFeatureStatus>`
                
                .. attribute:: link_order_status
                
                	The status of the link order signaling feature on the bundle
                	**type**\:   :py:class:`BmFeatureStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmFeatureStatus>`
                
                .. attribute:: load_balance_hash_type
                
                	The type of hash to use for load balancing
                	**type**\:  str
                
                .. attribute:: load_balance_locality_threshold
                
                	The number of links required per rack for localized load balancing
                	**type**\:  int
                
                	**range:** 0..65535
                
                .. attribute:: mac_address
                
                	MAC address of this member
                	**type**\:   :py:class:`MacAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.BundleBriefs.BundleBrief.BundleBriefItem.MacAddress>`
                
                .. attribute:: mac_source
                
                	The source of the MAC Address
                	**type**\:   :py:class:`BmBdlMacSource <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmBdlMacSource>`
                
                .. attribute:: mac_source_member
                
                	The name of the member that supplied the MAC address
                	**type**\:  str
                
                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                
                .. attribute:: maximize_threshold_value_band_width
                
                	Attempt to maximize the bundle if bandwidth is below this value
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: maximize_threshold_value_links
                
                	Attempt to maximize the bundle if links are below this value
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: maximum_active_links
                
                	Maximum number of active links in the bundle
                	**type**\:  int
                
                	**range:** 0..255
                
                .. attribute:: maximum_active_links_source
                
                	Source of maximum active links value
                	**type**\:   :py:class:`BmWhichSystem <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmWhichSystem>`
                
                .. attribute:: minimum_active_links
                
                	Minimum number of active links for bundle to go up
                	**type**\:  int
                
                	**range:** 0..255
                
                .. attribute:: minimum_bandwidth
                
                	Minimum bundle bandwidth for bundle to go up (kbps)
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: kbit/s
                
                .. attribute:: mlacp_mode
                
                	Indicates the mode of the device for the bundle
                	**type**\:   :py:class:`BundleMlacpMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleMlacpMode>`
                
                .. attribute:: mlacp_status
                
                	The status of the mLACP feature on the bundle
                	**type**\:   :py:class:`BmFeatureStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmFeatureStatus>`
                
                .. attribute:: primary_member
                
                	Primary bundle member (no longer applicable)
                	**type**\:  str
                
                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                
                .. attribute:: recovery_delay
                
                	Number of seconds to wait before becoming active after recovering from a failure
                	**type**\:  int
                
                	**range:** 0..65535
                
                	**units**\: second
                
                .. attribute:: singleton
                
                	Is the ICCP group of the bundle in singleton mode (1 = singleton; 0 = not singleton)
                	**type**\:  bool
                
                .. attribute:: standby_member_count
                
                	The number of standby local members on the bundle
                	**type**\:  int
                
                	**range:** 0..65535
                
                .. attribute:: suppression_timer
                
                	Timer for suppressing bundle state flaps
                	**type**\:  int
                
                	**range:** 0..65535
                
                .. attribute:: switchover_type
                
                	How a switchover of the bundle from this device will occur
                	**type**\:   :py:class:`BmdMlacpSwitchover <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmdMlacpSwitchover>`
                
                .. attribute:: wait_while_timer
                
                	The wait while time used for member ports
                	**type**\:  int
                
                	**range:** 0..65535
                
                

                """

                _prefix = 'bundlemgr-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(BundleInformation.BundleBriefs.BundleBrief.BundleBriefItem, self).__init__()

                    self.yang_name = "bundle-brief-item"
                    self.yang_parent_name = "bundle-brief"

                    self.active_foreign_member_count = YLeaf(YType.uint16, "active-foreign-member-count")

                    self.active_member_count = YLeaf(YType.uint16, "active-member-count")

                    self.available_bandwidth = YLeaf(YType.uint32, "available-bandwidth")

                    self.bundle_interface_name = YLeaf(YType.str, "bundle-interface-name")

                    self.bundle_status = YLeaf(YType.enumeration, "bundle-status")

                    self.cisco_extensions = YLeaf(YType.boolean, "cisco-extensions")

                    self.collector_max_delay = YLeaf(YType.uint16, "collector-max-delay")

                    self.configured_bandwidth = YLeaf(YType.uint32, "configured-bandwidth")

                    self.configured_foreign_member_count = YLeaf(YType.uint16, "configured-foreign-member-count")

                    self.configured_member_count = YLeaf(YType.uint16, "configured-member-count")

                    self.effective_bandwidth = YLeaf(YType.uint32, "effective-bandwidth")

                    self.iccp_group_id = YLeaf(YType.uint32, "iccp-group-id")

                    self.inter_chassis = YLeaf(YType.boolean, "inter-chassis")

                    self.ipv4bfd_status = YLeaf(YType.enumeration, "ipv4bfd-status")

                    self.ipv6bfd_status = YLeaf(YType.enumeration, "ipv6bfd-status")

                    self.is_active = YLeaf(YType.boolean, "is-active")

                    self.lacp_nonrevertive = YLeaf(YType.boolean, "lacp-nonrevertive")

                    self.lacp_status = YLeaf(YType.enumeration, "lacp-status")

                    self.link_order_status = YLeaf(YType.enumeration, "link-order-status")

                    self.load_balance_hash_type = YLeaf(YType.str, "load-balance-hash-type")

                    self.load_balance_locality_threshold = YLeaf(YType.uint16, "load-balance-locality-threshold")

                    self.mac_source = YLeaf(YType.enumeration, "mac-source")

                    self.mac_source_member = YLeaf(YType.str, "mac-source-member")

                    self.maximize_threshold_value_band_width = YLeaf(YType.uint32, "maximize-threshold-value-band-width")

                    self.maximize_threshold_value_links = YLeaf(YType.uint32, "maximize-threshold-value-links")

                    self.maximum_active_links = YLeaf(YType.uint8, "maximum-active-links")

                    self.maximum_active_links_source = YLeaf(YType.enumeration, "maximum-active-links-source")

                    self.minimum_active_links = YLeaf(YType.uint8, "minimum-active-links")

                    self.minimum_bandwidth = YLeaf(YType.uint32, "minimum-bandwidth")

                    self.mlacp_mode = YLeaf(YType.enumeration, "mlacp-mode")

                    self.mlacp_status = YLeaf(YType.enumeration, "mlacp-status")

                    self.primary_member = YLeaf(YType.str, "primary-member")

                    self.recovery_delay = YLeaf(YType.uint16, "recovery-delay")

                    self.singleton = YLeaf(YType.boolean, "singleton")

                    self.standby_member_count = YLeaf(YType.uint16, "standby-member-count")

                    self.suppression_timer = YLeaf(YType.uint16, "suppression-timer")

                    self.switchover_type = YLeaf(YType.enumeration, "switchover-type")

                    self.wait_while_timer = YLeaf(YType.uint16, "wait-while-timer")

                    self.mac_address = BundleInformation.BundleBriefs.BundleBrief.BundleBriefItem.MacAddress()
                    self.mac_address.parent = self
                    self._children_name_map["mac_address"] = "mac-address"
                    self._children_yang_names.add("mac-address")

                    self.bfd_config = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("active_foreign_member_count",
                                    "active_member_count",
                                    "available_bandwidth",
                                    "bundle_interface_name",
                                    "bundle_status",
                                    "cisco_extensions",
                                    "collector_max_delay",
                                    "configured_bandwidth",
                                    "configured_foreign_member_count",
                                    "configured_member_count",
                                    "effective_bandwidth",
                                    "iccp_group_id",
                                    "inter_chassis",
                                    "ipv4bfd_status",
                                    "ipv6bfd_status",
                                    "is_active",
                                    "lacp_nonrevertive",
                                    "lacp_status",
                                    "link_order_status",
                                    "load_balance_hash_type",
                                    "load_balance_locality_threshold",
                                    "mac_source",
                                    "mac_source_member",
                                    "maximize_threshold_value_band_width",
                                    "maximize_threshold_value_links",
                                    "maximum_active_links",
                                    "maximum_active_links_source",
                                    "minimum_active_links",
                                    "minimum_bandwidth",
                                    "mlacp_mode",
                                    "mlacp_status",
                                    "primary_member",
                                    "recovery_delay",
                                    "singleton",
                                    "standby_member_count",
                                    "suppression_timer",
                                    "switchover_type",
                                    "wait_while_timer") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(BundleInformation.BundleBriefs.BundleBrief.BundleBriefItem, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(BundleInformation.BundleBriefs.BundleBrief.BundleBriefItem, self).__setattr__(name, value)


                class MacAddress(Entity):
                    """
                    MAC address of this member
                    
                    .. attribute:: address
                    
                    	MAC address
                    	**type**\:  str
                    
                    	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                    
                    

                    """

                    _prefix = 'bundlemgr-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(BundleInformation.BundleBriefs.BundleBrief.BundleBriefItem.MacAddress, self).__init__()

                        self.yang_name = "mac-address"
                        self.yang_parent_name = "bundle-brief-item"

                        self.address = YLeaf(YType.str, "address")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("address") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(BundleInformation.BundleBriefs.BundleBrief.BundleBriefItem.MacAddress, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(BundleInformation.BundleBriefs.BundleBrief.BundleBriefItem.MacAddress, self).__setattr__(name, value)

                    def has_data(self):
                        return self.address.is_set

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.address.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "mac-address" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.address.is_set or self.address.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.address.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "address"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "address"):
                            self.address = value
                            self.address.value_namespace = name_space
                            self.address.value_namespace_prefix = name_space_prefix


                class BfdConfig(Entity):
                    """
                    Configuration values for BFD on bundle members
                    
                    .. attribute:: bundle_status
                    
                    	Status of BFD on the bundle
                    	**type**\:   :py:class:`BmdBfdBdlState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmdBfdBdlState>`
                    
                    .. attribute:: destination_address
                    
                    	Configured destination address for BFD session
                    	**type**\:   :py:class:`DestinationAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.BundleBriefs.BundleBrief.BundleBriefItem.BfdConfig.DestinationAddress>`
                    
                    .. attribute:: fast_detect
                    
                    	Flag indicating if BFD is enabled (1 = enabled; 0 = not enabled)
                    	**type**\:  bool
                    
                    .. attribute:: mode_info
                    
                    	Standard used for per\-member BFD
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: nbr_unconfig_timer
                    
                    	Time to wait on session NBR\_UNCONFIG before declaring DOWN
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: pref_echo_min_interval
                    
                    	Preferred echo minimum interval for the BFD session (ms)
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: pref_min_interval
                    
                    	Preferred minimum interval for the BFD session (ms)
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: pref_multiplier
                    
                    	Preferred multiplier for the BFD session
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: start_timer
                    
                    	Time to wait on session start before declaring DOWN
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'bundlemgr-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(BundleInformation.BundleBriefs.BundleBrief.BundleBriefItem.BfdConfig, self).__init__()

                        self.yang_name = "bfd-config"
                        self.yang_parent_name = "bundle-brief-item"

                        self.bundle_status = YLeaf(YType.enumeration, "bundle-status")

                        self.fast_detect = YLeaf(YType.boolean, "fast-detect")

                        self.mode_info = YLeaf(YType.uint32, "mode-info")

                        self.nbr_unconfig_timer = YLeaf(YType.uint32, "nbr-unconfig-timer")

                        self.pref_echo_min_interval = YLeaf(YType.uint32, "pref-echo-min-interval")

                        self.pref_min_interval = YLeaf(YType.uint32, "pref-min-interval")

                        self.pref_multiplier = YLeaf(YType.uint16, "pref-multiplier")

                        self.start_timer = YLeaf(YType.uint32, "start-timer")

                        self.destination_address = BundleInformation.BundleBriefs.BundleBrief.BundleBriefItem.BfdConfig.DestinationAddress()
                        self.destination_address.parent = self
                        self._children_name_map["destination_address"] = "destination-address"
                        self._children_yang_names.add("destination-address")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("bundle_status",
                                        "fast_detect",
                                        "mode_info",
                                        "nbr_unconfig_timer",
                                        "pref_echo_min_interval",
                                        "pref_min_interval",
                                        "pref_multiplier",
                                        "start_timer") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(BundleInformation.BundleBriefs.BundleBrief.BundleBriefItem.BfdConfig, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(BundleInformation.BundleBriefs.BundleBrief.BundleBriefItem.BfdConfig, self).__setattr__(name, value)


                    class DestinationAddress(Entity):
                        """
                        Configured destination address for BFD session
                        
                        .. attribute:: af
                        
                        	AF
                        	**type**\:   :py:class:`BmAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmAfId>`
                        
                        .. attribute:: ipv4
                        
                        	IPv4 address type
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6
                        
                        	IPv6 address type
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'bundlemgr-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(BundleInformation.BundleBriefs.BundleBrief.BundleBriefItem.BfdConfig.DestinationAddress, self).__init__()

                            self.yang_name = "destination-address"
                            self.yang_parent_name = "bfd-config"

                            self.af = YLeaf(YType.enumeration, "af")

                            self.ipv4 = YLeaf(YType.str, "ipv4")

                            self.ipv6 = YLeaf(YType.str, "ipv6")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af",
                                            "ipv4",
                                            "ipv6") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(BundleInformation.BundleBriefs.BundleBrief.BundleBriefItem.BfdConfig.DestinationAddress, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(BundleInformation.BundleBriefs.BundleBrief.BundleBriefItem.BfdConfig.DestinationAddress, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af.is_set or
                                self.ipv4.is_set or
                                self.ipv6.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af.yfilter != YFilter.not_set or
                                self.ipv4.yfilter != YFilter.not_set or
                                self.ipv6.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "destination-address" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af.is_set or self.af.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af.get_name_leafdata())
                            if (self.ipv4.is_set or self.ipv4.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4.get_name_leafdata())
                            if (self.ipv6.is_set or self.ipv6.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af" or name == "ipv4" or name == "ipv6"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af"):
                                self.af = value
                                self.af.value_namespace = name_space
                                self.af.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4"):
                                self.ipv4 = value
                                self.ipv4.value_namespace = name_space
                                self.ipv4.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6"):
                                self.ipv6 = value
                                self.ipv6.value_namespace = name_space
                                self.ipv6.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.bundle_status.is_set or
                            self.fast_detect.is_set or
                            self.mode_info.is_set or
                            self.nbr_unconfig_timer.is_set or
                            self.pref_echo_min_interval.is_set or
                            self.pref_min_interval.is_set or
                            self.pref_multiplier.is_set or
                            self.start_timer.is_set or
                            (self.destination_address is not None and self.destination_address.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.bundle_status.yfilter != YFilter.not_set or
                            self.fast_detect.yfilter != YFilter.not_set or
                            self.mode_info.yfilter != YFilter.not_set or
                            self.nbr_unconfig_timer.yfilter != YFilter.not_set or
                            self.pref_echo_min_interval.yfilter != YFilter.not_set or
                            self.pref_min_interval.yfilter != YFilter.not_set or
                            self.pref_multiplier.yfilter != YFilter.not_set or
                            self.start_timer.yfilter != YFilter.not_set or
                            (self.destination_address is not None and self.destination_address.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "bfd-config" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.bundle_status.is_set or self.bundle_status.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bundle_status.get_name_leafdata())
                        if (self.fast_detect.is_set or self.fast_detect.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.fast_detect.get_name_leafdata())
                        if (self.mode_info.is_set or self.mode_info.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mode_info.get_name_leafdata())
                        if (self.nbr_unconfig_timer.is_set or self.nbr_unconfig_timer.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.nbr_unconfig_timer.get_name_leafdata())
                        if (self.pref_echo_min_interval.is_set or self.pref_echo_min_interval.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.pref_echo_min_interval.get_name_leafdata())
                        if (self.pref_min_interval.is_set or self.pref_min_interval.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.pref_min_interval.get_name_leafdata())
                        if (self.pref_multiplier.is_set or self.pref_multiplier.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.pref_multiplier.get_name_leafdata())
                        if (self.start_timer.is_set or self.start_timer.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.start_timer.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "destination-address"):
                            if (self.destination_address is None):
                                self.destination_address = BundleInformation.BundleBriefs.BundleBrief.BundleBriefItem.BfdConfig.DestinationAddress()
                                self.destination_address.parent = self
                                self._children_name_map["destination_address"] = "destination-address"
                            return self.destination_address

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "destination-address" or name == "bundle-status" or name == "fast-detect" or name == "mode-info" or name == "nbr-unconfig-timer" or name == "pref-echo-min-interval" or name == "pref-min-interval" or name == "pref-multiplier" or name == "start-timer"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "bundle-status"):
                            self.bundle_status = value
                            self.bundle_status.value_namespace = name_space
                            self.bundle_status.value_namespace_prefix = name_space_prefix
                        if(value_path == "fast-detect"):
                            self.fast_detect = value
                            self.fast_detect.value_namespace = name_space
                            self.fast_detect.value_namespace_prefix = name_space_prefix
                        if(value_path == "mode-info"):
                            self.mode_info = value
                            self.mode_info.value_namespace = name_space
                            self.mode_info.value_namespace_prefix = name_space_prefix
                        if(value_path == "nbr-unconfig-timer"):
                            self.nbr_unconfig_timer = value
                            self.nbr_unconfig_timer.value_namespace = name_space
                            self.nbr_unconfig_timer.value_namespace_prefix = name_space_prefix
                        if(value_path == "pref-echo-min-interval"):
                            self.pref_echo_min_interval = value
                            self.pref_echo_min_interval.value_namespace = name_space
                            self.pref_echo_min_interval.value_namespace_prefix = name_space_prefix
                        if(value_path == "pref-min-interval"):
                            self.pref_min_interval = value
                            self.pref_min_interval.value_namespace = name_space
                            self.pref_min_interval.value_namespace_prefix = name_space_prefix
                        if(value_path == "pref-multiplier"):
                            self.pref_multiplier = value
                            self.pref_multiplier.value_namespace = name_space
                            self.pref_multiplier.value_namespace_prefix = name_space_prefix
                        if(value_path == "start-timer"):
                            self.start_timer = value
                            self.start_timer.value_namespace = name_space
                            self.start_timer.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.bfd_config:
                        if (c.has_data()):
                            return True
                    return (
                        self.active_foreign_member_count.is_set or
                        self.active_member_count.is_set or
                        self.available_bandwidth.is_set or
                        self.bundle_interface_name.is_set or
                        self.bundle_status.is_set or
                        self.cisco_extensions.is_set or
                        self.collector_max_delay.is_set or
                        self.configured_bandwidth.is_set or
                        self.configured_foreign_member_count.is_set or
                        self.configured_member_count.is_set or
                        self.effective_bandwidth.is_set or
                        self.iccp_group_id.is_set or
                        self.inter_chassis.is_set or
                        self.ipv4bfd_status.is_set or
                        self.ipv6bfd_status.is_set or
                        self.is_active.is_set or
                        self.lacp_nonrevertive.is_set or
                        self.lacp_status.is_set or
                        self.link_order_status.is_set or
                        self.load_balance_hash_type.is_set or
                        self.load_balance_locality_threshold.is_set or
                        self.mac_source.is_set or
                        self.mac_source_member.is_set or
                        self.maximize_threshold_value_band_width.is_set or
                        self.maximize_threshold_value_links.is_set or
                        self.maximum_active_links.is_set or
                        self.maximum_active_links_source.is_set or
                        self.minimum_active_links.is_set or
                        self.minimum_bandwidth.is_set or
                        self.mlacp_mode.is_set or
                        self.mlacp_status.is_set or
                        self.primary_member.is_set or
                        self.recovery_delay.is_set or
                        self.singleton.is_set or
                        self.standby_member_count.is_set or
                        self.suppression_timer.is_set or
                        self.switchover_type.is_set or
                        self.wait_while_timer.is_set or
                        (self.mac_address is not None and self.mac_address.has_data()))

                def has_operation(self):
                    for c in self.bfd_config:
                        if (c.has_operation()):
                            return True
                    return (
                        self.yfilter != YFilter.not_set or
                        self.active_foreign_member_count.yfilter != YFilter.not_set or
                        self.active_member_count.yfilter != YFilter.not_set or
                        self.available_bandwidth.yfilter != YFilter.not_set or
                        self.bundle_interface_name.yfilter != YFilter.not_set or
                        self.bundle_status.yfilter != YFilter.not_set or
                        self.cisco_extensions.yfilter != YFilter.not_set or
                        self.collector_max_delay.yfilter != YFilter.not_set or
                        self.configured_bandwidth.yfilter != YFilter.not_set or
                        self.configured_foreign_member_count.yfilter != YFilter.not_set or
                        self.configured_member_count.yfilter != YFilter.not_set or
                        self.effective_bandwidth.yfilter != YFilter.not_set or
                        self.iccp_group_id.yfilter != YFilter.not_set or
                        self.inter_chassis.yfilter != YFilter.not_set or
                        self.ipv4bfd_status.yfilter != YFilter.not_set or
                        self.ipv6bfd_status.yfilter != YFilter.not_set or
                        self.is_active.yfilter != YFilter.not_set or
                        self.lacp_nonrevertive.yfilter != YFilter.not_set or
                        self.lacp_status.yfilter != YFilter.not_set or
                        self.link_order_status.yfilter != YFilter.not_set or
                        self.load_balance_hash_type.yfilter != YFilter.not_set or
                        self.load_balance_locality_threshold.yfilter != YFilter.not_set or
                        self.mac_source.yfilter != YFilter.not_set or
                        self.mac_source_member.yfilter != YFilter.not_set or
                        self.maximize_threshold_value_band_width.yfilter != YFilter.not_set or
                        self.maximize_threshold_value_links.yfilter != YFilter.not_set or
                        self.maximum_active_links.yfilter != YFilter.not_set or
                        self.maximum_active_links_source.yfilter != YFilter.not_set or
                        self.minimum_active_links.yfilter != YFilter.not_set or
                        self.minimum_bandwidth.yfilter != YFilter.not_set or
                        self.mlacp_mode.yfilter != YFilter.not_set or
                        self.mlacp_status.yfilter != YFilter.not_set or
                        self.primary_member.yfilter != YFilter.not_set or
                        self.recovery_delay.yfilter != YFilter.not_set or
                        self.singleton.yfilter != YFilter.not_set or
                        self.standby_member_count.yfilter != YFilter.not_set or
                        self.suppression_timer.yfilter != YFilter.not_set or
                        self.switchover_type.yfilter != YFilter.not_set or
                        self.wait_while_timer.yfilter != YFilter.not_set or
                        (self.mac_address is not None and self.mac_address.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "bundle-brief-item" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.active_foreign_member_count.is_set or self.active_foreign_member_count.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.active_foreign_member_count.get_name_leafdata())
                    if (self.active_member_count.is_set or self.active_member_count.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.active_member_count.get_name_leafdata())
                    if (self.available_bandwidth.is_set or self.available_bandwidth.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.available_bandwidth.get_name_leafdata())
                    if (self.bundle_interface_name.is_set or self.bundle_interface_name.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.bundle_interface_name.get_name_leafdata())
                    if (self.bundle_status.is_set or self.bundle_status.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.bundle_status.get_name_leafdata())
                    if (self.cisco_extensions.is_set or self.cisco_extensions.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.cisco_extensions.get_name_leafdata())
                    if (self.collector_max_delay.is_set or self.collector_max_delay.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.collector_max_delay.get_name_leafdata())
                    if (self.configured_bandwidth.is_set or self.configured_bandwidth.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.configured_bandwidth.get_name_leafdata())
                    if (self.configured_foreign_member_count.is_set or self.configured_foreign_member_count.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.configured_foreign_member_count.get_name_leafdata())
                    if (self.configured_member_count.is_set or self.configured_member_count.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.configured_member_count.get_name_leafdata())
                    if (self.effective_bandwidth.is_set or self.effective_bandwidth.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.effective_bandwidth.get_name_leafdata())
                    if (self.iccp_group_id.is_set or self.iccp_group_id.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.iccp_group_id.get_name_leafdata())
                    if (self.inter_chassis.is_set or self.inter_chassis.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.inter_chassis.get_name_leafdata())
                    if (self.ipv4bfd_status.is_set or self.ipv4bfd_status.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.ipv4bfd_status.get_name_leafdata())
                    if (self.ipv6bfd_status.is_set or self.ipv6bfd_status.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.ipv6bfd_status.get_name_leafdata())
                    if (self.is_active.is_set or self.is_active.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_active.get_name_leafdata())
                    if (self.lacp_nonrevertive.is_set or self.lacp_nonrevertive.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.lacp_nonrevertive.get_name_leafdata())
                    if (self.lacp_status.is_set or self.lacp_status.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.lacp_status.get_name_leafdata())
                    if (self.link_order_status.is_set or self.link_order_status.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.link_order_status.get_name_leafdata())
                    if (self.load_balance_hash_type.is_set or self.load_balance_hash_type.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.load_balance_hash_type.get_name_leafdata())
                    if (self.load_balance_locality_threshold.is_set or self.load_balance_locality_threshold.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.load_balance_locality_threshold.get_name_leafdata())
                    if (self.mac_source.is_set or self.mac_source.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mac_source.get_name_leafdata())
                    if (self.mac_source_member.is_set or self.mac_source_member.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mac_source_member.get_name_leafdata())
                    if (self.maximize_threshold_value_band_width.is_set or self.maximize_threshold_value_band_width.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.maximize_threshold_value_band_width.get_name_leafdata())
                    if (self.maximize_threshold_value_links.is_set or self.maximize_threshold_value_links.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.maximize_threshold_value_links.get_name_leafdata())
                    if (self.maximum_active_links.is_set or self.maximum_active_links.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.maximum_active_links.get_name_leafdata())
                    if (self.maximum_active_links_source.is_set or self.maximum_active_links_source.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.maximum_active_links_source.get_name_leafdata())
                    if (self.minimum_active_links.is_set or self.minimum_active_links.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.minimum_active_links.get_name_leafdata())
                    if (self.minimum_bandwidth.is_set or self.minimum_bandwidth.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.minimum_bandwidth.get_name_leafdata())
                    if (self.mlacp_mode.is_set or self.mlacp_mode.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mlacp_mode.get_name_leafdata())
                    if (self.mlacp_status.is_set or self.mlacp_status.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mlacp_status.get_name_leafdata())
                    if (self.primary_member.is_set or self.primary_member.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.primary_member.get_name_leafdata())
                    if (self.recovery_delay.is_set or self.recovery_delay.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.recovery_delay.get_name_leafdata())
                    if (self.singleton.is_set or self.singleton.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.singleton.get_name_leafdata())
                    if (self.standby_member_count.is_set or self.standby_member_count.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.standby_member_count.get_name_leafdata())
                    if (self.suppression_timer.is_set or self.suppression_timer.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.suppression_timer.get_name_leafdata())
                    if (self.switchover_type.is_set or self.switchover_type.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.switchover_type.get_name_leafdata())
                    if (self.wait_while_timer.is_set or self.wait_while_timer.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.wait_while_timer.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "bfd-config"):
                        for c in self.bfd_config:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = BundleInformation.BundleBriefs.BundleBrief.BundleBriefItem.BfdConfig()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.bfd_config.append(c)
                        return c

                    if (child_yang_name == "mac-address"):
                        if (self.mac_address is None):
                            self.mac_address = BundleInformation.BundleBriefs.BundleBrief.BundleBriefItem.MacAddress()
                            self.mac_address.parent = self
                            self._children_name_map["mac_address"] = "mac-address"
                        return self.mac_address

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "bfd-config" or name == "mac-address" or name == "active-foreign-member-count" or name == "active-member-count" or name == "available-bandwidth" or name == "bundle-interface-name" or name == "bundle-status" or name == "cisco-extensions" or name == "collector-max-delay" or name == "configured-bandwidth" or name == "configured-foreign-member-count" or name == "configured-member-count" or name == "effective-bandwidth" or name == "iccp-group-id" or name == "inter-chassis" or name == "ipv4bfd-status" or name == "ipv6bfd-status" or name == "is-active" or name == "lacp-nonrevertive" or name == "lacp-status" or name == "link-order-status" or name == "load-balance-hash-type" or name == "load-balance-locality-threshold" or name == "mac-source" or name == "mac-source-member" or name == "maximize-threshold-value-band-width" or name == "maximize-threshold-value-links" or name == "maximum-active-links" or name == "maximum-active-links-source" or name == "minimum-active-links" or name == "minimum-bandwidth" or name == "mlacp-mode" or name == "mlacp-status" or name == "primary-member" or name == "recovery-delay" or name == "singleton" or name == "standby-member-count" or name == "suppression-timer" or name == "switchover-type" or name == "wait-while-timer"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "active-foreign-member-count"):
                        self.active_foreign_member_count = value
                        self.active_foreign_member_count.value_namespace = name_space
                        self.active_foreign_member_count.value_namespace_prefix = name_space_prefix
                    if(value_path == "active-member-count"):
                        self.active_member_count = value
                        self.active_member_count.value_namespace = name_space
                        self.active_member_count.value_namespace_prefix = name_space_prefix
                    if(value_path == "available-bandwidth"):
                        self.available_bandwidth = value
                        self.available_bandwidth.value_namespace = name_space
                        self.available_bandwidth.value_namespace_prefix = name_space_prefix
                    if(value_path == "bundle-interface-name"):
                        self.bundle_interface_name = value
                        self.bundle_interface_name.value_namespace = name_space
                        self.bundle_interface_name.value_namespace_prefix = name_space_prefix
                    if(value_path == "bundle-status"):
                        self.bundle_status = value
                        self.bundle_status.value_namespace = name_space
                        self.bundle_status.value_namespace_prefix = name_space_prefix
                    if(value_path == "cisco-extensions"):
                        self.cisco_extensions = value
                        self.cisco_extensions.value_namespace = name_space
                        self.cisco_extensions.value_namespace_prefix = name_space_prefix
                    if(value_path == "collector-max-delay"):
                        self.collector_max_delay = value
                        self.collector_max_delay.value_namespace = name_space
                        self.collector_max_delay.value_namespace_prefix = name_space_prefix
                    if(value_path == "configured-bandwidth"):
                        self.configured_bandwidth = value
                        self.configured_bandwidth.value_namespace = name_space
                        self.configured_bandwidth.value_namespace_prefix = name_space_prefix
                    if(value_path == "configured-foreign-member-count"):
                        self.configured_foreign_member_count = value
                        self.configured_foreign_member_count.value_namespace = name_space
                        self.configured_foreign_member_count.value_namespace_prefix = name_space_prefix
                    if(value_path == "configured-member-count"):
                        self.configured_member_count = value
                        self.configured_member_count.value_namespace = name_space
                        self.configured_member_count.value_namespace_prefix = name_space_prefix
                    if(value_path == "effective-bandwidth"):
                        self.effective_bandwidth = value
                        self.effective_bandwidth.value_namespace = name_space
                        self.effective_bandwidth.value_namespace_prefix = name_space_prefix
                    if(value_path == "iccp-group-id"):
                        self.iccp_group_id = value
                        self.iccp_group_id.value_namespace = name_space
                        self.iccp_group_id.value_namespace_prefix = name_space_prefix
                    if(value_path == "inter-chassis"):
                        self.inter_chassis = value
                        self.inter_chassis.value_namespace = name_space
                        self.inter_chassis.value_namespace_prefix = name_space_prefix
                    if(value_path == "ipv4bfd-status"):
                        self.ipv4bfd_status = value
                        self.ipv4bfd_status.value_namespace = name_space
                        self.ipv4bfd_status.value_namespace_prefix = name_space_prefix
                    if(value_path == "ipv6bfd-status"):
                        self.ipv6bfd_status = value
                        self.ipv6bfd_status.value_namespace = name_space
                        self.ipv6bfd_status.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-active"):
                        self.is_active = value
                        self.is_active.value_namespace = name_space
                        self.is_active.value_namespace_prefix = name_space_prefix
                    if(value_path == "lacp-nonrevertive"):
                        self.lacp_nonrevertive = value
                        self.lacp_nonrevertive.value_namespace = name_space
                        self.lacp_nonrevertive.value_namespace_prefix = name_space_prefix
                    if(value_path == "lacp-status"):
                        self.lacp_status = value
                        self.lacp_status.value_namespace = name_space
                        self.lacp_status.value_namespace_prefix = name_space_prefix
                    if(value_path == "link-order-status"):
                        self.link_order_status = value
                        self.link_order_status.value_namespace = name_space
                        self.link_order_status.value_namespace_prefix = name_space_prefix
                    if(value_path == "load-balance-hash-type"):
                        self.load_balance_hash_type = value
                        self.load_balance_hash_type.value_namespace = name_space
                        self.load_balance_hash_type.value_namespace_prefix = name_space_prefix
                    if(value_path == "load-balance-locality-threshold"):
                        self.load_balance_locality_threshold = value
                        self.load_balance_locality_threshold.value_namespace = name_space
                        self.load_balance_locality_threshold.value_namespace_prefix = name_space_prefix
                    if(value_path == "mac-source"):
                        self.mac_source = value
                        self.mac_source.value_namespace = name_space
                        self.mac_source.value_namespace_prefix = name_space_prefix
                    if(value_path == "mac-source-member"):
                        self.mac_source_member = value
                        self.mac_source_member.value_namespace = name_space
                        self.mac_source_member.value_namespace_prefix = name_space_prefix
                    if(value_path == "maximize-threshold-value-band-width"):
                        self.maximize_threshold_value_band_width = value
                        self.maximize_threshold_value_band_width.value_namespace = name_space
                        self.maximize_threshold_value_band_width.value_namespace_prefix = name_space_prefix
                    if(value_path == "maximize-threshold-value-links"):
                        self.maximize_threshold_value_links = value
                        self.maximize_threshold_value_links.value_namespace = name_space
                        self.maximize_threshold_value_links.value_namespace_prefix = name_space_prefix
                    if(value_path == "maximum-active-links"):
                        self.maximum_active_links = value
                        self.maximum_active_links.value_namespace = name_space
                        self.maximum_active_links.value_namespace_prefix = name_space_prefix
                    if(value_path == "maximum-active-links-source"):
                        self.maximum_active_links_source = value
                        self.maximum_active_links_source.value_namespace = name_space
                        self.maximum_active_links_source.value_namespace_prefix = name_space_prefix
                    if(value_path == "minimum-active-links"):
                        self.minimum_active_links = value
                        self.minimum_active_links.value_namespace = name_space
                        self.minimum_active_links.value_namespace_prefix = name_space_prefix
                    if(value_path == "minimum-bandwidth"):
                        self.minimum_bandwidth = value
                        self.minimum_bandwidth.value_namespace = name_space
                        self.minimum_bandwidth.value_namespace_prefix = name_space_prefix
                    if(value_path == "mlacp-mode"):
                        self.mlacp_mode = value
                        self.mlacp_mode.value_namespace = name_space
                        self.mlacp_mode.value_namespace_prefix = name_space_prefix
                    if(value_path == "mlacp-status"):
                        self.mlacp_status = value
                        self.mlacp_status.value_namespace = name_space
                        self.mlacp_status.value_namespace_prefix = name_space_prefix
                    if(value_path == "primary-member"):
                        self.primary_member = value
                        self.primary_member.value_namespace = name_space
                        self.primary_member.value_namespace_prefix = name_space_prefix
                    if(value_path == "recovery-delay"):
                        self.recovery_delay = value
                        self.recovery_delay.value_namespace = name_space
                        self.recovery_delay.value_namespace_prefix = name_space_prefix
                    if(value_path == "singleton"):
                        self.singleton = value
                        self.singleton.value_namespace = name_space
                        self.singleton.value_namespace_prefix = name_space_prefix
                    if(value_path == "standby-member-count"):
                        self.standby_member_count = value
                        self.standby_member_count.value_namespace = name_space
                        self.standby_member_count.value_namespace_prefix = name_space_prefix
                    if(value_path == "suppression-timer"):
                        self.suppression_timer = value
                        self.suppression_timer.value_namespace = name_space
                        self.suppression_timer.value_namespace_prefix = name_space_prefix
                    if(value_path == "switchover-type"):
                        self.switchover_type = value
                        self.switchover_type.value_namespace = name_space
                        self.switchover_type.value_namespace_prefix = name_space_prefix
                    if(value_path == "wait-while-timer"):
                        self.wait_while_timer = value
                        self.wait_while_timer.value_namespace = name_space
                        self.wait_while_timer.value_namespace_prefix = name_space_prefix

            def has_data(self):
                return (
                    self.bundle_interface.is_set or
                    (self.bundle_brief_item is not None and self.bundle_brief_item.has_data()))

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    self.bundle_interface.yfilter != YFilter.not_set or
                    (self.bundle_brief_item is not None and self.bundle_brief_item.has_operation()))

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "bundle-brief" + "[bundle-interface='" + self.bundle_interface.get() + "']" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-bundlemgr-oper:bundle-information/bundle-briefs/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()
                if (self.bundle_interface.is_set or self.bundle_interface.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.bundle_interface.get_name_leafdata())

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "bundle-brief-item"):
                    if (self.bundle_brief_item is None):
                        self.bundle_brief_item = BundleInformation.BundleBriefs.BundleBrief.BundleBriefItem()
                        self.bundle_brief_item.parent = self
                        self._children_name_map["bundle_brief_item"] = "bundle-brief-item"
                    return self.bundle_brief_item

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "bundle-brief-item" or name == "bundle-interface"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                if(value_path == "bundle-interface"):
                    self.bundle_interface = value
                    self.bundle_interface.value_namespace = name_space
                    self.bundle_interface.value_namespace_prefix = name_space_prefix

        def has_data(self):
            for c in self.bundle_brief:
                if (c.has_data()):
                    return True
            return False

        def has_operation(self):
            for c in self.bundle_brief:
                if (c.has_operation()):
                    return True
            return self.yfilter != YFilter.not_set

        def get_segment_path(self):
            path_buffer = ""
            path_buffer = "bundle-briefs" + path_buffer

            return path_buffer

        def get_entity_path(self, ancestor):
            path_buffer = ""
            if (ancestor is None):
                path_buffer = "Cisco-IOS-XR-bundlemgr-oper:bundle-information/%s" % self.get_segment_path()
            else:
                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

            leaf_name_data = LeafDataList()

            entity_path = EntityPath(path_buffer, leaf_name_data)
            return entity_path

        def get_child_by_name(self, child_yang_name, segment_path):
            child = self._get_child_by_seg_name([child_yang_name, segment_path])
            if child is not None:
                return child

            if (child_yang_name == "bundle-brief"):
                for c in self.bundle_brief:
                    segment = c.get_segment_path()
                    if (segment_path == segment):
                        return c
                c = BundleInformation.BundleBriefs.BundleBrief()
                c.parent = self
                local_reference_key = "ydk::seg::%s" % segment_path
                self._local_refs[local_reference_key] = c
                self.bundle_brief.append(c)
                return c

            return None

        def has_leaf_or_child_of_name(self, name):
            if(name == "bundle-brief"):
                return True
            return False

        def set_value(self, value_path, value, name_space, name_space_prefix):
            pass


    class EventsMbr(Entity):
        """
        Bundle member events information for bundles and
        members
        
        .. attribute:: events_mbr_bundles
        
        	Bundle interfaces with member events information
        	**type**\:   :py:class:`EventsMbrBundles <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.EventsMbr.EventsMbrBundles>`
        
        .. attribute:: events_mbr_iccp_groups
        
        	Member events for all ICCP Groups
        	**type**\:   :py:class:`EventsMbrIccpGroups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.EventsMbr.EventsMbrIccpGroups>`
        
        .. attribute:: events_mbr_members
        
        	Member interfaces with bundle member events information
        	**type**\:   :py:class:`EventsMbrMembers <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.EventsMbr.EventsMbrMembers>`
        
        

        """

        _prefix = 'bundlemgr-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(BundleInformation.EventsMbr, self).__init__()

            self.yang_name = "events-mbr"
            self.yang_parent_name = "bundle-information"

            self.events_mbr_bundles = BundleInformation.EventsMbr.EventsMbrBundles()
            self.events_mbr_bundles.parent = self
            self._children_name_map["events_mbr_bundles"] = "events-mbr-bundles"
            self._children_yang_names.add("events-mbr-bundles")

            self.events_mbr_iccp_groups = BundleInformation.EventsMbr.EventsMbrIccpGroups()
            self.events_mbr_iccp_groups.parent = self
            self._children_name_map["events_mbr_iccp_groups"] = "events-mbr-iccp-groups"
            self._children_yang_names.add("events-mbr-iccp-groups")

            self.events_mbr_members = BundleInformation.EventsMbr.EventsMbrMembers()
            self.events_mbr_members.parent = self
            self._children_name_map["events_mbr_members"] = "events-mbr-members"
            self._children_yang_names.add("events-mbr-members")


        class EventsMbrBundles(Entity):
            """
            Bundle interfaces with member events
            information
            
            .. attribute:: events_mbr_bundle
            
            	Bundle interface
            	**type**\: list of    :py:class:`EventsMbrBundle <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.EventsMbr.EventsMbrBundles.EventsMbrBundle>`
            
            

            """

            _prefix = 'bundlemgr-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(BundleInformation.EventsMbr.EventsMbrBundles, self).__init__()

                self.yang_name = "events-mbr-bundles"
                self.yang_parent_name = "events-mbr"

                self.events_mbr_bundle = YList(self)

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in () and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(BundleInformation.EventsMbr.EventsMbrBundles, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(BundleInformation.EventsMbr.EventsMbrBundles, self).__setattr__(name, value)


            class EventsMbrBundle(Entity):
                """
                Bundle interface
                
                .. attribute:: bundle_interface  <key>
                
                	Bundle interface
                	**type**\:  str
                
                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                
                .. attribute:: events_mbr_bundle_children_members
                
                	Children of bundle with member events information
                	**type**\:   :py:class:`EventsMbrBundleChildrenMembers <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.EventsMbr.EventsMbrBundles.EventsMbrBundle.EventsMbrBundleChildrenMembers>`
                
                .. attribute:: events_mbr_bundle_descendant
                
                	Data for this item and all its members
                	**type**\:   :py:class:`EventsMbrBundleDescendant <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.EventsMbr.EventsMbrBundles.EventsMbrBundle.EventsMbrBundleDescendant>`
                
                

                """

                _prefix = 'bundlemgr-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(BundleInformation.EventsMbr.EventsMbrBundles.EventsMbrBundle, self).__init__()

                    self.yang_name = "events-mbr-bundle"
                    self.yang_parent_name = "events-mbr-bundles"

                    self.bundle_interface = YLeaf(YType.str, "bundle-interface")

                    self.events_mbr_bundle_children_members = BundleInformation.EventsMbr.EventsMbrBundles.EventsMbrBundle.EventsMbrBundleChildrenMembers()
                    self.events_mbr_bundle_children_members.parent = self
                    self._children_name_map["events_mbr_bundle_children_members"] = "events-mbr-bundle-children-members"
                    self._children_yang_names.add("events-mbr-bundle-children-members")

                    self.events_mbr_bundle_descendant = BundleInformation.EventsMbr.EventsMbrBundles.EventsMbrBundle.EventsMbrBundleDescendant()
                    self.events_mbr_bundle_descendant.parent = self
                    self._children_name_map["events_mbr_bundle_descendant"] = "events-mbr-bundle-descendant"
                    self._children_yang_names.add("events-mbr-bundle-descendant")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("bundle_interface") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(BundleInformation.EventsMbr.EventsMbrBundles.EventsMbrBundle, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(BundleInformation.EventsMbr.EventsMbrBundles.EventsMbrBundle, self).__setattr__(name, value)


                class EventsMbrBundleChildrenMembers(Entity):
                    """
                    Children of bundle with member events
                    information
                    
                    .. attribute:: events_mbr_bundle_children_member
                    
                    	Bundle member item with member events information
                    	**type**\: list of    :py:class:`EventsMbrBundleChildrenMember <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.EventsMbr.EventsMbrBundles.EventsMbrBundle.EventsMbrBundleChildrenMembers.EventsMbrBundleChildrenMember>`
                    
                    

                    """

                    _prefix = 'bundlemgr-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(BundleInformation.EventsMbr.EventsMbrBundles.EventsMbrBundle.EventsMbrBundleChildrenMembers, self).__init__()

                        self.yang_name = "events-mbr-bundle-children-members"
                        self.yang_parent_name = "events-mbr-bundle"

                        self.events_mbr_bundle_children_member = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(BundleInformation.EventsMbr.EventsMbrBundles.EventsMbrBundle.EventsMbrBundleChildrenMembers, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(BundleInformation.EventsMbr.EventsMbrBundles.EventsMbrBundle.EventsMbrBundleChildrenMembers, self).__setattr__(name, value)


                    class EventsMbrBundleChildrenMember(Entity):
                        """
                        Bundle member item with member events
                        information
                        
                        .. attribute:: member_interface  <key>
                        
                        	Member interface
                        	**type**\:  str
                        
                        .. attribute:: item_name
                        
                        	Name for the current item to use
                        	**type**\:  str
                        
                        .. attribute:: items
                        
                        	Event items
                        	**type**\: list of    :py:class:`Items <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.EventsMbr.EventsMbrBundles.EventsMbrBundle.EventsMbrBundleChildrenMembers.EventsMbrBundleChildrenMember.Items>`
                        
                        

                        """

                        _prefix = 'bundlemgr-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(BundleInformation.EventsMbr.EventsMbrBundles.EventsMbrBundle.EventsMbrBundleChildrenMembers.EventsMbrBundleChildrenMember, self).__init__()

                            self.yang_name = "events-mbr-bundle-children-member"
                            self.yang_parent_name = "events-mbr-bundle-children-members"

                            self.member_interface = YLeaf(YType.str, "member-interface")

                            self.item_name = YLeaf(YType.str, "item-name")

                            self.items = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("member_interface",
                                            "item_name") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(BundleInformation.EventsMbr.EventsMbrBundles.EventsMbrBundle.EventsMbrBundleChildrenMembers.EventsMbrBundleChildrenMember, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(BundleInformation.EventsMbr.EventsMbrBundles.EventsMbrBundle.EventsMbrBundleChildrenMembers.EventsMbrBundleChildrenMember, self).__setattr__(name, value)


                        class Items(Entity):
                            """
                            Event items
                            
                            .. attribute:: bundle_evt_info
                            
                            	Event information for a bundle
                            	**type**\:   :py:class:`BundleEvtInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.EventsMbr.EventsMbrBundles.EventsMbrBundle.EventsMbrBundleChildrenMembers.EventsMbrBundleChildrenMember.Items.BundleEvtInfo>`
                            
                            .. attribute:: event_type
                            
                            	EventType
                            	**type**\:   :py:class:`BmdBagTarget <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmdBagTarget>`
                            
                            .. attribute:: member_evt_info
                            
                            	Event information for a member
                            	**type**\:   :py:class:`MemberEvtInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.EventsMbr.EventsMbrBundles.EventsMbrBundle.EventsMbrBundleChildrenMembers.EventsMbrBundleChildrenMember.Items.MemberEvtInfo>`
                            
                            .. attribute:: rg_evt_info
                            
                            	Event information for an RG
                            	**type**\:   :py:class:`RgEvtInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.EventsMbr.EventsMbrBundles.EventsMbrBundle.EventsMbrBundleChildrenMembers.EventsMbrBundleChildrenMember.Items.RgEvtInfo>`
                            
                            

                            """

                            _prefix = 'bundlemgr-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(BundleInformation.EventsMbr.EventsMbrBundles.EventsMbrBundle.EventsMbrBundleChildrenMembers.EventsMbrBundleChildrenMember.Items, self).__init__()

                                self.yang_name = "items"
                                self.yang_parent_name = "events-mbr-bundle-children-member"

                                self.event_type = YLeaf(YType.enumeration, "event-type")

                                self.bundle_evt_info = BundleInformation.EventsMbr.EventsMbrBundles.EventsMbrBundle.EventsMbrBundleChildrenMembers.EventsMbrBundleChildrenMember.Items.BundleEvtInfo()
                                self.bundle_evt_info.parent = self
                                self._children_name_map["bundle_evt_info"] = "bundle-evt-info"
                                self._children_yang_names.add("bundle-evt-info")

                                self.member_evt_info = BundleInformation.EventsMbr.EventsMbrBundles.EventsMbrBundle.EventsMbrBundleChildrenMembers.EventsMbrBundleChildrenMember.Items.MemberEvtInfo()
                                self.member_evt_info.parent = self
                                self._children_name_map["member_evt_info"] = "member-evt-info"
                                self._children_yang_names.add("member-evt-info")

                                self.rg_evt_info = BundleInformation.EventsMbr.EventsMbrBundles.EventsMbrBundle.EventsMbrBundleChildrenMembers.EventsMbrBundleChildrenMember.Items.RgEvtInfo()
                                self.rg_evt_info.parent = self
                                self._children_name_map["rg_evt_info"] = "rg-evt-info"
                                self._children_yang_names.add("rg-evt-info")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("event_type") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(BundleInformation.EventsMbr.EventsMbrBundles.EventsMbrBundle.EventsMbrBundleChildrenMembers.EventsMbrBundleChildrenMember.Items, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(BundleInformation.EventsMbr.EventsMbrBundles.EventsMbrBundle.EventsMbrBundleChildrenMembers.EventsMbrBundleChildrenMember.Items, self).__setattr__(name, value)


                            class MemberEvtInfo(Entity):
                                """
                                Event information for a member
                                
                                .. attribute:: data
                                
                                	Additional data for the event
                                	**type**\:   :py:class:`Data <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.EventsMbr.EventsMbrBundles.EventsMbrBundle.EventsMbrBundleChildrenMembers.EventsMbrBundleChildrenMember.Items.MemberEvtInfo.Data>`
                                
                                .. attribute:: member_event_type
                                
                                	Type of event for member
                                	**type**\:   :py:class:`BmdBagEventMbrItem <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmdBagEventMbrItem>`
                                
                                .. attribute:: time_stamp
                                
                                	Time stamp of the event
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'bundlemgr-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(BundleInformation.EventsMbr.EventsMbrBundles.EventsMbrBundle.EventsMbrBundleChildrenMembers.EventsMbrBundleChildrenMember.Items.MemberEvtInfo, self).__init__()

                                    self.yang_name = "member-evt-info"
                                    self.yang_parent_name = "items"

                                    self.member_event_type = YLeaf(YType.enumeration, "member-event-type")

                                    self.time_stamp = YLeaf(YType.uint64, "time-stamp")

                                    self.data = BundleInformation.EventsMbr.EventsMbrBundles.EventsMbrBundle.EventsMbrBundleChildrenMembers.EventsMbrBundleChildrenMember.Items.MemberEvtInfo.Data()
                                    self.data.parent = self
                                    self._children_name_map["data"] = "data"
                                    self._children_yang_names.add("data")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("member_event_type",
                                                    "time_stamp") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(BundleInformation.EventsMbr.EventsMbrBundles.EventsMbrBundle.EventsMbrBundleChildrenMembers.EventsMbrBundleChildrenMember.Items.MemberEvtInfo, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(BundleInformation.EventsMbr.EventsMbrBundles.EventsMbrBundle.EventsMbrBundleChildrenMembers.EventsMbrBundleChildrenMember.Items.MemberEvtInfo, self).__setattr__(name, value)


                                class Data(Entity):
                                    """
                                    Additional data for the event
                                    
                                    .. attribute:: data_type
                                    
                                    	DataType
                                    	**type**\:   :py:class:`BmdBagEventData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmdBagEventData>`
                                    
                                    .. attribute:: error
                                    
                                    	Error
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: no_data
                                    
                                    	NoData
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: string_data
                                    
                                    	StringData
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'bundlemgr-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(BundleInformation.EventsMbr.EventsMbrBundles.EventsMbrBundle.EventsMbrBundleChildrenMembers.EventsMbrBundleChildrenMember.Items.MemberEvtInfo.Data, self).__init__()

                                        self.yang_name = "data"
                                        self.yang_parent_name = "member-evt-info"

                                        self.data_type = YLeaf(YType.enumeration, "data-type")

                                        self.error = YLeaf(YType.uint32, "error")

                                        self.no_data = YLeaf(YType.uint8, "no-data")

                                        self.string_data = YLeaf(YType.str, "string-data")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data_type",
                                                        "error",
                                                        "no_data",
                                                        "string_data") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(BundleInformation.EventsMbr.EventsMbrBundles.EventsMbrBundle.EventsMbrBundleChildrenMembers.EventsMbrBundleChildrenMember.Items.MemberEvtInfo.Data, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(BundleInformation.EventsMbr.EventsMbrBundles.EventsMbrBundle.EventsMbrBundleChildrenMembers.EventsMbrBundleChildrenMember.Items.MemberEvtInfo.Data, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data_type.is_set or
                                            self.error.is_set or
                                            self.no_data.is_set or
                                            self.string_data.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data_type.yfilter != YFilter.not_set or
                                            self.error.yfilter != YFilter.not_set or
                                            self.no_data.yfilter != YFilter.not_set or
                                            self.string_data.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "data" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data_type.is_set or self.data_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data_type.get_name_leafdata())
                                        if (self.error.is_set or self.error.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.error.get_name_leafdata())
                                        if (self.no_data.is_set or self.no_data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.no_data.get_name_leafdata())
                                        if (self.string_data.is_set or self.string_data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.string_data.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data-type" or name == "error" or name == "no-data" or name == "string-data"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data-type"):
                                            self.data_type = value
                                            self.data_type.value_namespace = name_space
                                            self.data_type.value_namespace_prefix = name_space_prefix
                                        if(value_path == "error"):
                                            self.error = value
                                            self.error.value_namespace = name_space
                                            self.error.value_namespace_prefix = name_space_prefix
                                        if(value_path == "no-data"):
                                            self.no_data = value
                                            self.no_data.value_namespace = name_space
                                            self.no_data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "string-data"):
                                            self.string_data = value
                                            self.string_data.value_namespace = name_space
                                            self.string_data.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.member_event_type.is_set or
                                        self.time_stamp.is_set or
                                        (self.data is not None and self.data.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.member_event_type.yfilter != YFilter.not_set or
                                        self.time_stamp.yfilter != YFilter.not_set or
                                        (self.data is not None and self.data.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "member-evt-info" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.member_event_type.is_set or self.member_event_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.member_event_type.get_name_leafdata())
                                    if (self.time_stamp.is_set or self.time_stamp.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.time_stamp.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "data"):
                                        if (self.data is None):
                                            self.data = BundleInformation.EventsMbr.EventsMbrBundles.EventsMbrBundle.EventsMbrBundleChildrenMembers.EventsMbrBundleChildrenMember.Items.MemberEvtInfo.Data()
                                            self.data.parent = self
                                            self._children_name_map["data"] = "data"
                                        return self.data

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "data" or name == "member-event-type" or name == "time-stamp"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "member-event-type"):
                                        self.member_event_type = value
                                        self.member_event_type.value_namespace = name_space
                                        self.member_event_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "time-stamp"):
                                        self.time_stamp = value
                                        self.time_stamp.value_namespace = name_space
                                        self.time_stamp.value_namespace_prefix = name_space_prefix


                            class BundleEvtInfo(Entity):
                                """
                                Event information for a bundle
                                
                                .. attribute:: bundle_event_type
                                
                                	Type of event for bundle
                                	**type**\:   :py:class:`BmdBagEventBdlItem <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmdBagEventBdlItem>`
                                
                                .. attribute:: data
                                
                                	Additional data for the event
                                	**type**\:   :py:class:`Data <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.EventsMbr.EventsMbrBundles.EventsMbrBundle.EventsMbrBundleChildrenMembers.EventsMbrBundleChildrenMember.Items.BundleEvtInfo.Data>`
                                
                                .. attribute:: time_stamp
                                
                                	Time stamp of the event
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'bundlemgr-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(BundleInformation.EventsMbr.EventsMbrBundles.EventsMbrBundle.EventsMbrBundleChildrenMembers.EventsMbrBundleChildrenMember.Items.BundleEvtInfo, self).__init__()

                                    self.yang_name = "bundle-evt-info"
                                    self.yang_parent_name = "items"

                                    self.bundle_event_type = YLeaf(YType.enumeration, "bundle-event-type")

                                    self.time_stamp = YLeaf(YType.uint64, "time-stamp")

                                    self.data = BundleInformation.EventsMbr.EventsMbrBundles.EventsMbrBundle.EventsMbrBundleChildrenMembers.EventsMbrBundleChildrenMember.Items.BundleEvtInfo.Data()
                                    self.data.parent = self
                                    self._children_name_map["data"] = "data"
                                    self._children_yang_names.add("data")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("bundle_event_type",
                                                    "time_stamp") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(BundleInformation.EventsMbr.EventsMbrBundles.EventsMbrBundle.EventsMbrBundleChildrenMembers.EventsMbrBundleChildrenMember.Items.BundleEvtInfo, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(BundleInformation.EventsMbr.EventsMbrBundles.EventsMbrBundle.EventsMbrBundleChildrenMembers.EventsMbrBundleChildrenMember.Items.BundleEvtInfo, self).__setattr__(name, value)


                                class Data(Entity):
                                    """
                                    Additional data for the event
                                    
                                    .. attribute:: data_type
                                    
                                    	DataType
                                    	**type**\:   :py:class:`BmdBagEventData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmdBagEventData>`
                                    
                                    .. attribute:: error
                                    
                                    	Error
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: no_data
                                    
                                    	NoData
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: string_data
                                    
                                    	StringData
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'bundlemgr-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(BundleInformation.EventsMbr.EventsMbrBundles.EventsMbrBundle.EventsMbrBundleChildrenMembers.EventsMbrBundleChildrenMember.Items.BundleEvtInfo.Data, self).__init__()

                                        self.yang_name = "data"
                                        self.yang_parent_name = "bundle-evt-info"

                                        self.data_type = YLeaf(YType.enumeration, "data-type")

                                        self.error = YLeaf(YType.uint32, "error")

                                        self.no_data = YLeaf(YType.uint8, "no-data")

                                        self.string_data = YLeaf(YType.str, "string-data")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data_type",
                                                        "error",
                                                        "no_data",
                                                        "string_data") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(BundleInformation.EventsMbr.EventsMbrBundles.EventsMbrBundle.EventsMbrBundleChildrenMembers.EventsMbrBundleChildrenMember.Items.BundleEvtInfo.Data, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(BundleInformation.EventsMbr.EventsMbrBundles.EventsMbrBundle.EventsMbrBundleChildrenMembers.EventsMbrBundleChildrenMember.Items.BundleEvtInfo.Data, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data_type.is_set or
                                            self.error.is_set or
                                            self.no_data.is_set or
                                            self.string_data.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data_type.yfilter != YFilter.not_set or
                                            self.error.yfilter != YFilter.not_set or
                                            self.no_data.yfilter != YFilter.not_set or
                                            self.string_data.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "data" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data_type.is_set or self.data_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data_type.get_name_leafdata())
                                        if (self.error.is_set or self.error.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.error.get_name_leafdata())
                                        if (self.no_data.is_set or self.no_data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.no_data.get_name_leafdata())
                                        if (self.string_data.is_set or self.string_data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.string_data.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data-type" or name == "error" or name == "no-data" or name == "string-data"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data-type"):
                                            self.data_type = value
                                            self.data_type.value_namespace = name_space
                                            self.data_type.value_namespace_prefix = name_space_prefix
                                        if(value_path == "error"):
                                            self.error = value
                                            self.error.value_namespace = name_space
                                            self.error.value_namespace_prefix = name_space_prefix
                                        if(value_path == "no-data"):
                                            self.no_data = value
                                            self.no_data.value_namespace = name_space
                                            self.no_data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "string-data"):
                                            self.string_data = value
                                            self.string_data.value_namespace = name_space
                                            self.string_data.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.bundle_event_type.is_set or
                                        self.time_stamp.is_set or
                                        (self.data is not None and self.data.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.bundle_event_type.yfilter != YFilter.not_set or
                                        self.time_stamp.yfilter != YFilter.not_set or
                                        (self.data is not None and self.data.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "bundle-evt-info" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.bundle_event_type.is_set or self.bundle_event_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.bundle_event_type.get_name_leafdata())
                                    if (self.time_stamp.is_set or self.time_stamp.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.time_stamp.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "data"):
                                        if (self.data is None):
                                            self.data = BundleInformation.EventsMbr.EventsMbrBundles.EventsMbrBundle.EventsMbrBundleChildrenMembers.EventsMbrBundleChildrenMember.Items.BundleEvtInfo.Data()
                                            self.data.parent = self
                                            self._children_name_map["data"] = "data"
                                        return self.data

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "data" or name == "bundle-event-type" or name == "time-stamp"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "bundle-event-type"):
                                        self.bundle_event_type = value
                                        self.bundle_event_type.value_namespace = name_space
                                        self.bundle_event_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "time-stamp"):
                                        self.time_stamp = value
                                        self.time_stamp.value_namespace = name_space
                                        self.time_stamp.value_namespace_prefix = name_space_prefix


                            class RgEvtInfo(Entity):
                                """
                                Event information for an RG
                                
                                .. attribute:: data
                                
                                	Additional data for the event
                                	**type**\:   :py:class:`Data <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.EventsMbr.EventsMbrBundles.EventsMbrBundle.EventsMbrBundleChildrenMembers.EventsMbrBundleChildrenMember.Items.RgEvtInfo.Data>`
                                
                                .. attribute:: rg_event_type
                                
                                	Type of event for RG
                                	**type**\:   :py:class:`BmdBagEventRgItem <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmdBagEventRgItem>`
                                
                                .. attribute:: time_stamp
                                
                                	Time stamp of the event
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'bundlemgr-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(BundleInformation.EventsMbr.EventsMbrBundles.EventsMbrBundle.EventsMbrBundleChildrenMembers.EventsMbrBundleChildrenMember.Items.RgEvtInfo, self).__init__()

                                    self.yang_name = "rg-evt-info"
                                    self.yang_parent_name = "items"

                                    self.rg_event_type = YLeaf(YType.enumeration, "rg-event-type")

                                    self.time_stamp = YLeaf(YType.uint64, "time-stamp")

                                    self.data = BundleInformation.EventsMbr.EventsMbrBundles.EventsMbrBundle.EventsMbrBundleChildrenMembers.EventsMbrBundleChildrenMember.Items.RgEvtInfo.Data()
                                    self.data.parent = self
                                    self._children_name_map["data"] = "data"
                                    self._children_yang_names.add("data")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("rg_event_type",
                                                    "time_stamp") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(BundleInformation.EventsMbr.EventsMbrBundles.EventsMbrBundle.EventsMbrBundleChildrenMembers.EventsMbrBundleChildrenMember.Items.RgEvtInfo, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(BundleInformation.EventsMbr.EventsMbrBundles.EventsMbrBundle.EventsMbrBundleChildrenMembers.EventsMbrBundleChildrenMember.Items.RgEvtInfo, self).__setattr__(name, value)


                                class Data(Entity):
                                    """
                                    Additional data for the event
                                    
                                    .. attribute:: data_type
                                    
                                    	DataType
                                    	**type**\:   :py:class:`BmdBagEventData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmdBagEventData>`
                                    
                                    .. attribute:: error
                                    
                                    	Error
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: no_data
                                    
                                    	NoData
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: string_data
                                    
                                    	StringData
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'bundlemgr-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(BundleInformation.EventsMbr.EventsMbrBundles.EventsMbrBundle.EventsMbrBundleChildrenMembers.EventsMbrBundleChildrenMember.Items.RgEvtInfo.Data, self).__init__()

                                        self.yang_name = "data"
                                        self.yang_parent_name = "rg-evt-info"

                                        self.data_type = YLeaf(YType.enumeration, "data-type")

                                        self.error = YLeaf(YType.uint32, "error")

                                        self.no_data = YLeaf(YType.uint8, "no-data")

                                        self.string_data = YLeaf(YType.str, "string-data")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data_type",
                                                        "error",
                                                        "no_data",
                                                        "string_data") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(BundleInformation.EventsMbr.EventsMbrBundles.EventsMbrBundle.EventsMbrBundleChildrenMembers.EventsMbrBundleChildrenMember.Items.RgEvtInfo.Data, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(BundleInformation.EventsMbr.EventsMbrBundles.EventsMbrBundle.EventsMbrBundleChildrenMembers.EventsMbrBundleChildrenMember.Items.RgEvtInfo.Data, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data_type.is_set or
                                            self.error.is_set or
                                            self.no_data.is_set or
                                            self.string_data.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data_type.yfilter != YFilter.not_set or
                                            self.error.yfilter != YFilter.not_set or
                                            self.no_data.yfilter != YFilter.not_set or
                                            self.string_data.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "data" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data_type.is_set or self.data_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data_type.get_name_leafdata())
                                        if (self.error.is_set or self.error.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.error.get_name_leafdata())
                                        if (self.no_data.is_set or self.no_data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.no_data.get_name_leafdata())
                                        if (self.string_data.is_set or self.string_data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.string_data.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data-type" or name == "error" or name == "no-data" or name == "string-data"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data-type"):
                                            self.data_type = value
                                            self.data_type.value_namespace = name_space
                                            self.data_type.value_namespace_prefix = name_space_prefix
                                        if(value_path == "error"):
                                            self.error = value
                                            self.error.value_namespace = name_space
                                            self.error.value_namespace_prefix = name_space_prefix
                                        if(value_path == "no-data"):
                                            self.no_data = value
                                            self.no_data.value_namespace = name_space
                                            self.no_data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "string-data"):
                                            self.string_data = value
                                            self.string_data.value_namespace = name_space
                                            self.string_data.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.rg_event_type.is_set or
                                        self.time_stamp.is_set or
                                        (self.data is not None and self.data.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.rg_event_type.yfilter != YFilter.not_set or
                                        self.time_stamp.yfilter != YFilter.not_set or
                                        (self.data is not None and self.data.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "rg-evt-info" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.rg_event_type.is_set or self.rg_event_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.rg_event_type.get_name_leafdata())
                                    if (self.time_stamp.is_set or self.time_stamp.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.time_stamp.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "data"):
                                        if (self.data is None):
                                            self.data = BundleInformation.EventsMbr.EventsMbrBundles.EventsMbrBundle.EventsMbrBundleChildrenMembers.EventsMbrBundleChildrenMember.Items.RgEvtInfo.Data()
                                            self.data.parent = self
                                            self._children_name_map["data"] = "data"
                                        return self.data

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "data" or name == "rg-event-type" or name == "time-stamp"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "rg-event-type"):
                                        self.rg_event_type = value
                                        self.rg_event_type.value_namespace = name_space
                                        self.rg_event_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "time-stamp"):
                                        self.time_stamp = value
                                        self.time_stamp.value_namespace = name_space
                                        self.time_stamp.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.event_type.is_set or
                                    (self.bundle_evt_info is not None and self.bundle_evt_info.has_data()) or
                                    (self.member_evt_info is not None and self.member_evt_info.has_data()) or
                                    (self.rg_evt_info is not None and self.rg_evt_info.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.event_type.yfilter != YFilter.not_set or
                                    (self.bundle_evt_info is not None and self.bundle_evt_info.has_operation()) or
                                    (self.member_evt_info is not None and self.member_evt_info.has_operation()) or
                                    (self.rg_evt_info is not None and self.rg_evt_info.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "items" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.event_type.is_set or self.event_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.event_type.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "bundle-evt-info"):
                                    if (self.bundle_evt_info is None):
                                        self.bundle_evt_info = BundleInformation.EventsMbr.EventsMbrBundles.EventsMbrBundle.EventsMbrBundleChildrenMembers.EventsMbrBundleChildrenMember.Items.BundleEvtInfo()
                                        self.bundle_evt_info.parent = self
                                        self._children_name_map["bundle_evt_info"] = "bundle-evt-info"
                                    return self.bundle_evt_info

                                if (child_yang_name == "member-evt-info"):
                                    if (self.member_evt_info is None):
                                        self.member_evt_info = BundleInformation.EventsMbr.EventsMbrBundles.EventsMbrBundle.EventsMbrBundleChildrenMembers.EventsMbrBundleChildrenMember.Items.MemberEvtInfo()
                                        self.member_evt_info.parent = self
                                        self._children_name_map["member_evt_info"] = "member-evt-info"
                                    return self.member_evt_info

                                if (child_yang_name == "rg-evt-info"):
                                    if (self.rg_evt_info is None):
                                        self.rg_evt_info = BundleInformation.EventsMbr.EventsMbrBundles.EventsMbrBundle.EventsMbrBundleChildrenMembers.EventsMbrBundleChildrenMember.Items.RgEvtInfo()
                                        self.rg_evt_info.parent = self
                                        self._children_name_map["rg_evt_info"] = "rg-evt-info"
                                    return self.rg_evt_info

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "bundle-evt-info" or name == "member-evt-info" or name == "rg-evt-info" or name == "event-type"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "event-type"):
                                    self.event_type = value
                                    self.event_type.value_namespace = name_space
                                    self.event_type.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.items:
                                if (c.has_data()):
                                    return True
                            return (
                                self.member_interface.is_set or
                                self.item_name.is_set)

                        def has_operation(self):
                            for c in self.items:
                                if (c.has_operation()):
                                    return True
                            return (
                                self.yfilter != YFilter.not_set or
                                self.member_interface.yfilter != YFilter.not_set or
                                self.item_name.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "events-mbr-bundle-children-member" + "[member-interface='" + self.member_interface.get() + "']" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.member_interface.is_set or self.member_interface.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.member_interface.get_name_leafdata())
                            if (self.item_name.is_set or self.item_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.item_name.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "items"):
                                for c in self.items:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = BundleInformation.EventsMbr.EventsMbrBundles.EventsMbrBundle.EventsMbrBundleChildrenMembers.EventsMbrBundleChildrenMember.Items()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.items.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "items" or name == "member-interface" or name == "item-name"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "member-interface"):
                                self.member_interface = value
                                self.member_interface.value_namespace = name_space
                                self.member_interface.value_namespace_prefix = name_space_prefix
                            if(value_path == "item-name"):
                                self.item_name = value
                                self.item_name.value_namespace = name_space
                                self.item_name.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.events_mbr_bundle_children_member:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.events_mbr_bundle_children_member:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "events-mbr-bundle-children-members" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "events-mbr-bundle-children-member"):
                            for c in self.events_mbr_bundle_children_member:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = BundleInformation.EventsMbr.EventsMbrBundles.EventsMbrBundle.EventsMbrBundleChildrenMembers.EventsMbrBundleChildrenMember()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.events_mbr_bundle_children_member.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "events-mbr-bundle-children-member"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class EventsMbrBundleDescendant(Entity):
                    """
                    Data for this item and all its members
                    
                    .. attribute:: events_item
                    
                    	Event items
                    	**type**\: list of    :py:class:`EventsItem <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.EventsMbr.EventsMbrBundles.EventsMbrBundle.EventsMbrBundleDescendant.EventsItem>`
                    
                    

                    """

                    _prefix = 'bundlemgr-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(BundleInformation.EventsMbr.EventsMbrBundles.EventsMbrBundle.EventsMbrBundleDescendant, self).__init__()

                        self.yang_name = "events-mbr-bundle-descendant"
                        self.yang_parent_name = "events-mbr-bundle"

                        self.events_item = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(BundleInformation.EventsMbr.EventsMbrBundles.EventsMbrBundle.EventsMbrBundleDescendant, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(BundleInformation.EventsMbr.EventsMbrBundles.EventsMbrBundle.EventsMbrBundleDescendant, self).__setattr__(name, value)


                    class EventsItem(Entity):
                        """
                        Event items
                        
                        .. attribute:: item_name
                        
                        	Name for the current item to use
                        	**type**\:  str
                        
                        .. attribute:: items
                        
                        	Event items
                        	**type**\: list of    :py:class:`Items <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.EventsMbr.EventsMbrBundles.EventsMbrBundle.EventsMbrBundleDescendant.EventsItem.Items>`
                        
                        

                        """

                        _prefix = 'bundlemgr-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(BundleInformation.EventsMbr.EventsMbrBundles.EventsMbrBundle.EventsMbrBundleDescendant.EventsItem, self).__init__()

                            self.yang_name = "events-item"
                            self.yang_parent_name = "events-mbr-bundle-descendant"

                            self.item_name = YLeaf(YType.str, "item-name")

                            self.items = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("item_name") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(BundleInformation.EventsMbr.EventsMbrBundles.EventsMbrBundle.EventsMbrBundleDescendant.EventsItem, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(BundleInformation.EventsMbr.EventsMbrBundles.EventsMbrBundle.EventsMbrBundleDescendant.EventsItem, self).__setattr__(name, value)


                        class Items(Entity):
                            """
                            Event items
                            
                            .. attribute:: bundle_evt_info
                            
                            	Event information for a bundle
                            	**type**\:   :py:class:`BundleEvtInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.EventsMbr.EventsMbrBundles.EventsMbrBundle.EventsMbrBundleDescendant.EventsItem.Items.BundleEvtInfo>`
                            
                            .. attribute:: event_type
                            
                            	EventType
                            	**type**\:   :py:class:`BmdBagTarget <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmdBagTarget>`
                            
                            .. attribute:: member_evt_info
                            
                            	Event information for a member
                            	**type**\:   :py:class:`MemberEvtInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.EventsMbr.EventsMbrBundles.EventsMbrBundle.EventsMbrBundleDescendant.EventsItem.Items.MemberEvtInfo>`
                            
                            .. attribute:: rg_evt_info
                            
                            	Event information for an RG
                            	**type**\:   :py:class:`RgEvtInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.EventsMbr.EventsMbrBundles.EventsMbrBundle.EventsMbrBundleDescendant.EventsItem.Items.RgEvtInfo>`
                            
                            

                            """

                            _prefix = 'bundlemgr-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(BundleInformation.EventsMbr.EventsMbrBundles.EventsMbrBundle.EventsMbrBundleDescendant.EventsItem.Items, self).__init__()

                                self.yang_name = "items"
                                self.yang_parent_name = "events-item"

                                self.event_type = YLeaf(YType.enumeration, "event-type")

                                self.bundle_evt_info = BundleInformation.EventsMbr.EventsMbrBundles.EventsMbrBundle.EventsMbrBundleDescendant.EventsItem.Items.BundleEvtInfo()
                                self.bundle_evt_info.parent = self
                                self._children_name_map["bundle_evt_info"] = "bundle-evt-info"
                                self._children_yang_names.add("bundle-evt-info")

                                self.member_evt_info = BundleInformation.EventsMbr.EventsMbrBundles.EventsMbrBundle.EventsMbrBundleDescendant.EventsItem.Items.MemberEvtInfo()
                                self.member_evt_info.parent = self
                                self._children_name_map["member_evt_info"] = "member-evt-info"
                                self._children_yang_names.add("member-evt-info")

                                self.rg_evt_info = BundleInformation.EventsMbr.EventsMbrBundles.EventsMbrBundle.EventsMbrBundleDescendant.EventsItem.Items.RgEvtInfo()
                                self.rg_evt_info.parent = self
                                self._children_name_map["rg_evt_info"] = "rg-evt-info"
                                self._children_yang_names.add("rg-evt-info")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("event_type") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(BundleInformation.EventsMbr.EventsMbrBundles.EventsMbrBundle.EventsMbrBundleDescendant.EventsItem.Items, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(BundleInformation.EventsMbr.EventsMbrBundles.EventsMbrBundle.EventsMbrBundleDescendant.EventsItem.Items, self).__setattr__(name, value)


                            class MemberEvtInfo(Entity):
                                """
                                Event information for a member
                                
                                .. attribute:: data
                                
                                	Additional data for the event
                                	**type**\:   :py:class:`Data <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.EventsMbr.EventsMbrBundles.EventsMbrBundle.EventsMbrBundleDescendant.EventsItem.Items.MemberEvtInfo.Data>`
                                
                                .. attribute:: member_event_type
                                
                                	Type of event for member
                                	**type**\:   :py:class:`BmdBagEventMbrItem <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmdBagEventMbrItem>`
                                
                                .. attribute:: time_stamp
                                
                                	Time stamp of the event
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'bundlemgr-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(BundleInformation.EventsMbr.EventsMbrBundles.EventsMbrBundle.EventsMbrBundleDescendant.EventsItem.Items.MemberEvtInfo, self).__init__()

                                    self.yang_name = "member-evt-info"
                                    self.yang_parent_name = "items"

                                    self.member_event_type = YLeaf(YType.enumeration, "member-event-type")

                                    self.time_stamp = YLeaf(YType.uint64, "time-stamp")

                                    self.data = BundleInformation.EventsMbr.EventsMbrBundles.EventsMbrBundle.EventsMbrBundleDescendant.EventsItem.Items.MemberEvtInfo.Data()
                                    self.data.parent = self
                                    self._children_name_map["data"] = "data"
                                    self._children_yang_names.add("data")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("member_event_type",
                                                    "time_stamp") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(BundleInformation.EventsMbr.EventsMbrBundles.EventsMbrBundle.EventsMbrBundleDescendant.EventsItem.Items.MemberEvtInfo, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(BundleInformation.EventsMbr.EventsMbrBundles.EventsMbrBundle.EventsMbrBundleDescendant.EventsItem.Items.MemberEvtInfo, self).__setattr__(name, value)


                                class Data(Entity):
                                    """
                                    Additional data for the event
                                    
                                    .. attribute:: data_type
                                    
                                    	DataType
                                    	**type**\:   :py:class:`BmdBagEventData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmdBagEventData>`
                                    
                                    .. attribute:: error
                                    
                                    	Error
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: no_data
                                    
                                    	NoData
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: string_data
                                    
                                    	StringData
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'bundlemgr-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(BundleInformation.EventsMbr.EventsMbrBundles.EventsMbrBundle.EventsMbrBundleDescendant.EventsItem.Items.MemberEvtInfo.Data, self).__init__()

                                        self.yang_name = "data"
                                        self.yang_parent_name = "member-evt-info"

                                        self.data_type = YLeaf(YType.enumeration, "data-type")

                                        self.error = YLeaf(YType.uint32, "error")

                                        self.no_data = YLeaf(YType.uint8, "no-data")

                                        self.string_data = YLeaf(YType.str, "string-data")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data_type",
                                                        "error",
                                                        "no_data",
                                                        "string_data") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(BundleInformation.EventsMbr.EventsMbrBundles.EventsMbrBundle.EventsMbrBundleDescendant.EventsItem.Items.MemberEvtInfo.Data, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(BundleInformation.EventsMbr.EventsMbrBundles.EventsMbrBundle.EventsMbrBundleDescendant.EventsItem.Items.MemberEvtInfo.Data, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data_type.is_set or
                                            self.error.is_set or
                                            self.no_data.is_set or
                                            self.string_data.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data_type.yfilter != YFilter.not_set or
                                            self.error.yfilter != YFilter.not_set or
                                            self.no_data.yfilter != YFilter.not_set or
                                            self.string_data.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "data" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data_type.is_set or self.data_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data_type.get_name_leafdata())
                                        if (self.error.is_set or self.error.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.error.get_name_leafdata())
                                        if (self.no_data.is_set or self.no_data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.no_data.get_name_leafdata())
                                        if (self.string_data.is_set or self.string_data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.string_data.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data-type" or name == "error" or name == "no-data" or name == "string-data"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data-type"):
                                            self.data_type = value
                                            self.data_type.value_namespace = name_space
                                            self.data_type.value_namespace_prefix = name_space_prefix
                                        if(value_path == "error"):
                                            self.error = value
                                            self.error.value_namespace = name_space
                                            self.error.value_namespace_prefix = name_space_prefix
                                        if(value_path == "no-data"):
                                            self.no_data = value
                                            self.no_data.value_namespace = name_space
                                            self.no_data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "string-data"):
                                            self.string_data = value
                                            self.string_data.value_namespace = name_space
                                            self.string_data.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.member_event_type.is_set or
                                        self.time_stamp.is_set or
                                        (self.data is not None and self.data.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.member_event_type.yfilter != YFilter.not_set or
                                        self.time_stamp.yfilter != YFilter.not_set or
                                        (self.data is not None and self.data.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "member-evt-info" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.member_event_type.is_set or self.member_event_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.member_event_type.get_name_leafdata())
                                    if (self.time_stamp.is_set or self.time_stamp.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.time_stamp.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "data"):
                                        if (self.data is None):
                                            self.data = BundleInformation.EventsMbr.EventsMbrBundles.EventsMbrBundle.EventsMbrBundleDescendant.EventsItem.Items.MemberEvtInfo.Data()
                                            self.data.parent = self
                                            self._children_name_map["data"] = "data"
                                        return self.data

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "data" or name == "member-event-type" or name == "time-stamp"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "member-event-type"):
                                        self.member_event_type = value
                                        self.member_event_type.value_namespace = name_space
                                        self.member_event_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "time-stamp"):
                                        self.time_stamp = value
                                        self.time_stamp.value_namespace = name_space
                                        self.time_stamp.value_namespace_prefix = name_space_prefix


                            class BundleEvtInfo(Entity):
                                """
                                Event information for a bundle
                                
                                .. attribute:: bundle_event_type
                                
                                	Type of event for bundle
                                	**type**\:   :py:class:`BmdBagEventBdlItem <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmdBagEventBdlItem>`
                                
                                .. attribute:: data
                                
                                	Additional data for the event
                                	**type**\:   :py:class:`Data <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.EventsMbr.EventsMbrBundles.EventsMbrBundle.EventsMbrBundleDescendant.EventsItem.Items.BundleEvtInfo.Data>`
                                
                                .. attribute:: time_stamp
                                
                                	Time stamp of the event
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'bundlemgr-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(BundleInformation.EventsMbr.EventsMbrBundles.EventsMbrBundle.EventsMbrBundleDescendant.EventsItem.Items.BundleEvtInfo, self).__init__()

                                    self.yang_name = "bundle-evt-info"
                                    self.yang_parent_name = "items"

                                    self.bundle_event_type = YLeaf(YType.enumeration, "bundle-event-type")

                                    self.time_stamp = YLeaf(YType.uint64, "time-stamp")

                                    self.data = BundleInformation.EventsMbr.EventsMbrBundles.EventsMbrBundle.EventsMbrBundleDescendant.EventsItem.Items.BundleEvtInfo.Data()
                                    self.data.parent = self
                                    self._children_name_map["data"] = "data"
                                    self._children_yang_names.add("data")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("bundle_event_type",
                                                    "time_stamp") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(BundleInformation.EventsMbr.EventsMbrBundles.EventsMbrBundle.EventsMbrBundleDescendant.EventsItem.Items.BundleEvtInfo, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(BundleInformation.EventsMbr.EventsMbrBundles.EventsMbrBundle.EventsMbrBundleDescendant.EventsItem.Items.BundleEvtInfo, self).__setattr__(name, value)


                                class Data(Entity):
                                    """
                                    Additional data for the event
                                    
                                    .. attribute:: data_type
                                    
                                    	DataType
                                    	**type**\:   :py:class:`BmdBagEventData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmdBagEventData>`
                                    
                                    .. attribute:: error
                                    
                                    	Error
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: no_data
                                    
                                    	NoData
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: string_data
                                    
                                    	StringData
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'bundlemgr-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(BundleInformation.EventsMbr.EventsMbrBundles.EventsMbrBundle.EventsMbrBundleDescendant.EventsItem.Items.BundleEvtInfo.Data, self).__init__()

                                        self.yang_name = "data"
                                        self.yang_parent_name = "bundle-evt-info"

                                        self.data_type = YLeaf(YType.enumeration, "data-type")

                                        self.error = YLeaf(YType.uint32, "error")

                                        self.no_data = YLeaf(YType.uint8, "no-data")

                                        self.string_data = YLeaf(YType.str, "string-data")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data_type",
                                                        "error",
                                                        "no_data",
                                                        "string_data") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(BundleInformation.EventsMbr.EventsMbrBundles.EventsMbrBundle.EventsMbrBundleDescendant.EventsItem.Items.BundleEvtInfo.Data, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(BundleInformation.EventsMbr.EventsMbrBundles.EventsMbrBundle.EventsMbrBundleDescendant.EventsItem.Items.BundleEvtInfo.Data, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data_type.is_set or
                                            self.error.is_set or
                                            self.no_data.is_set or
                                            self.string_data.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data_type.yfilter != YFilter.not_set or
                                            self.error.yfilter != YFilter.not_set or
                                            self.no_data.yfilter != YFilter.not_set or
                                            self.string_data.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "data" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data_type.is_set or self.data_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data_type.get_name_leafdata())
                                        if (self.error.is_set or self.error.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.error.get_name_leafdata())
                                        if (self.no_data.is_set or self.no_data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.no_data.get_name_leafdata())
                                        if (self.string_data.is_set or self.string_data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.string_data.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data-type" or name == "error" or name == "no-data" or name == "string-data"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data-type"):
                                            self.data_type = value
                                            self.data_type.value_namespace = name_space
                                            self.data_type.value_namespace_prefix = name_space_prefix
                                        if(value_path == "error"):
                                            self.error = value
                                            self.error.value_namespace = name_space
                                            self.error.value_namespace_prefix = name_space_prefix
                                        if(value_path == "no-data"):
                                            self.no_data = value
                                            self.no_data.value_namespace = name_space
                                            self.no_data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "string-data"):
                                            self.string_data = value
                                            self.string_data.value_namespace = name_space
                                            self.string_data.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.bundle_event_type.is_set or
                                        self.time_stamp.is_set or
                                        (self.data is not None and self.data.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.bundle_event_type.yfilter != YFilter.not_set or
                                        self.time_stamp.yfilter != YFilter.not_set or
                                        (self.data is not None and self.data.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "bundle-evt-info" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.bundle_event_type.is_set or self.bundle_event_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.bundle_event_type.get_name_leafdata())
                                    if (self.time_stamp.is_set or self.time_stamp.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.time_stamp.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "data"):
                                        if (self.data is None):
                                            self.data = BundleInformation.EventsMbr.EventsMbrBundles.EventsMbrBundle.EventsMbrBundleDescendant.EventsItem.Items.BundleEvtInfo.Data()
                                            self.data.parent = self
                                            self._children_name_map["data"] = "data"
                                        return self.data

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "data" or name == "bundle-event-type" or name == "time-stamp"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "bundle-event-type"):
                                        self.bundle_event_type = value
                                        self.bundle_event_type.value_namespace = name_space
                                        self.bundle_event_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "time-stamp"):
                                        self.time_stamp = value
                                        self.time_stamp.value_namespace = name_space
                                        self.time_stamp.value_namespace_prefix = name_space_prefix


                            class RgEvtInfo(Entity):
                                """
                                Event information for an RG
                                
                                .. attribute:: data
                                
                                	Additional data for the event
                                	**type**\:   :py:class:`Data <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.EventsMbr.EventsMbrBundles.EventsMbrBundle.EventsMbrBundleDescendant.EventsItem.Items.RgEvtInfo.Data>`
                                
                                .. attribute:: rg_event_type
                                
                                	Type of event for RG
                                	**type**\:   :py:class:`BmdBagEventRgItem <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmdBagEventRgItem>`
                                
                                .. attribute:: time_stamp
                                
                                	Time stamp of the event
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'bundlemgr-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(BundleInformation.EventsMbr.EventsMbrBundles.EventsMbrBundle.EventsMbrBundleDescendant.EventsItem.Items.RgEvtInfo, self).__init__()

                                    self.yang_name = "rg-evt-info"
                                    self.yang_parent_name = "items"

                                    self.rg_event_type = YLeaf(YType.enumeration, "rg-event-type")

                                    self.time_stamp = YLeaf(YType.uint64, "time-stamp")

                                    self.data = BundleInformation.EventsMbr.EventsMbrBundles.EventsMbrBundle.EventsMbrBundleDescendant.EventsItem.Items.RgEvtInfo.Data()
                                    self.data.parent = self
                                    self._children_name_map["data"] = "data"
                                    self._children_yang_names.add("data")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("rg_event_type",
                                                    "time_stamp") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(BundleInformation.EventsMbr.EventsMbrBundles.EventsMbrBundle.EventsMbrBundleDescendant.EventsItem.Items.RgEvtInfo, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(BundleInformation.EventsMbr.EventsMbrBundles.EventsMbrBundle.EventsMbrBundleDescendant.EventsItem.Items.RgEvtInfo, self).__setattr__(name, value)


                                class Data(Entity):
                                    """
                                    Additional data for the event
                                    
                                    .. attribute:: data_type
                                    
                                    	DataType
                                    	**type**\:   :py:class:`BmdBagEventData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmdBagEventData>`
                                    
                                    .. attribute:: error
                                    
                                    	Error
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: no_data
                                    
                                    	NoData
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: string_data
                                    
                                    	StringData
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'bundlemgr-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(BundleInformation.EventsMbr.EventsMbrBundles.EventsMbrBundle.EventsMbrBundleDescendant.EventsItem.Items.RgEvtInfo.Data, self).__init__()

                                        self.yang_name = "data"
                                        self.yang_parent_name = "rg-evt-info"

                                        self.data_type = YLeaf(YType.enumeration, "data-type")

                                        self.error = YLeaf(YType.uint32, "error")

                                        self.no_data = YLeaf(YType.uint8, "no-data")

                                        self.string_data = YLeaf(YType.str, "string-data")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data_type",
                                                        "error",
                                                        "no_data",
                                                        "string_data") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(BundleInformation.EventsMbr.EventsMbrBundles.EventsMbrBundle.EventsMbrBundleDescendant.EventsItem.Items.RgEvtInfo.Data, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(BundleInformation.EventsMbr.EventsMbrBundles.EventsMbrBundle.EventsMbrBundleDescendant.EventsItem.Items.RgEvtInfo.Data, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data_type.is_set or
                                            self.error.is_set or
                                            self.no_data.is_set or
                                            self.string_data.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data_type.yfilter != YFilter.not_set or
                                            self.error.yfilter != YFilter.not_set or
                                            self.no_data.yfilter != YFilter.not_set or
                                            self.string_data.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "data" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data_type.is_set or self.data_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data_type.get_name_leafdata())
                                        if (self.error.is_set or self.error.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.error.get_name_leafdata())
                                        if (self.no_data.is_set or self.no_data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.no_data.get_name_leafdata())
                                        if (self.string_data.is_set or self.string_data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.string_data.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data-type" or name == "error" or name == "no-data" or name == "string-data"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data-type"):
                                            self.data_type = value
                                            self.data_type.value_namespace = name_space
                                            self.data_type.value_namespace_prefix = name_space_prefix
                                        if(value_path == "error"):
                                            self.error = value
                                            self.error.value_namespace = name_space
                                            self.error.value_namespace_prefix = name_space_prefix
                                        if(value_path == "no-data"):
                                            self.no_data = value
                                            self.no_data.value_namespace = name_space
                                            self.no_data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "string-data"):
                                            self.string_data = value
                                            self.string_data.value_namespace = name_space
                                            self.string_data.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.rg_event_type.is_set or
                                        self.time_stamp.is_set or
                                        (self.data is not None and self.data.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.rg_event_type.yfilter != YFilter.not_set or
                                        self.time_stamp.yfilter != YFilter.not_set or
                                        (self.data is not None and self.data.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "rg-evt-info" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.rg_event_type.is_set or self.rg_event_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.rg_event_type.get_name_leafdata())
                                    if (self.time_stamp.is_set or self.time_stamp.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.time_stamp.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "data"):
                                        if (self.data is None):
                                            self.data = BundleInformation.EventsMbr.EventsMbrBundles.EventsMbrBundle.EventsMbrBundleDescendant.EventsItem.Items.RgEvtInfo.Data()
                                            self.data.parent = self
                                            self._children_name_map["data"] = "data"
                                        return self.data

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "data" or name == "rg-event-type" or name == "time-stamp"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "rg-event-type"):
                                        self.rg_event_type = value
                                        self.rg_event_type.value_namespace = name_space
                                        self.rg_event_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "time-stamp"):
                                        self.time_stamp = value
                                        self.time_stamp.value_namespace = name_space
                                        self.time_stamp.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.event_type.is_set or
                                    (self.bundle_evt_info is not None and self.bundle_evt_info.has_data()) or
                                    (self.member_evt_info is not None and self.member_evt_info.has_data()) or
                                    (self.rg_evt_info is not None and self.rg_evt_info.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.event_type.yfilter != YFilter.not_set or
                                    (self.bundle_evt_info is not None and self.bundle_evt_info.has_operation()) or
                                    (self.member_evt_info is not None and self.member_evt_info.has_operation()) or
                                    (self.rg_evt_info is not None and self.rg_evt_info.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "items" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.event_type.is_set or self.event_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.event_type.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "bundle-evt-info"):
                                    if (self.bundle_evt_info is None):
                                        self.bundle_evt_info = BundleInformation.EventsMbr.EventsMbrBundles.EventsMbrBundle.EventsMbrBundleDescendant.EventsItem.Items.BundleEvtInfo()
                                        self.bundle_evt_info.parent = self
                                        self._children_name_map["bundle_evt_info"] = "bundle-evt-info"
                                    return self.bundle_evt_info

                                if (child_yang_name == "member-evt-info"):
                                    if (self.member_evt_info is None):
                                        self.member_evt_info = BundleInformation.EventsMbr.EventsMbrBundles.EventsMbrBundle.EventsMbrBundleDescendant.EventsItem.Items.MemberEvtInfo()
                                        self.member_evt_info.parent = self
                                        self._children_name_map["member_evt_info"] = "member-evt-info"
                                    return self.member_evt_info

                                if (child_yang_name == "rg-evt-info"):
                                    if (self.rg_evt_info is None):
                                        self.rg_evt_info = BundleInformation.EventsMbr.EventsMbrBundles.EventsMbrBundle.EventsMbrBundleDescendant.EventsItem.Items.RgEvtInfo()
                                        self.rg_evt_info.parent = self
                                        self._children_name_map["rg_evt_info"] = "rg-evt-info"
                                    return self.rg_evt_info

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "bundle-evt-info" or name == "member-evt-info" or name == "rg-evt-info" or name == "event-type"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "event-type"):
                                    self.event_type = value
                                    self.event_type.value_namespace = name_space
                                    self.event_type.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.items:
                                if (c.has_data()):
                                    return True
                            return self.item_name.is_set

                        def has_operation(self):
                            for c in self.items:
                                if (c.has_operation()):
                                    return True
                            return (
                                self.yfilter != YFilter.not_set or
                                self.item_name.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "events-item" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.item_name.is_set or self.item_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.item_name.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "items"):
                                for c in self.items:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = BundleInformation.EventsMbr.EventsMbrBundles.EventsMbrBundle.EventsMbrBundleDescendant.EventsItem.Items()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.items.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "items" or name == "item-name"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "item-name"):
                                self.item_name = value
                                self.item_name.value_namespace = name_space
                                self.item_name.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.events_item:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.events_item:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "events-mbr-bundle-descendant" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "events-item"):
                            for c in self.events_item:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = BundleInformation.EventsMbr.EventsMbrBundles.EventsMbrBundle.EventsMbrBundleDescendant.EventsItem()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.events_item.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "events-item"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass

                def has_data(self):
                    return (
                        self.bundle_interface.is_set or
                        (self.events_mbr_bundle_children_members is not None and self.events_mbr_bundle_children_members.has_data()) or
                        (self.events_mbr_bundle_descendant is not None and self.events_mbr_bundle_descendant.has_data()))

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.bundle_interface.yfilter != YFilter.not_set or
                        (self.events_mbr_bundle_children_members is not None and self.events_mbr_bundle_children_members.has_operation()) or
                        (self.events_mbr_bundle_descendant is not None and self.events_mbr_bundle_descendant.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "events-mbr-bundle" + "[bundle-interface='" + self.bundle_interface.get() + "']" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-bundlemgr-oper:bundle-information/events-mbr/events-mbr-bundles/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.bundle_interface.is_set or self.bundle_interface.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.bundle_interface.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "events-mbr-bundle-children-members"):
                        if (self.events_mbr_bundle_children_members is None):
                            self.events_mbr_bundle_children_members = BundleInformation.EventsMbr.EventsMbrBundles.EventsMbrBundle.EventsMbrBundleChildrenMembers()
                            self.events_mbr_bundle_children_members.parent = self
                            self._children_name_map["events_mbr_bundle_children_members"] = "events-mbr-bundle-children-members"
                        return self.events_mbr_bundle_children_members

                    if (child_yang_name == "events-mbr-bundle-descendant"):
                        if (self.events_mbr_bundle_descendant is None):
                            self.events_mbr_bundle_descendant = BundleInformation.EventsMbr.EventsMbrBundles.EventsMbrBundle.EventsMbrBundleDescendant()
                            self.events_mbr_bundle_descendant.parent = self
                            self._children_name_map["events_mbr_bundle_descendant"] = "events-mbr-bundle-descendant"
                        return self.events_mbr_bundle_descendant

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "events-mbr-bundle-children-members" or name == "events-mbr-bundle-descendant" or name == "bundle-interface"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "bundle-interface"):
                        self.bundle_interface = value
                        self.bundle_interface.value_namespace = name_space
                        self.bundle_interface.value_namespace_prefix = name_space_prefix

            def has_data(self):
                for c in self.events_mbr_bundle:
                    if (c.has_data()):
                        return True
                return False

            def has_operation(self):
                for c in self.events_mbr_bundle:
                    if (c.has_operation()):
                        return True
                return self.yfilter != YFilter.not_set

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "events-mbr-bundles" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-bundlemgr-oper:bundle-information/events-mbr/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "events-mbr-bundle"):
                    for c in self.events_mbr_bundle:
                        segment = c.get_segment_path()
                        if (segment_path == segment):
                            return c
                    c = BundleInformation.EventsMbr.EventsMbrBundles.EventsMbrBundle()
                    c.parent = self
                    local_reference_key = "ydk::seg::%s" % segment_path
                    self._local_refs[local_reference_key] = c
                    self.events_mbr_bundle.append(c)
                    return c

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "events-mbr-bundle"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                pass


        class EventsMbrMembers(Entity):
            """
            Member interfaces with bundle member events
            information
            
            .. attribute:: events_mbr_member
            
            	Member interface
            	**type**\: list of    :py:class:`EventsMbrMember <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.EventsMbr.EventsMbrMembers.EventsMbrMember>`
            
            

            """

            _prefix = 'bundlemgr-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(BundleInformation.EventsMbr.EventsMbrMembers, self).__init__()

                self.yang_name = "events-mbr-members"
                self.yang_parent_name = "events-mbr"

                self.events_mbr_member = YList(self)

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in () and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(BundleInformation.EventsMbr.EventsMbrMembers, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(BundleInformation.EventsMbr.EventsMbrMembers, self).__setattr__(name, value)


            class EventsMbrMember(Entity):
                """
                Member interface
                
                .. attribute:: member_interface  <key>
                
                	Member interface
                	**type**\:  str
                
                .. attribute:: events_mbr_member_item
                
                	Data for this item
                	**type**\:   :py:class:`EventsMbrMemberItem <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.EventsMbr.EventsMbrMembers.EventsMbrMember.EventsMbrMemberItem>`
                
                

                """

                _prefix = 'bundlemgr-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(BundleInformation.EventsMbr.EventsMbrMembers.EventsMbrMember, self).__init__()

                    self.yang_name = "events-mbr-member"
                    self.yang_parent_name = "events-mbr-members"

                    self.member_interface = YLeaf(YType.str, "member-interface")

                    self.events_mbr_member_item = BundleInformation.EventsMbr.EventsMbrMembers.EventsMbrMember.EventsMbrMemberItem()
                    self.events_mbr_member_item.parent = self
                    self._children_name_map["events_mbr_member_item"] = "events-mbr-member-item"
                    self._children_yang_names.add("events-mbr-member-item")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("member_interface") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(BundleInformation.EventsMbr.EventsMbrMembers.EventsMbrMember, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(BundleInformation.EventsMbr.EventsMbrMembers.EventsMbrMember, self).__setattr__(name, value)


                class EventsMbrMemberItem(Entity):
                    """
                    Data for this item
                    
                    .. attribute:: item_name
                    
                    	Name for the current item to use
                    	**type**\:  str
                    
                    .. attribute:: items
                    
                    	Event items
                    	**type**\: list of    :py:class:`Items <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.EventsMbr.EventsMbrMembers.EventsMbrMember.EventsMbrMemberItem.Items>`
                    
                    

                    """

                    _prefix = 'bundlemgr-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(BundleInformation.EventsMbr.EventsMbrMembers.EventsMbrMember.EventsMbrMemberItem, self).__init__()

                        self.yang_name = "events-mbr-member-item"
                        self.yang_parent_name = "events-mbr-member"

                        self.item_name = YLeaf(YType.str, "item-name")

                        self.items = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("item_name") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(BundleInformation.EventsMbr.EventsMbrMembers.EventsMbrMember.EventsMbrMemberItem, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(BundleInformation.EventsMbr.EventsMbrMembers.EventsMbrMember.EventsMbrMemberItem, self).__setattr__(name, value)


                    class Items(Entity):
                        """
                        Event items
                        
                        .. attribute:: bundle_evt_info
                        
                        	Event information for a bundle
                        	**type**\:   :py:class:`BundleEvtInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.EventsMbr.EventsMbrMembers.EventsMbrMember.EventsMbrMemberItem.Items.BundleEvtInfo>`
                        
                        .. attribute:: event_type
                        
                        	EventType
                        	**type**\:   :py:class:`BmdBagTarget <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmdBagTarget>`
                        
                        .. attribute:: member_evt_info
                        
                        	Event information for a member
                        	**type**\:   :py:class:`MemberEvtInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.EventsMbr.EventsMbrMembers.EventsMbrMember.EventsMbrMemberItem.Items.MemberEvtInfo>`
                        
                        .. attribute:: rg_evt_info
                        
                        	Event information for an RG
                        	**type**\:   :py:class:`RgEvtInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.EventsMbr.EventsMbrMembers.EventsMbrMember.EventsMbrMemberItem.Items.RgEvtInfo>`
                        
                        

                        """

                        _prefix = 'bundlemgr-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(BundleInformation.EventsMbr.EventsMbrMembers.EventsMbrMember.EventsMbrMemberItem.Items, self).__init__()

                            self.yang_name = "items"
                            self.yang_parent_name = "events-mbr-member-item"

                            self.event_type = YLeaf(YType.enumeration, "event-type")

                            self.bundle_evt_info = BundleInformation.EventsMbr.EventsMbrMembers.EventsMbrMember.EventsMbrMemberItem.Items.BundleEvtInfo()
                            self.bundle_evt_info.parent = self
                            self._children_name_map["bundle_evt_info"] = "bundle-evt-info"
                            self._children_yang_names.add("bundle-evt-info")

                            self.member_evt_info = BundleInformation.EventsMbr.EventsMbrMembers.EventsMbrMember.EventsMbrMemberItem.Items.MemberEvtInfo()
                            self.member_evt_info.parent = self
                            self._children_name_map["member_evt_info"] = "member-evt-info"
                            self._children_yang_names.add("member-evt-info")

                            self.rg_evt_info = BundleInformation.EventsMbr.EventsMbrMembers.EventsMbrMember.EventsMbrMemberItem.Items.RgEvtInfo()
                            self.rg_evt_info.parent = self
                            self._children_name_map["rg_evt_info"] = "rg-evt-info"
                            self._children_yang_names.add("rg-evt-info")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("event_type") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(BundleInformation.EventsMbr.EventsMbrMembers.EventsMbrMember.EventsMbrMemberItem.Items, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(BundleInformation.EventsMbr.EventsMbrMembers.EventsMbrMember.EventsMbrMemberItem.Items, self).__setattr__(name, value)


                        class MemberEvtInfo(Entity):
                            """
                            Event information for a member
                            
                            .. attribute:: data
                            
                            	Additional data for the event
                            	**type**\:   :py:class:`Data <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.EventsMbr.EventsMbrMembers.EventsMbrMember.EventsMbrMemberItem.Items.MemberEvtInfo.Data>`
                            
                            .. attribute:: member_event_type
                            
                            	Type of event for member
                            	**type**\:   :py:class:`BmdBagEventMbrItem <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmdBagEventMbrItem>`
                            
                            .. attribute:: time_stamp
                            
                            	Time stamp of the event
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            

                            """

                            _prefix = 'bundlemgr-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(BundleInformation.EventsMbr.EventsMbrMembers.EventsMbrMember.EventsMbrMemberItem.Items.MemberEvtInfo, self).__init__()

                                self.yang_name = "member-evt-info"
                                self.yang_parent_name = "items"

                                self.member_event_type = YLeaf(YType.enumeration, "member-event-type")

                                self.time_stamp = YLeaf(YType.uint64, "time-stamp")

                                self.data = BundleInformation.EventsMbr.EventsMbrMembers.EventsMbrMember.EventsMbrMemberItem.Items.MemberEvtInfo.Data()
                                self.data.parent = self
                                self._children_name_map["data"] = "data"
                                self._children_yang_names.add("data")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("member_event_type",
                                                "time_stamp") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(BundleInformation.EventsMbr.EventsMbrMembers.EventsMbrMember.EventsMbrMemberItem.Items.MemberEvtInfo, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(BundleInformation.EventsMbr.EventsMbrMembers.EventsMbrMember.EventsMbrMemberItem.Items.MemberEvtInfo, self).__setattr__(name, value)


                            class Data(Entity):
                                """
                                Additional data for the event
                                
                                .. attribute:: data_type
                                
                                	DataType
                                	**type**\:   :py:class:`BmdBagEventData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmdBagEventData>`
                                
                                .. attribute:: error
                                
                                	Error
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: no_data
                                
                                	NoData
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: string_data
                                
                                	StringData
                                	**type**\:  str
                                
                                

                                """

                                _prefix = 'bundlemgr-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(BundleInformation.EventsMbr.EventsMbrMembers.EventsMbrMember.EventsMbrMemberItem.Items.MemberEvtInfo.Data, self).__init__()

                                    self.yang_name = "data"
                                    self.yang_parent_name = "member-evt-info"

                                    self.data_type = YLeaf(YType.enumeration, "data-type")

                                    self.error = YLeaf(YType.uint32, "error")

                                    self.no_data = YLeaf(YType.uint8, "no-data")

                                    self.string_data = YLeaf(YType.str, "string-data")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("data_type",
                                                    "error",
                                                    "no_data",
                                                    "string_data") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(BundleInformation.EventsMbr.EventsMbrMembers.EventsMbrMember.EventsMbrMemberItem.Items.MemberEvtInfo.Data, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(BundleInformation.EventsMbr.EventsMbrMembers.EventsMbrMember.EventsMbrMemberItem.Items.MemberEvtInfo.Data, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.data_type.is_set or
                                        self.error.is_set or
                                        self.no_data.is_set or
                                        self.string_data.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.data_type.yfilter != YFilter.not_set or
                                        self.error.yfilter != YFilter.not_set or
                                        self.no_data.yfilter != YFilter.not_set or
                                        self.string_data.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "data" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.data_type.is_set or self.data_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.data_type.get_name_leafdata())
                                    if (self.error.is_set or self.error.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.error.get_name_leafdata())
                                    if (self.no_data.is_set or self.no_data.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.no_data.get_name_leafdata())
                                    if (self.string_data.is_set or self.string_data.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.string_data.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "data-type" or name == "error" or name == "no-data" or name == "string-data"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "data-type"):
                                        self.data_type = value
                                        self.data_type.value_namespace = name_space
                                        self.data_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "error"):
                                        self.error = value
                                        self.error.value_namespace = name_space
                                        self.error.value_namespace_prefix = name_space_prefix
                                    if(value_path == "no-data"):
                                        self.no_data = value
                                        self.no_data.value_namespace = name_space
                                        self.no_data.value_namespace_prefix = name_space_prefix
                                    if(value_path == "string-data"):
                                        self.string_data = value
                                        self.string_data.value_namespace = name_space
                                        self.string_data.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.member_event_type.is_set or
                                    self.time_stamp.is_set or
                                    (self.data is not None and self.data.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.member_event_type.yfilter != YFilter.not_set or
                                    self.time_stamp.yfilter != YFilter.not_set or
                                    (self.data is not None and self.data.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "member-evt-info" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.member_event_type.is_set or self.member_event_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.member_event_type.get_name_leafdata())
                                if (self.time_stamp.is_set or self.time_stamp.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.time_stamp.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "data"):
                                    if (self.data is None):
                                        self.data = BundleInformation.EventsMbr.EventsMbrMembers.EventsMbrMember.EventsMbrMemberItem.Items.MemberEvtInfo.Data()
                                        self.data.parent = self
                                        self._children_name_map["data"] = "data"
                                    return self.data

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "data" or name == "member-event-type" or name == "time-stamp"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "member-event-type"):
                                    self.member_event_type = value
                                    self.member_event_type.value_namespace = name_space
                                    self.member_event_type.value_namespace_prefix = name_space_prefix
                                if(value_path == "time-stamp"):
                                    self.time_stamp = value
                                    self.time_stamp.value_namespace = name_space
                                    self.time_stamp.value_namespace_prefix = name_space_prefix


                        class BundleEvtInfo(Entity):
                            """
                            Event information for a bundle
                            
                            .. attribute:: bundle_event_type
                            
                            	Type of event for bundle
                            	**type**\:   :py:class:`BmdBagEventBdlItem <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmdBagEventBdlItem>`
                            
                            .. attribute:: data
                            
                            	Additional data for the event
                            	**type**\:   :py:class:`Data <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.EventsMbr.EventsMbrMembers.EventsMbrMember.EventsMbrMemberItem.Items.BundleEvtInfo.Data>`
                            
                            .. attribute:: time_stamp
                            
                            	Time stamp of the event
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            

                            """

                            _prefix = 'bundlemgr-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(BundleInformation.EventsMbr.EventsMbrMembers.EventsMbrMember.EventsMbrMemberItem.Items.BundleEvtInfo, self).__init__()

                                self.yang_name = "bundle-evt-info"
                                self.yang_parent_name = "items"

                                self.bundle_event_type = YLeaf(YType.enumeration, "bundle-event-type")

                                self.time_stamp = YLeaf(YType.uint64, "time-stamp")

                                self.data = BundleInformation.EventsMbr.EventsMbrMembers.EventsMbrMember.EventsMbrMemberItem.Items.BundleEvtInfo.Data()
                                self.data.parent = self
                                self._children_name_map["data"] = "data"
                                self._children_yang_names.add("data")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("bundle_event_type",
                                                "time_stamp") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(BundleInformation.EventsMbr.EventsMbrMembers.EventsMbrMember.EventsMbrMemberItem.Items.BundleEvtInfo, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(BundleInformation.EventsMbr.EventsMbrMembers.EventsMbrMember.EventsMbrMemberItem.Items.BundleEvtInfo, self).__setattr__(name, value)


                            class Data(Entity):
                                """
                                Additional data for the event
                                
                                .. attribute:: data_type
                                
                                	DataType
                                	**type**\:   :py:class:`BmdBagEventData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmdBagEventData>`
                                
                                .. attribute:: error
                                
                                	Error
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: no_data
                                
                                	NoData
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: string_data
                                
                                	StringData
                                	**type**\:  str
                                
                                

                                """

                                _prefix = 'bundlemgr-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(BundleInformation.EventsMbr.EventsMbrMembers.EventsMbrMember.EventsMbrMemberItem.Items.BundleEvtInfo.Data, self).__init__()

                                    self.yang_name = "data"
                                    self.yang_parent_name = "bundle-evt-info"

                                    self.data_type = YLeaf(YType.enumeration, "data-type")

                                    self.error = YLeaf(YType.uint32, "error")

                                    self.no_data = YLeaf(YType.uint8, "no-data")

                                    self.string_data = YLeaf(YType.str, "string-data")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("data_type",
                                                    "error",
                                                    "no_data",
                                                    "string_data") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(BundleInformation.EventsMbr.EventsMbrMembers.EventsMbrMember.EventsMbrMemberItem.Items.BundleEvtInfo.Data, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(BundleInformation.EventsMbr.EventsMbrMembers.EventsMbrMember.EventsMbrMemberItem.Items.BundleEvtInfo.Data, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.data_type.is_set or
                                        self.error.is_set or
                                        self.no_data.is_set or
                                        self.string_data.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.data_type.yfilter != YFilter.not_set or
                                        self.error.yfilter != YFilter.not_set or
                                        self.no_data.yfilter != YFilter.not_set or
                                        self.string_data.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "data" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.data_type.is_set or self.data_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.data_type.get_name_leafdata())
                                    if (self.error.is_set or self.error.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.error.get_name_leafdata())
                                    if (self.no_data.is_set or self.no_data.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.no_data.get_name_leafdata())
                                    if (self.string_data.is_set or self.string_data.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.string_data.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "data-type" or name == "error" or name == "no-data" or name == "string-data"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "data-type"):
                                        self.data_type = value
                                        self.data_type.value_namespace = name_space
                                        self.data_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "error"):
                                        self.error = value
                                        self.error.value_namespace = name_space
                                        self.error.value_namespace_prefix = name_space_prefix
                                    if(value_path == "no-data"):
                                        self.no_data = value
                                        self.no_data.value_namespace = name_space
                                        self.no_data.value_namespace_prefix = name_space_prefix
                                    if(value_path == "string-data"):
                                        self.string_data = value
                                        self.string_data.value_namespace = name_space
                                        self.string_data.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.bundle_event_type.is_set or
                                    self.time_stamp.is_set or
                                    (self.data is not None and self.data.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.bundle_event_type.yfilter != YFilter.not_set or
                                    self.time_stamp.yfilter != YFilter.not_set or
                                    (self.data is not None and self.data.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "bundle-evt-info" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.bundle_event_type.is_set or self.bundle_event_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.bundle_event_type.get_name_leafdata())
                                if (self.time_stamp.is_set or self.time_stamp.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.time_stamp.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "data"):
                                    if (self.data is None):
                                        self.data = BundleInformation.EventsMbr.EventsMbrMembers.EventsMbrMember.EventsMbrMemberItem.Items.BundleEvtInfo.Data()
                                        self.data.parent = self
                                        self._children_name_map["data"] = "data"
                                    return self.data

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "data" or name == "bundle-event-type" or name == "time-stamp"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "bundle-event-type"):
                                    self.bundle_event_type = value
                                    self.bundle_event_type.value_namespace = name_space
                                    self.bundle_event_type.value_namespace_prefix = name_space_prefix
                                if(value_path == "time-stamp"):
                                    self.time_stamp = value
                                    self.time_stamp.value_namespace = name_space
                                    self.time_stamp.value_namespace_prefix = name_space_prefix


                        class RgEvtInfo(Entity):
                            """
                            Event information for an RG
                            
                            .. attribute:: data
                            
                            	Additional data for the event
                            	**type**\:   :py:class:`Data <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.EventsMbr.EventsMbrMembers.EventsMbrMember.EventsMbrMemberItem.Items.RgEvtInfo.Data>`
                            
                            .. attribute:: rg_event_type
                            
                            	Type of event for RG
                            	**type**\:   :py:class:`BmdBagEventRgItem <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmdBagEventRgItem>`
                            
                            .. attribute:: time_stamp
                            
                            	Time stamp of the event
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            

                            """

                            _prefix = 'bundlemgr-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(BundleInformation.EventsMbr.EventsMbrMembers.EventsMbrMember.EventsMbrMemberItem.Items.RgEvtInfo, self).__init__()

                                self.yang_name = "rg-evt-info"
                                self.yang_parent_name = "items"

                                self.rg_event_type = YLeaf(YType.enumeration, "rg-event-type")

                                self.time_stamp = YLeaf(YType.uint64, "time-stamp")

                                self.data = BundleInformation.EventsMbr.EventsMbrMembers.EventsMbrMember.EventsMbrMemberItem.Items.RgEvtInfo.Data()
                                self.data.parent = self
                                self._children_name_map["data"] = "data"
                                self._children_yang_names.add("data")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("rg_event_type",
                                                "time_stamp") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(BundleInformation.EventsMbr.EventsMbrMembers.EventsMbrMember.EventsMbrMemberItem.Items.RgEvtInfo, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(BundleInformation.EventsMbr.EventsMbrMembers.EventsMbrMember.EventsMbrMemberItem.Items.RgEvtInfo, self).__setattr__(name, value)


                            class Data(Entity):
                                """
                                Additional data for the event
                                
                                .. attribute:: data_type
                                
                                	DataType
                                	**type**\:   :py:class:`BmdBagEventData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmdBagEventData>`
                                
                                .. attribute:: error
                                
                                	Error
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: no_data
                                
                                	NoData
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: string_data
                                
                                	StringData
                                	**type**\:  str
                                
                                

                                """

                                _prefix = 'bundlemgr-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(BundleInformation.EventsMbr.EventsMbrMembers.EventsMbrMember.EventsMbrMemberItem.Items.RgEvtInfo.Data, self).__init__()

                                    self.yang_name = "data"
                                    self.yang_parent_name = "rg-evt-info"

                                    self.data_type = YLeaf(YType.enumeration, "data-type")

                                    self.error = YLeaf(YType.uint32, "error")

                                    self.no_data = YLeaf(YType.uint8, "no-data")

                                    self.string_data = YLeaf(YType.str, "string-data")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("data_type",
                                                    "error",
                                                    "no_data",
                                                    "string_data") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(BundleInformation.EventsMbr.EventsMbrMembers.EventsMbrMember.EventsMbrMemberItem.Items.RgEvtInfo.Data, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(BundleInformation.EventsMbr.EventsMbrMembers.EventsMbrMember.EventsMbrMemberItem.Items.RgEvtInfo.Data, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.data_type.is_set or
                                        self.error.is_set or
                                        self.no_data.is_set or
                                        self.string_data.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.data_type.yfilter != YFilter.not_set or
                                        self.error.yfilter != YFilter.not_set or
                                        self.no_data.yfilter != YFilter.not_set or
                                        self.string_data.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "data" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.data_type.is_set or self.data_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.data_type.get_name_leafdata())
                                    if (self.error.is_set or self.error.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.error.get_name_leafdata())
                                    if (self.no_data.is_set or self.no_data.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.no_data.get_name_leafdata())
                                    if (self.string_data.is_set or self.string_data.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.string_data.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "data-type" or name == "error" or name == "no-data" or name == "string-data"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "data-type"):
                                        self.data_type = value
                                        self.data_type.value_namespace = name_space
                                        self.data_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "error"):
                                        self.error = value
                                        self.error.value_namespace = name_space
                                        self.error.value_namespace_prefix = name_space_prefix
                                    if(value_path == "no-data"):
                                        self.no_data = value
                                        self.no_data.value_namespace = name_space
                                        self.no_data.value_namespace_prefix = name_space_prefix
                                    if(value_path == "string-data"):
                                        self.string_data = value
                                        self.string_data.value_namespace = name_space
                                        self.string_data.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.rg_event_type.is_set or
                                    self.time_stamp.is_set or
                                    (self.data is not None and self.data.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.rg_event_type.yfilter != YFilter.not_set or
                                    self.time_stamp.yfilter != YFilter.not_set or
                                    (self.data is not None and self.data.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "rg-evt-info" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.rg_event_type.is_set or self.rg_event_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.rg_event_type.get_name_leafdata())
                                if (self.time_stamp.is_set or self.time_stamp.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.time_stamp.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "data"):
                                    if (self.data is None):
                                        self.data = BundleInformation.EventsMbr.EventsMbrMembers.EventsMbrMember.EventsMbrMemberItem.Items.RgEvtInfo.Data()
                                        self.data.parent = self
                                        self._children_name_map["data"] = "data"
                                    return self.data

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "data" or name == "rg-event-type" or name == "time-stamp"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "rg-event-type"):
                                    self.rg_event_type = value
                                    self.rg_event_type.value_namespace = name_space
                                    self.rg_event_type.value_namespace_prefix = name_space_prefix
                                if(value_path == "time-stamp"):
                                    self.time_stamp = value
                                    self.time_stamp.value_namespace = name_space
                                    self.time_stamp.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.event_type.is_set or
                                (self.bundle_evt_info is not None and self.bundle_evt_info.has_data()) or
                                (self.member_evt_info is not None and self.member_evt_info.has_data()) or
                                (self.rg_evt_info is not None and self.rg_evt_info.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.event_type.yfilter != YFilter.not_set or
                                (self.bundle_evt_info is not None and self.bundle_evt_info.has_operation()) or
                                (self.member_evt_info is not None and self.member_evt_info.has_operation()) or
                                (self.rg_evt_info is not None and self.rg_evt_info.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "items" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.event_type.is_set or self.event_type.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.event_type.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "bundle-evt-info"):
                                if (self.bundle_evt_info is None):
                                    self.bundle_evt_info = BundleInformation.EventsMbr.EventsMbrMembers.EventsMbrMember.EventsMbrMemberItem.Items.BundleEvtInfo()
                                    self.bundle_evt_info.parent = self
                                    self._children_name_map["bundle_evt_info"] = "bundle-evt-info"
                                return self.bundle_evt_info

                            if (child_yang_name == "member-evt-info"):
                                if (self.member_evt_info is None):
                                    self.member_evt_info = BundleInformation.EventsMbr.EventsMbrMembers.EventsMbrMember.EventsMbrMemberItem.Items.MemberEvtInfo()
                                    self.member_evt_info.parent = self
                                    self._children_name_map["member_evt_info"] = "member-evt-info"
                                return self.member_evt_info

                            if (child_yang_name == "rg-evt-info"):
                                if (self.rg_evt_info is None):
                                    self.rg_evt_info = BundleInformation.EventsMbr.EventsMbrMembers.EventsMbrMember.EventsMbrMemberItem.Items.RgEvtInfo()
                                    self.rg_evt_info.parent = self
                                    self._children_name_map["rg_evt_info"] = "rg-evt-info"
                                return self.rg_evt_info

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "bundle-evt-info" or name == "member-evt-info" or name == "rg-evt-info" or name == "event-type"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "event-type"):
                                self.event_type = value
                                self.event_type.value_namespace = name_space
                                self.event_type.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.items:
                            if (c.has_data()):
                                return True
                        return self.item_name.is_set

                    def has_operation(self):
                        for c in self.items:
                            if (c.has_operation()):
                                return True
                        return (
                            self.yfilter != YFilter.not_set or
                            self.item_name.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "events-mbr-member-item" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.item_name.is_set or self.item_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.item_name.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "items"):
                            for c in self.items:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = BundleInformation.EventsMbr.EventsMbrMembers.EventsMbrMember.EventsMbrMemberItem.Items()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.items.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "items" or name == "item-name"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "item-name"):
                            self.item_name = value
                            self.item_name.value_namespace = name_space
                            self.item_name.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    return (
                        self.member_interface.is_set or
                        (self.events_mbr_member_item is not None and self.events_mbr_member_item.has_data()))

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.member_interface.yfilter != YFilter.not_set or
                        (self.events_mbr_member_item is not None and self.events_mbr_member_item.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "events-mbr-member" + "[member-interface='" + self.member_interface.get() + "']" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-bundlemgr-oper:bundle-information/events-mbr/events-mbr-members/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.member_interface.is_set or self.member_interface.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.member_interface.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "events-mbr-member-item"):
                        if (self.events_mbr_member_item is None):
                            self.events_mbr_member_item = BundleInformation.EventsMbr.EventsMbrMembers.EventsMbrMember.EventsMbrMemberItem()
                            self.events_mbr_member_item.parent = self
                            self._children_name_map["events_mbr_member_item"] = "events-mbr-member-item"
                        return self.events_mbr_member_item

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "events-mbr-member-item" or name == "member-interface"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "member-interface"):
                        self.member_interface = value
                        self.member_interface.value_namespace = name_space
                        self.member_interface.value_namespace_prefix = name_space_prefix

            def has_data(self):
                for c in self.events_mbr_member:
                    if (c.has_data()):
                        return True
                return False

            def has_operation(self):
                for c in self.events_mbr_member:
                    if (c.has_operation()):
                        return True
                return self.yfilter != YFilter.not_set

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "events-mbr-members" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-bundlemgr-oper:bundle-information/events-mbr/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "events-mbr-member"):
                    for c in self.events_mbr_member:
                        segment = c.get_segment_path()
                        if (segment_path == segment):
                            return c
                    c = BundleInformation.EventsMbr.EventsMbrMembers.EventsMbrMember()
                    c.parent = self
                    local_reference_key = "ydk::seg::%s" % segment_path
                    self._local_refs[local_reference_key] = c
                    self.events_mbr_member.append(c)
                    return c

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "events-mbr-member"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                pass


        class EventsMbrIccpGroups(Entity):
            """
            Member events for all ICCP Groups
            
            .. attribute:: events_mbr_iccp_group
            
            	ICCP Group ID
            	**type**\: list of    :py:class:`EventsMbrIccpGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.EventsMbr.EventsMbrIccpGroups.EventsMbrIccpGroup>`
            
            

            """

            _prefix = 'bundlemgr-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(BundleInformation.EventsMbr.EventsMbrIccpGroups, self).__init__()

                self.yang_name = "events-mbr-iccp-groups"
                self.yang_parent_name = "events-mbr"

                self.events_mbr_iccp_group = YList(self)

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in () and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(BundleInformation.EventsMbr.EventsMbrIccpGroups, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(BundleInformation.EventsMbr.EventsMbrIccpGroups, self).__setattr__(name, value)


            class EventsMbrIccpGroup(Entity):
                """
                ICCP Group ID
                
                .. attribute:: iccp_group  <key>
                
                	ICCP Group ID
                	**type**\:  int
                
                	**range:** 1..4294967295
                
                .. attribute:: events_mbr_bundle_children_member_iccp_groups
                
                	Children of bundle with member events information
                	**type**\:   :py:class:`EventsMbrBundleChildrenMemberIccpGroups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.EventsMbr.EventsMbrIccpGroups.EventsMbrIccpGroup.EventsMbrBundleChildrenMemberIccpGroups>`
                
                .. attribute:: events_mbr_bundle_descendant_iccp_group
                
                	Data for this item and all its members
                	**type**\:   :py:class:`EventsMbrBundleDescendantIccpGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.EventsMbr.EventsMbrIccpGroups.EventsMbrIccpGroup.EventsMbrBundleDescendantIccpGroup>`
                
                

                """

                _prefix = 'bundlemgr-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(BundleInformation.EventsMbr.EventsMbrIccpGroups.EventsMbrIccpGroup, self).__init__()

                    self.yang_name = "events-mbr-iccp-group"
                    self.yang_parent_name = "events-mbr-iccp-groups"

                    self.iccp_group = YLeaf(YType.uint32, "iccp-group")

                    self.events_mbr_bundle_children_member_iccp_groups = BundleInformation.EventsMbr.EventsMbrIccpGroups.EventsMbrIccpGroup.EventsMbrBundleChildrenMemberIccpGroups()
                    self.events_mbr_bundle_children_member_iccp_groups.parent = self
                    self._children_name_map["events_mbr_bundle_children_member_iccp_groups"] = "events-mbr-bundle-children-member-iccp-groups"
                    self._children_yang_names.add("events-mbr-bundle-children-member-iccp-groups")

                    self.events_mbr_bundle_descendant_iccp_group = BundleInformation.EventsMbr.EventsMbrIccpGroups.EventsMbrIccpGroup.EventsMbrBundleDescendantIccpGroup()
                    self.events_mbr_bundle_descendant_iccp_group.parent = self
                    self._children_name_map["events_mbr_bundle_descendant_iccp_group"] = "events-mbr-bundle-descendant-iccp-group"
                    self._children_yang_names.add("events-mbr-bundle-descendant-iccp-group")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("iccp_group") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(BundleInformation.EventsMbr.EventsMbrIccpGroups.EventsMbrIccpGroup, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(BundleInformation.EventsMbr.EventsMbrIccpGroups.EventsMbrIccpGroup, self).__setattr__(name, value)


                class EventsMbrBundleChildrenMemberIccpGroups(Entity):
                    """
                    Children of bundle with member events
                    information
                    
                    .. attribute:: events_mbr_bundle_children_member_iccp_group
                    
                    	Bundle member item with ICCP events information
                    	**type**\: list of    :py:class:`EventsMbrBundleChildrenMemberIccpGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.EventsMbr.EventsMbrIccpGroups.EventsMbrIccpGroup.EventsMbrBundleChildrenMemberIccpGroups.EventsMbrBundleChildrenMemberIccpGroup>`
                    
                    

                    """

                    _prefix = 'bundlemgr-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(BundleInformation.EventsMbr.EventsMbrIccpGroups.EventsMbrIccpGroup.EventsMbrBundleChildrenMemberIccpGroups, self).__init__()

                        self.yang_name = "events-mbr-bundle-children-member-iccp-groups"
                        self.yang_parent_name = "events-mbr-iccp-group"

                        self.events_mbr_bundle_children_member_iccp_group = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(BundleInformation.EventsMbr.EventsMbrIccpGroups.EventsMbrIccpGroup.EventsMbrBundleChildrenMemberIccpGroups, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(BundleInformation.EventsMbr.EventsMbrIccpGroups.EventsMbrIccpGroup.EventsMbrBundleChildrenMemberIccpGroups, self).__setattr__(name, value)


                    class EventsMbrBundleChildrenMemberIccpGroup(Entity):
                        """
                        Bundle member item with ICCP events
                        information
                        
                        .. attribute:: member_interface  <key>
                        
                        	Member interface
                        	**type**\:  str
                        
                        .. attribute:: item_name
                        
                        	Name for the current item to use
                        	**type**\:  str
                        
                        .. attribute:: items
                        
                        	Event items
                        	**type**\: list of    :py:class:`Items <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.EventsMbr.EventsMbrIccpGroups.EventsMbrIccpGroup.EventsMbrBundleChildrenMemberIccpGroups.EventsMbrBundleChildrenMemberIccpGroup.Items>`
                        
                        

                        """

                        _prefix = 'bundlemgr-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(BundleInformation.EventsMbr.EventsMbrIccpGroups.EventsMbrIccpGroup.EventsMbrBundleChildrenMemberIccpGroups.EventsMbrBundleChildrenMemberIccpGroup, self).__init__()

                            self.yang_name = "events-mbr-bundle-children-member-iccp-group"
                            self.yang_parent_name = "events-mbr-bundle-children-member-iccp-groups"

                            self.member_interface = YLeaf(YType.str, "member-interface")

                            self.item_name = YLeaf(YType.str, "item-name")

                            self.items = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("member_interface",
                                            "item_name") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(BundleInformation.EventsMbr.EventsMbrIccpGroups.EventsMbrIccpGroup.EventsMbrBundleChildrenMemberIccpGroups.EventsMbrBundleChildrenMemberIccpGroup, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(BundleInformation.EventsMbr.EventsMbrIccpGroups.EventsMbrIccpGroup.EventsMbrBundleChildrenMemberIccpGroups.EventsMbrBundleChildrenMemberIccpGroup, self).__setattr__(name, value)


                        class Items(Entity):
                            """
                            Event items
                            
                            .. attribute:: bundle_evt_info
                            
                            	Event information for a bundle
                            	**type**\:   :py:class:`BundleEvtInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.EventsMbr.EventsMbrIccpGroups.EventsMbrIccpGroup.EventsMbrBundleChildrenMemberIccpGroups.EventsMbrBundleChildrenMemberIccpGroup.Items.BundleEvtInfo>`
                            
                            .. attribute:: event_type
                            
                            	EventType
                            	**type**\:   :py:class:`BmdBagTarget <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmdBagTarget>`
                            
                            .. attribute:: member_evt_info
                            
                            	Event information for a member
                            	**type**\:   :py:class:`MemberEvtInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.EventsMbr.EventsMbrIccpGroups.EventsMbrIccpGroup.EventsMbrBundleChildrenMemberIccpGroups.EventsMbrBundleChildrenMemberIccpGroup.Items.MemberEvtInfo>`
                            
                            .. attribute:: rg_evt_info
                            
                            	Event information for an RG
                            	**type**\:   :py:class:`RgEvtInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.EventsMbr.EventsMbrIccpGroups.EventsMbrIccpGroup.EventsMbrBundleChildrenMemberIccpGroups.EventsMbrBundleChildrenMemberIccpGroup.Items.RgEvtInfo>`
                            
                            

                            """

                            _prefix = 'bundlemgr-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(BundleInformation.EventsMbr.EventsMbrIccpGroups.EventsMbrIccpGroup.EventsMbrBundleChildrenMemberIccpGroups.EventsMbrBundleChildrenMemberIccpGroup.Items, self).__init__()

                                self.yang_name = "items"
                                self.yang_parent_name = "events-mbr-bundle-children-member-iccp-group"

                                self.event_type = YLeaf(YType.enumeration, "event-type")

                                self.bundle_evt_info = BundleInformation.EventsMbr.EventsMbrIccpGroups.EventsMbrIccpGroup.EventsMbrBundleChildrenMemberIccpGroups.EventsMbrBundleChildrenMemberIccpGroup.Items.BundleEvtInfo()
                                self.bundle_evt_info.parent = self
                                self._children_name_map["bundle_evt_info"] = "bundle-evt-info"
                                self._children_yang_names.add("bundle-evt-info")

                                self.member_evt_info = BundleInformation.EventsMbr.EventsMbrIccpGroups.EventsMbrIccpGroup.EventsMbrBundleChildrenMemberIccpGroups.EventsMbrBundleChildrenMemberIccpGroup.Items.MemberEvtInfo()
                                self.member_evt_info.parent = self
                                self._children_name_map["member_evt_info"] = "member-evt-info"
                                self._children_yang_names.add("member-evt-info")

                                self.rg_evt_info = BundleInformation.EventsMbr.EventsMbrIccpGroups.EventsMbrIccpGroup.EventsMbrBundleChildrenMemberIccpGroups.EventsMbrBundleChildrenMemberIccpGroup.Items.RgEvtInfo()
                                self.rg_evt_info.parent = self
                                self._children_name_map["rg_evt_info"] = "rg-evt-info"
                                self._children_yang_names.add("rg-evt-info")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("event_type") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(BundleInformation.EventsMbr.EventsMbrIccpGroups.EventsMbrIccpGroup.EventsMbrBundleChildrenMemberIccpGroups.EventsMbrBundleChildrenMemberIccpGroup.Items, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(BundleInformation.EventsMbr.EventsMbrIccpGroups.EventsMbrIccpGroup.EventsMbrBundleChildrenMemberIccpGroups.EventsMbrBundleChildrenMemberIccpGroup.Items, self).__setattr__(name, value)


                            class MemberEvtInfo(Entity):
                                """
                                Event information for a member
                                
                                .. attribute:: data
                                
                                	Additional data for the event
                                	**type**\:   :py:class:`Data <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.EventsMbr.EventsMbrIccpGroups.EventsMbrIccpGroup.EventsMbrBundleChildrenMemberIccpGroups.EventsMbrBundleChildrenMemberIccpGroup.Items.MemberEvtInfo.Data>`
                                
                                .. attribute:: member_event_type
                                
                                	Type of event for member
                                	**type**\:   :py:class:`BmdBagEventMbrItem <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmdBagEventMbrItem>`
                                
                                .. attribute:: time_stamp
                                
                                	Time stamp of the event
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'bundlemgr-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(BundleInformation.EventsMbr.EventsMbrIccpGroups.EventsMbrIccpGroup.EventsMbrBundleChildrenMemberIccpGroups.EventsMbrBundleChildrenMemberIccpGroup.Items.MemberEvtInfo, self).__init__()

                                    self.yang_name = "member-evt-info"
                                    self.yang_parent_name = "items"

                                    self.member_event_type = YLeaf(YType.enumeration, "member-event-type")

                                    self.time_stamp = YLeaf(YType.uint64, "time-stamp")

                                    self.data = BundleInformation.EventsMbr.EventsMbrIccpGroups.EventsMbrIccpGroup.EventsMbrBundleChildrenMemberIccpGroups.EventsMbrBundleChildrenMemberIccpGroup.Items.MemberEvtInfo.Data()
                                    self.data.parent = self
                                    self._children_name_map["data"] = "data"
                                    self._children_yang_names.add("data")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("member_event_type",
                                                    "time_stamp") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(BundleInformation.EventsMbr.EventsMbrIccpGroups.EventsMbrIccpGroup.EventsMbrBundleChildrenMemberIccpGroups.EventsMbrBundleChildrenMemberIccpGroup.Items.MemberEvtInfo, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(BundleInformation.EventsMbr.EventsMbrIccpGroups.EventsMbrIccpGroup.EventsMbrBundleChildrenMemberIccpGroups.EventsMbrBundleChildrenMemberIccpGroup.Items.MemberEvtInfo, self).__setattr__(name, value)


                                class Data(Entity):
                                    """
                                    Additional data for the event
                                    
                                    .. attribute:: data_type
                                    
                                    	DataType
                                    	**type**\:   :py:class:`BmdBagEventData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmdBagEventData>`
                                    
                                    .. attribute:: error
                                    
                                    	Error
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: no_data
                                    
                                    	NoData
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: string_data
                                    
                                    	StringData
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'bundlemgr-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(BundleInformation.EventsMbr.EventsMbrIccpGroups.EventsMbrIccpGroup.EventsMbrBundleChildrenMemberIccpGroups.EventsMbrBundleChildrenMemberIccpGroup.Items.MemberEvtInfo.Data, self).__init__()

                                        self.yang_name = "data"
                                        self.yang_parent_name = "member-evt-info"

                                        self.data_type = YLeaf(YType.enumeration, "data-type")

                                        self.error = YLeaf(YType.uint32, "error")

                                        self.no_data = YLeaf(YType.uint8, "no-data")

                                        self.string_data = YLeaf(YType.str, "string-data")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data_type",
                                                        "error",
                                                        "no_data",
                                                        "string_data") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(BundleInformation.EventsMbr.EventsMbrIccpGroups.EventsMbrIccpGroup.EventsMbrBundleChildrenMemberIccpGroups.EventsMbrBundleChildrenMemberIccpGroup.Items.MemberEvtInfo.Data, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(BundleInformation.EventsMbr.EventsMbrIccpGroups.EventsMbrIccpGroup.EventsMbrBundleChildrenMemberIccpGroups.EventsMbrBundleChildrenMemberIccpGroup.Items.MemberEvtInfo.Data, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data_type.is_set or
                                            self.error.is_set or
                                            self.no_data.is_set or
                                            self.string_data.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data_type.yfilter != YFilter.not_set or
                                            self.error.yfilter != YFilter.not_set or
                                            self.no_data.yfilter != YFilter.not_set or
                                            self.string_data.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "data" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data_type.is_set or self.data_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data_type.get_name_leafdata())
                                        if (self.error.is_set or self.error.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.error.get_name_leafdata())
                                        if (self.no_data.is_set or self.no_data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.no_data.get_name_leafdata())
                                        if (self.string_data.is_set or self.string_data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.string_data.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data-type" or name == "error" or name == "no-data" or name == "string-data"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data-type"):
                                            self.data_type = value
                                            self.data_type.value_namespace = name_space
                                            self.data_type.value_namespace_prefix = name_space_prefix
                                        if(value_path == "error"):
                                            self.error = value
                                            self.error.value_namespace = name_space
                                            self.error.value_namespace_prefix = name_space_prefix
                                        if(value_path == "no-data"):
                                            self.no_data = value
                                            self.no_data.value_namespace = name_space
                                            self.no_data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "string-data"):
                                            self.string_data = value
                                            self.string_data.value_namespace = name_space
                                            self.string_data.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.member_event_type.is_set or
                                        self.time_stamp.is_set or
                                        (self.data is not None and self.data.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.member_event_type.yfilter != YFilter.not_set or
                                        self.time_stamp.yfilter != YFilter.not_set or
                                        (self.data is not None and self.data.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "member-evt-info" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.member_event_type.is_set or self.member_event_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.member_event_type.get_name_leafdata())
                                    if (self.time_stamp.is_set or self.time_stamp.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.time_stamp.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "data"):
                                        if (self.data is None):
                                            self.data = BundleInformation.EventsMbr.EventsMbrIccpGroups.EventsMbrIccpGroup.EventsMbrBundleChildrenMemberIccpGroups.EventsMbrBundleChildrenMemberIccpGroup.Items.MemberEvtInfo.Data()
                                            self.data.parent = self
                                            self._children_name_map["data"] = "data"
                                        return self.data

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "data" or name == "member-event-type" or name == "time-stamp"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "member-event-type"):
                                        self.member_event_type = value
                                        self.member_event_type.value_namespace = name_space
                                        self.member_event_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "time-stamp"):
                                        self.time_stamp = value
                                        self.time_stamp.value_namespace = name_space
                                        self.time_stamp.value_namespace_prefix = name_space_prefix


                            class BundleEvtInfo(Entity):
                                """
                                Event information for a bundle
                                
                                .. attribute:: bundle_event_type
                                
                                	Type of event for bundle
                                	**type**\:   :py:class:`BmdBagEventBdlItem <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmdBagEventBdlItem>`
                                
                                .. attribute:: data
                                
                                	Additional data for the event
                                	**type**\:   :py:class:`Data <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.EventsMbr.EventsMbrIccpGroups.EventsMbrIccpGroup.EventsMbrBundleChildrenMemberIccpGroups.EventsMbrBundleChildrenMemberIccpGroup.Items.BundleEvtInfo.Data>`
                                
                                .. attribute:: time_stamp
                                
                                	Time stamp of the event
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'bundlemgr-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(BundleInformation.EventsMbr.EventsMbrIccpGroups.EventsMbrIccpGroup.EventsMbrBundleChildrenMemberIccpGroups.EventsMbrBundleChildrenMemberIccpGroup.Items.BundleEvtInfo, self).__init__()

                                    self.yang_name = "bundle-evt-info"
                                    self.yang_parent_name = "items"

                                    self.bundle_event_type = YLeaf(YType.enumeration, "bundle-event-type")

                                    self.time_stamp = YLeaf(YType.uint64, "time-stamp")

                                    self.data = BundleInformation.EventsMbr.EventsMbrIccpGroups.EventsMbrIccpGroup.EventsMbrBundleChildrenMemberIccpGroups.EventsMbrBundleChildrenMemberIccpGroup.Items.BundleEvtInfo.Data()
                                    self.data.parent = self
                                    self._children_name_map["data"] = "data"
                                    self._children_yang_names.add("data")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("bundle_event_type",
                                                    "time_stamp") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(BundleInformation.EventsMbr.EventsMbrIccpGroups.EventsMbrIccpGroup.EventsMbrBundleChildrenMemberIccpGroups.EventsMbrBundleChildrenMemberIccpGroup.Items.BundleEvtInfo, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(BundleInformation.EventsMbr.EventsMbrIccpGroups.EventsMbrIccpGroup.EventsMbrBundleChildrenMemberIccpGroups.EventsMbrBundleChildrenMemberIccpGroup.Items.BundleEvtInfo, self).__setattr__(name, value)


                                class Data(Entity):
                                    """
                                    Additional data for the event
                                    
                                    .. attribute:: data_type
                                    
                                    	DataType
                                    	**type**\:   :py:class:`BmdBagEventData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmdBagEventData>`
                                    
                                    .. attribute:: error
                                    
                                    	Error
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: no_data
                                    
                                    	NoData
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: string_data
                                    
                                    	StringData
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'bundlemgr-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(BundleInformation.EventsMbr.EventsMbrIccpGroups.EventsMbrIccpGroup.EventsMbrBundleChildrenMemberIccpGroups.EventsMbrBundleChildrenMemberIccpGroup.Items.BundleEvtInfo.Data, self).__init__()

                                        self.yang_name = "data"
                                        self.yang_parent_name = "bundle-evt-info"

                                        self.data_type = YLeaf(YType.enumeration, "data-type")

                                        self.error = YLeaf(YType.uint32, "error")

                                        self.no_data = YLeaf(YType.uint8, "no-data")

                                        self.string_data = YLeaf(YType.str, "string-data")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data_type",
                                                        "error",
                                                        "no_data",
                                                        "string_data") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(BundleInformation.EventsMbr.EventsMbrIccpGroups.EventsMbrIccpGroup.EventsMbrBundleChildrenMemberIccpGroups.EventsMbrBundleChildrenMemberIccpGroup.Items.BundleEvtInfo.Data, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(BundleInformation.EventsMbr.EventsMbrIccpGroups.EventsMbrIccpGroup.EventsMbrBundleChildrenMemberIccpGroups.EventsMbrBundleChildrenMemberIccpGroup.Items.BundleEvtInfo.Data, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data_type.is_set or
                                            self.error.is_set or
                                            self.no_data.is_set or
                                            self.string_data.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data_type.yfilter != YFilter.not_set or
                                            self.error.yfilter != YFilter.not_set or
                                            self.no_data.yfilter != YFilter.not_set or
                                            self.string_data.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "data" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data_type.is_set or self.data_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data_type.get_name_leafdata())
                                        if (self.error.is_set or self.error.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.error.get_name_leafdata())
                                        if (self.no_data.is_set or self.no_data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.no_data.get_name_leafdata())
                                        if (self.string_data.is_set or self.string_data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.string_data.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data-type" or name == "error" or name == "no-data" or name == "string-data"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data-type"):
                                            self.data_type = value
                                            self.data_type.value_namespace = name_space
                                            self.data_type.value_namespace_prefix = name_space_prefix
                                        if(value_path == "error"):
                                            self.error = value
                                            self.error.value_namespace = name_space
                                            self.error.value_namespace_prefix = name_space_prefix
                                        if(value_path == "no-data"):
                                            self.no_data = value
                                            self.no_data.value_namespace = name_space
                                            self.no_data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "string-data"):
                                            self.string_data = value
                                            self.string_data.value_namespace = name_space
                                            self.string_data.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.bundle_event_type.is_set or
                                        self.time_stamp.is_set or
                                        (self.data is not None and self.data.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.bundle_event_type.yfilter != YFilter.not_set or
                                        self.time_stamp.yfilter != YFilter.not_set or
                                        (self.data is not None and self.data.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "bundle-evt-info" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.bundle_event_type.is_set or self.bundle_event_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.bundle_event_type.get_name_leafdata())
                                    if (self.time_stamp.is_set or self.time_stamp.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.time_stamp.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "data"):
                                        if (self.data is None):
                                            self.data = BundleInformation.EventsMbr.EventsMbrIccpGroups.EventsMbrIccpGroup.EventsMbrBundleChildrenMemberIccpGroups.EventsMbrBundleChildrenMemberIccpGroup.Items.BundleEvtInfo.Data()
                                            self.data.parent = self
                                            self._children_name_map["data"] = "data"
                                        return self.data

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "data" or name == "bundle-event-type" or name == "time-stamp"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "bundle-event-type"):
                                        self.bundle_event_type = value
                                        self.bundle_event_type.value_namespace = name_space
                                        self.bundle_event_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "time-stamp"):
                                        self.time_stamp = value
                                        self.time_stamp.value_namespace = name_space
                                        self.time_stamp.value_namespace_prefix = name_space_prefix


                            class RgEvtInfo(Entity):
                                """
                                Event information for an RG
                                
                                .. attribute:: data
                                
                                	Additional data for the event
                                	**type**\:   :py:class:`Data <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.EventsMbr.EventsMbrIccpGroups.EventsMbrIccpGroup.EventsMbrBundleChildrenMemberIccpGroups.EventsMbrBundleChildrenMemberIccpGroup.Items.RgEvtInfo.Data>`
                                
                                .. attribute:: rg_event_type
                                
                                	Type of event for RG
                                	**type**\:   :py:class:`BmdBagEventRgItem <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmdBagEventRgItem>`
                                
                                .. attribute:: time_stamp
                                
                                	Time stamp of the event
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'bundlemgr-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(BundleInformation.EventsMbr.EventsMbrIccpGroups.EventsMbrIccpGroup.EventsMbrBundleChildrenMemberIccpGroups.EventsMbrBundleChildrenMemberIccpGroup.Items.RgEvtInfo, self).__init__()

                                    self.yang_name = "rg-evt-info"
                                    self.yang_parent_name = "items"

                                    self.rg_event_type = YLeaf(YType.enumeration, "rg-event-type")

                                    self.time_stamp = YLeaf(YType.uint64, "time-stamp")

                                    self.data = BundleInformation.EventsMbr.EventsMbrIccpGroups.EventsMbrIccpGroup.EventsMbrBundleChildrenMemberIccpGroups.EventsMbrBundleChildrenMemberIccpGroup.Items.RgEvtInfo.Data()
                                    self.data.parent = self
                                    self._children_name_map["data"] = "data"
                                    self._children_yang_names.add("data")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("rg_event_type",
                                                    "time_stamp") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(BundleInformation.EventsMbr.EventsMbrIccpGroups.EventsMbrIccpGroup.EventsMbrBundleChildrenMemberIccpGroups.EventsMbrBundleChildrenMemberIccpGroup.Items.RgEvtInfo, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(BundleInformation.EventsMbr.EventsMbrIccpGroups.EventsMbrIccpGroup.EventsMbrBundleChildrenMemberIccpGroups.EventsMbrBundleChildrenMemberIccpGroup.Items.RgEvtInfo, self).__setattr__(name, value)


                                class Data(Entity):
                                    """
                                    Additional data for the event
                                    
                                    .. attribute:: data_type
                                    
                                    	DataType
                                    	**type**\:   :py:class:`BmdBagEventData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmdBagEventData>`
                                    
                                    .. attribute:: error
                                    
                                    	Error
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: no_data
                                    
                                    	NoData
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: string_data
                                    
                                    	StringData
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'bundlemgr-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(BundleInformation.EventsMbr.EventsMbrIccpGroups.EventsMbrIccpGroup.EventsMbrBundleChildrenMemberIccpGroups.EventsMbrBundleChildrenMemberIccpGroup.Items.RgEvtInfo.Data, self).__init__()

                                        self.yang_name = "data"
                                        self.yang_parent_name = "rg-evt-info"

                                        self.data_type = YLeaf(YType.enumeration, "data-type")

                                        self.error = YLeaf(YType.uint32, "error")

                                        self.no_data = YLeaf(YType.uint8, "no-data")

                                        self.string_data = YLeaf(YType.str, "string-data")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data_type",
                                                        "error",
                                                        "no_data",
                                                        "string_data") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(BundleInformation.EventsMbr.EventsMbrIccpGroups.EventsMbrIccpGroup.EventsMbrBundleChildrenMemberIccpGroups.EventsMbrBundleChildrenMemberIccpGroup.Items.RgEvtInfo.Data, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(BundleInformation.EventsMbr.EventsMbrIccpGroups.EventsMbrIccpGroup.EventsMbrBundleChildrenMemberIccpGroups.EventsMbrBundleChildrenMemberIccpGroup.Items.RgEvtInfo.Data, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data_type.is_set or
                                            self.error.is_set or
                                            self.no_data.is_set or
                                            self.string_data.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data_type.yfilter != YFilter.not_set or
                                            self.error.yfilter != YFilter.not_set or
                                            self.no_data.yfilter != YFilter.not_set or
                                            self.string_data.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "data" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data_type.is_set or self.data_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data_type.get_name_leafdata())
                                        if (self.error.is_set or self.error.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.error.get_name_leafdata())
                                        if (self.no_data.is_set or self.no_data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.no_data.get_name_leafdata())
                                        if (self.string_data.is_set or self.string_data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.string_data.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data-type" or name == "error" or name == "no-data" or name == "string-data"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data-type"):
                                            self.data_type = value
                                            self.data_type.value_namespace = name_space
                                            self.data_type.value_namespace_prefix = name_space_prefix
                                        if(value_path == "error"):
                                            self.error = value
                                            self.error.value_namespace = name_space
                                            self.error.value_namespace_prefix = name_space_prefix
                                        if(value_path == "no-data"):
                                            self.no_data = value
                                            self.no_data.value_namespace = name_space
                                            self.no_data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "string-data"):
                                            self.string_data = value
                                            self.string_data.value_namespace = name_space
                                            self.string_data.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.rg_event_type.is_set or
                                        self.time_stamp.is_set or
                                        (self.data is not None and self.data.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.rg_event_type.yfilter != YFilter.not_set or
                                        self.time_stamp.yfilter != YFilter.not_set or
                                        (self.data is not None and self.data.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "rg-evt-info" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.rg_event_type.is_set or self.rg_event_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.rg_event_type.get_name_leafdata())
                                    if (self.time_stamp.is_set or self.time_stamp.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.time_stamp.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "data"):
                                        if (self.data is None):
                                            self.data = BundleInformation.EventsMbr.EventsMbrIccpGroups.EventsMbrIccpGroup.EventsMbrBundleChildrenMemberIccpGroups.EventsMbrBundleChildrenMemberIccpGroup.Items.RgEvtInfo.Data()
                                            self.data.parent = self
                                            self._children_name_map["data"] = "data"
                                        return self.data

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "data" or name == "rg-event-type" or name == "time-stamp"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "rg-event-type"):
                                        self.rg_event_type = value
                                        self.rg_event_type.value_namespace = name_space
                                        self.rg_event_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "time-stamp"):
                                        self.time_stamp = value
                                        self.time_stamp.value_namespace = name_space
                                        self.time_stamp.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.event_type.is_set or
                                    (self.bundle_evt_info is not None and self.bundle_evt_info.has_data()) or
                                    (self.member_evt_info is not None and self.member_evt_info.has_data()) or
                                    (self.rg_evt_info is not None and self.rg_evt_info.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.event_type.yfilter != YFilter.not_set or
                                    (self.bundle_evt_info is not None and self.bundle_evt_info.has_operation()) or
                                    (self.member_evt_info is not None and self.member_evt_info.has_operation()) or
                                    (self.rg_evt_info is not None and self.rg_evt_info.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "items" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.event_type.is_set or self.event_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.event_type.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "bundle-evt-info"):
                                    if (self.bundle_evt_info is None):
                                        self.bundle_evt_info = BundleInformation.EventsMbr.EventsMbrIccpGroups.EventsMbrIccpGroup.EventsMbrBundleChildrenMemberIccpGroups.EventsMbrBundleChildrenMemberIccpGroup.Items.BundleEvtInfo()
                                        self.bundle_evt_info.parent = self
                                        self._children_name_map["bundle_evt_info"] = "bundle-evt-info"
                                    return self.bundle_evt_info

                                if (child_yang_name == "member-evt-info"):
                                    if (self.member_evt_info is None):
                                        self.member_evt_info = BundleInformation.EventsMbr.EventsMbrIccpGroups.EventsMbrIccpGroup.EventsMbrBundleChildrenMemberIccpGroups.EventsMbrBundleChildrenMemberIccpGroup.Items.MemberEvtInfo()
                                        self.member_evt_info.parent = self
                                        self._children_name_map["member_evt_info"] = "member-evt-info"
                                    return self.member_evt_info

                                if (child_yang_name == "rg-evt-info"):
                                    if (self.rg_evt_info is None):
                                        self.rg_evt_info = BundleInformation.EventsMbr.EventsMbrIccpGroups.EventsMbrIccpGroup.EventsMbrBundleChildrenMemberIccpGroups.EventsMbrBundleChildrenMemberIccpGroup.Items.RgEvtInfo()
                                        self.rg_evt_info.parent = self
                                        self._children_name_map["rg_evt_info"] = "rg-evt-info"
                                    return self.rg_evt_info

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "bundle-evt-info" or name == "member-evt-info" or name == "rg-evt-info" or name == "event-type"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "event-type"):
                                    self.event_type = value
                                    self.event_type.value_namespace = name_space
                                    self.event_type.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.items:
                                if (c.has_data()):
                                    return True
                            return (
                                self.member_interface.is_set or
                                self.item_name.is_set)

                        def has_operation(self):
                            for c in self.items:
                                if (c.has_operation()):
                                    return True
                            return (
                                self.yfilter != YFilter.not_set or
                                self.member_interface.yfilter != YFilter.not_set or
                                self.item_name.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "events-mbr-bundle-children-member-iccp-group" + "[member-interface='" + self.member_interface.get() + "']" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.member_interface.is_set or self.member_interface.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.member_interface.get_name_leafdata())
                            if (self.item_name.is_set or self.item_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.item_name.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "items"):
                                for c in self.items:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = BundleInformation.EventsMbr.EventsMbrIccpGroups.EventsMbrIccpGroup.EventsMbrBundleChildrenMemberIccpGroups.EventsMbrBundleChildrenMemberIccpGroup.Items()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.items.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "items" or name == "member-interface" or name == "item-name"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "member-interface"):
                                self.member_interface = value
                                self.member_interface.value_namespace = name_space
                                self.member_interface.value_namespace_prefix = name_space_prefix
                            if(value_path == "item-name"):
                                self.item_name = value
                                self.item_name.value_namespace = name_space
                                self.item_name.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.events_mbr_bundle_children_member_iccp_group:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.events_mbr_bundle_children_member_iccp_group:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "events-mbr-bundle-children-member-iccp-groups" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "events-mbr-bundle-children-member-iccp-group"):
                            for c in self.events_mbr_bundle_children_member_iccp_group:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = BundleInformation.EventsMbr.EventsMbrIccpGroups.EventsMbrIccpGroup.EventsMbrBundleChildrenMemberIccpGroups.EventsMbrBundleChildrenMemberIccpGroup()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.events_mbr_bundle_children_member_iccp_group.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "events-mbr-bundle-children-member-iccp-group"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class EventsMbrBundleDescendantIccpGroup(Entity):
                    """
                    Data for this item and all its members
                    
                    .. attribute:: events_item
                    
                    	Event items
                    	**type**\: list of    :py:class:`EventsItem <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.EventsMbr.EventsMbrIccpGroups.EventsMbrIccpGroup.EventsMbrBundleDescendantIccpGroup.EventsItem>`
                    
                    

                    """

                    _prefix = 'bundlemgr-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(BundleInformation.EventsMbr.EventsMbrIccpGroups.EventsMbrIccpGroup.EventsMbrBundleDescendantIccpGroup, self).__init__()

                        self.yang_name = "events-mbr-bundle-descendant-iccp-group"
                        self.yang_parent_name = "events-mbr-iccp-group"

                        self.events_item = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(BundleInformation.EventsMbr.EventsMbrIccpGroups.EventsMbrIccpGroup.EventsMbrBundleDescendantIccpGroup, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(BundleInformation.EventsMbr.EventsMbrIccpGroups.EventsMbrIccpGroup.EventsMbrBundleDescendantIccpGroup, self).__setattr__(name, value)


                    class EventsItem(Entity):
                        """
                        Event items
                        
                        .. attribute:: item_name
                        
                        	Name for the current item to use
                        	**type**\:  str
                        
                        .. attribute:: items
                        
                        	Event items
                        	**type**\: list of    :py:class:`Items <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.EventsMbr.EventsMbrIccpGroups.EventsMbrIccpGroup.EventsMbrBundleDescendantIccpGroup.EventsItem.Items>`
                        
                        

                        """

                        _prefix = 'bundlemgr-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(BundleInformation.EventsMbr.EventsMbrIccpGroups.EventsMbrIccpGroup.EventsMbrBundleDescendantIccpGroup.EventsItem, self).__init__()

                            self.yang_name = "events-item"
                            self.yang_parent_name = "events-mbr-bundle-descendant-iccp-group"

                            self.item_name = YLeaf(YType.str, "item-name")

                            self.items = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("item_name") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(BundleInformation.EventsMbr.EventsMbrIccpGroups.EventsMbrIccpGroup.EventsMbrBundleDescendantIccpGroup.EventsItem, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(BundleInformation.EventsMbr.EventsMbrIccpGroups.EventsMbrIccpGroup.EventsMbrBundleDescendantIccpGroup.EventsItem, self).__setattr__(name, value)


                        class Items(Entity):
                            """
                            Event items
                            
                            .. attribute:: bundle_evt_info
                            
                            	Event information for a bundle
                            	**type**\:   :py:class:`BundleEvtInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.EventsMbr.EventsMbrIccpGroups.EventsMbrIccpGroup.EventsMbrBundleDescendantIccpGroup.EventsItem.Items.BundleEvtInfo>`
                            
                            .. attribute:: event_type
                            
                            	EventType
                            	**type**\:   :py:class:`BmdBagTarget <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmdBagTarget>`
                            
                            .. attribute:: member_evt_info
                            
                            	Event information for a member
                            	**type**\:   :py:class:`MemberEvtInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.EventsMbr.EventsMbrIccpGroups.EventsMbrIccpGroup.EventsMbrBundleDescendantIccpGroup.EventsItem.Items.MemberEvtInfo>`
                            
                            .. attribute:: rg_evt_info
                            
                            	Event information for an RG
                            	**type**\:   :py:class:`RgEvtInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.EventsMbr.EventsMbrIccpGroups.EventsMbrIccpGroup.EventsMbrBundleDescendantIccpGroup.EventsItem.Items.RgEvtInfo>`
                            
                            

                            """

                            _prefix = 'bundlemgr-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(BundleInformation.EventsMbr.EventsMbrIccpGroups.EventsMbrIccpGroup.EventsMbrBundleDescendantIccpGroup.EventsItem.Items, self).__init__()

                                self.yang_name = "items"
                                self.yang_parent_name = "events-item"

                                self.event_type = YLeaf(YType.enumeration, "event-type")

                                self.bundle_evt_info = BundleInformation.EventsMbr.EventsMbrIccpGroups.EventsMbrIccpGroup.EventsMbrBundleDescendantIccpGroup.EventsItem.Items.BundleEvtInfo()
                                self.bundle_evt_info.parent = self
                                self._children_name_map["bundle_evt_info"] = "bundle-evt-info"
                                self._children_yang_names.add("bundle-evt-info")

                                self.member_evt_info = BundleInformation.EventsMbr.EventsMbrIccpGroups.EventsMbrIccpGroup.EventsMbrBundleDescendantIccpGroup.EventsItem.Items.MemberEvtInfo()
                                self.member_evt_info.parent = self
                                self._children_name_map["member_evt_info"] = "member-evt-info"
                                self._children_yang_names.add("member-evt-info")

                                self.rg_evt_info = BundleInformation.EventsMbr.EventsMbrIccpGroups.EventsMbrIccpGroup.EventsMbrBundleDescendantIccpGroup.EventsItem.Items.RgEvtInfo()
                                self.rg_evt_info.parent = self
                                self._children_name_map["rg_evt_info"] = "rg-evt-info"
                                self._children_yang_names.add("rg-evt-info")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("event_type") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(BundleInformation.EventsMbr.EventsMbrIccpGroups.EventsMbrIccpGroup.EventsMbrBundleDescendantIccpGroup.EventsItem.Items, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(BundleInformation.EventsMbr.EventsMbrIccpGroups.EventsMbrIccpGroup.EventsMbrBundleDescendantIccpGroup.EventsItem.Items, self).__setattr__(name, value)


                            class MemberEvtInfo(Entity):
                                """
                                Event information for a member
                                
                                .. attribute:: data
                                
                                	Additional data for the event
                                	**type**\:   :py:class:`Data <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.EventsMbr.EventsMbrIccpGroups.EventsMbrIccpGroup.EventsMbrBundleDescendantIccpGroup.EventsItem.Items.MemberEvtInfo.Data>`
                                
                                .. attribute:: member_event_type
                                
                                	Type of event for member
                                	**type**\:   :py:class:`BmdBagEventMbrItem <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmdBagEventMbrItem>`
                                
                                .. attribute:: time_stamp
                                
                                	Time stamp of the event
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'bundlemgr-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(BundleInformation.EventsMbr.EventsMbrIccpGroups.EventsMbrIccpGroup.EventsMbrBundleDescendantIccpGroup.EventsItem.Items.MemberEvtInfo, self).__init__()

                                    self.yang_name = "member-evt-info"
                                    self.yang_parent_name = "items"

                                    self.member_event_type = YLeaf(YType.enumeration, "member-event-type")

                                    self.time_stamp = YLeaf(YType.uint64, "time-stamp")

                                    self.data = BundleInformation.EventsMbr.EventsMbrIccpGroups.EventsMbrIccpGroup.EventsMbrBundleDescendantIccpGroup.EventsItem.Items.MemberEvtInfo.Data()
                                    self.data.parent = self
                                    self._children_name_map["data"] = "data"
                                    self._children_yang_names.add("data")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("member_event_type",
                                                    "time_stamp") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(BundleInformation.EventsMbr.EventsMbrIccpGroups.EventsMbrIccpGroup.EventsMbrBundleDescendantIccpGroup.EventsItem.Items.MemberEvtInfo, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(BundleInformation.EventsMbr.EventsMbrIccpGroups.EventsMbrIccpGroup.EventsMbrBundleDescendantIccpGroup.EventsItem.Items.MemberEvtInfo, self).__setattr__(name, value)


                                class Data(Entity):
                                    """
                                    Additional data for the event
                                    
                                    .. attribute:: data_type
                                    
                                    	DataType
                                    	**type**\:   :py:class:`BmdBagEventData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmdBagEventData>`
                                    
                                    .. attribute:: error
                                    
                                    	Error
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: no_data
                                    
                                    	NoData
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: string_data
                                    
                                    	StringData
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'bundlemgr-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(BundleInformation.EventsMbr.EventsMbrIccpGroups.EventsMbrIccpGroup.EventsMbrBundleDescendantIccpGroup.EventsItem.Items.MemberEvtInfo.Data, self).__init__()

                                        self.yang_name = "data"
                                        self.yang_parent_name = "member-evt-info"

                                        self.data_type = YLeaf(YType.enumeration, "data-type")

                                        self.error = YLeaf(YType.uint32, "error")

                                        self.no_data = YLeaf(YType.uint8, "no-data")

                                        self.string_data = YLeaf(YType.str, "string-data")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data_type",
                                                        "error",
                                                        "no_data",
                                                        "string_data") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(BundleInformation.EventsMbr.EventsMbrIccpGroups.EventsMbrIccpGroup.EventsMbrBundleDescendantIccpGroup.EventsItem.Items.MemberEvtInfo.Data, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(BundleInformation.EventsMbr.EventsMbrIccpGroups.EventsMbrIccpGroup.EventsMbrBundleDescendantIccpGroup.EventsItem.Items.MemberEvtInfo.Data, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data_type.is_set or
                                            self.error.is_set or
                                            self.no_data.is_set or
                                            self.string_data.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data_type.yfilter != YFilter.not_set or
                                            self.error.yfilter != YFilter.not_set or
                                            self.no_data.yfilter != YFilter.not_set or
                                            self.string_data.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "data" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data_type.is_set or self.data_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data_type.get_name_leafdata())
                                        if (self.error.is_set or self.error.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.error.get_name_leafdata())
                                        if (self.no_data.is_set or self.no_data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.no_data.get_name_leafdata())
                                        if (self.string_data.is_set or self.string_data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.string_data.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data-type" or name == "error" or name == "no-data" or name == "string-data"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data-type"):
                                            self.data_type = value
                                            self.data_type.value_namespace = name_space
                                            self.data_type.value_namespace_prefix = name_space_prefix
                                        if(value_path == "error"):
                                            self.error = value
                                            self.error.value_namespace = name_space
                                            self.error.value_namespace_prefix = name_space_prefix
                                        if(value_path == "no-data"):
                                            self.no_data = value
                                            self.no_data.value_namespace = name_space
                                            self.no_data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "string-data"):
                                            self.string_data = value
                                            self.string_data.value_namespace = name_space
                                            self.string_data.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.member_event_type.is_set or
                                        self.time_stamp.is_set or
                                        (self.data is not None and self.data.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.member_event_type.yfilter != YFilter.not_set or
                                        self.time_stamp.yfilter != YFilter.not_set or
                                        (self.data is not None and self.data.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "member-evt-info" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.member_event_type.is_set or self.member_event_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.member_event_type.get_name_leafdata())
                                    if (self.time_stamp.is_set or self.time_stamp.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.time_stamp.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "data"):
                                        if (self.data is None):
                                            self.data = BundleInformation.EventsMbr.EventsMbrIccpGroups.EventsMbrIccpGroup.EventsMbrBundleDescendantIccpGroup.EventsItem.Items.MemberEvtInfo.Data()
                                            self.data.parent = self
                                            self._children_name_map["data"] = "data"
                                        return self.data

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "data" or name == "member-event-type" or name == "time-stamp"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "member-event-type"):
                                        self.member_event_type = value
                                        self.member_event_type.value_namespace = name_space
                                        self.member_event_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "time-stamp"):
                                        self.time_stamp = value
                                        self.time_stamp.value_namespace = name_space
                                        self.time_stamp.value_namespace_prefix = name_space_prefix


                            class BundleEvtInfo(Entity):
                                """
                                Event information for a bundle
                                
                                .. attribute:: bundle_event_type
                                
                                	Type of event for bundle
                                	**type**\:   :py:class:`BmdBagEventBdlItem <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmdBagEventBdlItem>`
                                
                                .. attribute:: data
                                
                                	Additional data for the event
                                	**type**\:   :py:class:`Data <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.EventsMbr.EventsMbrIccpGroups.EventsMbrIccpGroup.EventsMbrBundleDescendantIccpGroup.EventsItem.Items.BundleEvtInfo.Data>`
                                
                                .. attribute:: time_stamp
                                
                                	Time stamp of the event
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'bundlemgr-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(BundleInformation.EventsMbr.EventsMbrIccpGroups.EventsMbrIccpGroup.EventsMbrBundleDescendantIccpGroup.EventsItem.Items.BundleEvtInfo, self).__init__()

                                    self.yang_name = "bundle-evt-info"
                                    self.yang_parent_name = "items"

                                    self.bundle_event_type = YLeaf(YType.enumeration, "bundle-event-type")

                                    self.time_stamp = YLeaf(YType.uint64, "time-stamp")

                                    self.data = BundleInformation.EventsMbr.EventsMbrIccpGroups.EventsMbrIccpGroup.EventsMbrBundleDescendantIccpGroup.EventsItem.Items.BundleEvtInfo.Data()
                                    self.data.parent = self
                                    self._children_name_map["data"] = "data"
                                    self._children_yang_names.add("data")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("bundle_event_type",
                                                    "time_stamp") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(BundleInformation.EventsMbr.EventsMbrIccpGroups.EventsMbrIccpGroup.EventsMbrBundleDescendantIccpGroup.EventsItem.Items.BundleEvtInfo, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(BundleInformation.EventsMbr.EventsMbrIccpGroups.EventsMbrIccpGroup.EventsMbrBundleDescendantIccpGroup.EventsItem.Items.BundleEvtInfo, self).__setattr__(name, value)


                                class Data(Entity):
                                    """
                                    Additional data for the event
                                    
                                    .. attribute:: data_type
                                    
                                    	DataType
                                    	**type**\:   :py:class:`BmdBagEventData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmdBagEventData>`
                                    
                                    .. attribute:: error
                                    
                                    	Error
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: no_data
                                    
                                    	NoData
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: string_data
                                    
                                    	StringData
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'bundlemgr-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(BundleInformation.EventsMbr.EventsMbrIccpGroups.EventsMbrIccpGroup.EventsMbrBundleDescendantIccpGroup.EventsItem.Items.BundleEvtInfo.Data, self).__init__()

                                        self.yang_name = "data"
                                        self.yang_parent_name = "bundle-evt-info"

                                        self.data_type = YLeaf(YType.enumeration, "data-type")

                                        self.error = YLeaf(YType.uint32, "error")

                                        self.no_data = YLeaf(YType.uint8, "no-data")

                                        self.string_data = YLeaf(YType.str, "string-data")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data_type",
                                                        "error",
                                                        "no_data",
                                                        "string_data") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(BundleInformation.EventsMbr.EventsMbrIccpGroups.EventsMbrIccpGroup.EventsMbrBundleDescendantIccpGroup.EventsItem.Items.BundleEvtInfo.Data, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(BundleInformation.EventsMbr.EventsMbrIccpGroups.EventsMbrIccpGroup.EventsMbrBundleDescendantIccpGroup.EventsItem.Items.BundleEvtInfo.Data, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data_type.is_set or
                                            self.error.is_set or
                                            self.no_data.is_set or
                                            self.string_data.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data_type.yfilter != YFilter.not_set or
                                            self.error.yfilter != YFilter.not_set or
                                            self.no_data.yfilter != YFilter.not_set or
                                            self.string_data.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "data" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data_type.is_set or self.data_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data_type.get_name_leafdata())
                                        if (self.error.is_set or self.error.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.error.get_name_leafdata())
                                        if (self.no_data.is_set or self.no_data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.no_data.get_name_leafdata())
                                        if (self.string_data.is_set or self.string_data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.string_data.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data-type" or name == "error" or name == "no-data" or name == "string-data"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data-type"):
                                            self.data_type = value
                                            self.data_type.value_namespace = name_space
                                            self.data_type.value_namespace_prefix = name_space_prefix
                                        if(value_path == "error"):
                                            self.error = value
                                            self.error.value_namespace = name_space
                                            self.error.value_namespace_prefix = name_space_prefix
                                        if(value_path == "no-data"):
                                            self.no_data = value
                                            self.no_data.value_namespace = name_space
                                            self.no_data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "string-data"):
                                            self.string_data = value
                                            self.string_data.value_namespace = name_space
                                            self.string_data.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.bundle_event_type.is_set or
                                        self.time_stamp.is_set or
                                        (self.data is not None and self.data.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.bundle_event_type.yfilter != YFilter.not_set or
                                        self.time_stamp.yfilter != YFilter.not_set or
                                        (self.data is not None and self.data.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "bundle-evt-info" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.bundle_event_type.is_set or self.bundle_event_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.bundle_event_type.get_name_leafdata())
                                    if (self.time_stamp.is_set or self.time_stamp.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.time_stamp.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "data"):
                                        if (self.data is None):
                                            self.data = BundleInformation.EventsMbr.EventsMbrIccpGroups.EventsMbrIccpGroup.EventsMbrBundleDescendantIccpGroup.EventsItem.Items.BundleEvtInfo.Data()
                                            self.data.parent = self
                                            self._children_name_map["data"] = "data"
                                        return self.data

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "data" or name == "bundle-event-type" or name == "time-stamp"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "bundle-event-type"):
                                        self.bundle_event_type = value
                                        self.bundle_event_type.value_namespace = name_space
                                        self.bundle_event_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "time-stamp"):
                                        self.time_stamp = value
                                        self.time_stamp.value_namespace = name_space
                                        self.time_stamp.value_namespace_prefix = name_space_prefix


                            class RgEvtInfo(Entity):
                                """
                                Event information for an RG
                                
                                .. attribute:: data
                                
                                	Additional data for the event
                                	**type**\:   :py:class:`Data <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.EventsMbr.EventsMbrIccpGroups.EventsMbrIccpGroup.EventsMbrBundleDescendantIccpGroup.EventsItem.Items.RgEvtInfo.Data>`
                                
                                .. attribute:: rg_event_type
                                
                                	Type of event for RG
                                	**type**\:   :py:class:`BmdBagEventRgItem <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmdBagEventRgItem>`
                                
                                .. attribute:: time_stamp
                                
                                	Time stamp of the event
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'bundlemgr-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(BundleInformation.EventsMbr.EventsMbrIccpGroups.EventsMbrIccpGroup.EventsMbrBundleDescendantIccpGroup.EventsItem.Items.RgEvtInfo, self).__init__()

                                    self.yang_name = "rg-evt-info"
                                    self.yang_parent_name = "items"

                                    self.rg_event_type = YLeaf(YType.enumeration, "rg-event-type")

                                    self.time_stamp = YLeaf(YType.uint64, "time-stamp")

                                    self.data = BundleInformation.EventsMbr.EventsMbrIccpGroups.EventsMbrIccpGroup.EventsMbrBundleDescendantIccpGroup.EventsItem.Items.RgEvtInfo.Data()
                                    self.data.parent = self
                                    self._children_name_map["data"] = "data"
                                    self._children_yang_names.add("data")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("rg_event_type",
                                                    "time_stamp") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(BundleInformation.EventsMbr.EventsMbrIccpGroups.EventsMbrIccpGroup.EventsMbrBundleDescendantIccpGroup.EventsItem.Items.RgEvtInfo, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(BundleInformation.EventsMbr.EventsMbrIccpGroups.EventsMbrIccpGroup.EventsMbrBundleDescendantIccpGroup.EventsItem.Items.RgEvtInfo, self).__setattr__(name, value)


                                class Data(Entity):
                                    """
                                    Additional data for the event
                                    
                                    .. attribute:: data_type
                                    
                                    	DataType
                                    	**type**\:   :py:class:`BmdBagEventData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmdBagEventData>`
                                    
                                    .. attribute:: error
                                    
                                    	Error
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: no_data
                                    
                                    	NoData
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: string_data
                                    
                                    	StringData
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'bundlemgr-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(BundleInformation.EventsMbr.EventsMbrIccpGroups.EventsMbrIccpGroup.EventsMbrBundleDescendantIccpGroup.EventsItem.Items.RgEvtInfo.Data, self).__init__()

                                        self.yang_name = "data"
                                        self.yang_parent_name = "rg-evt-info"

                                        self.data_type = YLeaf(YType.enumeration, "data-type")

                                        self.error = YLeaf(YType.uint32, "error")

                                        self.no_data = YLeaf(YType.uint8, "no-data")

                                        self.string_data = YLeaf(YType.str, "string-data")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data_type",
                                                        "error",
                                                        "no_data",
                                                        "string_data") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(BundleInformation.EventsMbr.EventsMbrIccpGroups.EventsMbrIccpGroup.EventsMbrBundleDescendantIccpGroup.EventsItem.Items.RgEvtInfo.Data, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(BundleInformation.EventsMbr.EventsMbrIccpGroups.EventsMbrIccpGroup.EventsMbrBundleDescendantIccpGroup.EventsItem.Items.RgEvtInfo.Data, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data_type.is_set or
                                            self.error.is_set or
                                            self.no_data.is_set or
                                            self.string_data.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data_type.yfilter != YFilter.not_set or
                                            self.error.yfilter != YFilter.not_set or
                                            self.no_data.yfilter != YFilter.not_set or
                                            self.string_data.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "data" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data_type.is_set or self.data_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data_type.get_name_leafdata())
                                        if (self.error.is_set or self.error.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.error.get_name_leafdata())
                                        if (self.no_data.is_set or self.no_data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.no_data.get_name_leafdata())
                                        if (self.string_data.is_set or self.string_data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.string_data.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data-type" or name == "error" or name == "no-data" or name == "string-data"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data-type"):
                                            self.data_type = value
                                            self.data_type.value_namespace = name_space
                                            self.data_type.value_namespace_prefix = name_space_prefix
                                        if(value_path == "error"):
                                            self.error = value
                                            self.error.value_namespace = name_space
                                            self.error.value_namespace_prefix = name_space_prefix
                                        if(value_path == "no-data"):
                                            self.no_data = value
                                            self.no_data.value_namespace = name_space
                                            self.no_data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "string-data"):
                                            self.string_data = value
                                            self.string_data.value_namespace = name_space
                                            self.string_data.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.rg_event_type.is_set or
                                        self.time_stamp.is_set or
                                        (self.data is not None and self.data.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.rg_event_type.yfilter != YFilter.not_set or
                                        self.time_stamp.yfilter != YFilter.not_set or
                                        (self.data is not None and self.data.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "rg-evt-info" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.rg_event_type.is_set or self.rg_event_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.rg_event_type.get_name_leafdata())
                                    if (self.time_stamp.is_set or self.time_stamp.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.time_stamp.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "data"):
                                        if (self.data is None):
                                            self.data = BundleInformation.EventsMbr.EventsMbrIccpGroups.EventsMbrIccpGroup.EventsMbrBundleDescendantIccpGroup.EventsItem.Items.RgEvtInfo.Data()
                                            self.data.parent = self
                                            self._children_name_map["data"] = "data"
                                        return self.data

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "data" or name == "rg-event-type" or name == "time-stamp"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "rg-event-type"):
                                        self.rg_event_type = value
                                        self.rg_event_type.value_namespace = name_space
                                        self.rg_event_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "time-stamp"):
                                        self.time_stamp = value
                                        self.time_stamp.value_namespace = name_space
                                        self.time_stamp.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.event_type.is_set or
                                    (self.bundle_evt_info is not None and self.bundle_evt_info.has_data()) or
                                    (self.member_evt_info is not None and self.member_evt_info.has_data()) or
                                    (self.rg_evt_info is not None and self.rg_evt_info.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.event_type.yfilter != YFilter.not_set or
                                    (self.bundle_evt_info is not None and self.bundle_evt_info.has_operation()) or
                                    (self.member_evt_info is not None and self.member_evt_info.has_operation()) or
                                    (self.rg_evt_info is not None and self.rg_evt_info.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "items" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.event_type.is_set or self.event_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.event_type.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "bundle-evt-info"):
                                    if (self.bundle_evt_info is None):
                                        self.bundle_evt_info = BundleInformation.EventsMbr.EventsMbrIccpGroups.EventsMbrIccpGroup.EventsMbrBundleDescendantIccpGroup.EventsItem.Items.BundleEvtInfo()
                                        self.bundle_evt_info.parent = self
                                        self._children_name_map["bundle_evt_info"] = "bundle-evt-info"
                                    return self.bundle_evt_info

                                if (child_yang_name == "member-evt-info"):
                                    if (self.member_evt_info is None):
                                        self.member_evt_info = BundleInformation.EventsMbr.EventsMbrIccpGroups.EventsMbrIccpGroup.EventsMbrBundleDescendantIccpGroup.EventsItem.Items.MemberEvtInfo()
                                        self.member_evt_info.parent = self
                                        self._children_name_map["member_evt_info"] = "member-evt-info"
                                    return self.member_evt_info

                                if (child_yang_name == "rg-evt-info"):
                                    if (self.rg_evt_info is None):
                                        self.rg_evt_info = BundleInformation.EventsMbr.EventsMbrIccpGroups.EventsMbrIccpGroup.EventsMbrBundleDescendantIccpGroup.EventsItem.Items.RgEvtInfo()
                                        self.rg_evt_info.parent = self
                                        self._children_name_map["rg_evt_info"] = "rg-evt-info"
                                    return self.rg_evt_info

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "bundle-evt-info" or name == "member-evt-info" or name == "rg-evt-info" or name == "event-type"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "event-type"):
                                    self.event_type = value
                                    self.event_type.value_namespace = name_space
                                    self.event_type.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.items:
                                if (c.has_data()):
                                    return True
                            return self.item_name.is_set

                        def has_operation(self):
                            for c in self.items:
                                if (c.has_operation()):
                                    return True
                            return (
                                self.yfilter != YFilter.not_set or
                                self.item_name.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "events-item" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.item_name.is_set or self.item_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.item_name.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "items"):
                                for c in self.items:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = BundleInformation.EventsMbr.EventsMbrIccpGroups.EventsMbrIccpGroup.EventsMbrBundleDescendantIccpGroup.EventsItem.Items()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.items.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "items" or name == "item-name"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "item-name"):
                                self.item_name = value
                                self.item_name.value_namespace = name_space
                                self.item_name.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.events_item:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.events_item:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "events-mbr-bundle-descendant-iccp-group" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "events-item"):
                            for c in self.events_item:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = BundleInformation.EventsMbr.EventsMbrIccpGroups.EventsMbrIccpGroup.EventsMbrBundleDescendantIccpGroup.EventsItem()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.events_item.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "events-item"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass

                def has_data(self):
                    return (
                        self.iccp_group.is_set or
                        (self.events_mbr_bundle_children_member_iccp_groups is not None and self.events_mbr_bundle_children_member_iccp_groups.has_data()) or
                        (self.events_mbr_bundle_descendant_iccp_group is not None and self.events_mbr_bundle_descendant_iccp_group.has_data()))

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.iccp_group.yfilter != YFilter.not_set or
                        (self.events_mbr_bundle_children_member_iccp_groups is not None and self.events_mbr_bundle_children_member_iccp_groups.has_operation()) or
                        (self.events_mbr_bundle_descendant_iccp_group is not None and self.events_mbr_bundle_descendant_iccp_group.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "events-mbr-iccp-group" + "[iccp-group='" + self.iccp_group.get() + "']" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-bundlemgr-oper:bundle-information/events-mbr/events-mbr-iccp-groups/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.iccp_group.is_set or self.iccp_group.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.iccp_group.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "events-mbr-bundle-children-member-iccp-groups"):
                        if (self.events_mbr_bundle_children_member_iccp_groups is None):
                            self.events_mbr_bundle_children_member_iccp_groups = BundleInformation.EventsMbr.EventsMbrIccpGroups.EventsMbrIccpGroup.EventsMbrBundleChildrenMemberIccpGroups()
                            self.events_mbr_bundle_children_member_iccp_groups.parent = self
                            self._children_name_map["events_mbr_bundle_children_member_iccp_groups"] = "events-mbr-bundle-children-member-iccp-groups"
                        return self.events_mbr_bundle_children_member_iccp_groups

                    if (child_yang_name == "events-mbr-bundle-descendant-iccp-group"):
                        if (self.events_mbr_bundle_descendant_iccp_group is None):
                            self.events_mbr_bundle_descendant_iccp_group = BundleInformation.EventsMbr.EventsMbrIccpGroups.EventsMbrIccpGroup.EventsMbrBundleDescendantIccpGroup()
                            self.events_mbr_bundle_descendant_iccp_group.parent = self
                            self._children_name_map["events_mbr_bundle_descendant_iccp_group"] = "events-mbr-bundle-descendant-iccp-group"
                        return self.events_mbr_bundle_descendant_iccp_group

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "events-mbr-bundle-children-member-iccp-groups" or name == "events-mbr-bundle-descendant-iccp-group" or name == "iccp-group"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "iccp-group"):
                        self.iccp_group = value
                        self.iccp_group.value_namespace = name_space
                        self.iccp_group.value_namespace_prefix = name_space_prefix

            def has_data(self):
                for c in self.events_mbr_iccp_group:
                    if (c.has_data()):
                        return True
                return False

            def has_operation(self):
                for c in self.events_mbr_iccp_group:
                    if (c.has_operation()):
                        return True
                return self.yfilter != YFilter.not_set

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "events-mbr-iccp-groups" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-bundlemgr-oper:bundle-information/events-mbr/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "events-mbr-iccp-group"):
                    for c in self.events_mbr_iccp_group:
                        segment = c.get_segment_path()
                        if (segment_path == segment):
                            return c
                    c = BundleInformation.EventsMbr.EventsMbrIccpGroups.EventsMbrIccpGroup()
                    c.parent = self
                    local_reference_key = "ydk::seg::%s" % segment_path
                    self._local_refs[local_reference_key] = c
                    self.events_mbr_iccp_group.append(c)
                    return c

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "events-mbr-iccp-group"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                pass

        def has_data(self):
            return (
                (self.events_mbr_bundles is not None and self.events_mbr_bundles.has_data()) or
                (self.events_mbr_iccp_groups is not None and self.events_mbr_iccp_groups.has_data()) or
                (self.events_mbr_members is not None and self.events_mbr_members.has_data()))

        def has_operation(self):
            return (
                self.yfilter != YFilter.not_set or
                (self.events_mbr_bundles is not None and self.events_mbr_bundles.has_operation()) or
                (self.events_mbr_iccp_groups is not None and self.events_mbr_iccp_groups.has_operation()) or
                (self.events_mbr_members is not None and self.events_mbr_members.has_operation()))

        def get_segment_path(self):
            path_buffer = ""
            path_buffer = "events-mbr" + path_buffer

            return path_buffer

        def get_entity_path(self, ancestor):
            path_buffer = ""
            if (ancestor is None):
                path_buffer = "Cisco-IOS-XR-bundlemgr-oper:bundle-information/%s" % self.get_segment_path()
            else:
                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

            leaf_name_data = LeafDataList()

            entity_path = EntityPath(path_buffer, leaf_name_data)
            return entity_path

        def get_child_by_name(self, child_yang_name, segment_path):
            child = self._get_child_by_seg_name([child_yang_name, segment_path])
            if child is not None:
                return child

            if (child_yang_name == "events-mbr-bundles"):
                if (self.events_mbr_bundles is None):
                    self.events_mbr_bundles = BundleInformation.EventsMbr.EventsMbrBundles()
                    self.events_mbr_bundles.parent = self
                    self._children_name_map["events_mbr_bundles"] = "events-mbr-bundles"
                return self.events_mbr_bundles

            if (child_yang_name == "events-mbr-iccp-groups"):
                if (self.events_mbr_iccp_groups is None):
                    self.events_mbr_iccp_groups = BundleInformation.EventsMbr.EventsMbrIccpGroups()
                    self.events_mbr_iccp_groups.parent = self
                    self._children_name_map["events_mbr_iccp_groups"] = "events-mbr-iccp-groups"
                return self.events_mbr_iccp_groups

            if (child_yang_name == "events-mbr-members"):
                if (self.events_mbr_members is None):
                    self.events_mbr_members = BundleInformation.EventsMbr.EventsMbrMembers()
                    self.events_mbr_members.parent = self
                    self._children_name_map["events_mbr_members"] = "events-mbr-members"
                return self.events_mbr_members

            return None

        def has_leaf_or_child_of_name(self, name):
            if(name == "events-mbr-bundles" or name == "events-mbr-iccp-groups" or name == "events-mbr-members"):
                return True
            return False

        def set_value(self, value_path, value, name_space, name_space_prefix):
            pass


    class MlacpIccpGroupCounters(Entity):
        """
        ICCP Group specific counters of mLACP events
        
        .. attribute:: iccp_groups
        
        	ICCP Groups with counters of mLACP events
        	**type**\:   :py:class:`IccpGroups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.MlacpIccpGroupCounters.IccpGroups>`
        
        

        """

        _prefix = 'bundlemgr-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(BundleInformation.MlacpIccpGroupCounters, self).__init__()

            self.yang_name = "mlacp-iccp-group-counters"
            self.yang_parent_name = "bundle-information"

            self.iccp_groups = BundleInformation.MlacpIccpGroupCounters.IccpGroups()
            self.iccp_groups.parent = self
            self._children_name_map["iccp_groups"] = "iccp-groups"
            self._children_yang_names.add("iccp-groups")


        class IccpGroups(Entity):
            """
            ICCP Groups with counters of mLACP events
            
            .. attribute:: iccp_group
            
            	ICCP Group ID
            	**type**\: list of    :py:class:`IccpGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.MlacpIccpGroupCounters.IccpGroups.IccpGroup>`
            
            

            """

            _prefix = 'bundlemgr-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(BundleInformation.MlacpIccpGroupCounters.IccpGroups, self).__init__()

                self.yang_name = "iccp-groups"
                self.yang_parent_name = "mlacp-iccp-group-counters"

                self.iccp_group = YList(self)

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in () and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(BundleInformation.MlacpIccpGroupCounters.IccpGroups, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(BundleInformation.MlacpIccpGroupCounters.IccpGroups, self).__setattr__(name, value)


            class IccpGroup(Entity):
                """
                ICCP Group ID
                
                .. attribute:: iccp_group  <key>
                
                	ICCP Group ID
                	**type**\:  int
                
                	**range:** 1..4294967295
                
                .. attribute:: iccp_group_ancestor_bundle
                
                	Data for this item and its parent RG
                	**type**\:   :py:class:`IccpGroupAncestorBundle <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.MlacpIccpGroupCounters.IccpGroups.IccpGroup.IccpGroupAncestorBundle>`
                
                .. attribute:: iccp_group_ancestor_member
                
                	Data for this item and its parent RG
                	**type**\:   :py:class:`IccpGroupAncestorMember <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.MlacpIccpGroupCounters.IccpGroups.IccpGroup.IccpGroupAncestorMember>`
                
                .. attribute:: iccp_group_ancestor_node
                
                	Data for this item and its parent RG
                	**type**\:   :py:class:`IccpGroupAncestorNode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.MlacpIccpGroupCounters.IccpGroups.IccpGroup.IccpGroupAncestorNode>`
                
                .. attribute:: iccp_group_item
                
                	Data for this item
                	**type**\:   :py:class:`IccpGroupItem <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.MlacpIccpGroupCounters.IccpGroups.IccpGroup.IccpGroupItem>`
                
                

                """

                _prefix = 'bundlemgr-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(BundleInformation.MlacpIccpGroupCounters.IccpGroups.IccpGroup, self).__init__()

                    self.yang_name = "iccp-group"
                    self.yang_parent_name = "iccp-groups"

                    self.iccp_group = YLeaf(YType.uint32, "iccp-group")

                    self.iccp_group_ancestor_bundle = BundleInformation.MlacpIccpGroupCounters.IccpGroups.IccpGroup.IccpGroupAncestorBundle()
                    self.iccp_group_ancestor_bundle.parent = self
                    self._children_name_map["iccp_group_ancestor_bundle"] = "iccp-group-ancestor-bundle"
                    self._children_yang_names.add("iccp-group-ancestor-bundle")

                    self.iccp_group_ancestor_member = BundleInformation.MlacpIccpGroupCounters.IccpGroups.IccpGroup.IccpGroupAncestorMember()
                    self.iccp_group_ancestor_member.parent = self
                    self._children_name_map["iccp_group_ancestor_member"] = "iccp-group-ancestor-member"
                    self._children_yang_names.add("iccp-group-ancestor-member")

                    self.iccp_group_ancestor_node = BundleInformation.MlacpIccpGroupCounters.IccpGroups.IccpGroup.IccpGroupAncestorNode()
                    self.iccp_group_ancestor_node.parent = self
                    self._children_name_map["iccp_group_ancestor_node"] = "iccp-group-ancestor-node"
                    self._children_yang_names.add("iccp-group-ancestor-node")

                    self.iccp_group_item = BundleInformation.MlacpIccpGroupCounters.IccpGroups.IccpGroup.IccpGroupItem()
                    self.iccp_group_item.parent = self
                    self._children_name_map["iccp_group_item"] = "iccp-group-item"
                    self._children_yang_names.add("iccp-group-item")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("iccp_group") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(BundleInformation.MlacpIccpGroupCounters.IccpGroups.IccpGroup, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(BundleInformation.MlacpIccpGroupCounters.IccpGroups.IccpGroup, self).__setattr__(name, value)


                class IccpGroupAncestorBundle(Entity):
                    """
                    Data for this item and its parent RG
                    
                    .. attribute:: iccp_group_counters
                    
                    	ICCP Group counters
                    	**type**\:   :py:class:`IccpGroupCounters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.MlacpIccpGroupCounters.IccpGroups.IccpGroup.IccpGroupAncestorBundle.IccpGroupCounters>`
                    
                    .. attribute:: iccp_group_id
                    
                    	ICCP Group ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'bundlemgr-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(BundleInformation.MlacpIccpGroupCounters.IccpGroups.IccpGroup.IccpGroupAncestorBundle, self).__init__()

                        self.yang_name = "iccp-group-ancestor-bundle"
                        self.yang_parent_name = "iccp-group"

                        self.iccp_group_id = YLeaf(YType.uint32, "iccp-group-id")

                        self.iccp_group_counters = BundleInformation.MlacpIccpGroupCounters.IccpGroups.IccpGroup.IccpGroupAncestorBundle.IccpGroupCounters()
                        self.iccp_group_counters.parent = self
                        self._children_name_map["iccp_group_counters"] = "iccp-group-counters"
                        self._children_yang_names.add("iccp-group-counters")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("iccp_group_id") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(BundleInformation.MlacpIccpGroupCounters.IccpGroups.IccpGroup.IccpGroupAncestorBundle, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(BundleInformation.MlacpIccpGroupCounters.IccpGroups.IccpGroup.IccpGroupAncestorBundle, self).__setattr__(name, value)


                    class IccpGroupCounters(Entity):
                        """
                        ICCP Group counters
                        
                        .. attribute:: connection
                        
                        	Number of connection events
                        	**type**\:   :py:class:`Connection <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.MlacpIccpGroupCounters.IccpGroups.IccpGroup.IccpGroupAncestorBundle.IccpGroupCounters.Connection>`
                        
                        .. attribute:: iccp_events
                        
                        	Number of ICCP events
                        	**type**\:   :py:class:`IccpEvents <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.MlacpIccpGroupCounters.IccpGroups.IccpGroup.IccpGroupAncestorBundle.IccpGroupCounters.IccpEvents>`
                        
                        .. attribute:: iccp_messages
                        
                        	Number ICCP messages sent and received
                        	**type**\:   :py:class:`IccpMessages <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.MlacpIccpGroupCounters.IccpGroups.IccpGroup.IccpGroupAncestorBundle.IccpGroupCounters.IccpMessages>`
                        
                        .. attribute:: invalid_tl_vs
                        
                        	Number invalid TLVs received
                        	**type**\:   :py:class:`InvalidTlVs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.MlacpIccpGroupCounters.IccpGroups.IccpGroup.IccpGroupAncestorBundle.IccpGroupCounters.InvalidTlVs>`
                        
                        .. attribute:: last_time_cleared
                        
                        	Time in nsecs from boot when counters were last cleared (deprecated)
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: nanosecond
                        
                        .. attribute:: last_unexpected_event
                        
                        	Elapsed time in nsecs since last unexpected event
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: nanosecond
                        
                        .. attribute:: time_since_cleared
                        
                        	Elapsed time in nsecs since counters were last cleared
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: nanosecond
                        
                        .. attribute:: tl_vs
                        
                        	Number TLVs sent and received
                        	**type**\:   :py:class:`TlVs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.MlacpIccpGroupCounters.IccpGroups.IccpGroup.IccpGroupAncestorBundle.IccpGroupCounters.TlVs>`
                        
                        

                        """

                        _prefix = 'bundlemgr-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(BundleInformation.MlacpIccpGroupCounters.IccpGroups.IccpGroup.IccpGroupAncestorBundle.IccpGroupCounters, self).__init__()

                            self.yang_name = "iccp-group-counters"
                            self.yang_parent_name = "iccp-group-ancestor-bundle"

                            self.last_time_cleared = YLeaf(YType.uint64, "last-time-cleared")

                            self.last_unexpected_event = YLeaf(YType.uint64, "last-unexpected-event")

                            self.time_since_cleared = YLeaf(YType.uint64, "time-since-cleared")

                            self.connection = BundleInformation.MlacpIccpGroupCounters.IccpGroups.IccpGroup.IccpGroupAncestorBundle.IccpGroupCounters.Connection()
                            self.connection.parent = self
                            self._children_name_map["connection"] = "connection"
                            self._children_yang_names.add("connection")

                            self.iccp_events = BundleInformation.MlacpIccpGroupCounters.IccpGroups.IccpGroup.IccpGroupAncestorBundle.IccpGroupCounters.IccpEvents()
                            self.iccp_events.parent = self
                            self._children_name_map["iccp_events"] = "iccp-events"
                            self._children_yang_names.add("iccp-events")

                            self.iccp_messages = BundleInformation.MlacpIccpGroupCounters.IccpGroups.IccpGroup.IccpGroupAncestorBundle.IccpGroupCounters.IccpMessages()
                            self.iccp_messages.parent = self
                            self._children_name_map["iccp_messages"] = "iccp-messages"
                            self._children_yang_names.add("iccp-messages")

                            self.invalid_tl_vs = BundleInformation.MlacpIccpGroupCounters.IccpGroups.IccpGroup.IccpGroupAncestorBundle.IccpGroupCounters.InvalidTlVs()
                            self.invalid_tl_vs.parent = self
                            self._children_name_map["invalid_tl_vs"] = "invalid-tl-vs"
                            self._children_yang_names.add("invalid-tl-vs")

                            self.tl_vs = BundleInformation.MlacpIccpGroupCounters.IccpGroups.IccpGroup.IccpGroupAncestorBundle.IccpGroupCounters.TlVs()
                            self.tl_vs.parent = self
                            self._children_name_map["tl_vs"] = "tl-vs"
                            self._children_yang_names.add("tl-vs")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("last_time_cleared",
                                            "last_unexpected_event",
                                            "time_since_cleared") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(BundleInformation.MlacpIccpGroupCounters.IccpGroups.IccpGroup.IccpGroupAncestorBundle.IccpGroupCounters, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(BundleInformation.MlacpIccpGroupCounters.IccpGroups.IccpGroup.IccpGroupAncestorBundle.IccpGroupCounters, self).__setattr__(name, value)


                        class Connection(Entity):
                            """
                            Number of connection events
                            
                            .. attribute:: iccp_config_connect_errors
                            
                            	Number of ICCP connection errors due to config
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: iccp_count_connect_errors
                            
                            	Number of ICCP connection errors due to max ICCP group count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: iccp_invalid_connects
                            
                            	Number of invalid ICCP connects
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: iccp_invalid_disconnects
                            
                            	Number of invalid ICCP disconnects
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: received_connects
                            
                            	Number of connect TLVs received
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: received_disconnects
                            
                            	Number of disconnect TLVs received
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: received_wrong_versions
                            
                            	Number of wrong version TLVs received
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: sent_connects
                            
                            	Number of connect TLVs sent
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: sent_disconnects
                            
                            	Number of disconnect TLVs sent
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: sent_wrong_versions
                            
                            	Number of wrong version TLVs sent
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'bundlemgr-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(BundleInformation.MlacpIccpGroupCounters.IccpGroups.IccpGroup.IccpGroupAncestorBundle.IccpGroupCounters.Connection, self).__init__()

                                self.yang_name = "connection"
                                self.yang_parent_name = "iccp-group-counters"

                                self.iccp_config_connect_errors = YLeaf(YType.uint32, "iccp-config-connect-errors")

                                self.iccp_count_connect_errors = YLeaf(YType.uint32, "iccp-count-connect-errors")

                                self.iccp_invalid_connects = YLeaf(YType.uint32, "iccp-invalid-connects")

                                self.iccp_invalid_disconnects = YLeaf(YType.uint32, "iccp-invalid-disconnects")

                                self.received_connects = YLeaf(YType.uint32, "received-connects")

                                self.received_disconnects = YLeaf(YType.uint32, "received-disconnects")

                                self.received_wrong_versions = YLeaf(YType.uint32, "received-wrong-versions")

                                self.sent_connects = YLeaf(YType.uint32, "sent-connects")

                                self.sent_disconnects = YLeaf(YType.uint32, "sent-disconnects")

                                self.sent_wrong_versions = YLeaf(YType.uint32, "sent-wrong-versions")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("iccp_config_connect_errors",
                                                "iccp_count_connect_errors",
                                                "iccp_invalid_connects",
                                                "iccp_invalid_disconnects",
                                                "received_connects",
                                                "received_disconnects",
                                                "received_wrong_versions",
                                                "sent_connects",
                                                "sent_disconnects",
                                                "sent_wrong_versions") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(BundleInformation.MlacpIccpGroupCounters.IccpGroups.IccpGroup.IccpGroupAncestorBundle.IccpGroupCounters.Connection, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(BundleInformation.MlacpIccpGroupCounters.IccpGroups.IccpGroup.IccpGroupAncestorBundle.IccpGroupCounters.Connection, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.iccp_config_connect_errors.is_set or
                                    self.iccp_count_connect_errors.is_set or
                                    self.iccp_invalid_connects.is_set or
                                    self.iccp_invalid_disconnects.is_set or
                                    self.received_connects.is_set or
                                    self.received_disconnects.is_set or
                                    self.received_wrong_versions.is_set or
                                    self.sent_connects.is_set or
                                    self.sent_disconnects.is_set or
                                    self.sent_wrong_versions.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.iccp_config_connect_errors.yfilter != YFilter.not_set or
                                    self.iccp_count_connect_errors.yfilter != YFilter.not_set or
                                    self.iccp_invalid_connects.yfilter != YFilter.not_set or
                                    self.iccp_invalid_disconnects.yfilter != YFilter.not_set or
                                    self.received_connects.yfilter != YFilter.not_set or
                                    self.received_disconnects.yfilter != YFilter.not_set or
                                    self.received_wrong_versions.yfilter != YFilter.not_set or
                                    self.sent_connects.yfilter != YFilter.not_set or
                                    self.sent_disconnects.yfilter != YFilter.not_set or
                                    self.sent_wrong_versions.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "connection" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.iccp_config_connect_errors.is_set or self.iccp_config_connect_errors.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.iccp_config_connect_errors.get_name_leafdata())
                                if (self.iccp_count_connect_errors.is_set or self.iccp_count_connect_errors.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.iccp_count_connect_errors.get_name_leafdata())
                                if (self.iccp_invalid_connects.is_set or self.iccp_invalid_connects.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.iccp_invalid_connects.get_name_leafdata())
                                if (self.iccp_invalid_disconnects.is_set or self.iccp_invalid_disconnects.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.iccp_invalid_disconnects.get_name_leafdata())
                                if (self.received_connects.is_set or self.received_connects.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.received_connects.get_name_leafdata())
                                if (self.received_disconnects.is_set or self.received_disconnects.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.received_disconnects.get_name_leafdata())
                                if (self.received_wrong_versions.is_set or self.received_wrong_versions.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.received_wrong_versions.get_name_leafdata())
                                if (self.sent_connects.is_set or self.sent_connects.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.sent_connects.get_name_leafdata())
                                if (self.sent_disconnects.is_set or self.sent_disconnects.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.sent_disconnects.get_name_leafdata())
                                if (self.sent_wrong_versions.is_set or self.sent_wrong_versions.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.sent_wrong_versions.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "iccp-config-connect-errors" or name == "iccp-count-connect-errors" or name == "iccp-invalid-connects" or name == "iccp-invalid-disconnects" or name == "received-connects" or name == "received-disconnects" or name == "received-wrong-versions" or name == "sent-connects" or name == "sent-disconnects" or name == "sent-wrong-versions"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "iccp-config-connect-errors"):
                                    self.iccp_config_connect_errors = value
                                    self.iccp_config_connect_errors.value_namespace = name_space
                                    self.iccp_config_connect_errors.value_namespace_prefix = name_space_prefix
                                if(value_path == "iccp-count-connect-errors"):
                                    self.iccp_count_connect_errors = value
                                    self.iccp_count_connect_errors.value_namespace = name_space
                                    self.iccp_count_connect_errors.value_namespace_prefix = name_space_prefix
                                if(value_path == "iccp-invalid-connects"):
                                    self.iccp_invalid_connects = value
                                    self.iccp_invalid_connects.value_namespace = name_space
                                    self.iccp_invalid_connects.value_namespace_prefix = name_space_prefix
                                if(value_path == "iccp-invalid-disconnects"):
                                    self.iccp_invalid_disconnects = value
                                    self.iccp_invalid_disconnects.value_namespace = name_space
                                    self.iccp_invalid_disconnects.value_namespace_prefix = name_space_prefix
                                if(value_path == "received-connects"):
                                    self.received_connects = value
                                    self.received_connects.value_namespace = name_space
                                    self.received_connects.value_namespace_prefix = name_space_prefix
                                if(value_path == "received-disconnects"):
                                    self.received_disconnects = value
                                    self.received_disconnects.value_namespace = name_space
                                    self.received_disconnects.value_namespace_prefix = name_space_prefix
                                if(value_path == "received-wrong-versions"):
                                    self.received_wrong_versions = value
                                    self.received_wrong_versions.value_namespace = name_space
                                    self.received_wrong_versions.value_namespace_prefix = name_space_prefix
                                if(value_path == "sent-connects"):
                                    self.sent_connects = value
                                    self.sent_connects.value_namespace = name_space
                                    self.sent_connects.value_namespace_prefix = name_space_prefix
                                if(value_path == "sent-disconnects"):
                                    self.sent_disconnects = value
                                    self.sent_disconnects.value_namespace = name_space
                                    self.sent_disconnects.value_namespace_prefix = name_space_prefix
                                if(value_path == "sent-wrong-versions"):
                                    self.sent_wrong_versions = value
                                    self.sent_wrong_versions.value_namespace = name_space
                                    self.sent_wrong_versions.value_namespace_prefix = name_space_prefix


                        class TlVs(Entity):
                            """
                            Number TLVs sent and received
                            
                            .. attribute:: received_config
                            
                            	Number of config TLVs received
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: received_config_sync_requests
                            
                            	Number of state config request TLVs received
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: received_na_ks
                            
                            	Number of NAK TLVs received
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: received_solicited_sync_data
                            
                            	Number of solicited sync data TLVs received
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: received_state
                            
                            	Number of state TLVs received
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: received_state_sync_requests
                            
                            	Number of state sync request TLVs received
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: received_sync_requests
                            
                            	Number of sync request TLVs received
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: received_unsolicited_sync_data
                            
                            	Number of unsolicited sync data TLVs received
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: sent_config
                            
                            	Number of config TLVs sent
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: sent_config_sync_requests
                            
                            	Number of config sync request TLVs sent
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: sent_na_ks
                            
                            	Number of NAK TLVs sent
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: sent_solicited_sync_data
                            
                            	Number of solicited sync data TLVs sent
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: sent_state
                            
                            	Number of state TLVs sent
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: sent_state_sync_requests
                            
                            	Number of state sync request TLVs sent
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: sent_sync_requests
                            
                            	Number of sync request TLVs sent
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: sent_unsolicited_sync_data
                            
                            	Number of unsolicited sync data TLVs sent
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'bundlemgr-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(BundleInformation.MlacpIccpGroupCounters.IccpGroups.IccpGroup.IccpGroupAncestorBundle.IccpGroupCounters.TlVs, self).__init__()

                                self.yang_name = "tl-vs"
                                self.yang_parent_name = "iccp-group-counters"

                                self.received_config = YLeaf(YType.uint32, "received-config")

                                self.received_config_sync_requests = YLeaf(YType.uint32, "received-config-sync-requests")

                                self.received_na_ks = YLeaf(YType.uint32, "received-na-ks")

                                self.received_solicited_sync_data = YLeaf(YType.uint32, "received-solicited-sync-data")

                                self.received_state = YLeaf(YType.uint32, "received-state")

                                self.received_state_sync_requests = YLeaf(YType.uint32, "received-state-sync-requests")

                                self.received_sync_requests = YLeaf(YType.uint32, "received-sync-requests")

                                self.received_unsolicited_sync_data = YLeaf(YType.uint32, "received-unsolicited-sync-data")

                                self.sent_config = YLeaf(YType.uint32, "sent-config")

                                self.sent_config_sync_requests = YLeaf(YType.uint32, "sent-config-sync-requests")

                                self.sent_na_ks = YLeaf(YType.uint32, "sent-na-ks")

                                self.sent_solicited_sync_data = YLeaf(YType.uint32, "sent-solicited-sync-data")

                                self.sent_state = YLeaf(YType.uint32, "sent-state")

                                self.sent_state_sync_requests = YLeaf(YType.uint32, "sent-state-sync-requests")

                                self.sent_sync_requests = YLeaf(YType.uint32, "sent-sync-requests")

                                self.sent_unsolicited_sync_data = YLeaf(YType.uint32, "sent-unsolicited-sync-data")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("received_config",
                                                "received_config_sync_requests",
                                                "received_na_ks",
                                                "received_solicited_sync_data",
                                                "received_state",
                                                "received_state_sync_requests",
                                                "received_sync_requests",
                                                "received_unsolicited_sync_data",
                                                "sent_config",
                                                "sent_config_sync_requests",
                                                "sent_na_ks",
                                                "sent_solicited_sync_data",
                                                "sent_state",
                                                "sent_state_sync_requests",
                                                "sent_sync_requests",
                                                "sent_unsolicited_sync_data") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(BundleInformation.MlacpIccpGroupCounters.IccpGroups.IccpGroup.IccpGroupAncestorBundle.IccpGroupCounters.TlVs, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(BundleInformation.MlacpIccpGroupCounters.IccpGroups.IccpGroup.IccpGroupAncestorBundle.IccpGroupCounters.TlVs, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.received_config.is_set or
                                    self.received_config_sync_requests.is_set or
                                    self.received_na_ks.is_set or
                                    self.received_solicited_sync_data.is_set or
                                    self.received_state.is_set or
                                    self.received_state_sync_requests.is_set or
                                    self.received_sync_requests.is_set or
                                    self.received_unsolicited_sync_data.is_set or
                                    self.sent_config.is_set or
                                    self.sent_config_sync_requests.is_set or
                                    self.sent_na_ks.is_set or
                                    self.sent_solicited_sync_data.is_set or
                                    self.sent_state.is_set or
                                    self.sent_state_sync_requests.is_set or
                                    self.sent_sync_requests.is_set or
                                    self.sent_unsolicited_sync_data.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.received_config.yfilter != YFilter.not_set or
                                    self.received_config_sync_requests.yfilter != YFilter.not_set or
                                    self.received_na_ks.yfilter != YFilter.not_set or
                                    self.received_solicited_sync_data.yfilter != YFilter.not_set or
                                    self.received_state.yfilter != YFilter.not_set or
                                    self.received_state_sync_requests.yfilter != YFilter.not_set or
                                    self.received_sync_requests.yfilter != YFilter.not_set or
                                    self.received_unsolicited_sync_data.yfilter != YFilter.not_set or
                                    self.sent_config.yfilter != YFilter.not_set or
                                    self.sent_config_sync_requests.yfilter != YFilter.not_set or
                                    self.sent_na_ks.yfilter != YFilter.not_set or
                                    self.sent_solicited_sync_data.yfilter != YFilter.not_set or
                                    self.sent_state.yfilter != YFilter.not_set or
                                    self.sent_state_sync_requests.yfilter != YFilter.not_set or
                                    self.sent_sync_requests.yfilter != YFilter.not_set or
                                    self.sent_unsolicited_sync_data.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "tl-vs" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.received_config.is_set or self.received_config.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.received_config.get_name_leafdata())
                                if (self.received_config_sync_requests.is_set or self.received_config_sync_requests.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.received_config_sync_requests.get_name_leafdata())
                                if (self.received_na_ks.is_set or self.received_na_ks.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.received_na_ks.get_name_leafdata())
                                if (self.received_solicited_sync_data.is_set or self.received_solicited_sync_data.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.received_solicited_sync_data.get_name_leafdata())
                                if (self.received_state.is_set or self.received_state.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.received_state.get_name_leafdata())
                                if (self.received_state_sync_requests.is_set or self.received_state_sync_requests.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.received_state_sync_requests.get_name_leafdata())
                                if (self.received_sync_requests.is_set or self.received_sync_requests.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.received_sync_requests.get_name_leafdata())
                                if (self.received_unsolicited_sync_data.is_set or self.received_unsolicited_sync_data.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.received_unsolicited_sync_data.get_name_leafdata())
                                if (self.sent_config.is_set or self.sent_config.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.sent_config.get_name_leafdata())
                                if (self.sent_config_sync_requests.is_set or self.sent_config_sync_requests.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.sent_config_sync_requests.get_name_leafdata())
                                if (self.sent_na_ks.is_set or self.sent_na_ks.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.sent_na_ks.get_name_leafdata())
                                if (self.sent_solicited_sync_data.is_set or self.sent_solicited_sync_data.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.sent_solicited_sync_data.get_name_leafdata())
                                if (self.sent_state.is_set or self.sent_state.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.sent_state.get_name_leafdata())
                                if (self.sent_state_sync_requests.is_set or self.sent_state_sync_requests.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.sent_state_sync_requests.get_name_leafdata())
                                if (self.sent_sync_requests.is_set or self.sent_sync_requests.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.sent_sync_requests.get_name_leafdata())
                                if (self.sent_unsolicited_sync_data.is_set or self.sent_unsolicited_sync_data.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.sent_unsolicited_sync_data.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "received-config" or name == "received-config-sync-requests" or name == "received-na-ks" or name == "received-solicited-sync-data" or name == "received-state" or name == "received-state-sync-requests" or name == "received-sync-requests" or name == "received-unsolicited-sync-data" or name == "sent-config" or name == "sent-config-sync-requests" or name == "sent-na-ks" or name == "sent-solicited-sync-data" or name == "sent-state" or name == "sent-state-sync-requests" or name == "sent-sync-requests" or name == "sent-unsolicited-sync-data"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "received-config"):
                                    self.received_config = value
                                    self.received_config.value_namespace = name_space
                                    self.received_config.value_namespace_prefix = name_space_prefix
                                if(value_path == "received-config-sync-requests"):
                                    self.received_config_sync_requests = value
                                    self.received_config_sync_requests.value_namespace = name_space
                                    self.received_config_sync_requests.value_namespace_prefix = name_space_prefix
                                if(value_path == "received-na-ks"):
                                    self.received_na_ks = value
                                    self.received_na_ks.value_namespace = name_space
                                    self.received_na_ks.value_namespace_prefix = name_space_prefix
                                if(value_path == "received-solicited-sync-data"):
                                    self.received_solicited_sync_data = value
                                    self.received_solicited_sync_data.value_namespace = name_space
                                    self.received_solicited_sync_data.value_namespace_prefix = name_space_prefix
                                if(value_path == "received-state"):
                                    self.received_state = value
                                    self.received_state.value_namespace = name_space
                                    self.received_state.value_namespace_prefix = name_space_prefix
                                if(value_path == "received-state-sync-requests"):
                                    self.received_state_sync_requests = value
                                    self.received_state_sync_requests.value_namespace = name_space
                                    self.received_state_sync_requests.value_namespace_prefix = name_space_prefix
                                if(value_path == "received-sync-requests"):
                                    self.received_sync_requests = value
                                    self.received_sync_requests.value_namespace = name_space
                                    self.received_sync_requests.value_namespace_prefix = name_space_prefix
                                if(value_path == "received-unsolicited-sync-data"):
                                    self.received_unsolicited_sync_data = value
                                    self.received_unsolicited_sync_data.value_namespace = name_space
                                    self.received_unsolicited_sync_data.value_namespace_prefix = name_space_prefix
                                if(value_path == "sent-config"):
                                    self.sent_config = value
                                    self.sent_config.value_namespace = name_space
                                    self.sent_config.value_namespace_prefix = name_space_prefix
                                if(value_path == "sent-config-sync-requests"):
                                    self.sent_config_sync_requests = value
                                    self.sent_config_sync_requests.value_namespace = name_space
                                    self.sent_config_sync_requests.value_namespace_prefix = name_space_prefix
                                if(value_path == "sent-na-ks"):
                                    self.sent_na_ks = value
                                    self.sent_na_ks.value_namespace = name_space
                                    self.sent_na_ks.value_namespace_prefix = name_space_prefix
                                if(value_path == "sent-solicited-sync-data"):
                                    self.sent_solicited_sync_data = value
                                    self.sent_solicited_sync_data.value_namespace = name_space
                                    self.sent_solicited_sync_data.value_namespace_prefix = name_space_prefix
                                if(value_path == "sent-state"):
                                    self.sent_state = value
                                    self.sent_state.value_namespace = name_space
                                    self.sent_state.value_namespace_prefix = name_space_prefix
                                if(value_path == "sent-state-sync-requests"):
                                    self.sent_state_sync_requests = value
                                    self.sent_state_sync_requests.value_namespace = name_space
                                    self.sent_state_sync_requests.value_namespace_prefix = name_space_prefix
                                if(value_path == "sent-sync-requests"):
                                    self.sent_sync_requests = value
                                    self.sent_sync_requests.value_namespace = name_space
                                    self.sent_sync_requests.value_namespace_prefix = name_space_prefix
                                if(value_path == "sent-unsolicited-sync-data"):
                                    self.sent_unsolicited_sync_data = value
                                    self.sent_unsolicited_sync_data.value_namespace = name_space
                                    self.sent_unsolicited_sync_data.value_namespace_prefix = name_space_prefix


                        class InvalidTlVs(Entity):
                            """
                            Number invalid TLVs received
                            
                            .. attribute:: incorrect_length
                            
                            	Number of messages received of an incorrect length
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: invalid_data
                            
                            	Number of messages received containing invalid data
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: invalid_type
                            
                            	Number of messages received with an invalid mLACP TLV type
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: unknown_bundle
                            
                            	Number of messages received for an unknown bundle
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: unknown_port
                            
                            	Number of messages received for an unknown port
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'bundlemgr-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(BundleInformation.MlacpIccpGroupCounters.IccpGroups.IccpGroup.IccpGroupAncestorBundle.IccpGroupCounters.InvalidTlVs, self).__init__()

                                self.yang_name = "invalid-tl-vs"
                                self.yang_parent_name = "iccp-group-counters"

                                self.incorrect_length = YLeaf(YType.uint32, "incorrect-length")

                                self.invalid_data = YLeaf(YType.uint32, "invalid-data")

                                self.invalid_type = YLeaf(YType.uint32, "invalid-type")

                                self.unknown_bundle = YLeaf(YType.uint32, "unknown-bundle")

                                self.unknown_port = YLeaf(YType.uint32, "unknown-port")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("incorrect_length",
                                                "invalid_data",
                                                "invalid_type",
                                                "unknown_bundle",
                                                "unknown_port") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(BundleInformation.MlacpIccpGroupCounters.IccpGroups.IccpGroup.IccpGroupAncestorBundle.IccpGroupCounters.InvalidTlVs, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(BundleInformation.MlacpIccpGroupCounters.IccpGroups.IccpGroup.IccpGroupAncestorBundle.IccpGroupCounters.InvalidTlVs, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.incorrect_length.is_set or
                                    self.invalid_data.is_set or
                                    self.invalid_type.is_set or
                                    self.unknown_bundle.is_set or
                                    self.unknown_port.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.incorrect_length.yfilter != YFilter.not_set or
                                    self.invalid_data.yfilter != YFilter.not_set or
                                    self.invalid_type.yfilter != YFilter.not_set or
                                    self.unknown_bundle.yfilter != YFilter.not_set or
                                    self.unknown_port.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "invalid-tl-vs" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.incorrect_length.is_set or self.incorrect_length.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.incorrect_length.get_name_leafdata())
                                if (self.invalid_data.is_set or self.invalid_data.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.invalid_data.get_name_leafdata())
                                if (self.invalid_type.is_set or self.invalid_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.invalid_type.get_name_leafdata())
                                if (self.unknown_bundle.is_set or self.unknown_bundle.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.unknown_bundle.get_name_leafdata())
                                if (self.unknown_port.is_set or self.unknown_port.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.unknown_port.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "incorrect-length" or name == "invalid-data" or name == "invalid-type" or name == "unknown-bundle" or name == "unknown-port"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "incorrect-length"):
                                    self.incorrect_length = value
                                    self.incorrect_length.value_namespace = name_space
                                    self.incorrect_length.value_namespace_prefix = name_space_prefix
                                if(value_path == "invalid-data"):
                                    self.invalid_data = value
                                    self.invalid_data.value_namespace = name_space
                                    self.invalid_data.value_namespace_prefix = name_space_prefix
                                if(value_path == "invalid-type"):
                                    self.invalid_type = value
                                    self.invalid_type.value_namespace = name_space
                                    self.invalid_type.value_namespace_prefix = name_space_prefix
                                if(value_path == "unknown-bundle"):
                                    self.unknown_bundle = value
                                    self.unknown_bundle.value_namespace = name_space
                                    self.unknown_bundle.value_namespace_prefix = name_space_prefix
                                if(value_path == "unknown-port"):
                                    self.unknown_port = value
                                    self.unknown_port.value_namespace = name_space
                                    self.unknown_port.value_namespace_prefix = name_space_prefix


                        class IccpMessages(Entity):
                            """
                            Number ICCP messages sent and received
                            
                            .. attribute:: received_messages
                            
                            	Number of messages received
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: sent_buffer_messages
                            
                            	Number of buffers sent (may be multiple per message)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: sent_messages
                            
                            	Number of messages sent
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: transmission_errors
                            
                            	Number of transmission errors
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'bundlemgr-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(BundleInformation.MlacpIccpGroupCounters.IccpGroups.IccpGroup.IccpGroupAncestorBundle.IccpGroupCounters.IccpMessages, self).__init__()

                                self.yang_name = "iccp-messages"
                                self.yang_parent_name = "iccp-group-counters"

                                self.received_messages = YLeaf(YType.uint32, "received-messages")

                                self.sent_buffer_messages = YLeaf(YType.uint32, "sent-buffer-messages")

                                self.sent_messages = YLeaf(YType.uint32, "sent-messages")

                                self.transmission_errors = YLeaf(YType.uint32, "transmission-errors")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("received_messages",
                                                "sent_buffer_messages",
                                                "sent_messages",
                                                "transmission_errors") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(BundleInformation.MlacpIccpGroupCounters.IccpGroups.IccpGroup.IccpGroupAncestorBundle.IccpGroupCounters.IccpMessages, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(BundleInformation.MlacpIccpGroupCounters.IccpGroups.IccpGroup.IccpGroupAncestorBundle.IccpGroupCounters.IccpMessages, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.received_messages.is_set or
                                    self.sent_buffer_messages.is_set or
                                    self.sent_messages.is_set or
                                    self.transmission_errors.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.received_messages.yfilter != YFilter.not_set or
                                    self.sent_buffer_messages.yfilter != YFilter.not_set or
                                    self.sent_messages.yfilter != YFilter.not_set or
                                    self.transmission_errors.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "iccp-messages" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.received_messages.is_set or self.received_messages.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.received_messages.get_name_leafdata())
                                if (self.sent_buffer_messages.is_set or self.sent_buffer_messages.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.sent_buffer_messages.get_name_leafdata())
                                if (self.sent_messages.is_set or self.sent_messages.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.sent_messages.get_name_leafdata())
                                if (self.transmission_errors.is_set or self.transmission_errors.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.transmission_errors.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "received-messages" or name == "sent-buffer-messages" or name == "sent-messages" or name == "transmission-errors"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "received-messages"):
                                    self.received_messages = value
                                    self.received_messages.value_namespace = name_space
                                    self.received_messages.value_namespace_prefix = name_space_prefix
                                if(value_path == "sent-buffer-messages"):
                                    self.sent_buffer_messages = value
                                    self.sent_buffer_messages.value_namespace = name_space
                                    self.sent_buffer_messages.value_namespace_prefix = name_space_prefix
                                if(value_path == "sent-messages"):
                                    self.sent_messages = value
                                    self.sent_messages.value_namespace = name_space
                                    self.sent_messages.value_namespace_prefix = name_space_prefix
                                if(value_path == "transmission-errors"):
                                    self.transmission_errors = value
                                    self.transmission_errors.value_namespace = name_space
                                    self.transmission_errors.value_namespace_prefix = name_space_prefix


                        class IccpEvents(Entity):
                            """
                            Number of ICCP events
                            
                            .. attribute:: configured_clear
                            
                            	Number of unconfigure events
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: configured_set
                            
                            	Number of configure events
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: member_status_down
                            
                            	Number of member status down events
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: member_status_up
                            
                            	Number of member status up events
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: pe_isolated
                            
                            	Number of PE isolation events
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: pe_isolated_clear
                            
                            	Number of PE isolation cleared events
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: reachability_cleared
                            
                            	Number of reachability cleared events
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: reachability_set
                            
                            	Number of reachability events
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: transport_down
                            
                            	Number of transport down events
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: transport_unavailable
                            
                            	Number of transport unavailable events
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: transport_up
                            
                            	Number of transport up events
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'bundlemgr-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(BundleInformation.MlacpIccpGroupCounters.IccpGroups.IccpGroup.IccpGroupAncestorBundle.IccpGroupCounters.IccpEvents, self).__init__()

                                self.yang_name = "iccp-events"
                                self.yang_parent_name = "iccp-group-counters"

                                self.configured_clear = YLeaf(YType.uint32, "configured-clear")

                                self.configured_set = YLeaf(YType.uint32, "configured-set")

                                self.member_status_down = YLeaf(YType.uint32, "member-status-down")

                                self.member_status_up = YLeaf(YType.uint32, "member-status-up")

                                self.pe_isolated = YLeaf(YType.uint32, "pe-isolated")

                                self.pe_isolated_clear = YLeaf(YType.uint32, "pe-isolated-clear")

                                self.reachability_cleared = YLeaf(YType.uint32, "reachability-cleared")

                                self.reachability_set = YLeaf(YType.uint32, "reachability-set")

                                self.transport_down = YLeaf(YType.uint32, "transport-down")

                                self.transport_unavailable = YLeaf(YType.uint32, "transport-unavailable")

                                self.transport_up = YLeaf(YType.uint32, "transport-up")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("configured_clear",
                                                "configured_set",
                                                "member_status_down",
                                                "member_status_up",
                                                "pe_isolated",
                                                "pe_isolated_clear",
                                                "reachability_cleared",
                                                "reachability_set",
                                                "transport_down",
                                                "transport_unavailable",
                                                "transport_up") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(BundleInformation.MlacpIccpGroupCounters.IccpGroups.IccpGroup.IccpGroupAncestorBundle.IccpGroupCounters.IccpEvents, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(BundleInformation.MlacpIccpGroupCounters.IccpGroups.IccpGroup.IccpGroupAncestorBundle.IccpGroupCounters.IccpEvents, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.configured_clear.is_set or
                                    self.configured_set.is_set or
                                    self.member_status_down.is_set or
                                    self.member_status_up.is_set or
                                    self.pe_isolated.is_set or
                                    self.pe_isolated_clear.is_set or
                                    self.reachability_cleared.is_set or
                                    self.reachability_set.is_set or
                                    self.transport_down.is_set or
                                    self.transport_unavailable.is_set or
                                    self.transport_up.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.configured_clear.yfilter != YFilter.not_set or
                                    self.configured_set.yfilter != YFilter.not_set or
                                    self.member_status_down.yfilter != YFilter.not_set or
                                    self.member_status_up.yfilter != YFilter.not_set or
                                    self.pe_isolated.yfilter != YFilter.not_set or
                                    self.pe_isolated_clear.yfilter != YFilter.not_set or
                                    self.reachability_cleared.yfilter != YFilter.not_set or
                                    self.reachability_set.yfilter != YFilter.not_set or
                                    self.transport_down.yfilter != YFilter.not_set or
                                    self.transport_unavailable.yfilter != YFilter.not_set or
                                    self.transport_up.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "iccp-events" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.configured_clear.is_set or self.configured_clear.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.configured_clear.get_name_leafdata())
                                if (self.configured_set.is_set or self.configured_set.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.configured_set.get_name_leafdata())
                                if (self.member_status_down.is_set or self.member_status_down.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.member_status_down.get_name_leafdata())
                                if (self.member_status_up.is_set or self.member_status_up.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.member_status_up.get_name_leafdata())
                                if (self.pe_isolated.is_set or self.pe_isolated.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pe_isolated.get_name_leafdata())
                                if (self.pe_isolated_clear.is_set or self.pe_isolated_clear.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pe_isolated_clear.get_name_leafdata())
                                if (self.reachability_cleared.is_set or self.reachability_cleared.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.reachability_cleared.get_name_leafdata())
                                if (self.reachability_set.is_set or self.reachability_set.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.reachability_set.get_name_leafdata())
                                if (self.transport_down.is_set or self.transport_down.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.transport_down.get_name_leafdata())
                                if (self.transport_unavailable.is_set or self.transport_unavailable.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.transport_unavailable.get_name_leafdata())
                                if (self.transport_up.is_set or self.transport_up.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.transport_up.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "configured-clear" or name == "configured-set" or name == "member-status-down" or name == "member-status-up" or name == "pe-isolated" or name == "pe-isolated-clear" or name == "reachability-cleared" or name == "reachability-set" or name == "transport-down" or name == "transport-unavailable" or name == "transport-up"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "configured-clear"):
                                    self.configured_clear = value
                                    self.configured_clear.value_namespace = name_space
                                    self.configured_clear.value_namespace_prefix = name_space_prefix
                                if(value_path == "configured-set"):
                                    self.configured_set = value
                                    self.configured_set.value_namespace = name_space
                                    self.configured_set.value_namespace_prefix = name_space_prefix
                                if(value_path == "member-status-down"):
                                    self.member_status_down = value
                                    self.member_status_down.value_namespace = name_space
                                    self.member_status_down.value_namespace_prefix = name_space_prefix
                                if(value_path == "member-status-up"):
                                    self.member_status_up = value
                                    self.member_status_up.value_namespace = name_space
                                    self.member_status_up.value_namespace_prefix = name_space_prefix
                                if(value_path == "pe-isolated"):
                                    self.pe_isolated = value
                                    self.pe_isolated.value_namespace = name_space
                                    self.pe_isolated.value_namespace_prefix = name_space_prefix
                                if(value_path == "pe-isolated-clear"):
                                    self.pe_isolated_clear = value
                                    self.pe_isolated_clear.value_namespace = name_space
                                    self.pe_isolated_clear.value_namespace_prefix = name_space_prefix
                                if(value_path == "reachability-cleared"):
                                    self.reachability_cleared = value
                                    self.reachability_cleared.value_namespace = name_space
                                    self.reachability_cleared.value_namespace_prefix = name_space_prefix
                                if(value_path == "reachability-set"):
                                    self.reachability_set = value
                                    self.reachability_set.value_namespace = name_space
                                    self.reachability_set.value_namespace_prefix = name_space_prefix
                                if(value_path == "transport-down"):
                                    self.transport_down = value
                                    self.transport_down.value_namespace = name_space
                                    self.transport_down.value_namespace_prefix = name_space_prefix
                                if(value_path == "transport-unavailable"):
                                    self.transport_unavailable = value
                                    self.transport_unavailable.value_namespace = name_space
                                    self.transport_unavailable.value_namespace_prefix = name_space_prefix
                                if(value_path == "transport-up"):
                                    self.transport_up = value
                                    self.transport_up.value_namespace = name_space
                                    self.transport_up.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.last_time_cleared.is_set or
                                self.last_unexpected_event.is_set or
                                self.time_since_cleared.is_set or
                                (self.connection is not None and self.connection.has_data()) or
                                (self.iccp_events is not None and self.iccp_events.has_data()) or
                                (self.iccp_messages is not None and self.iccp_messages.has_data()) or
                                (self.invalid_tl_vs is not None and self.invalid_tl_vs.has_data()) or
                                (self.tl_vs is not None and self.tl_vs.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.last_time_cleared.yfilter != YFilter.not_set or
                                self.last_unexpected_event.yfilter != YFilter.not_set or
                                self.time_since_cleared.yfilter != YFilter.not_set or
                                (self.connection is not None and self.connection.has_operation()) or
                                (self.iccp_events is not None and self.iccp_events.has_operation()) or
                                (self.iccp_messages is not None and self.iccp_messages.has_operation()) or
                                (self.invalid_tl_vs is not None and self.invalid_tl_vs.has_operation()) or
                                (self.tl_vs is not None and self.tl_vs.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "iccp-group-counters" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.last_time_cleared.is_set or self.last_time_cleared.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.last_time_cleared.get_name_leafdata())
                            if (self.last_unexpected_event.is_set or self.last_unexpected_event.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.last_unexpected_event.get_name_leafdata())
                            if (self.time_since_cleared.is_set or self.time_since_cleared.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.time_since_cleared.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "connection"):
                                if (self.connection is None):
                                    self.connection = BundleInformation.MlacpIccpGroupCounters.IccpGroups.IccpGroup.IccpGroupAncestorBundle.IccpGroupCounters.Connection()
                                    self.connection.parent = self
                                    self._children_name_map["connection"] = "connection"
                                return self.connection

                            if (child_yang_name == "iccp-events"):
                                if (self.iccp_events is None):
                                    self.iccp_events = BundleInformation.MlacpIccpGroupCounters.IccpGroups.IccpGroup.IccpGroupAncestorBundle.IccpGroupCounters.IccpEvents()
                                    self.iccp_events.parent = self
                                    self._children_name_map["iccp_events"] = "iccp-events"
                                return self.iccp_events

                            if (child_yang_name == "iccp-messages"):
                                if (self.iccp_messages is None):
                                    self.iccp_messages = BundleInformation.MlacpIccpGroupCounters.IccpGroups.IccpGroup.IccpGroupAncestorBundle.IccpGroupCounters.IccpMessages()
                                    self.iccp_messages.parent = self
                                    self._children_name_map["iccp_messages"] = "iccp-messages"
                                return self.iccp_messages

                            if (child_yang_name == "invalid-tl-vs"):
                                if (self.invalid_tl_vs is None):
                                    self.invalid_tl_vs = BundleInformation.MlacpIccpGroupCounters.IccpGroups.IccpGroup.IccpGroupAncestorBundle.IccpGroupCounters.InvalidTlVs()
                                    self.invalid_tl_vs.parent = self
                                    self._children_name_map["invalid_tl_vs"] = "invalid-tl-vs"
                                return self.invalid_tl_vs

                            if (child_yang_name == "tl-vs"):
                                if (self.tl_vs is None):
                                    self.tl_vs = BundleInformation.MlacpIccpGroupCounters.IccpGroups.IccpGroup.IccpGroupAncestorBundle.IccpGroupCounters.TlVs()
                                    self.tl_vs.parent = self
                                    self._children_name_map["tl_vs"] = "tl-vs"
                                return self.tl_vs

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "connection" or name == "iccp-events" or name == "iccp-messages" or name == "invalid-tl-vs" or name == "tl-vs" or name == "last-time-cleared" or name == "last-unexpected-event" or name == "time-since-cleared"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "last-time-cleared"):
                                self.last_time_cleared = value
                                self.last_time_cleared.value_namespace = name_space
                                self.last_time_cleared.value_namespace_prefix = name_space_prefix
                            if(value_path == "last-unexpected-event"):
                                self.last_unexpected_event = value
                                self.last_unexpected_event.value_namespace = name_space
                                self.last_unexpected_event.value_namespace_prefix = name_space_prefix
                            if(value_path == "time-since-cleared"):
                                self.time_since_cleared = value
                                self.time_since_cleared.value_namespace = name_space
                                self.time_since_cleared.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.iccp_group_id.is_set or
                            (self.iccp_group_counters is not None and self.iccp_group_counters.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.iccp_group_id.yfilter != YFilter.not_set or
                            (self.iccp_group_counters is not None and self.iccp_group_counters.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "iccp-group-ancestor-bundle" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.iccp_group_id.is_set or self.iccp_group_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.iccp_group_id.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "iccp-group-counters"):
                            if (self.iccp_group_counters is None):
                                self.iccp_group_counters = BundleInformation.MlacpIccpGroupCounters.IccpGroups.IccpGroup.IccpGroupAncestorBundle.IccpGroupCounters()
                                self.iccp_group_counters.parent = self
                                self._children_name_map["iccp_group_counters"] = "iccp-group-counters"
                            return self.iccp_group_counters

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "iccp-group-counters" or name == "iccp-group-id"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "iccp-group-id"):
                            self.iccp_group_id = value
                            self.iccp_group_id.value_namespace = name_space
                            self.iccp_group_id.value_namespace_prefix = name_space_prefix


                class IccpGroupAncestorMember(Entity):
                    """
                    Data for this item and its parent RG
                    
                    .. attribute:: iccp_group_counters
                    
                    	ICCP Group counters
                    	**type**\:   :py:class:`IccpGroupCounters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.MlacpIccpGroupCounters.IccpGroups.IccpGroup.IccpGroupAncestorMember.IccpGroupCounters>`
                    
                    .. attribute:: iccp_group_id
                    
                    	ICCP Group ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'bundlemgr-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(BundleInformation.MlacpIccpGroupCounters.IccpGroups.IccpGroup.IccpGroupAncestorMember, self).__init__()

                        self.yang_name = "iccp-group-ancestor-member"
                        self.yang_parent_name = "iccp-group"

                        self.iccp_group_id = YLeaf(YType.uint32, "iccp-group-id")

                        self.iccp_group_counters = BundleInformation.MlacpIccpGroupCounters.IccpGroups.IccpGroup.IccpGroupAncestorMember.IccpGroupCounters()
                        self.iccp_group_counters.parent = self
                        self._children_name_map["iccp_group_counters"] = "iccp-group-counters"
                        self._children_yang_names.add("iccp-group-counters")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("iccp_group_id") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(BundleInformation.MlacpIccpGroupCounters.IccpGroups.IccpGroup.IccpGroupAncestorMember, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(BundleInformation.MlacpIccpGroupCounters.IccpGroups.IccpGroup.IccpGroupAncestorMember, self).__setattr__(name, value)


                    class IccpGroupCounters(Entity):
                        """
                        ICCP Group counters
                        
                        .. attribute:: connection
                        
                        	Number of connection events
                        	**type**\:   :py:class:`Connection <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.MlacpIccpGroupCounters.IccpGroups.IccpGroup.IccpGroupAncestorMember.IccpGroupCounters.Connection>`
                        
                        .. attribute:: iccp_events
                        
                        	Number of ICCP events
                        	**type**\:   :py:class:`IccpEvents <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.MlacpIccpGroupCounters.IccpGroups.IccpGroup.IccpGroupAncestorMember.IccpGroupCounters.IccpEvents>`
                        
                        .. attribute:: iccp_messages
                        
                        	Number ICCP messages sent and received
                        	**type**\:   :py:class:`IccpMessages <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.MlacpIccpGroupCounters.IccpGroups.IccpGroup.IccpGroupAncestorMember.IccpGroupCounters.IccpMessages>`
                        
                        .. attribute:: invalid_tl_vs
                        
                        	Number invalid TLVs received
                        	**type**\:   :py:class:`InvalidTlVs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.MlacpIccpGroupCounters.IccpGroups.IccpGroup.IccpGroupAncestorMember.IccpGroupCounters.InvalidTlVs>`
                        
                        .. attribute:: last_time_cleared
                        
                        	Time in nsecs from boot when counters were last cleared (deprecated)
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: nanosecond
                        
                        .. attribute:: last_unexpected_event
                        
                        	Elapsed time in nsecs since last unexpected event
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: nanosecond
                        
                        .. attribute:: time_since_cleared
                        
                        	Elapsed time in nsecs since counters were last cleared
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: nanosecond
                        
                        .. attribute:: tl_vs
                        
                        	Number TLVs sent and received
                        	**type**\:   :py:class:`TlVs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.MlacpIccpGroupCounters.IccpGroups.IccpGroup.IccpGroupAncestorMember.IccpGroupCounters.TlVs>`
                        
                        

                        """

                        _prefix = 'bundlemgr-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(BundleInformation.MlacpIccpGroupCounters.IccpGroups.IccpGroup.IccpGroupAncestorMember.IccpGroupCounters, self).__init__()

                            self.yang_name = "iccp-group-counters"
                            self.yang_parent_name = "iccp-group-ancestor-member"

                            self.last_time_cleared = YLeaf(YType.uint64, "last-time-cleared")

                            self.last_unexpected_event = YLeaf(YType.uint64, "last-unexpected-event")

                            self.time_since_cleared = YLeaf(YType.uint64, "time-since-cleared")

                            self.connection = BundleInformation.MlacpIccpGroupCounters.IccpGroups.IccpGroup.IccpGroupAncestorMember.IccpGroupCounters.Connection()
                            self.connection.parent = self
                            self._children_name_map["connection"] = "connection"
                            self._children_yang_names.add("connection")

                            self.iccp_events = BundleInformation.MlacpIccpGroupCounters.IccpGroups.IccpGroup.IccpGroupAncestorMember.IccpGroupCounters.IccpEvents()
                            self.iccp_events.parent = self
                            self._children_name_map["iccp_events"] = "iccp-events"
                            self._children_yang_names.add("iccp-events")

                            self.iccp_messages = BundleInformation.MlacpIccpGroupCounters.IccpGroups.IccpGroup.IccpGroupAncestorMember.IccpGroupCounters.IccpMessages()
                            self.iccp_messages.parent = self
                            self._children_name_map["iccp_messages"] = "iccp-messages"
                            self._children_yang_names.add("iccp-messages")

                            self.invalid_tl_vs = BundleInformation.MlacpIccpGroupCounters.IccpGroups.IccpGroup.IccpGroupAncestorMember.IccpGroupCounters.InvalidTlVs()
                            self.invalid_tl_vs.parent = self
                            self._children_name_map["invalid_tl_vs"] = "invalid-tl-vs"
                            self._children_yang_names.add("invalid-tl-vs")

                            self.tl_vs = BundleInformation.MlacpIccpGroupCounters.IccpGroups.IccpGroup.IccpGroupAncestorMember.IccpGroupCounters.TlVs()
                            self.tl_vs.parent = self
                            self._children_name_map["tl_vs"] = "tl-vs"
                            self._children_yang_names.add("tl-vs")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("last_time_cleared",
                                            "last_unexpected_event",
                                            "time_since_cleared") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(BundleInformation.MlacpIccpGroupCounters.IccpGroups.IccpGroup.IccpGroupAncestorMember.IccpGroupCounters, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(BundleInformation.MlacpIccpGroupCounters.IccpGroups.IccpGroup.IccpGroupAncestorMember.IccpGroupCounters, self).__setattr__(name, value)


                        class Connection(Entity):
                            """
                            Number of connection events
                            
                            .. attribute:: iccp_config_connect_errors
                            
                            	Number of ICCP connection errors due to config
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: iccp_count_connect_errors
                            
                            	Number of ICCP connection errors due to max ICCP group count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: iccp_invalid_connects
                            
                            	Number of invalid ICCP connects
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: iccp_invalid_disconnects
                            
                            	Number of invalid ICCP disconnects
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: received_connects
                            
                            	Number of connect TLVs received
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: received_disconnects
                            
                            	Number of disconnect TLVs received
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: received_wrong_versions
                            
                            	Number of wrong version TLVs received
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: sent_connects
                            
                            	Number of connect TLVs sent
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: sent_disconnects
                            
                            	Number of disconnect TLVs sent
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: sent_wrong_versions
                            
                            	Number of wrong version TLVs sent
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'bundlemgr-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(BundleInformation.MlacpIccpGroupCounters.IccpGroups.IccpGroup.IccpGroupAncestorMember.IccpGroupCounters.Connection, self).__init__()

                                self.yang_name = "connection"
                                self.yang_parent_name = "iccp-group-counters"

                                self.iccp_config_connect_errors = YLeaf(YType.uint32, "iccp-config-connect-errors")

                                self.iccp_count_connect_errors = YLeaf(YType.uint32, "iccp-count-connect-errors")

                                self.iccp_invalid_connects = YLeaf(YType.uint32, "iccp-invalid-connects")

                                self.iccp_invalid_disconnects = YLeaf(YType.uint32, "iccp-invalid-disconnects")

                                self.received_connects = YLeaf(YType.uint32, "received-connects")

                                self.received_disconnects = YLeaf(YType.uint32, "received-disconnects")

                                self.received_wrong_versions = YLeaf(YType.uint32, "received-wrong-versions")

                                self.sent_connects = YLeaf(YType.uint32, "sent-connects")

                                self.sent_disconnects = YLeaf(YType.uint32, "sent-disconnects")

                                self.sent_wrong_versions = YLeaf(YType.uint32, "sent-wrong-versions")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("iccp_config_connect_errors",
                                                "iccp_count_connect_errors",
                                                "iccp_invalid_connects",
                                                "iccp_invalid_disconnects",
                                                "received_connects",
                                                "received_disconnects",
                                                "received_wrong_versions",
                                                "sent_connects",
                                                "sent_disconnects",
                                                "sent_wrong_versions") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(BundleInformation.MlacpIccpGroupCounters.IccpGroups.IccpGroup.IccpGroupAncestorMember.IccpGroupCounters.Connection, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(BundleInformation.MlacpIccpGroupCounters.IccpGroups.IccpGroup.IccpGroupAncestorMember.IccpGroupCounters.Connection, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.iccp_config_connect_errors.is_set or
                                    self.iccp_count_connect_errors.is_set or
                                    self.iccp_invalid_connects.is_set or
                                    self.iccp_invalid_disconnects.is_set or
                                    self.received_connects.is_set or
                                    self.received_disconnects.is_set or
                                    self.received_wrong_versions.is_set or
                                    self.sent_connects.is_set or
                                    self.sent_disconnects.is_set or
                                    self.sent_wrong_versions.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.iccp_config_connect_errors.yfilter != YFilter.not_set or
                                    self.iccp_count_connect_errors.yfilter != YFilter.not_set or
                                    self.iccp_invalid_connects.yfilter != YFilter.not_set or
                                    self.iccp_invalid_disconnects.yfilter != YFilter.not_set or
                                    self.received_connects.yfilter != YFilter.not_set or
                                    self.received_disconnects.yfilter != YFilter.not_set or
                                    self.received_wrong_versions.yfilter != YFilter.not_set or
                                    self.sent_connects.yfilter != YFilter.not_set or
                                    self.sent_disconnects.yfilter != YFilter.not_set or
                                    self.sent_wrong_versions.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "connection" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.iccp_config_connect_errors.is_set or self.iccp_config_connect_errors.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.iccp_config_connect_errors.get_name_leafdata())
                                if (self.iccp_count_connect_errors.is_set or self.iccp_count_connect_errors.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.iccp_count_connect_errors.get_name_leafdata())
                                if (self.iccp_invalid_connects.is_set or self.iccp_invalid_connects.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.iccp_invalid_connects.get_name_leafdata())
                                if (self.iccp_invalid_disconnects.is_set or self.iccp_invalid_disconnects.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.iccp_invalid_disconnects.get_name_leafdata())
                                if (self.received_connects.is_set or self.received_connects.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.received_connects.get_name_leafdata())
                                if (self.received_disconnects.is_set or self.received_disconnects.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.received_disconnects.get_name_leafdata())
                                if (self.received_wrong_versions.is_set or self.received_wrong_versions.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.received_wrong_versions.get_name_leafdata())
                                if (self.sent_connects.is_set or self.sent_connects.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.sent_connects.get_name_leafdata())
                                if (self.sent_disconnects.is_set or self.sent_disconnects.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.sent_disconnects.get_name_leafdata())
                                if (self.sent_wrong_versions.is_set or self.sent_wrong_versions.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.sent_wrong_versions.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "iccp-config-connect-errors" or name == "iccp-count-connect-errors" or name == "iccp-invalid-connects" or name == "iccp-invalid-disconnects" or name == "received-connects" or name == "received-disconnects" or name == "received-wrong-versions" or name == "sent-connects" or name == "sent-disconnects" or name == "sent-wrong-versions"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "iccp-config-connect-errors"):
                                    self.iccp_config_connect_errors = value
                                    self.iccp_config_connect_errors.value_namespace = name_space
                                    self.iccp_config_connect_errors.value_namespace_prefix = name_space_prefix
                                if(value_path == "iccp-count-connect-errors"):
                                    self.iccp_count_connect_errors = value
                                    self.iccp_count_connect_errors.value_namespace = name_space
                                    self.iccp_count_connect_errors.value_namespace_prefix = name_space_prefix
                                if(value_path == "iccp-invalid-connects"):
                                    self.iccp_invalid_connects = value
                                    self.iccp_invalid_connects.value_namespace = name_space
                                    self.iccp_invalid_connects.value_namespace_prefix = name_space_prefix
                                if(value_path == "iccp-invalid-disconnects"):
                                    self.iccp_invalid_disconnects = value
                                    self.iccp_invalid_disconnects.value_namespace = name_space
                                    self.iccp_invalid_disconnects.value_namespace_prefix = name_space_prefix
                                if(value_path == "received-connects"):
                                    self.received_connects = value
                                    self.received_connects.value_namespace = name_space
                                    self.received_connects.value_namespace_prefix = name_space_prefix
                                if(value_path == "received-disconnects"):
                                    self.received_disconnects = value
                                    self.received_disconnects.value_namespace = name_space
                                    self.received_disconnects.value_namespace_prefix = name_space_prefix
                                if(value_path == "received-wrong-versions"):
                                    self.received_wrong_versions = value
                                    self.received_wrong_versions.value_namespace = name_space
                                    self.received_wrong_versions.value_namespace_prefix = name_space_prefix
                                if(value_path == "sent-connects"):
                                    self.sent_connects = value
                                    self.sent_connects.value_namespace = name_space
                                    self.sent_connects.value_namespace_prefix = name_space_prefix
                                if(value_path == "sent-disconnects"):
                                    self.sent_disconnects = value
                                    self.sent_disconnects.value_namespace = name_space
                                    self.sent_disconnects.value_namespace_prefix = name_space_prefix
                                if(value_path == "sent-wrong-versions"):
                                    self.sent_wrong_versions = value
                                    self.sent_wrong_versions.value_namespace = name_space
                                    self.sent_wrong_versions.value_namespace_prefix = name_space_prefix


                        class TlVs(Entity):
                            """
                            Number TLVs sent and received
                            
                            .. attribute:: received_config
                            
                            	Number of config TLVs received
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: received_config_sync_requests
                            
                            	Number of state config request TLVs received
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: received_na_ks
                            
                            	Number of NAK TLVs received
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: received_solicited_sync_data
                            
                            	Number of solicited sync data TLVs received
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: received_state
                            
                            	Number of state TLVs received
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: received_state_sync_requests
                            
                            	Number of state sync request TLVs received
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: received_sync_requests
                            
                            	Number of sync request TLVs received
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: received_unsolicited_sync_data
                            
                            	Number of unsolicited sync data TLVs received
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: sent_config
                            
                            	Number of config TLVs sent
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: sent_config_sync_requests
                            
                            	Number of config sync request TLVs sent
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: sent_na_ks
                            
                            	Number of NAK TLVs sent
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: sent_solicited_sync_data
                            
                            	Number of solicited sync data TLVs sent
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: sent_state
                            
                            	Number of state TLVs sent
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: sent_state_sync_requests
                            
                            	Number of state sync request TLVs sent
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: sent_sync_requests
                            
                            	Number of sync request TLVs sent
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: sent_unsolicited_sync_data
                            
                            	Number of unsolicited sync data TLVs sent
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'bundlemgr-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(BundleInformation.MlacpIccpGroupCounters.IccpGroups.IccpGroup.IccpGroupAncestorMember.IccpGroupCounters.TlVs, self).__init__()

                                self.yang_name = "tl-vs"
                                self.yang_parent_name = "iccp-group-counters"

                                self.received_config = YLeaf(YType.uint32, "received-config")

                                self.received_config_sync_requests = YLeaf(YType.uint32, "received-config-sync-requests")

                                self.received_na_ks = YLeaf(YType.uint32, "received-na-ks")

                                self.received_solicited_sync_data = YLeaf(YType.uint32, "received-solicited-sync-data")

                                self.received_state = YLeaf(YType.uint32, "received-state")

                                self.received_state_sync_requests = YLeaf(YType.uint32, "received-state-sync-requests")

                                self.received_sync_requests = YLeaf(YType.uint32, "received-sync-requests")

                                self.received_unsolicited_sync_data = YLeaf(YType.uint32, "received-unsolicited-sync-data")

                                self.sent_config = YLeaf(YType.uint32, "sent-config")

                                self.sent_config_sync_requests = YLeaf(YType.uint32, "sent-config-sync-requests")

                                self.sent_na_ks = YLeaf(YType.uint32, "sent-na-ks")

                                self.sent_solicited_sync_data = YLeaf(YType.uint32, "sent-solicited-sync-data")

                                self.sent_state = YLeaf(YType.uint32, "sent-state")

                                self.sent_state_sync_requests = YLeaf(YType.uint32, "sent-state-sync-requests")

                                self.sent_sync_requests = YLeaf(YType.uint32, "sent-sync-requests")

                                self.sent_unsolicited_sync_data = YLeaf(YType.uint32, "sent-unsolicited-sync-data")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("received_config",
                                                "received_config_sync_requests",
                                                "received_na_ks",
                                                "received_solicited_sync_data",
                                                "received_state",
                                                "received_state_sync_requests",
                                                "received_sync_requests",
                                                "received_unsolicited_sync_data",
                                                "sent_config",
                                                "sent_config_sync_requests",
                                                "sent_na_ks",
                                                "sent_solicited_sync_data",
                                                "sent_state",
                                                "sent_state_sync_requests",
                                                "sent_sync_requests",
                                                "sent_unsolicited_sync_data") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(BundleInformation.MlacpIccpGroupCounters.IccpGroups.IccpGroup.IccpGroupAncestorMember.IccpGroupCounters.TlVs, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(BundleInformation.MlacpIccpGroupCounters.IccpGroups.IccpGroup.IccpGroupAncestorMember.IccpGroupCounters.TlVs, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.received_config.is_set or
                                    self.received_config_sync_requests.is_set or
                                    self.received_na_ks.is_set or
                                    self.received_solicited_sync_data.is_set or
                                    self.received_state.is_set or
                                    self.received_state_sync_requests.is_set or
                                    self.received_sync_requests.is_set or
                                    self.received_unsolicited_sync_data.is_set or
                                    self.sent_config.is_set or
                                    self.sent_config_sync_requests.is_set or
                                    self.sent_na_ks.is_set or
                                    self.sent_solicited_sync_data.is_set or
                                    self.sent_state.is_set or
                                    self.sent_state_sync_requests.is_set or
                                    self.sent_sync_requests.is_set or
                                    self.sent_unsolicited_sync_data.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.received_config.yfilter != YFilter.not_set or
                                    self.received_config_sync_requests.yfilter != YFilter.not_set or
                                    self.received_na_ks.yfilter != YFilter.not_set or
                                    self.received_solicited_sync_data.yfilter != YFilter.not_set or
                                    self.received_state.yfilter != YFilter.not_set or
                                    self.received_state_sync_requests.yfilter != YFilter.not_set or
                                    self.received_sync_requests.yfilter != YFilter.not_set or
                                    self.received_unsolicited_sync_data.yfilter != YFilter.not_set or
                                    self.sent_config.yfilter != YFilter.not_set or
                                    self.sent_config_sync_requests.yfilter != YFilter.not_set or
                                    self.sent_na_ks.yfilter != YFilter.not_set or
                                    self.sent_solicited_sync_data.yfilter != YFilter.not_set or
                                    self.sent_state.yfilter != YFilter.not_set or
                                    self.sent_state_sync_requests.yfilter != YFilter.not_set or
                                    self.sent_sync_requests.yfilter != YFilter.not_set or
                                    self.sent_unsolicited_sync_data.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "tl-vs" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.received_config.is_set or self.received_config.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.received_config.get_name_leafdata())
                                if (self.received_config_sync_requests.is_set or self.received_config_sync_requests.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.received_config_sync_requests.get_name_leafdata())
                                if (self.received_na_ks.is_set or self.received_na_ks.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.received_na_ks.get_name_leafdata())
                                if (self.received_solicited_sync_data.is_set or self.received_solicited_sync_data.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.received_solicited_sync_data.get_name_leafdata())
                                if (self.received_state.is_set or self.received_state.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.received_state.get_name_leafdata())
                                if (self.received_state_sync_requests.is_set or self.received_state_sync_requests.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.received_state_sync_requests.get_name_leafdata())
                                if (self.received_sync_requests.is_set or self.received_sync_requests.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.received_sync_requests.get_name_leafdata())
                                if (self.received_unsolicited_sync_data.is_set or self.received_unsolicited_sync_data.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.received_unsolicited_sync_data.get_name_leafdata())
                                if (self.sent_config.is_set or self.sent_config.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.sent_config.get_name_leafdata())
                                if (self.sent_config_sync_requests.is_set or self.sent_config_sync_requests.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.sent_config_sync_requests.get_name_leafdata())
                                if (self.sent_na_ks.is_set or self.sent_na_ks.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.sent_na_ks.get_name_leafdata())
                                if (self.sent_solicited_sync_data.is_set or self.sent_solicited_sync_data.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.sent_solicited_sync_data.get_name_leafdata())
                                if (self.sent_state.is_set or self.sent_state.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.sent_state.get_name_leafdata())
                                if (self.sent_state_sync_requests.is_set or self.sent_state_sync_requests.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.sent_state_sync_requests.get_name_leafdata())
                                if (self.sent_sync_requests.is_set or self.sent_sync_requests.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.sent_sync_requests.get_name_leafdata())
                                if (self.sent_unsolicited_sync_data.is_set or self.sent_unsolicited_sync_data.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.sent_unsolicited_sync_data.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "received-config" or name == "received-config-sync-requests" or name == "received-na-ks" or name == "received-solicited-sync-data" or name == "received-state" or name == "received-state-sync-requests" or name == "received-sync-requests" or name == "received-unsolicited-sync-data" or name == "sent-config" or name == "sent-config-sync-requests" or name == "sent-na-ks" or name == "sent-solicited-sync-data" or name == "sent-state" or name == "sent-state-sync-requests" or name == "sent-sync-requests" or name == "sent-unsolicited-sync-data"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "received-config"):
                                    self.received_config = value
                                    self.received_config.value_namespace = name_space
                                    self.received_config.value_namespace_prefix = name_space_prefix
                                if(value_path == "received-config-sync-requests"):
                                    self.received_config_sync_requests = value
                                    self.received_config_sync_requests.value_namespace = name_space
                                    self.received_config_sync_requests.value_namespace_prefix = name_space_prefix
                                if(value_path == "received-na-ks"):
                                    self.received_na_ks = value
                                    self.received_na_ks.value_namespace = name_space
                                    self.received_na_ks.value_namespace_prefix = name_space_prefix
                                if(value_path == "received-solicited-sync-data"):
                                    self.received_solicited_sync_data = value
                                    self.received_solicited_sync_data.value_namespace = name_space
                                    self.received_solicited_sync_data.value_namespace_prefix = name_space_prefix
                                if(value_path == "received-state"):
                                    self.received_state = value
                                    self.received_state.value_namespace = name_space
                                    self.received_state.value_namespace_prefix = name_space_prefix
                                if(value_path == "received-state-sync-requests"):
                                    self.received_state_sync_requests = value
                                    self.received_state_sync_requests.value_namespace = name_space
                                    self.received_state_sync_requests.value_namespace_prefix = name_space_prefix
                                if(value_path == "received-sync-requests"):
                                    self.received_sync_requests = value
                                    self.received_sync_requests.value_namespace = name_space
                                    self.received_sync_requests.value_namespace_prefix = name_space_prefix
                                if(value_path == "received-unsolicited-sync-data"):
                                    self.received_unsolicited_sync_data = value
                                    self.received_unsolicited_sync_data.value_namespace = name_space
                                    self.received_unsolicited_sync_data.value_namespace_prefix = name_space_prefix
                                if(value_path == "sent-config"):
                                    self.sent_config = value
                                    self.sent_config.value_namespace = name_space
                                    self.sent_config.value_namespace_prefix = name_space_prefix
                                if(value_path == "sent-config-sync-requests"):
                                    self.sent_config_sync_requests = value
                                    self.sent_config_sync_requests.value_namespace = name_space
                                    self.sent_config_sync_requests.value_namespace_prefix = name_space_prefix
                                if(value_path == "sent-na-ks"):
                                    self.sent_na_ks = value
                                    self.sent_na_ks.value_namespace = name_space
                                    self.sent_na_ks.value_namespace_prefix = name_space_prefix
                                if(value_path == "sent-solicited-sync-data"):
                                    self.sent_solicited_sync_data = value
                                    self.sent_solicited_sync_data.value_namespace = name_space
                                    self.sent_solicited_sync_data.value_namespace_prefix = name_space_prefix
                                if(value_path == "sent-state"):
                                    self.sent_state = value
                                    self.sent_state.value_namespace = name_space
                                    self.sent_state.value_namespace_prefix = name_space_prefix
                                if(value_path == "sent-state-sync-requests"):
                                    self.sent_state_sync_requests = value
                                    self.sent_state_sync_requests.value_namespace = name_space
                                    self.sent_state_sync_requests.value_namespace_prefix = name_space_prefix
                                if(value_path == "sent-sync-requests"):
                                    self.sent_sync_requests = value
                                    self.sent_sync_requests.value_namespace = name_space
                                    self.sent_sync_requests.value_namespace_prefix = name_space_prefix
                                if(value_path == "sent-unsolicited-sync-data"):
                                    self.sent_unsolicited_sync_data = value
                                    self.sent_unsolicited_sync_data.value_namespace = name_space
                                    self.sent_unsolicited_sync_data.value_namespace_prefix = name_space_prefix


                        class InvalidTlVs(Entity):
                            """
                            Number invalid TLVs received
                            
                            .. attribute:: incorrect_length
                            
                            	Number of messages received of an incorrect length
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: invalid_data
                            
                            	Number of messages received containing invalid data
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: invalid_type
                            
                            	Number of messages received with an invalid mLACP TLV type
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: unknown_bundle
                            
                            	Number of messages received for an unknown bundle
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: unknown_port
                            
                            	Number of messages received for an unknown port
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'bundlemgr-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(BundleInformation.MlacpIccpGroupCounters.IccpGroups.IccpGroup.IccpGroupAncestorMember.IccpGroupCounters.InvalidTlVs, self).__init__()

                                self.yang_name = "invalid-tl-vs"
                                self.yang_parent_name = "iccp-group-counters"

                                self.incorrect_length = YLeaf(YType.uint32, "incorrect-length")

                                self.invalid_data = YLeaf(YType.uint32, "invalid-data")

                                self.invalid_type = YLeaf(YType.uint32, "invalid-type")

                                self.unknown_bundle = YLeaf(YType.uint32, "unknown-bundle")

                                self.unknown_port = YLeaf(YType.uint32, "unknown-port")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("incorrect_length",
                                                "invalid_data",
                                                "invalid_type",
                                                "unknown_bundle",
                                                "unknown_port") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(BundleInformation.MlacpIccpGroupCounters.IccpGroups.IccpGroup.IccpGroupAncestorMember.IccpGroupCounters.InvalidTlVs, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(BundleInformation.MlacpIccpGroupCounters.IccpGroups.IccpGroup.IccpGroupAncestorMember.IccpGroupCounters.InvalidTlVs, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.incorrect_length.is_set or
                                    self.invalid_data.is_set or
                                    self.invalid_type.is_set or
                                    self.unknown_bundle.is_set or
                                    self.unknown_port.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.incorrect_length.yfilter != YFilter.not_set or
                                    self.invalid_data.yfilter != YFilter.not_set or
                                    self.invalid_type.yfilter != YFilter.not_set or
                                    self.unknown_bundle.yfilter != YFilter.not_set or
                                    self.unknown_port.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "invalid-tl-vs" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.incorrect_length.is_set or self.incorrect_length.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.incorrect_length.get_name_leafdata())
                                if (self.invalid_data.is_set or self.invalid_data.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.invalid_data.get_name_leafdata())
                                if (self.invalid_type.is_set or self.invalid_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.invalid_type.get_name_leafdata())
                                if (self.unknown_bundle.is_set or self.unknown_bundle.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.unknown_bundle.get_name_leafdata())
                                if (self.unknown_port.is_set or self.unknown_port.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.unknown_port.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "incorrect-length" or name == "invalid-data" or name == "invalid-type" or name == "unknown-bundle" or name == "unknown-port"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "incorrect-length"):
                                    self.incorrect_length = value
                                    self.incorrect_length.value_namespace = name_space
                                    self.incorrect_length.value_namespace_prefix = name_space_prefix
                                if(value_path == "invalid-data"):
                                    self.invalid_data = value
                                    self.invalid_data.value_namespace = name_space
                                    self.invalid_data.value_namespace_prefix = name_space_prefix
                                if(value_path == "invalid-type"):
                                    self.invalid_type = value
                                    self.invalid_type.value_namespace = name_space
                                    self.invalid_type.value_namespace_prefix = name_space_prefix
                                if(value_path == "unknown-bundle"):
                                    self.unknown_bundle = value
                                    self.unknown_bundle.value_namespace = name_space
                                    self.unknown_bundle.value_namespace_prefix = name_space_prefix
                                if(value_path == "unknown-port"):
                                    self.unknown_port = value
                                    self.unknown_port.value_namespace = name_space
                                    self.unknown_port.value_namespace_prefix = name_space_prefix


                        class IccpMessages(Entity):
                            """
                            Number ICCP messages sent and received
                            
                            .. attribute:: received_messages
                            
                            	Number of messages received
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: sent_buffer_messages
                            
                            	Number of buffers sent (may be multiple per message)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: sent_messages
                            
                            	Number of messages sent
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: transmission_errors
                            
                            	Number of transmission errors
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'bundlemgr-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(BundleInformation.MlacpIccpGroupCounters.IccpGroups.IccpGroup.IccpGroupAncestorMember.IccpGroupCounters.IccpMessages, self).__init__()

                                self.yang_name = "iccp-messages"
                                self.yang_parent_name = "iccp-group-counters"

                                self.received_messages = YLeaf(YType.uint32, "received-messages")

                                self.sent_buffer_messages = YLeaf(YType.uint32, "sent-buffer-messages")

                                self.sent_messages = YLeaf(YType.uint32, "sent-messages")

                                self.transmission_errors = YLeaf(YType.uint32, "transmission-errors")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("received_messages",
                                                "sent_buffer_messages",
                                                "sent_messages",
                                                "transmission_errors") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(BundleInformation.MlacpIccpGroupCounters.IccpGroups.IccpGroup.IccpGroupAncestorMember.IccpGroupCounters.IccpMessages, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(BundleInformation.MlacpIccpGroupCounters.IccpGroups.IccpGroup.IccpGroupAncestorMember.IccpGroupCounters.IccpMessages, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.received_messages.is_set or
                                    self.sent_buffer_messages.is_set or
                                    self.sent_messages.is_set or
                                    self.transmission_errors.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.received_messages.yfilter != YFilter.not_set or
                                    self.sent_buffer_messages.yfilter != YFilter.not_set or
                                    self.sent_messages.yfilter != YFilter.not_set or
                                    self.transmission_errors.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "iccp-messages" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.received_messages.is_set or self.received_messages.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.received_messages.get_name_leafdata())
                                if (self.sent_buffer_messages.is_set or self.sent_buffer_messages.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.sent_buffer_messages.get_name_leafdata())
                                if (self.sent_messages.is_set or self.sent_messages.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.sent_messages.get_name_leafdata())
                                if (self.transmission_errors.is_set or self.transmission_errors.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.transmission_errors.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "received-messages" or name == "sent-buffer-messages" or name == "sent-messages" or name == "transmission-errors"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "received-messages"):
                                    self.received_messages = value
                                    self.received_messages.value_namespace = name_space
                                    self.received_messages.value_namespace_prefix = name_space_prefix
                                if(value_path == "sent-buffer-messages"):
                                    self.sent_buffer_messages = value
                                    self.sent_buffer_messages.value_namespace = name_space
                                    self.sent_buffer_messages.value_namespace_prefix = name_space_prefix
                                if(value_path == "sent-messages"):
                                    self.sent_messages = value
                                    self.sent_messages.value_namespace = name_space
                                    self.sent_messages.value_namespace_prefix = name_space_prefix
                                if(value_path == "transmission-errors"):
                                    self.transmission_errors = value
                                    self.transmission_errors.value_namespace = name_space
                                    self.transmission_errors.value_namespace_prefix = name_space_prefix


                        class IccpEvents(Entity):
                            """
                            Number of ICCP events
                            
                            .. attribute:: configured_clear
                            
                            	Number of unconfigure events
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: configured_set
                            
                            	Number of configure events
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: member_status_down
                            
                            	Number of member status down events
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: member_status_up
                            
                            	Number of member status up events
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: pe_isolated
                            
                            	Number of PE isolation events
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: pe_isolated_clear
                            
                            	Number of PE isolation cleared events
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: reachability_cleared
                            
                            	Number of reachability cleared events
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: reachability_set
                            
                            	Number of reachability events
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: transport_down
                            
                            	Number of transport down events
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: transport_unavailable
                            
                            	Number of transport unavailable events
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: transport_up
                            
                            	Number of transport up events
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'bundlemgr-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(BundleInformation.MlacpIccpGroupCounters.IccpGroups.IccpGroup.IccpGroupAncestorMember.IccpGroupCounters.IccpEvents, self).__init__()

                                self.yang_name = "iccp-events"
                                self.yang_parent_name = "iccp-group-counters"

                                self.configured_clear = YLeaf(YType.uint32, "configured-clear")

                                self.configured_set = YLeaf(YType.uint32, "configured-set")

                                self.member_status_down = YLeaf(YType.uint32, "member-status-down")

                                self.member_status_up = YLeaf(YType.uint32, "member-status-up")

                                self.pe_isolated = YLeaf(YType.uint32, "pe-isolated")

                                self.pe_isolated_clear = YLeaf(YType.uint32, "pe-isolated-clear")

                                self.reachability_cleared = YLeaf(YType.uint32, "reachability-cleared")

                                self.reachability_set = YLeaf(YType.uint32, "reachability-set")

                                self.transport_down = YLeaf(YType.uint32, "transport-down")

                                self.transport_unavailable = YLeaf(YType.uint32, "transport-unavailable")

                                self.transport_up = YLeaf(YType.uint32, "transport-up")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("configured_clear",
                                                "configured_set",
                                                "member_status_down",
                                                "member_status_up",
                                                "pe_isolated",
                                                "pe_isolated_clear",
                                                "reachability_cleared",
                                                "reachability_set",
                                                "transport_down",
                                                "transport_unavailable",
                                                "transport_up") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(BundleInformation.MlacpIccpGroupCounters.IccpGroups.IccpGroup.IccpGroupAncestorMember.IccpGroupCounters.IccpEvents, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(BundleInformation.MlacpIccpGroupCounters.IccpGroups.IccpGroup.IccpGroupAncestorMember.IccpGroupCounters.IccpEvents, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.configured_clear.is_set or
                                    self.configured_set.is_set or
                                    self.member_status_down.is_set or
                                    self.member_status_up.is_set or
                                    self.pe_isolated.is_set or
                                    self.pe_isolated_clear.is_set or
                                    self.reachability_cleared.is_set or
                                    self.reachability_set.is_set or
                                    self.transport_down.is_set or
                                    self.transport_unavailable.is_set or
                                    self.transport_up.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.configured_clear.yfilter != YFilter.not_set or
                                    self.configured_set.yfilter != YFilter.not_set or
                                    self.member_status_down.yfilter != YFilter.not_set or
                                    self.member_status_up.yfilter != YFilter.not_set or
                                    self.pe_isolated.yfilter != YFilter.not_set or
                                    self.pe_isolated_clear.yfilter != YFilter.not_set or
                                    self.reachability_cleared.yfilter != YFilter.not_set or
                                    self.reachability_set.yfilter != YFilter.not_set or
                                    self.transport_down.yfilter != YFilter.not_set or
                                    self.transport_unavailable.yfilter != YFilter.not_set or
                                    self.transport_up.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "iccp-events" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.configured_clear.is_set or self.configured_clear.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.configured_clear.get_name_leafdata())
                                if (self.configured_set.is_set or self.configured_set.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.configured_set.get_name_leafdata())
                                if (self.member_status_down.is_set or self.member_status_down.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.member_status_down.get_name_leafdata())
                                if (self.member_status_up.is_set or self.member_status_up.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.member_status_up.get_name_leafdata())
                                if (self.pe_isolated.is_set or self.pe_isolated.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pe_isolated.get_name_leafdata())
                                if (self.pe_isolated_clear.is_set or self.pe_isolated_clear.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pe_isolated_clear.get_name_leafdata())
                                if (self.reachability_cleared.is_set or self.reachability_cleared.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.reachability_cleared.get_name_leafdata())
                                if (self.reachability_set.is_set or self.reachability_set.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.reachability_set.get_name_leafdata())
                                if (self.transport_down.is_set or self.transport_down.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.transport_down.get_name_leafdata())
                                if (self.transport_unavailable.is_set or self.transport_unavailable.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.transport_unavailable.get_name_leafdata())
                                if (self.transport_up.is_set or self.transport_up.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.transport_up.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "configured-clear" or name == "configured-set" or name == "member-status-down" or name == "member-status-up" or name == "pe-isolated" or name == "pe-isolated-clear" or name == "reachability-cleared" or name == "reachability-set" or name == "transport-down" or name == "transport-unavailable" or name == "transport-up"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "configured-clear"):
                                    self.configured_clear = value
                                    self.configured_clear.value_namespace = name_space
                                    self.configured_clear.value_namespace_prefix = name_space_prefix
                                if(value_path == "configured-set"):
                                    self.configured_set = value
                                    self.configured_set.value_namespace = name_space
                                    self.configured_set.value_namespace_prefix = name_space_prefix
                                if(value_path == "member-status-down"):
                                    self.member_status_down = value
                                    self.member_status_down.value_namespace = name_space
                                    self.member_status_down.value_namespace_prefix = name_space_prefix
                                if(value_path == "member-status-up"):
                                    self.member_status_up = value
                                    self.member_status_up.value_namespace = name_space
                                    self.member_status_up.value_namespace_prefix = name_space_prefix
                                if(value_path == "pe-isolated"):
                                    self.pe_isolated = value
                                    self.pe_isolated.value_namespace = name_space
                                    self.pe_isolated.value_namespace_prefix = name_space_prefix
                                if(value_path == "pe-isolated-clear"):
                                    self.pe_isolated_clear = value
                                    self.pe_isolated_clear.value_namespace = name_space
                                    self.pe_isolated_clear.value_namespace_prefix = name_space_prefix
                                if(value_path == "reachability-cleared"):
                                    self.reachability_cleared = value
                                    self.reachability_cleared.value_namespace = name_space
                                    self.reachability_cleared.value_namespace_prefix = name_space_prefix
                                if(value_path == "reachability-set"):
                                    self.reachability_set = value
                                    self.reachability_set.value_namespace = name_space
                                    self.reachability_set.value_namespace_prefix = name_space_prefix
                                if(value_path == "transport-down"):
                                    self.transport_down = value
                                    self.transport_down.value_namespace = name_space
                                    self.transport_down.value_namespace_prefix = name_space_prefix
                                if(value_path == "transport-unavailable"):
                                    self.transport_unavailable = value
                                    self.transport_unavailable.value_namespace = name_space
                                    self.transport_unavailable.value_namespace_prefix = name_space_prefix
                                if(value_path == "transport-up"):
                                    self.transport_up = value
                                    self.transport_up.value_namespace = name_space
                                    self.transport_up.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.last_time_cleared.is_set or
                                self.last_unexpected_event.is_set or
                                self.time_since_cleared.is_set or
                                (self.connection is not None and self.connection.has_data()) or
                                (self.iccp_events is not None and self.iccp_events.has_data()) or
                                (self.iccp_messages is not None and self.iccp_messages.has_data()) or
                                (self.invalid_tl_vs is not None and self.invalid_tl_vs.has_data()) or
                                (self.tl_vs is not None and self.tl_vs.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.last_time_cleared.yfilter != YFilter.not_set or
                                self.last_unexpected_event.yfilter != YFilter.not_set or
                                self.time_since_cleared.yfilter != YFilter.not_set or
                                (self.connection is not None and self.connection.has_operation()) or
                                (self.iccp_events is not None and self.iccp_events.has_operation()) or
                                (self.iccp_messages is not None and self.iccp_messages.has_operation()) or
                                (self.invalid_tl_vs is not None and self.invalid_tl_vs.has_operation()) or
                                (self.tl_vs is not None and self.tl_vs.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "iccp-group-counters" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.last_time_cleared.is_set or self.last_time_cleared.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.last_time_cleared.get_name_leafdata())
                            if (self.last_unexpected_event.is_set or self.last_unexpected_event.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.last_unexpected_event.get_name_leafdata())
                            if (self.time_since_cleared.is_set or self.time_since_cleared.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.time_since_cleared.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "connection"):
                                if (self.connection is None):
                                    self.connection = BundleInformation.MlacpIccpGroupCounters.IccpGroups.IccpGroup.IccpGroupAncestorMember.IccpGroupCounters.Connection()
                                    self.connection.parent = self
                                    self._children_name_map["connection"] = "connection"
                                return self.connection

                            if (child_yang_name == "iccp-events"):
                                if (self.iccp_events is None):
                                    self.iccp_events = BundleInformation.MlacpIccpGroupCounters.IccpGroups.IccpGroup.IccpGroupAncestorMember.IccpGroupCounters.IccpEvents()
                                    self.iccp_events.parent = self
                                    self._children_name_map["iccp_events"] = "iccp-events"
                                return self.iccp_events

                            if (child_yang_name == "iccp-messages"):
                                if (self.iccp_messages is None):
                                    self.iccp_messages = BundleInformation.MlacpIccpGroupCounters.IccpGroups.IccpGroup.IccpGroupAncestorMember.IccpGroupCounters.IccpMessages()
                                    self.iccp_messages.parent = self
                                    self._children_name_map["iccp_messages"] = "iccp-messages"
                                return self.iccp_messages

                            if (child_yang_name == "invalid-tl-vs"):
                                if (self.invalid_tl_vs is None):
                                    self.invalid_tl_vs = BundleInformation.MlacpIccpGroupCounters.IccpGroups.IccpGroup.IccpGroupAncestorMember.IccpGroupCounters.InvalidTlVs()
                                    self.invalid_tl_vs.parent = self
                                    self._children_name_map["invalid_tl_vs"] = "invalid-tl-vs"
                                return self.invalid_tl_vs

                            if (child_yang_name == "tl-vs"):
                                if (self.tl_vs is None):
                                    self.tl_vs = BundleInformation.MlacpIccpGroupCounters.IccpGroups.IccpGroup.IccpGroupAncestorMember.IccpGroupCounters.TlVs()
                                    self.tl_vs.parent = self
                                    self._children_name_map["tl_vs"] = "tl-vs"
                                return self.tl_vs

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "connection" or name == "iccp-events" or name == "iccp-messages" or name == "invalid-tl-vs" or name == "tl-vs" or name == "last-time-cleared" or name == "last-unexpected-event" or name == "time-since-cleared"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "last-time-cleared"):
                                self.last_time_cleared = value
                                self.last_time_cleared.value_namespace = name_space
                                self.last_time_cleared.value_namespace_prefix = name_space_prefix
                            if(value_path == "last-unexpected-event"):
                                self.last_unexpected_event = value
                                self.last_unexpected_event.value_namespace = name_space
                                self.last_unexpected_event.value_namespace_prefix = name_space_prefix
                            if(value_path == "time-since-cleared"):
                                self.time_since_cleared = value
                                self.time_since_cleared.value_namespace = name_space
                                self.time_since_cleared.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.iccp_group_id.is_set or
                            (self.iccp_group_counters is not None and self.iccp_group_counters.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.iccp_group_id.yfilter != YFilter.not_set or
                            (self.iccp_group_counters is not None and self.iccp_group_counters.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "iccp-group-ancestor-member" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.iccp_group_id.is_set or self.iccp_group_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.iccp_group_id.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "iccp-group-counters"):
                            if (self.iccp_group_counters is None):
                                self.iccp_group_counters = BundleInformation.MlacpIccpGroupCounters.IccpGroups.IccpGroup.IccpGroupAncestorMember.IccpGroupCounters()
                                self.iccp_group_counters.parent = self
                                self._children_name_map["iccp_group_counters"] = "iccp-group-counters"
                            return self.iccp_group_counters

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "iccp-group-counters" or name == "iccp-group-id"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "iccp-group-id"):
                            self.iccp_group_id = value
                            self.iccp_group_id.value_namespace = name_space
                            self.iccp_group_id.value_namespace_prefix = name_space_prefix


                class IccpGroupAncestorNode(Entity):
                    """
                    Data for this item and its parent RG
                    
                    .. attribute:: iccp_group_counters
                    
                    	ICCP Group counters
                    	**type**\:   :py:class:`IccpGroupCounters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.MlacpIccpGroupCounters.IccpGroups.IccpGroup.IccpGroupAncestorNode.IccpGroupCounters>`
                    
                    .. attribute:: iccp_group_id
                    
                    	ICCP Group ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'bundlemgr-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(BundleInformation.MlacpIccpGroupCounters.IccpGroups.IccpGroup.IccpGroupAncestorNode, self).__init__()

                        self.yang_name = "iccp-group-ancestor-node"
                        self.yang_parent_name = "iccp-group"

                        self.iccp_group_id = YLeaf(YType.uint32, "iccp-group-id")

                        self.iccp_group_counters = BundleInformation.MlacpIccpGroupCounters.IccpGroups.IccpGroup.IccpGroupAncestorNode.IccpGroupCounters()
                        self.iccp_group_counters.parent = self
                        self._children_name_map["iccp_group_counters"] = "iccp-group-counters"
                        self._children_yang_names.add("iccp-group-counters")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("iccp_group_id") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(BundleInformation.MlacpIccpGroupCounters.IccpGroups.IccpGroup.IccpGroupAncestorNode, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(BundleInformation.MlacpIccpGroupCounters.IccpGroups.IccpGroup.IccpGroupAncestorNode, self).__setattr__(name, value)


                    class IccpGroupCounters(Entity):
                        """
                        ICCP Group counters
                        
                        .. attribute:: connection
                        
                        	Number of connection events
                        	**type**\:   :py:class:`Connection <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.MlacpIccpGroupCounters.IccpGroups.IccpGroup.IccpGroupAncestorNode.IccpGroupCounters.Connection>`
                        
                        .. attribute:: iccp_events
                        
                        	Number of ICCP events
                        	**type**\:   :py:class:`IccpEvents <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.MlacpIccpGroupCounters.IccpGroups.IccpGroup.IccpGroupAncestorNode.IccpGroupCounters.IccpEvents>`
                        
                        .. attribute:: iccp_messages
                        
                        	Number ICCP messages sent and received
                        	**type**\:   :py:class:`IccpMessages <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.MlacpIccpGroupCounters.IccpGroups.IccpGroup.IccpGroupAncestorNode.IccpGroupCounters.IccpMessages>`
                        
                        .. attribute:: invalid_tl_vs
                        
                        	Number invalid TLVs received
                        	**type**\:   :py:class:`InvalidTlVs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.MlacpIccpGroupCounters.IccpGroups.IccpGroup.IccpGroupAncestorNode.IccpGroupCounters.InvalidTlVs>`
                        
                        .. attribute:: last_time_cleared
                        
                        	Time in nsecs from boot when counters were last cleared (deprecated)
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: nanosecond
                        
                        .. attribute:: last_unexpected_event
                        
                        	Elapsed time in nsecs since last unexpected event
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: nanosecond
                        
                        .. attribute:: time_since_cleared
                        
                        	Elapsed time in nsecs since counters were last cleared
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: nanosecond
                        
                        .. attribute:: tl_vs
                        
                        	Number TLVs sent and received
                        	**type**\:   :py:class:`TlVs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.MlacpIccpGroupCounters.IccpGroups.IccpGroup.IccpGroupAncestorNode.IccpGroupCounters.TlVs>`
                        
                        

                        """

                        _prefix = 'bundlemgr-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(BundleInformation.MlacpIccpGroupCounters.IccpGroups.IccpGroup.IccpGroupAncestorNode.IccpGroupCounters, self).__init__()

                            self.yang_name = "iccp-group-counters"
                            self.yang_parent_name = "iccp-group-ancestor-node"

                            self.last_time_cleared = YLeaf(YType.uint64, "last-time-cleared")

                            self.last_unexpected_event = YLeaf(YType.uint64, "last-unexpected-event")

                            self.time_since_cleared = YLeaf(YType.uint64, "time-since-cleared")

                            self.connection = BundleInformation.MlacpIccpGroupCounters.IccpGroups.IccpGroup.IccpGroupAncestorNode.IccpGroupCounters.Connection()
                            self.connection.parent = self
                            self._children_name_map["connection"] = "connection"
                            self._children_yang_names.add("connection")

                            self.iccp_events = BundleInformation.MlacpIccpGroupCounters.IccpGroups.IccpGroup.IccpGroupAncestorNode.IccpGroupCounters.IccpEvents()
                            self.iccp_events.parent = self
                            self._children_name_map["iccp_events"] = "iccp-events"
                            self._children_yang_names.add("iccp-events")

                            self.iccp_messages = BundleInformation.MlacpIccpGroupCounters.IccpGroups.IccpGroup.IccpGroupAncestorNode.IccpGroupCounters.IccpMessages()
                            self.iccp_messages.parent = self
                            self._children_name_map["iccp_messages"] = "iccp-messages"
                            self._children_yang_names.add("iccp-messages")

                            self.invalid_tl_vs = BundleInformation.MlacpIccpGroupCounters.IccpGroups.IccpGroup.IccpGroupAncestorNode.IccpGroupCounters.InvalidTlVs()
                            self.invalid_tl_vs.parent = self
                            self._children_name_map["invalid_tl_vs"] = "invalid-tl-vs"
                            self._children_yang_names.add("invalid-tl-vs")

                            self.tl_vs = BundleInformation.MlacpIccpGroupCounters.IccpGroups.IccpGroup.IccpGroupAncestorNode.IccpGroupCounters.TlVs()
                            self.tl_vs.parent = self
                            self._children_name_map["tl_vs"] = "tl-vs"
                            self._children_yang_names.add("tl-vs")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("last_time_cleared",
                                            "last_unexpected_event",
                                            "time_since_cleared") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(BundleInformation.MlacpIccpGroupCounters.IccpGroups.IccpGroup.IccpGroupAncestorNode.IccpGroupCounters, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(BundleInformation.MlacpIccpGroupCounters.IccpGroups.IccpGroup.IccpGroupAncestorNode.IccpGroupCounters, self).__setattr__(name, value)


                        class Connection(Entity):
                            """
                            Number of connection events
                            
                            .. attribute:: iccp_config_connect_errors
                            
                            	Number of ICCP connection errors due to config
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: iccp_count_connect_errors
                            
                            	Number of ICCP connection errors due to max ICCP group count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: iccp_invalid_connects
                            
                            	Number of invalid ICCP connects
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: iccp_invalid_disconnects
                            
                            	Number of invalid ICCP disconnects
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: received_connects
                            
                            	Number of connect TLVs received
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: received_disconnects
                            
                            	Number of disconnect TLVs received
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: received_wrong_versions
                            
                            	Number of wrong version TLVs received
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: sent_connects
                            
                            	Number of connect TLVs sent
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: sent_disconnects
                            
                            	Number of disconnect TLVs sent
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: sent_wrong_versions
                            
                            	Number of wrong version TLVs sent
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'bundlemgr-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(BundleInformation.MlacpIccpGroupCounters.IccpGroups.IccpGroup.IccpGroupAncestorNode.IccpGroupCounters.Connection, self).__init__()

                                self.yang_name = "connection"
                                self.yang_parent_name = "iccp-group-counters"

                                self.iccp_config_connect_errors = YLeaf(YType.uint32, "iccp-config-connect-errors")

                                self.iccp_count_connect_errors = YLeaf(YType.uint32, "iccp-count-connect-errors")

                                self.iccp_invalid_connects = YLeaf(YType.uint32, "iccp-invalid-connects")

                                self.iccp_invalid_disconnects = YLeaf(YType.uint32, "iccp-invalid-disconnects")

                                self.received_connects = YLeaf(YType.uint32, "received-connects")

                                self.received_disconnects = YLeaf(YType.uint32, "received-disconnects")

                                self.received_wrong_versions = YLeaf(YType.uint32, "received-wrong-versions")

                                self.sent_connects = YLeaf(YType.uint32, "sent-connects")

                                self.sent_disconnects = YLeaf(YType.uint32, "sent-disconnects")

                                self.sent_wrong_versions = YLeaf(YType.uint32, "sent-wrong-versions")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("iccp_config_connect_errors",
                                                "iccp_count_connect_errors",
                                                "iccp_invalid_connects",
                                                "iccp_invalid_disconnects",
                                                "received_connects",
                                                "received_disconnects",
                                                "received_wrong_versions",
                                                "sent_connects",
                                                "sent_disconnects",
                                                "sent_wrong_versions") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(BundleInformation.MlacpIccpGroupCounters.IccpGroups.IccpGroup.IccpGroupAncestorNode.IccpGroupCounters.Connection, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(BundleInformation.MlacpIccpGroupCounters.IccpGroups.IccpGroup.IccpGroupAncestorNode.IccpGroupCounters.Connection, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.iccp_config_connect_errors.is_set or
                                    self.iccp_count_connect_errors.is_set or
                                    self.iccp_invalid_connects.is_set or
                                    self.iccp_invalid_disconnects.is_set or
                                    self.received_connects.is_set or
                                    self.received_disconnects.is_set or
                                    self.received_wrong_versions.is_set or
                                    self.sent_connects.is_set or
                                    self.sent_disconnects.is_set or
                                    self.sent_wrong_versions.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.iccp_config_connect_errors.yfilter != YFilter.not_set or
                                    self.iccp_count_connect_errors.yfilter != YFilter.not_set or
                                    self.iccp_invalid_connects.yfilter != YFilter.not_set or
                                    self.iccp_invalid_disconnects.yfilter != YFilter.not_set or
                                    self.received_connects.yfilter != YFilter.not_set or
                                    self.received_disconnects.yfilter != YFilter.not_set or
                                    self.received_wrong_versions.yfilter != YFilter.not_set or
                                    self.sent_connects.yfilter != YFilter.not_set or
                                    self.sent_disconnects.yfilter != YFilter.not_set or
                                    self.sent_wrong_versions.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "connection" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.iccp_config_connect_errors.is_set or self.iccp_config_connect_errors.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.iccp_config_connect_errors.get_name_leafdata())
                                if (self.iccp_count_connect_errors.is_set or self.iccp_count_connect_errors.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.iccp_count_connect_errors.get_name_leafdata())
                                if (self.iccp_invalid_connects.is_set or self.iccp_invalid_connects.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.iccp_invalid_connects.get_name_leafdata())
                                if (self.iccp_invalid_disconnects.is_set or self.iccp_invalid_disconnects.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.iccp_invalid_disconnects.get_name_leafdata())
                                if (self.received_connects.is_set or self.received_connects.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.received_connects.get_name_leafdata())
                                if (self.received_disconnects.is_set or self.received_disconnects.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.received_disconnects.get_name_leafdata())
                                if (self.received_wrong_versions.is_set or self.received_wrong_versions.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.received_wrong_versions.get_name_leafdata())
                                if (self.sent_connects.is_set or self.sent_connects.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.sent_connects.get_name_leafdata())
                                if (self.sent_disconnects.is_set or self.sent_disconnects.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.sent_disconnects.get_name_leafdata())
                                if (self.sent_wrong_versions.is_set or self.sent_wrong_versions.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.sent_wrong_versions.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "iccp-config-connect-errors" or name == "iccp-count-connect-errors" or name == "iccp-invalid-connects" or name == "iccp-invalid-disconnects" or name == "received-connects" or name == "received-disconnects" or name == "received-wrong-versions" or name == "sent-connects" or name == "sent-disconnects" or name == "sent-wrong-versions"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "iccp-config-connect-errors"):
                                    self.iccp_config_connect_errors = value
                                    self.iccp_config_connect_errors.value_namespace = name_space
                                    self.iccp_config_connect_errors.value_namespace_prefix = name_space_prefix
                                if(value_path == "iccp-count-connect-errors"):
                                    self.iccp_count_connect_errors = value
                                    self.iccp_count_connect_errors.value_namespace = name_space
                                    self.iccp_count_connect_errors.value_namespace_prefix = name_space_prefix
                                if(value_path == "iccp-invalid-connects"):
                                    self.iccp_invalid_connects = value
                                    self.iccp_invalid_connects.value_namespace = name_space
                                    self.iccp_invalid_connects.value_namespace_prefix = name_space_prefix
                                if(value_path == "iccp-invalid-disconnects"):
                                    self.iccp_invalid_disconnects = value
                                    self.iccp_invalid_disconnects.value_namespace = name_space
                                    self.iccp_invalid_disconnects.value_namespace_prefix = name_space_prefix
                                if(value_path == "received-connects"):
                                    self.received_connects = value
                                    self.received_connects.value_namespace = name_space
                                    self.received_connects.value_namespace_prefix = name_space_prefix
                                if(value_path == "received-disconnects"):
                                    self.received_disconnects = value
                                    self.received_disconnects.value_namespace = name_space
                                    self.received_disconnects.value_namespace_prefix = name_space_prefix
                                if(value_path == "received-wrong-versions"):
                                    self.received_wrong_versions = value
                                    self.received_wrong_versions.value_namespace = name_space
                                    self.received_wrong_versions.value_namespace_prefix = name_space_prefix
                                if(value_path == "sent-connects"):
                                    self.sent_connects = value
                                    self.sent_connects.value_namespace = name_space
                                    self.sent_connects.value_namespace_prefix = name_space_prefix
                                if(value_path == "sent-disconnects"):
                                    self.sent_disconnects = value
                                    self.sent_disconnects.value_namespace = name_space
                                    self.sent_disconnects.value_namespace_prefix = name_space_prefix
                                if(value_path == "sent-wrong-versions"):
                                    self.sent_wrong_versions = value
                                    self.sent_wrong_versions.value_namespace = name_space
                                    self.sent_wrong_versions.value_namespace_prefix = name_space_prefix


                        class TlVs(Entity):
                            """
                            Number TLVs sent and received
                            
                            .. attribute:: received_config
                            
                            	Number of config TLVs received
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: received_config_sync_requests
                            
                            	Number of state config request TLVs received
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: received_na_ks
                            
                            	Number of NAK TLVs received
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: received_solicited_sync_data
                            
                            	Number of solicited sync data TLVs received
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: received_state
                            
                            	Number of state TLVs received
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: received_state_sync_requests
                            
                            	Number of state sync request TLVs received
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: received_sync_requests
                            
                            	Number of sync request TLVs received
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: received_unsolicited_sync_data
                            
                            	Number of unsolicited sync data TLVs received
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: sent_config
                            
                            	Number of config TLVs sent
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: sent_config_sync_requests
                            
                            	Number of config sync request TLVs sent
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: sent_na_ks
                            
                            	Number of NAK TLVs sent
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: sent_solicited_sync_data
                            
                            	Number of solicited sync data TLVs sent
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: sent_state
                            
                            	Number of state TLVs sent
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: sent_state_sync_requests
                            
                            	Number of state sync request TLVs sent
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: sent_sync_requests
                            
                            	Number of sync request TLVs sent
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: sent_unsolicited_sync_data
                            
                            	Number of unsolicited sync data TLVs sent
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'bundlemgr-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(BundleInformation.MlacpIccpGroupCounters.IccpGroups.IccpGroup.IccpGroupAncestorNode.IccpGroupCounters.TlVs, self).__init__()

                                self.yang_name = "tl-vs"
                                self.yang_parent_name = "iccp-group-counters"

                                self.received_config = YLeaf(YType.uint32, "received-config")

                                self.received_config_sync_requests = YLeaf(YType.uint32, "received-config-sync-requests")

                                self.received_na_ks = YLeaf(YType.uint32, "received-na-ks")

                                self.received_solicited_sync_data = YLeaf(YType.uint32, "received-solicited-sync-data")

                                self.received_state = YLeaf(YType.uint32, "received-state")

                                self.received_state_sync_requests = YLeaf(YType.uint32, "received-state-sync-requests")

                                self.received_sync_requests = YLeaf(YType.uint32, "received-sync-requests")

                                self.received_unsolicited_sync_data = YLeaf(YType.uint32, "received-unsolicited-sync-data")

                                self.sent_config = YLeaf(YType.uint32, "sent-config")

                                self.sent_config_sync_requests = YLeaf(YType.uint32, "sent-config-sync-requests")

                                self.sent_na_ks = YLeaf(YType.uint32, "sent-na-ks")

                                self.sent_solicited_sync_data = YLeaf(YType.uint32, "sent-solicited-sync-data")

                                self.sent_state = YLeaf(YType.uint32, "sent-state")

                                self.sent_state_sync_requests = YLeaf(YType.uint32, "sent-state-sync-requests")

                                self.sent_sync_requests = YLeaf(YType.uint32, "sent-sync-requests")

                                self.sent_unsolicited_sync_data = YLeaf(YType.uint32, "sent-unsolicited-sync-data")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("received_config",
                                                "received_config_sync_requests",
                                                "received_na_ks",
                                                "received_solicited_sync_data",
                                                "received_state",
                                                "received_state_sync_requests",
                                                "received_sync_requests",
                                                "received_unsolicited_sync_data",
                                                "sent_config",
                                                "sent_config_sync_requests",
                                                "sent_na_ks",
                                                "sent_solicited_sync_data",
                                                "sent_state",
                                                "sent_state_sync_requests",
                                                "sent_sync_requests",
                                                "sent_unsolicited_sync_data") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(BundleInformation.MlacpIccpGroupCounters.IccpGroups.IccpGroup.IccpGroupAncestorNode.IccpGroupCounters.TlVs, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(BundleInformation.MlacpIccpGroupCounters.IccpGroups.IccpGroup.IccpGroupAncestorNode.IccpGroupCounters.TlVs, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.received_config.is_set or
                                    self.received_config_sync_requests.is_set or
                                    self.received_na_ks.is_set or
                                    self.received_solicited_sync_data.is_set or
                                    self.received_state.is_set or
                                    self.received_state_sync_requests.is_set or
                                    self.received_sync_requests.is_set or
                                    self.received_unsolicited_sync_data.is_set or
                                    self.sent_config.is_set or
                                    self.sent_config_sync_requests.is_set or
                                    self.sent_na_ks.is_set or
                                    self.sent_solicited_sync_data.is_set or
                                    self.sent_state.is_set or
                                    self.sent_state_sync_requests.is_set or
                                    self.sent_sync_requests.is_set or
                                    self.sent_unsolicited_sync_data.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.received_config.yfilter != YFilter.not_set or
                                    self.received_config_sync_requests.yfilter != YFilter.not_set or
                                    self.received_na_ks.yfilter != YFilter.not_set or
                                    self.received_solicited_sync_data.yfilter != YFilter.not_set or
                                    self.received_state.yfilter != YFilter.not_set or
                                    self.received_state_sync_requests.yfilter != YFilter.not_set or
                                    self.received_sync_requests.yfilter != YFilter.not_set or
                                    self.received_unsolicited_sync_data.yfilter != YFilter.not_set or
                                    self.sent_config.yfilter != YFilter.not_set or
                                    self.sent_config_sync_requests.yfilter != YFilter.not_set or
                                    self.sent_na_ks.yfilter != YFilter.not_set or
                                    self.sent_solicited_sync_data.yfilter != YFilter.not_set or
                                    self.sent_state.yfilter != YFilter.not_set or
                                    self.sent_state_sync_requests.yfilter != YFilter.not_set or
                                    self.sent_sync_requests.yfilter != YFilter.not_set or
                                    self.sent_unsolicited_sync_data.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "tl-vs" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.received_config.is_set or self.received_config.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.received_config.get_name_leafdata())
                                if (self.received_config_sync_requests.is_set or self.received_config_sync_requests.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.received_config_sync_requests.get_name_leafdata())
                                if (self.received_na_ks.is_set or self.received_na_ks.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.received_na_ks.get_name_leafdata())
                                if (self.received_solicited_sync_data.is_set or self.received_solicited_sync_data.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.received_solicited_sync_data.get_name_leafdata())
                                if (self.received_state.is_set or self.received_state.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.received_state.get_name_leafdata())
                                if (self.received_state_sync_requests.is_set or self.received_state_sync_requests.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.received_state_sync_requests.get_name_leafdata())
                                if (self.received_sync_requests.is_set or self.received_sync_requests.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.received_sync_requests.get_name_leafdata())
                                if (self.received_unsolicited_sync_data.is_set or self.received_unsolicited_sync_data.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.received_unsolicited_sync_data.get_name_leafdata())
                                if (self.sent_config.is_set or self.sent_config.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.sent_config.get_name_leafdata())
                                if (self.sent_config_sync_requests.is_set or self.sent_config_sync_requests.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.sent_config_sync_requests.get_name_leafdata())
                                if (self.sent_na_ks.is_set or self.sent_na_ks.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.sent_na_ks.get_name_leafdata())
                                if (self.sent_solicited_sync_data.is_set or self.sent_solicited_sync_data.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.sent_solicited_sync_data.get_name_leafdata())
                                if (self.sent_state.is_set or self.sent_state.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.sent_state.get_name_leafdata())
                                if (self.sent_state_sync_requests.is_set or self.sent_state_sync_requests.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.sent_state_sync_requests.get_name_leafdata())
                                if (self.sent_sync_requests.is_set or self.sent_sync_requests.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.sent_sync_requests.get_name_leafdata())
                                if (self.sent_unsolicited_sync_data.is_set or self.sent_unsolicited_sync_data.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.sent_unsolicited_sync_data.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "received-config" or name == "received-config-sync-requests" or name == "received-na-ks" or name == "received-solicited-sync-data" or name == "received-state" or name == "received-state-sync-requests" or name == "received-sync-requests" or name == "received-unsolicited-sync-data" or name == "sent-config" or name == "sent-config-sync-requests" or name == "sent-na-ks" or name == "sent-solicited-sync-data" or name == "sent-state" or name == "sent-state-sync-requests" or name == "sent-sync-requests" or name == "sent-unsolicited-sync-data"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "received-config"):
                                    self.received_config = value
                                    self.received_config.value_namespace = name_space
                                    self.received_config.value_namespace_prefix = name_space_prefix
                                if(value_path == "received-config-sync-requests"):
                                    self.received_config_sync_requests = value
                                    self.received_config_sync_requests.value_namespace = name_space
                                    self.received_config_sync_requests.value_namespace_prefix = name_space_prefix
                                if(value_path == "received-na-ks"):
                                    self.received_na_ks = value
                                    self.received_na_ks.value_namespace = name_space
                                    self.received_na_ks.value_namespace_prefix = name_space_prefix
                                if(value_path == "received-solicited-sync-data"):
                                    self.received_solicited_sync_data = value
                                    self.received_solicited_sync_data.value_namespace = name_space
                                    self.received_solicited_sync_data.value_namespace_prefix = name_space_prefix
                                if(value_path == "received-state"):
                                    self.received_state = value
                                    self.received_state.value_namespace = name_space
                                    self.received_state.value_namespace_prefix = name_space_prefix
                                if(value_path == "received-state-sync-requests"):
                                    self.received_state_sync_requests = value
                                    self.received_state_sync_requests.value_namespace = name_space
                                    self.received_state_sync_requests.value_namespace_prefix = name_space_prefix
                                if(value_path == "received-sync-requests"):
                                    self.received_sync_requests = value
                                    self.received_sync_requests.value_namespace = name_space
                                    self.received_sync_requests.value_namespace_prefix = name_space_prefix
                                if(value_path == "received-unsolicited-sync-data"):
                                    self.received_unsolicited_sync_data = value
                                    self.received_unsolicited_sync_data.value_namespace = name_space
                                    self.received_unsolicited_sync_data.value_namespace_prefix = name_space_prefix
                                if(value_path == "sent-config"):
                                    self.sent_config = value
                                    self.sent_config.value_namespace = name_space
                                    self.sent_config.value_namespace_prefix = name_space_prefix
                                if(value_path == "sent-config-sync-requests"):
                                    self.sent_config_sync_requests = value
                                    self.sent_config_sync_requests.value_namespace = name_space
                                    self.sent_config_sync_requests.value_namespace_prefix = name_space_prefix
                                if(value_path == "sent-na-ks"):
                                    self.sent_na_ks = value
                                    self.sent_na_ks.value_namespace = name_space
                                    self.sent_na_ks.value_namespace_prefix = name_space_prefix
                                if(value_path == "sent-solicited-sync-data"):
                                    self.sent_solicited_sync_data = value
                                    self.sent_solicited_sync_data.value_namespace = name_space
                                    self.sent_solicited_sync_data.value_namespace_prefix = name_space_prefix
                                if(value_path == "sent-state"):
                                    self.sent_state = value
                                    self.sent_state.value_namespace = name_space
                                    self.sent_state.value_namespace_prefix = name_space_prefix
                                if(value_path == "sent-state-sync-requests"):
                                    self.sent_state_sync_requests = value
                                    self.sent_state_sync_requests.value_namespace = name_space
                                    self.sent_state_sync_requests.value_namespace_prefix = name_space_prefix
                                if(value_path == "sent-sync-requests"):
                                    self.sent_sync_requests = value
                                    self.sent_sync_requests.value_namespace = name_space
                                    self.sent_sync_requests.value_namespace_prefix = name_space_prefix
                                if(value_path == "sent-unsolicited-sync-data"):
                                    self.sent_unsolicited_sync_data = value
                                    self.sent_unsolicited_sync_data.value_namespace = name_space
                                    self.sent_unsolicited_sync_data.value_namespace_prefix = name_space_prefix


                        class InvalidTlVs(Entity):
                            """
                            Number invalid TLVs received
                            
                            .. attribute:: incorrect_length
                            
                            	Number of messages received of an incorrect length
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: invalid_data
                            
                            	Number of messages received containing invalid data
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: invalid_type
                            
                            	Number of messages received with an invalid mLACP TLV type
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: unknown_bundle
                            
                            	Number of messages received for an unknown bundle
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: unknown_port
                            
                            	Number of messages received for an unknown port
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'bundlemgr-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(BundleInformation.MlacpIccpGroupCounters.IccpGroups.IccpGroup.IccpGroupAncestorNode.IccpGroupCounters.InvalidTlVs, self).__init__()

                                self.yang_name = "invalid-tl-vs"
                                self.yang_parent_name = "iccp-group-counters"

                                self.incorrect_length = YLeaf(YType.uint32, "incorrect-length")

                                self.invalid_data = YLeaf(YType.uint32, "invalid-data")

                                self.invalid_type = YLeaf(YType.uint32, "invalid-type")

                                self.unknown_bundle = YLeaf(YType.uint32, "unknown-bundle")

                                self.unknown_port = YLeaf(YType.uint32, "unknown-port")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("incorrect_length",
                                                "invalid_data",
                                                "invalid_type",
                                                "unknown_bundle",
                                                "unknown_port") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(BundleInformation.MlacpIccpGroupCounters.IccpGroups.IccpGroup.IccpGroupAncestorNode.IccpGroupCounters.InvalidTlVs, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(BundleInformation.MlacpIccpGroupCounters.IccpGroups.IccpGroup.IccpGroupAncestorNode.IccpGroupCounters.InvalidTlVs, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.incorrect_length.is_set or
                                    self.invalid_data.is_set or
                                    self.invalid_type.is_set or
                                    self.unknown_bundle.is_set or
                                    self.unknown_port.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.incorrect_length.yfilter != YFilter.not_set or
                                    self.invalid_data.yfilter != YFilter.not_set or
                                    self.invalid_type.yfilter != YFilter.not_set or
                                    self.unknown_bundle.yfilter != YFilter.not_set or
                                    self.unknown_port.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "invalid-tl-vs" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.incorrect_length.is_set or self.incorrect_length.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.incorrect_length.get_name_leafdata())
                                if (self.invalid_data.is_set or self.invalid_data.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.invalid_data.get_name_leafdata())
                                if (self.invalid_type.is_set or self.invalid_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.invalid_type.get_name_leafdata())
                                if (self.unknown_bundle.is_set or self.unknown_bundle.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.unknown_bundle.get_name_leafdata())
                                if (self.unknown_port.is_set or self.unknown_port.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.unknown_port.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "incorrect-length" or name == "invalid-data" or name == "invalid-type" or name == "unknown-bundle" or name == "unknown-port"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "incorrect-length"):
                                    self.incorrect_length = value
                                    self.incorrect_length.value_namespace = name_space
                                    self.incorrect_length.value_namespace_prefix = name_space_prefix
                                if(value_path == "invalid-data"):
                                    self.invalid_data = value
                                    self.invalid_data.value_namespace = name_space
                                    self.invalid_data.value_namespace_prefix = name_space_prefix
                                if(value_path == "invalid-type"):
                                    self.invalid_type = value
                                    self.invalid_type.value_namespace = name_space
                                    self.invalid_type.value_namespace_prefix = name_space_prefix
                                if(value_path == "unknown-bundle"):
                                    self.unknown_bundle = value
                                    self.unknown_bundle.value_namespace = name_space
                                    self.unknown_bundle.value_namespace_prefix = name_space_prefix
                                if(value_path == "unknown-port"):
                                    self.unknown_port = value
                                    self.unknown_port.value_namespace = name_space
                                    self.unknown_port.value_namespace_prefix = name_space_prefix


                        class IccpMessages(Entity):
                            """
                            Number ICCP messages sent and received
                            
                            .. attribute:: received_messages
                            
                            	Number of messages received
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: sent_buffer_messages
                            
                            	Number of buffers sent (may be multiple per message)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: sent_messages
                            
                            	Number of messages sent
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: transmission_errors
                            
                            	Number of transmission errors
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'bundlemgr-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(BundleInformation.MlacpIccpGroupCounters.IccpGroups.IccpGroup.IccpGroupAncestorNode.IccpGroupCounters.IccpMessages, self).__init__()

                                self.yang_name = "iccp-messages"
                                self.yang_parent_name = "iccp-group-counters"

                                self.received_messages = YLeaf(YType.uint32, "received-messages")

                                self.sent_buffer_messages = YLeaf(YType.uint32, "sent-buffer-messages")

                                self.sent_messages = YLeaf(YType.uint32, "sent-messages")

                                self.transmission_errors = YLeaf(YType.uint32, "transmission-errors")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("received_messages",
                                                "sent_buffer_messages",
                                                "sent_messages",
                                                "transmission_errors") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(BundleInformation.MlacpIccpGroupCounters.IccpGroups.IccpGroup.IccpGroupAncestorNode.IccpGroupCounters.IccpMessages, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(BundleInformation.MlacpIccpGroupCounters.IccpGroups.IccpGroup.IccpGroupAncestorNode.IccpGroupCounters.IccpMessages, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.received_messages.is_set or
                                    self.sent_buffer_messages.is_set or
                                    self.sent_messages.is_set or
                                    self.transmission_errors.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.received_messages.yfilter != YFilter.not_set or
                                    self.sent_buffer_messages.yfilter != YFilter.not_set or
                                    self.sent_messages.yfilter != YFilter.not_set or
                                    self.transmission_errors.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "iccp-messages" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.received_messages.is_set or self.received_messages.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.received_messages.get_name_leafdata())
                                if (self.sent_buffer_messages.is_set or self.sent_buffer_messages.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.sent_buffer_messages.get_name_leafdata())
                                if (self.sent_messages.is_set or self.sent_messages.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.sent_messages.get_name_leafdata())
                                if (self.transmission_errors.is_set or self.transmission_errors.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.transmission_errors.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "received-messages" or name == "sent-buffer-messages" or name == "sent-messages" or name == "transmission-errors"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "received-messages"):
                                    self.received_messages = value
                                    self.received_messages.value_namespace = name_space
                                    self.received_messages.value_namespace_prefix = name_space_prefix
                                if(value_path == "sent-buffer-messages"):
                                    self.sent_buffer_messages = value
                                    self.sent_buffer_messages.value_namespace = name_space
                                    self.sent_buffer_messages.value_namespace_prefix = name_space_prefix
                                if(value_path == "sent-messages"):
                                    self.sent_messages = value
                                    self.sent_messages.value_namespace = name_space
                                    self.sent_messages.value_namespace_prefix = name_space_prefix
                                if(value_path == "transmission-errors"):
                                    self.transmission_errors = value
                                    self.transmission_errors.value_namespace = name_space
                                    self.transmission_errors.value_namespace_prefix = name_space_prefix


                        class IccpEvents(Entity):
                            """
                            Number of ICCP events
                            
                            .. attribute:: configured_clear
                            
                            	Number of unconfigure events
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: configured_set
                            
                            	Number of configure events
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: member_status_down
                            
                            	Number of member status down events
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: member_status_up
                            
                            	Number of member status up events
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: pe_isolated
                            
                            	Number of PE isolation events
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: pe_isolated_clear
                            
                            	Number of PE isolation cleared events
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: reachability_cleared
                            
                            	Number of reachability cleared events
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: reachability_set
                            
                            	Number of reachability events
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: transport_down
                            
                            	Number of transport down events
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: transport_unavailable
                            
                            	Number of transport unavailable events
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: transport_up
                            
                            	Number of transport up events
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'bundlemgr-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(BundleInformation.MlacpIccpGroupCounters.IccpGroups.IccpGroup.IccpGroupAncestorNode.IccpGroupCounters.IccpEvents, self).__init__()

                                self.yang_name = "iccp-events"
                                self.yang_parent_name = "iccp-group-counters"

                                self.configured_clear = YLeaf(YType.uint32, "configured-clear")

                                self.configured_set = YLeaf(YType.uint32, "configured-set")

                                self.member_status_down = YLeaf(YType.uint32, "member-status-down")

                                self.member_status_up = YLeaf(YType.uint32, "member-status-up")

                                self.pe_isolated = YLeaf(YType.uint32, "pe-isolated")

                                self.pe_isolated_clear = YLeaf(YType.uint32, "pe-isolated-clear")

                                self.reachability_cleared = YLeaf(YType.uint32, "reachability-cleared")

                                self.reachability_set = YLeaf(YType.uint32, "reachability-set")

                                self.transport_down = YLeaf(YType.uint32, "transport-down")

                                self.transport_unavailable = YLeaf(YType.uint32, "transport-unavailable")

                                self.transport_up = YLeaf(YType.uint32, "transport-up")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("configured_clear",
                                                "configured_set",
                                                "member_status_down",
                                                "member_status_up",
                                                "pe_isolated",
                                                "pe_isolated_clear",
                                                "reachability_cleared",
                                                "reachability_set",
                                                "transport_down",
                                                "transport_unavailable",
                                                "transport_up") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(BundleInformation.MlacpIccpGroupCounters.IccpGroups.IccpGroup.IccpGroupAncestorNode.IccpGroupCounters.IccpEvents, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(BundleInformation.MlacpIccpGroupCounters.IccpGroups.IccpGroup.IccpGroupAncestorNode.IccpGroupCounters.IccpEvents, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.configured_clear.is_set or
                                    self.configured_set.is_set or
                                    self.member_status_down.is_set or
                                    self.member_status_up.is_set or
                                    self.pe_isolated.is_set or
                                    self.pe_isolated_clear.is_set or
                                    self.reachability_cleared.is_set or
                                    self.reachability_set.is_set or
                                    self.transport_down.is_set or
                                    self.transport_unavailable.is_set or
                                    self.transport_up.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.configured_clear.yfilter != YFilter.not_set or
                                    self.configured_set.yfilter != YFilter.not_set or
                                    self.member_status_down.yfilter != YFilter.not_set or
                                    self.member_status_up.yfilter != YFilter.not_set or
                                    self.pe_isolated.yfilter != YFilter.not_set or
                                    self.pe_isolated_clear.yfilter != YFilter.not_set or
                                    self.reachability_cleared.yfilter != YFilter.not_set or
                                    self.reachability_set.yfilter != YFilter.not_set or
                                    self.transport_down.yfilter != YFilter.not_set or
                                    self.transport_unavailable.yfilter != YFilter.not_set or
                                    self.transport_up.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "iccp-events" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.configured_clear.is_set or self.configured_clear.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.configured_clear.get_name_leafdata())
                                if (self.configured_set.is_set or self.configured_set.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.configured_set.get_name_leafdata())
                                if (self.member_status_down.is_set or self.member_status_down.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.member_status_down.get_name_leafdata())
                                if (self.member_status_up.is_set or self.member_status_up.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.member_status_up.get_name_leafdata())
                                if (self.pe_isolated.is_set or self.pe_isolated.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pe_isolated.get_name_leafdata())
                                if (self.pe_isolated_clear.is_set or self.pe_isolated_clear.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pe_isolated_clear.get_name_leafdata())
                                if (self.reachability_cleared.is_set or self.reachability_cleared.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.reachability_cleared.get_name_leafdata())
                                if (self.reachability_set.is_set or self.reachability_set.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.reachability_set.get_name_leafdata())
                                if (self.transport_down.is_set or self.transport_down.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.transport_down.get_name_leafdata())
                                if (self.transport_unavailable.is_set or self.transport_unavailable.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.transport_unavailable.get_name_leafdata())
                                if (self.transport_up.is_set or self.transport_up.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.transport_up.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "configured-clear" or name == "configured-set" or name == "member-status-down" or name == "member-status-up" or name == "pe-isolated" or name == "pe-isolated-clear" or name == "reachability-cleared" or name == "reachability-set" or name == "transport-down" or name == "transport-unavailable" or name == "transport-up"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "configured-clear"):
                                    self.configured_clear = value
                                    self.configured_clear.value_namespace = name_space
                                    self.configured_clear.value_namespace_prefix = name_space_prefix
                                if(value_path == "configured-set"):
                                    self.configured_set = value
                                    self.configured_set.value_namespace = name_space
                                    self.configured_set.value_namespace_prefix = name_space_prefix
                                if(value_path == "member-status-down"):
                                    self.member_status_down = value
                                    self.member_status_down.value_namespace = name_space
                                    self.member_status_down.value_namespace_prefix = name_space_prefix
                                if(value_path == "member-status-up"):
                                    self.member_status_up = value
                                    self.member_status_up.value_namespace = name_space
                                    self.member_status_up.value_namespace_prefix = name_space_prefix
                                if(value_path == "pe-isolated"):
                                    self.pe_isolated = value
                                    self.pe_isolated.value_namespace = name_space
                                    self.pe_isolated.value_namespace_prefix = name_space_prefix
                                if(value_path == "pe-isolated-clear"):
                                    self.pe_isolated_clear = value
                                    self.pe_isolated_clear.value_namespace = name_space
                                    self.pe_isolated_clear.value_namespace_prefix = name_space_prefix
                                if(value_path == "reachability-cleared"):
                                    self.reachability_cleared = value
                                    self.reachability_cleared.value_namespace = name_space
                                    self.reachability_cleared.value_namespace_prefix = name_space_prefix
                                if(value_path == "reachability-set"):
                                    self.reachability_set = value
                                    self.reachability_set.value_namespace = name_space
                                    self.reachability_set.value_namespace_prefix = name_space_prefix
                                if(value_path == "transport-down"):
                                    self.transport_down = value
                                    self.transport_down.value_namespace = name_space
                                    self.transport_down.value_namespace_prefix = name_space_prefix
                                if(value_path == "transport-unavailable"):
                                    self.transport_unavailable = value
                                    self.transport_unavailable.value_namespace = name_space
                                    self.transport_unavailable.value_namespace_prefix = name_space_prefix
                                if(value_path == "transport-up"):
                                    self.transport_up = value
                                    self.transport_up.value_namespace = name_space
                                    self.transport_up.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.last_time_cleared.is_set or
                                self.last_unexpected_event.is_set or
                                self.time_since_cleared.is_set or
                                (self.connection is not None and self.connection.has_data()) or
                                (self.iccp_events is not None and self.iccp_events.has_data()) or
                                (self.iccp_messages is not None and self.iccp_messages.has_data()) or
                                (self.invalid_tl_vs is not None and self.invalid_tl_vs.has_data()) or
                                (self.tl_vs is not None and self.tl_vs.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.last_time_cleared.yfilter != YFilter.not_set or
                                self.last_unexpected_event.yfilter != YFilter.not_set or
                                self.time_since_cleared.yfilter != YFilter.not_set or
                                (self.connection is not None and self.connection.has_operation()) or
                                (self.iccp_events is not None and self.iccp_events.has_operation()) or
                                (self.iccp_messages is not None and self.iccp_messages.has_operation()) or
                                (self.invalid_tl_vs is not None and self.invalid_tl_vs.has_operation()) or
                                (self.tl_vs is not None and self.tl_vs.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "iccp-group-counters" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.last_time_cleared.is_set or self.last_time_cleared.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.last_time_cleared.get_name_leafdata())
                            if (self.last_unexpected_event.is_set or self.last_unexpected_event.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.last_unexpected_event.get_name_leafdata())
                            if (self.time_since_cleared.is_set or self.time_since_cleared.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.time_since_cleared.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "connection"):
                                if (self.connection is None):
                                    self.connection = BundleInformation.MlacpIccpGroupCounters.IccpGroups.IccpGroup.IccpGroupAncestorNode.IccpGroupCounters.Connection()
                                    self.connection.parent = self
                                    self._children_name_map["connection"] = "connection"
                                return self.connection

                            if (child_yang_name == "iccp-events"):
                                if (self.iccp_events is None):
                                    self.iccp_events = BundleInformation.MlacpIccpGroupCounters.IccpGroups.IccpGroup.IccpGroupAncestorNode.IccpGroupCounters.IccpEvents()
                                    self.iccp_events.parent = self
                                    self._children_name_map["iccp_events"] = "iccp-events"
                                return self.iccp_events

                            if (child_yang_name == "iccp-messages"):
                                if (self.iccp_messages is None):
                                    self.iccp_messages = BundleInformation.MlacpIccpGroupCounters.IccpGroups.IccpGroup.IccpGroupAncestorNode.IccpGroupCounters.IccpMessages()
                                    self.iccp_messages.parent = self
                                    self._children_name_map["iccp_messages"] = "iccp-messages"
                                return self.iccp_messages

                            if (child_yang_name == "invalid-tl-vs"):
                                if (self.invalid_tl_vs is None):
                                    self.invalid_tl_vs = BundleInformation.MlacpIccpGroupCounters.IccpGroups.IccpGroup.IccpGroupAncestorNode.IccpGroupCounters.InvalidTlVs()
                                    self.invalid_tl_vs.parent = self
                                    self._children_name_map["invalid_tl_vs"] = "invalid-tl-vs"
                                return self.invalid_tl_vs

                            if (child_yang_name == "tl-vs"):
                                if (self.tl_vs is None):
                                    self.tl_vs = BundleInformation.MlacpIccpGroupCounters.IccpGroups.IccpGroup.IccpGroupAncestorNode.IccpGroupCounters.TlVs()
                                    self.tl_vs.parent = self
                                    self._children_name_map["tl_vs"] = "tl-vs"
                                return self.tl_vs

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "connection" or name == "iccp-events" or name == "iccp-messages" or name == "invalid-tl-vs" or name == "tl-vs" or name == "last-time-cleared" or name == "last-unexpected-event" or name == "time-since-cleared"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "last-time-cleared"):
                                self.last_time_cleared = value
                                self.last_time_cleared.value_namespace = name_space
                                self.last_time_cleared.value_namespace_prefix = name_space_prefix
                            if(value_path == "last-unexpected-event"):
                                self.last_unexpected_event = value
                                self.last_unexpected_event.value_namespace = name_space
                                self.last_unexpected_event.value_namespace_prefix = name_space_prefix
                            if(value_path == "time-since-cleared"):
                                self.time_since_cleared = value
                                self.time_since_cleared.value_namespace = name_space
                                self.time_since_cleared.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.iccp_group_id.is_set or
                            (self.iccp_group_counters is not None and self.iccp_group_counters.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.iccp_group_id.yfilter != YFilter.not_set or
                            (self.iccp_group_counters is not None and self.iccp_group_counters.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "iccp-group-ancestor-node" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.iccp_group_id.is_set or self.iccp_group_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.iccp_group_id.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "iccp-group-counters"):
                            if (self.iccp_group_counters is None):
                                self.iccp_group_counters = BundleInformation.MlacpIccpGroupCounters.IccpGroups.IccpGroup.IccpGroupAncestorNode.IccpGroupCounters()
                                self.iccp_group_counters.parent = self
                                self._children_name_map["iccp_group_counters"] = "iccp-group-counters"
                            return self.iccp_group_counters

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "iccp-group-counters" or name == "iccp-group-id"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "iccp-group-id"):
                            self.iccp_group_id = value
                            self.iccp_group_id.value_namespace = name_space
                            self.iccp_group_id.value_namespace_prefix = name_space_prefix


                class IccpGroupItem(Entity):
                    """
                    Data for this item
                    
                    .. attribute:: iccp_group_counters
                    
                    	ICCP Group counters
                    	**type**\:   :py:class:`IccpGroupCounters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.MlacpIccpGroupCounters.IccpGroups.IccpGroup.IccpGroupItem.IccpGroupCounters>`
                    
                    .. attribute:: iccp_group_id
                    
                    	ICCP Group ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'bundlemgr-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(BundleInformation.MlacpIccpGroupCounters.IccpGroups.IccpGroup.IccpGroupItem, self).__init__()

                        self.yang_name = "iccp-group-item"
                        self.yang_parent_name = "iccp-group"

                        self.iccp_group_id = YLeaf(YType.uint32, "iccp-group-id")

                        self.iccp_group_counters = BundleInformation.MlacpIccpGroupCounters.IccpGroups.IccpGroup.IccpGroupItem.IccpGroupCounters()
                        self.iccp_group_counters.parent = self
                        self._children_name_map["iccp_group_counters"] = "iccp-group-counters"
                        self._children_yang_names.add("iccp-group-counters")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("iccp_group_id") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(BundleInformation.MlacpIccpGroupCounters.IccpGroups.IccpGroup.IccpGroupItem, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(BundleInformation.MlacpIccpGroupCounters.IccpGroups.IccpGroup.IccpGroupItem, self).__setattr__(name, value)


                    class IccpGroupCounters(Entity):
                        """
                        ICCP Group counters
                        
                        .. attribute:: connection
                        
                        	Number of connection events
                        	**type**\:   :py:class:`Connection <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.MlacpIccpGroupCounters.IccpGroups.IccpGroup.IccpGroupItem.IccpGroupCounters.Connection>`
                        
                        .. attribute:: iccp_events
                        
                        	Number of ICCP events
                        	**type**\:   :py:class:`IccpEvents <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.MlacpIccpGroupCounters.IccpGroups.IccpGroup.IccpGroupItem.IccpGroupCounters.IccpEvents>`
                        
                        .. attribute:: iccp_messages
                        
                        	Number ICCP messages sent and received
                        	**type**\:   :py:class:`IccpMessages <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.MlacpIccpGroupCounters.IccpGroups.IccpGroup.IccpGroupItem.IccpGroupCounters.IccpMessages>`
                        
                        .. attribute:: invalid_tl_vs
                        
                        	Number invalid TLVs received
                        	**type**\:   :py:class:`InvalidTlVs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.MlacpIccpGroupCounters.IccpGroups.IccpGroup.IccpGroupItem.IccpGroupCounters.InvalidTlVs>`
                        
                        .. attribute:: last_time_cleared
                        
                        	Time in nsecs from boot when counters were last cleared (deprecated)
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: nanosecond
                        
                        .. attribute:: last_unexpected_event
                        
                        	Elapsed time in nsecs since last unexpected event
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: nanosecond
                        
                        .. attribute:: time_since_cleared
                        
                        	Elapsed time in nsecs since counters were last cleared
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: nanosecond
                        
                        .. attribute:: tl_vs
                        
                        	Number TLVs sent and received
                        	**type**\:   :py:class:`TlVs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.MlacpIccpGroupCounters.IccpGroups.IccpGroup.IccpGroupItem.IccpGroupCounters.TlVs>`
                        
                        

                        """

                        _prefix = 'bundlemgr-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(BundleInformation.MlacpIccpGroupCounters.IccpGroups.IccpGroup.IccpGroupItem.IccpGroupCounters, self).__init__()

                            self.yang_name = "iccp-group-counters"
                            self.yang_parent_name = "iccp-group-item"

                            self.last_time_cleared = YLeaf(YType.uint64, "last-time-cleared")

                            self.last_unexpected_event = YLeaf(YType.uint64, "last-unexpected-event")

                            self.time_since_cleared = YLeaf(YType.uint64, "time-since-cleared")

                            self.connection = BundleInformation.MlacpIccpGroupCounters.IccpGroups.IccpGroup.IccpGroupItem.IccpGroupCounters.Connection()
                            self.connection.parent = self
                            self._children_name_map["connection"] = "connection"
                            self._children_yang_names.add("connection")

                            self.iccp_events = BundleInformation.MlacpIccpGroupCounters.IccpGroups.IccpGroup.IccpGroupItem.IccpGroupCounters.IccpEvents()
                            self.iccp_events.parent = self
                            self._children_name_map["iccp_events"] = "iccp-events"
                            self._children_yang_names.add("iccp-events")

                            self.iccp_messages = BundleInformation.MlacpIccpGroupCounters.IccpGroups.IccpGroup.IccpGroupItem.IccpGroupCounters.IccpMessages()
                            self.iccp_messages.parent = self
                            self._children_name_map["iccp_messages"] = "iccp-messages"
                            self._children_yang_names.add("iccp-messages")

                            self.invalid_tl_vs = BundleInformation.MlacpIccpGroupCounters.IccpGroups.IccpGroup.IccpGroupItem.IccpGroupCounters.InvalidTlVs()
                            self.invalid_tl_vs.parent = self
                            self._children_name_map["invalid_tl_vs"] = "invalid-tl-vs"
                            self._children_yang_names.add("invalid-tl-vs")

                            self.tl_vs = BundleInformation.MlacpIccpGroupCounters.IccpGroups.IccpGroup.IccpGroupItem.IccpGroupCounters.TlVs()
                            self.tl_vs.parent = self
                            self._children_name_map["tl_vs"] = "tl-vs"
                            self._children_yang_names.add("tl-vs")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("last_time_cleared",
                                            "last_unexpected_event",
                                            "time_since_cleared") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(BundleInformation.MlacpIccpGroupCounters.IccpGroups.IccpGroup.IccpGroupItem.IccpGroupCounters, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(BundleInformation.MlacpIccpGroupCounters.IccpGroups.IccpGroup.IccpGroupItem.IccpGroupCounters, self).__setattr__(name, value)


                        class Connection(Entity):
                            """
                            Number of connection events
                            
                            .. attribute:: iccp_config_connect_errors
                            
                            	Number of ICCP connection errors due to config
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: iccp_count_connect_errors
                            
                            	Number of ICCP connection errors due to max ICCP group count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: iccp_invalid_connects
                            
                            	Number of invalid ICCP connects
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: iccp_invalid_disconnects
                            
                            	Number of invalid ICCP disconnects
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: received_connects
                            
                            	Number of connect TLVs received
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: received_disconnects
                            
                            	Number of disconnect TLVs received
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: received_wrong_versions
                            
                            	Number of wrong version TLVs received
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: sent_connects
                            
                            	Number of connect TLVs sent
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: sent_disconnects
                            
                            	Number of disconnect TLVs sent
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: sent_wrong_versions
                            
                            	Number of wrong version TLVs sent
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'bundlemgr-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(BundleInformation.MlacpIccpGroupCounters.IccpGroups.IccpGroup.IccpGroupItem.IccpGroupCounters.Connection, self).__init__()

                                self.yang_name = "connection"
                                self.yang_parent_name = "iccp-group-counters"

                                self.iccp_config_connect_errors = YLeaf(YType.uint32, "iccp-config-connect-errors")

                                self.iccp_count_connect_errors = YLeaf(YType.uint32, "iccp-count-connect-errors")

                                self.iccp_invalid_connects = YLeaf(YType.uint32, "iccp-invalid-connects")

                                self.iccp_invalid_disconnects = YLeaf(YType.uint32, "iccp-invalid-disconnects")

                                self.received_connects = YLeaf(YType.uint32, "received-connects")

                                self.received_disconnects = YLeaf(YType.uint32, "received-disconnects")

                                self.received_wrong_versions = YLeaf(YType.uint32, "received-wrong-versions")

                                self.sent_connects = YLeaf(YType.uint32, "sent-connects")

                                self.sent_disconnects = YLeaf(YType.uint32, "sent-disconnects")

                                self.sent_wrong_versions = YLeaf(YType.uint32, "sent-wrong-versions")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("iccp_config_connect_errors",
                                                "iccp_count_connect_errors",
                                                "iccp_invalid_connects",
                                                "iccp_invalid_disconnects",
                                                "received_connects",
                                                "received_disconnects",
                                                "received_wrong_versions",
                                                "sent_connects",
                                                "sent_disconnects",
                                                "sent_wrong_versions") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(BundleInformation.MlacpIccpGroupCounters.IccpGroups.IccpGroup.IccpGroupItem.IccpGroupCounters.Connection, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(BundleInformation.MlacpIccpGroupCounters.IccpGroups.IccpGroup.IccpGroupItem.IccpGroupCounters.Connection, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.iccp_config_connect_errors.is_set or
                                    self.iccp_count_connect_errors.is_set or
                                    self.iccp_invalid_connects.is_set or
                                    self.iccp_invalid_disconnects.is_set or
                                    self.received_connects.is_set or
                                    self.received_disconnects.is_set or
                                    self.received_wrong_versions.is_set or
                                    self.sent_connects.is_set or
                                    self.sent_disconnects.is_set or
                                    self.sent_wrong_versions.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.iccp_config_connect_errors.yfilter != YFilter.not_set or
                                    self.iccp_count_connect_errors.yfilter != YFilter.not_set or
                                    self.iccp_invalid_connects.yfilter != YFilter.not_set or
                                    self.iccp_invalid_disconnects.yfilter != YFilter.not_set or
                                    self.received_connects.yfilter != YFilter.not_set or
                                    self.received_disconnects.yfilter != YFilter.not_set or
                                    self.received_wrong_versions.yfilter != YFilter.not_set or
                                    self.sent_connects.yfilter != YFilter.not_set or
                                    self.sent_disconnects.yfilter != YFilter.not_set or
                                    self.sent_wrong_versions.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "connection" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.iccp_config_connect_errors.is_set or self.iccp_config_connect_errors.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.iccp_config_connect_errors.get_name_leafdata())
                                if (self.iccp_count_connect_errors.is_set or self.iccp_count_connect_errors.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.iccp_count_connect_errors.get_name_leafdata())
                                if (self.iccp_invalid_connects.is_set or self.iccp_invalid_connects.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.iccp_invalid_connects.get_name_leafdata())
                                if (self.iccp_invalid_disconnects.is_set or self.iccp_invalid_disconnects.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.iccp_invalid_disconnects.get_name_leafdata())
                                if (self.received_connects.is_set or self.received_connects.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.received_connects.get_name_leafdata())
                                if (self.received_disconnects.is_set or self.received_disconnects.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.received_disconnects.get_name_leafdata())
                                if (self.received_wrong_versions.is_set or self.received_wrong_versions.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.received_wrong_versions.get_name_leafdata())
                                if (self.sent_connects.is_set or self.sent_connects.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.sent_connects.get_name_leafdata())
                                if (self.sent_disconnects.is_set or self.sent_disconnects.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.sent_disconnects.get_name_leafdata())
                                if (self.sent_wrong_versions.is_set or self.sent_wrong_versions.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.sent_wrong_versions.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "iccp-config-connect-errors" or name == "iccp-count-connect-errors" or name == "iccp-invalid-connects" or name == "iccp-invalid-disconnects" or name == "received-connects" or name == "received-disconnects" or name == "received-wrong-versions" or name == "sent-connects" or name == "sent-disconnects" or name == "sent-wrong-versions"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "iccp-config-connect-errors"):
                                    self.iccp_config_connect_errors = value
                                    self.iccp_config_connect_errors.value_namespace = name_space
                                    self.iccp_config_connect_errors.value_namespace_prefix = name_space_prefix
                                if(value_path == "iccp-count-connect-errors"):
                                    self.iccp_count_connect_errors = value
                                    self.iccp_count_connect_errors.value_namespace = name_space
                                    self.iccp_count_connect_errors.value_namespace_prefix = name_space_prefix
                                if(value_path == "iccp-invalid-connects"):
                                    self.iccp_invalid_connects = value
                                    self.iccp_invalid_connects.value_namespace = name_space
                                    self.iccp_invalid_connects.value_namespace_prefix = name_space_prefix
                                if(value_path == "iccp-invalid-disconnects"):
                                    self.iccp_invalid_disconnects = value
                                    self.iccp_invalid_disconnects.value_namespace = name_space
                                    self.iccp_invalid_disconnects.value_namespace_prefix = name_space_prefix
                                if(value_path == "received-connects"):
                                    self.received_connects = value
                                    self.received_connects.value_namespace = name_space
                                    self.received_connects.value_namespace_prefix = name_space_prefix
                                if(value_path == "received-disconnects"):
                                    self.received_disconnects = value
                                    self.received_disconnects.value_namespace = name_space
                                    self.received_disconnects.value_namespace_prefix = name_space_prefix
                                if(value_path == "received-wrong-versions"):
                                    self.received_wrong_versions = value
                                    self.received_wrong_versions.value_namespace = name_space
                                    self.received_wrong_versions.value_namespace_prefix = name_space_prefix
                                if(value_path == "sent-connects"):
                                    self.sent_connects = value
                                    self.sent_connects.value_namespace = name_space
                                    self.sent_connects.value_namespace_prefix = name_space_prefix
                                if(value_path == "sent-disconnects"):
                                    self.sent_disconnects = value
                                    self.sent_disconnects.value_namespace = name_space
                                    self.sent_disconnects.value_namespace_prefix = name_space_prefix
                                if(value_path == "sent-wrong-versions"):
                                    self.sent_wrong_versions = value
                                    self.sent_wrong_versions.value_namespace = name_space
                                    self.sent_wrong_versions.value_namespace_prefix = name_space_prefix


                        class TlVs(Entity):
                            """
                            Number TLVs sent and received
                            
                            .. attribute:: received_config
                            
                            	Number of config TLVs received
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: received_config_sync_requests
                            
                            	Number of state config request TLVs received
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: received_na_ks
                            
                            	Number of NAK TLVs received
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: received_solicited_sync_data
                            
                            	Number of solicited sync data TLVs received
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: received_state
                            
                            	Number of state TLVs received
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: received_state_sync_requests
                            
                            	Number of state sync request TLVs received
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: received_sync_requests
                            
                            	Number of sync request TLVs received
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: received_unsolicited_sync_data
                            
                            	Number of unsolicited sync data TLVs received
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: sent_config
                            
                            	Number of config TLVs sent
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: sent_config_sync_requests
                            
                            	Number of config sync request TLVs sent
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: sent_na_ks
                            
                            	Number of NAK TLVs sent
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: sent_solicited_sync_data
                            
                            	Number of solicited sync data TLVs sent
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: sent_state
                            
                            	Number of state TLVs sent
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: sent_state_sync_requests
                            
                            	Number of state sync request TLVs sent
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: sent_sync_requests
                            
                            	Number of sync request TLVs sent
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: sent_unsolicited_sync_data
                            
                            	Number of unsolicited sync data TLVs sent
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'bundlemgr-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(BundleInformation.MlacpIccpGroupCounters.IccpGroups.IccpGroup.IccpGroupItem.IccpGroupCounters.TlVs, self).__init__()

                                self.yang_name = "tl-vs"
                                self.yang_parent_name = "iccp-group-counters"

                                self.received_config = YLeaf(YType.uint32, "received-config")

                                self.received_config_sync_requests = YLeaf(YType.uint32, "received-config-sync-requests")

                                self.received_na_ks = YLeaf(YType.uint32, "received-na-ks")

                                self.received_solicited_sync_data = YLeaf(YType.uint32, "received-solicited-sync-data")

                                self.received_state = YLeaf(YType.uint32, "received-state")

                                self.received_state_sync_requests = YLeaf(YType.uint32, "received-state-sync-requests")

                                self.received_sync_requests = YLeaf(YType.uint32, "received-sync-requests")

                                self.received_unsolicited_sync_data = YLeaf(YType.uint32, "received-unsolicited-sync-data")

                                self.sent_config = YLeaf(YType.uint32, "sent-config")

                                self.sent_config_sync_requests = YLeaf(YType.uint32, "sent-config-sync-requests")

                                self.sent_na_ks = YLeaf(YType.uint32, "sent-na-ks")

                                self.sent_solicited_sync_data = YLeaf(YType.uint32, "sent-solicited-sync-data")

                                self.sent_state = YLeaf(YType.uint32, "sent-state")

                                self.sent_state_sync_requests = YLeaf(YType.uint32, "sent-state-sync-requests")

                                self.sent_sync_requests = YLeaf(YType.uint32, "sent-sync-requests")

                                self.sent_unsolicited_sync_data = YLeaf(YType.uint32, "sent-unsolicited-sync-data")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("received_config",
                                                "received_config_sync_requests",
                                                "received_na_ks",
                                                "received_solicited_sync_data",
                                                "received_state",
                                                "received_state_sync_requests",
                                                "received_sync_requests",
                                                "received_unsolicited_sync_data",
                                                "sent_config",
                                                "sent_config_sync_requests",
                                                "sent_na_ks",
                                                "sent_solicited_sync_data",
                                                "sent_state",
                                                "sent_state_sync_requests",
                                                "sent_sync_requests",
                                                "sent_unsolicited_sync_data") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(BundleInformation.MlacpIccpGroupCounters.IccpGroups.IccpGroup.IccpGroupItem.IccpGroupCounters.TlVs, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(BundleInformation.MlacpIccpGroupCounters.IccpGroups.IccpGroup.IccpGroupItem.IccpGroupCounters.TlVs, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.received_config.is_set or
                                    self.received_config_sync_requests.is_set or
                                    self.received_na_ks.is_set or
                                    self.received_solicited_sync_data.is_set or
                                    self.received_state.is_set or
                                    self.received_state_sync_requests.is_set or
                                    self.received_sync_requests.is_set or
                                    self.received_unsolicited_sync_data.is_set or
                                    self.sent_config.is_set or
                                    self.sent_config_sync_requests.is_set or
                                    self.sent_na_ks.is_set or
                                    self.sent_solicited_sync_data.is_set or
                                    self.sent_state.is_set or
                                    self.sent_state_sync_requests.is_set or
                                    self.sent_sync_requests.is_set or
                                    self.sent_unsolicited_sync_data.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.received_config.yfilter != YFilter.not_set or
                                    self.received_config_sync_requests.yfilter != YFilter.not_set or
                                    self.received_na_ks.yfilter != YFilter.not_set or
                                    self.received_solicited_sync_data.yfilter != YFilter.not_set or
                                    self.received_state.yfilter != YFilter.not_set or
                                    self.received_state_sync_requests.yfilter != YFilter.not_set or
                                    self.received_sync_requests.yfilter != YFilter.not_set or
                                    self.received_unsolicited_sync_data.yfilter != YFilter.not_set or
                                    self.sent_config.yfilter != YFilter.not_set or
                                    self.sent_config_sync_requests.yfilter != YFilter.not_set or
                                    self.sent_na_ks.yfilter != YFilter.not_set or
                                    self.sent_solicited_sync_data.yfilter != YFilter.not_set or
                                    self.sent_state.yfilter != YFilter.not_set or
                                    self.sent_state_sync_requests.yfilter != YFilter.not_set or
                                    self.sent_sync_requests.yfilter != YFilter.not_set or
                                    self.sent_unsolicited_sync_data.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "tl-vs" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.received_config.is_set or self.received_config.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.received_config.get_name_leafdata())
                                if (self.received_config_sync_requests.is_set or self.received_config_sync_requests.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.received_config_sync_requests.get_name_leafdata())
                                if (self.received_na_ks.is_set or self.received_na_ks.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.received_na_ks.get_name_leafdata())
                                if (self.received_solicited_sync_data.is_set or self.received_solicited_sync_data.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.received_solicited_sync_data.get_name_leafdata())
                                if (self.received_state.is_set or self.received_state.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.received_state.get_name_leafdata())
                                if (self.received_state_sync_requests.is_set or self.received_state_sync_requests.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.received_state_sync_requests.get_name_leafdata())
                                if (self.received_sync_requests.is_set or self.received_sync_requests.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.received_sync_requests.get_name_leafdata())
                                if (self.received_unsolicited_sync_data.is_set or self.received_unsolicited_sync_data.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.received_unsolicited_sync_data.get_name_leafdata())
                                if (self.sent_config.is_set or self.sent_config.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.sent_config.get_name_leafdata())
                                if (self.sent_config_sync_requests.is_set or self.sent_config_sync_requests.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.sent_config_sync_requests.get_name_leafdata())
                                if (self.sent_na_ks.is_set or self.sent_na_ks.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.sent_na_ks.get_name_leafdata())
                                if (self.sent_solicited_sync_data.is_set or self.sent_solicited_sync_data.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.sent_solicited_sync_data.get_name_leafdata())
                                if (self.sent_state.is_set or self.sent_state.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.sent_state.get_name_leafdata())
                                if (self.sent_state_sync_requests.is_set or self.sent_state_sync_requests.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.sent_state_sync_requests.get_name_leafdata())
                                if (self.sent_sync_requests.is_set or self.sent_sync_requests.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.sent_sync_requests.get_name_leafdata())
                                if (self.sent_unsolicited_sync_data.is_set or self.sent_unsolicited_sync_data.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.sent_unsolicited_sync_data.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "received-config" or name == "received-config-sync-requests" or name == "received-na-ks" or name == "received-solicited-sync-data" or name == "received-state" or name == "received-state-sync-requests" or name == "received-sync-requests" or name == "received-unsolicited-sync-data" or name == "sent-config" or name == "sent-config-sync-requests" or name == "sent-na-ks" or name == "sent-solicited-sync-data" or name == "sent-state" or name == "sent-state-sync-requests" or name == "sent-sync-requests" or name == "sent-unsolicited-sync-data"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "received-config"):
                                    self.received_config = value
                                    self.received_config.value_namespace = name_space
                                    self.received_config.value_namespace_prefix = name_space_prefix
                                if(value_path == "received-config-sync-requests"):
                                    self.received_config_sync_requests = value
                                    self.received_config_sync_requests.value_namespace = name_space
                                    self.received_config_sync_requests.value_namespace_prefix = name_space_prefix
                                if(value_path == "received-na-ks"):
                                    self.received_na_ks = value
                                    self.received_na_ks.value_namespace = name_space
                                    self.received_na_ks.value_namespace_prefix = name_space_prefix
                                if(value_path == "received-solicited-sync-data"):
                                    self.received_solicited_sync_data = value
                                    self.received_solicited_sync_data.value_namespace = name_space
                                    self.received_solicited_sync_data.value_namespace_prefix = name_space_prefix
                                if(value_path == "received-state"):
                                    self.received_state = value
                                    self.received_state.value_namespace = name_space
                                    self.received_state.value_namespace_prefix = name_space_prefix
                                if(value_path == "received-state-sync-requests"):
                                    self.received_state_sync_requests = value
                                    self.received_state_sync_requests.value_namespace = name_space
                                    self.received_state_sync_requests.value_namespace_prefix = name_space_prefix
                                if(value_path == "received-sync-requests"):
                                    self.received_sync_requests = value
                                    self.received_sync_requests.value_namespace = name_space
                                    self.received_sync_requests.value_namespace_prefix = name_space_prefix
                                if(value_path == "received-unsolicited-sync-data"):
                                    self.received_unsolicited_sync_data = value
                                    self.received_unsolicited_sync_data.value_namespace = name_space
                                    self.received_unsolicited_sync_data.value_namespace_prefix = name_space_prefix
                                if(value_path == "sent-config"):
                                    self.sent_config = value
                                    self.sent_config.value_namespace = name_space
                                    self.sent_config.value_namespace_prefix = name_space_prefix
                                if(value_path == "sent-config-sync-requests"):
                                    self.sent_config_sync_requests = value
                                    self.sent_config_sync_requests.value_namespace = name_space
                                    self.sent_config_sync_requests.value_namespace_prefix = name_space_prefix
                                if(value_path == "sent-na-ks"):
                                    self.sent_na_ks = value
                                    self.sent_na_ks.value_namespace = name_space
                                    self.sent_na_ks.value_namespace_prefix = name_space_prefix
                                if(value_path == "sent-solicited-sync-data"):
                                    self.sent_solicited_sync_data = value
                                    self.sent_solicited_sync_data.value_namespace = name_space
                                    self.sent_solicited_sync_data.value_namespace_prefix = name_space_prefix
                                if(value_path == "sent-state"):
                                    self.sent_state = value
                                    self.sent_state.value_namespace = name_space
                                    self.sent_state.value_namespace_prefix = name_space_prefix
                                if(value_path == "sent-state-sync-requests"):
                                    self.sent_state_sync_requests = value
                                    self.sent_state_sync_requests.value_namespace = name_space
                                    self.sent_state_sync_requests.value_namespace_prefix = name_space_prefix
                                if(value_path == "sent-sync-requests"):
                                    self.sent_sync_requests = value
                                    self.sent_sync_requests.value_namespace = name_space
                                    self.sent_sync_requests.value_namespace_prefix = name_space_prefix
                                if(value_path == "sent-unsolicited-sync-data"):
                                    self.sent_unsolicited_sync_data = value
                                    self.sent_unsolicited_sync_data.value_namespace = name_space
                                    self.sent_unsolicited_sync_data.value_namespace_prefix = name_space_prefix


                        class InvalidTlVs(Entity):
                            """
                            Number invalid TLVs received
                            
                            .. attribute:: incorrect_length
                            
                            	Number of messages received of an incorrect length
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: invalid_data
                            
                            	Number of messages received containing invalid data
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: invalid_type
                            
                            	Number of messages received with an invalid mLACP TLV type
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: unknown_bundle
                            
                            	Number of messages received for an unknown bundle
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: unknown_port
                            
                            	Number of messages received for an unknown port
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'bundlemgr-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(BundleInformation.MlacpIccpGroupCounters.IccpGroups.IccpGroup.IccpGroupItem.IccpGroupCounters.InvalidTlVs, self).__init__()

                                self.yang_name = "invalid-tl-vs"
                                self.yang_parent_name = "iccp-group-counters"

                                self.incorrect_length = YLeaf(YType.uint32, "incorrect-length")

                                self.invalid_data = YLeaf(YType.uint32, "invalid-data")

                                self.invalid_type = YLeaf(YType.uint32, "invalid-type")

                                self.unknown_bundle = YLeaf(YType.uint32, "unknown-bundle")

                                self.unknown_port = YLeaf(YType.uint32, "unknown-port")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("incorrect_length",
                                                "invalid_data",
                                                "invalid_type",
                                                "unknown_bundle",
                                                "unknown_port") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(BundleInformation.MlacpIccpGroupCounters.IccpGroups.IccpGroup.IccpGroupItem.IccpGroupCounters.InvalidTlVs, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(BundleInformation.MlacpIccpGroupCounters.IccpGroups.IccpGroup.IccpGroupItem.IccpGroupCounters.InvalidTlVs, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.incorrect_length.is_set or
                                    self.invalid_data.is_set or
                                    self.invalid_type.is_set or
                                    self.unknown_bundle.is_set or
                                    self.unknown_port.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.incorrect_length.yfilter != YFilter.not_set or
                                    self.invalid_data.yfilter != YFilter.not_set or
                                    self.invalid_type.yfilter != YFilter.not_set or
                                    self.unknown_bundle.yfilter != YFilter.not_set or
                                    self.unknown_port.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "invalid-tl-vs" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.incorrect_length.is_set or self.incorrect_length.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.incorrect_length.get_name_leafdata())
                                if (self.invalid_data.is_set or self.invalid_data.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.invalid_data.get_name_leafdata())
                                if (self.invalid_type.is_set or self.invalid_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.invalid_type.get_name_leafdata())
                                if (self.unknown_bundle.is_set or self.unknown_bundle.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.unknown_bundle.get_name_leafdata())
                                if (self.unknown_port.is_set or self.unknown_port.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.unknown_port.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "incorrect-length" or name == "invalid-data" or name == "invalid-type" or name == "unknown-bundle" or name == "unknown-port"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "incorrect-length"):
                                    self.incorrect_length = value
                                    self.incorrect_length.value_namespace = name_space
                                    self.incorrect_length.value_namespace_prefix = name_space_prefix
                                if(value_path == "invalid-data"):
                                    self.invalid_data = value
                                    self.invalid_data.value_namespace = name_space
                                    self.invalid_data.value_namespace_prefix = name_space_prefix
                                if(value_path == "invalid-type"):
                                    self.invalid_type = value
                                    self.invalid_type.value_namespace = name_space
                                    self.invalid_type.value_namespace_prefix = name_space_prefix
                                if(value_path == "unknown-bundle"):
                                    self.unknown_bundle = value
                                    self.unknown_bundle.value_namespace = name_space
                                    self.unknown_bundle.value_namespace_prefix = name_space_prefix
                                if(value_path == "unknown-port"):
                                    self.unknown_port = value
                                    self.unknown_port.value_namespace = name_space
                                    self.unknown_port.value_namespace_prefix = name_space_prefix


                        class IccpMessages(Entity):
                            """
                            Number ICCP messages sent and received
                            
                            .. attribute:: received_messages
                            
                            	Number of messages received
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: sent_buffer_messages
                            
                            	Number of buffers sent (may be multiple per message)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: sent_messages
                            
                            	Number of messages sent
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: transmission_errors
                            
                            	Number of transmission errors
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'bundlemgr-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(BundleInformation.MlacpIccpGroupCounters.IccpGroups.IccpGroup.IccpGroupItem.IccpGroupCounters.IccpMessages, self).__init__()

                                self.yang_name = "iccp-messages"
                                self.yang_parent_name = "iccp-group-counters"

                                self.received_messages = YLeaf(YType.uint32, "received-messages")

                                self.sent_buffer_messages = YLeaf(YType.uint32, "sent-buffer-messages")

                                self.sent_messages = YLeaf(YType.uint32, "sent-messages")

                                self.transmission_errors = YLeaf(YType.uint32, "transmission-errors")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("received_messages",
                                                "sent_buffer_messages",
                                                "sent_messages",
                                                "transmission_errors") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(BundleInformation.MlacpIccpGroupCounters.IccpGroups.IccpGroup.IccpGroupItem.IccpGroupCounters.IccpMessages, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(BundleInformation.MlacpIccpGroupCounters.IccpGroups.IccpGroup.IccpGroupItem.IccpGroupCounters.IccpMessages, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.received_messages.is_set or
                                    self.sent_buffer_messages.is_set or
                                    self.sent_messages.is_set or
                                    self.transmission_errors.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.received_messages.yfilter != YFilter.not_set or
                                    self.sent_buffer_messages.yfilter != YFilter.not_set or
                                    self.sent_messages.yfilter != YFilter.not_set or
                                    self.transmission_errors.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "iccp-messages" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.received_messages.is_set or self.received_messages.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.received_messages.get_name_leafdata())
                                if (self.sent_buffer_messages.is_set or self.sent_buffer_messages.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.sent_buffer_messages.get_name_leafdata())
                                if (self.sent_messages.is_set or self.sent_messages.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.sent_messages.get_name_leafdata())
                                if (self.transmission_errors.is_set or self.transmission_errors.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.transmission_errors.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "received-messages" or name == "sent-buffer-messages" or name == "sent-messages" or name == "transmission-errors"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "received-messages"):
                                    self.received_messages = value
                                    self.received_messages.value_namespace = name_space
                                    self.received_messages.value_namespace_prefix = name_space_prefix
                                if(value_path == "sent-buffer-messages"):
                                    self.sent_buffer_messages = value
                                    self.sent_buffer_messages.value_namespace = name_space
                                    self.sent_buffer_messages.value_namespace_prefix = name_space_prefix
                                if(value_path == "sent-messages"):
                                    self.sent_messages = value
                                    self.sent_messages.value_namespace = name_space
                                    self.sent_messages.value_namespace_prefix = name_space_prefix
                                if(value_path == "transmission-errors"):
                                    self.transmission_errors = value
                                    self.transmission_errors.value_namespace = name_space
                                    self.transmission_errors.value_namespace_prefix = name_space_prefix


                        class IccpEvents(Entity):
                            """
                            Number of ICCP events
                            
                            .. attribute:: configured_clear
                            
                            	Number of unconfigure events
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: configured_set
                            
                            	Number of configure events
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: member_status_down
                            
                            	Number of member status down events
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: member_status_up
                            
                            	Number of member status up events
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: pe_isolated
                            
                            	Number of PE isolation events
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: pe_isolated_clear
                            
                            	Number of PE isolation cleared events
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: reachability_cleared
                            
                            	Number of reachability cleared events
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: reachability_set
                            
                            	Number of reachability events
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: transport_down
                            
                            	Number of transport down events
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: transport_unavailable
                            
                            	Number of transport unavailable events
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: transport_up
                            
                            	Number of transport up events
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'bundlemgr-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(BundleInformation.MlacpIccpGroupCounters.IccpGroups.IccpGroup.IccpGroupItem.IccpGroupCounters.IccpEvents, self).__init__()

                                self.yang_name = "iccp-events"
                                self.yang_parent_name = "iccp-group-counters"

                                self.configured_clear = YLeaf(YType.uint32, "configured-clear")

                                self.configured_set = YLeaf(YType.uint32, "configured-set")

                                self.member_status_down = YLeaf(YType.uint32, "member-status-down")

                                self.member_status_up = YLeaf(YType.uint32, "member-status-up")

                                self.pe_isolated = YLeaf(YType.uint32, "pe-isolated")

                                self.pe_isolated_clear = YLeaf(YType.uint32, "pe-isolated-clear")

                                self.reachability_cleared = YLeaf(YType.uint32, "reachability-cleared")

                                self.reachability_set = YLeaf(YType.uint32, "reachability-set")

                                self.transport_down = YLeaf(YType.uint32, "transport-down")

                                self.transport_unavailable = YLeaf(YType.uint32, "transport-unavailable")

                                self.transport_up = YLeaf(YType.uint32, "transport-up")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("configured_clear",
                                                "configured_set",
                                                "member_status_down",
                                                "member_status_up",
                                                "pe_isolated",
                                                "pe_isolated_clear",
                                                "reachability_cleared",
                                                "reachability_set",
                                                "transport_down",
                                                "transport_unavailable",
                                                "transport_up") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(BundleInformation.MlacpIccpGroupCounters.IccpGroups.IccpGroup.IccpGroupItem.IccpGroupCounters.IccpEvents, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(BundleInformation.MlacpIccpGroupCounters.IccpGroups.IccpGroup.IccpGroupItem.IccpGroupCounters.IccpEvents, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.configured_clear.is_set or
                                    self.configured_set.is_set or
                                    self.member_status_down.is_set or
                                    self.member_status_up.is_set or
                                    self.pe_isolated.is_set or
                                    self.pe_isolated_clear.is_set or
                                    self.reachability_cleared.is_set or
                                    self.reachability_set.is_set or
                                    self.transport_down.is_set or
                                    self.transport_unavailable.is_set or
                                    self.transport_up.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.configured_clear.yfilter != YFilter.not_set or
                                    self.configured_set.yfilter != YFilter.not_set or
                                    self.member_status_down.yfilter != YFilter.not_set or
                                    self.member_status_up.yfilter != YFilter.not_set or
                                    self.pe_isolated.yfilter != YFilter.not_set or
                                    self.pe_isolated_clear.yfilter != YFilter.not_set or
                                    self.reachability_cleared.yfilter != YFilter.not_set or
                                    self.reachability_set.yfilter != YFilter.not_set or
                                    self.transport_down.yfilter != YFilter.not_set or
                                    self.transport_unavailable.yfilter != YFilter.not_set or
                                    self.transport_up.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "iccp-events" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.configured_clear.is_set or self.configured_clear.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.configured_clear.get_name_leafdata())
                                if (self.configured_set.is_set or self.configured_set.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.configured_set.get_name_leafdata())
                                if (self.member_status_down.is_set or self.member_status_down.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.member_status_down.get_name_leafdata())
                                if (self.member_status_up.is_set or self.member_status_up.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.member_status_up.get_name_leafdata())
                                if (self.pe_isolated.is_set or self.pe_isolated.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pe_isolated.get_name_leafdata())
                                if (self.pe_isolated_clear.is_set or self.pe_isolated_clear.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pe_isolated_clear.get_name_leafdata())
                                if (self.reachability_cleared.is_set or self.reachability_cleared.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.reachability_cleared.get_name_leafdata())
                                if (self.reachability_set.is_set or self.reachability_set.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.reachability_set.get_name_leafdata())
                                if (self.transport_down.is_set or self.transport_down.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.transport_down.get_name_leafdata())
                                if (self.transport_unavailable.is_set or self.transport_unavailable.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.transport_unavailable.get_name_leafdata())
                                if (self.transport_up.is_set or self.transport_up.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.transport_up.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "configured-clear" or name == "configured-set" or name == "member-status-down" or name == "member-status-up" or name == "pe-isolated" or name == "pe-isolated-clear" or name == "reachability-cleared" or name == "reachability-set" or name == "transport-down" or name == "transport-unavailable" or name == "transport-up"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "configured-clear"):
                                    self.configured_clear = value
                                    self.configured_clear.value_namespace = name_space
                                    self.configured_clear.value_namespace_prefix = name_space_prefix
                                if(value_path == "configured-set"):
                                    self.configured_set = value
                                    self.configured_set.value_namespace = name_space
                                    self.configured_set.value_namespace_prefix = name_space_prefix
                                if(value_path == "member-status-down"):
                                    self.member_status_down = value
                                    self.member_status_down.value_namespace = name_space
                                    self.member_status_down.value_namespace_prefix = name_space_prefix
                                if(value_path == "member-status-up"):
                                    self.member_status_up = value
                                    self.member_status_up.value_namespace = name_space
                                    self.member_status_up.value_namespace_prefix = name_space_prefix
                                if(value_path == "pe-isolated"):
                                    self.pe_isolated = value
                                    self.pe_isolated.value_namespace = name_space
                                    self.pe_isolated.value_namespace_prefix = name_space_prefix
                                if(value_path == "pe-isolated-clear"):
                                    self.pe_isolated_clear = value
                                    self.pe_isolated_clear.value_namespace = name_space
                                    self.pe_isolated_clear.value_namespace_prefix = name_space_prefix
                                if(value_path == "reachability-cleared"):
                                    self.reachability_cleared = value
                                    self.reachability_cleared.value_namespace = name_space
                                    self.reachability_cleared.value_namespace_prefix = name_space_prefix
                                if(value_path == "reachability-set"):
                                    self.reachability_set = value
                                    self.reachability_set.value_namespace = name_space
                                    self.reachability_set.value_namespace_prefix = name_space_prefix
                                if(value_path == "transport-down"):
                                    self.transport_down = value
                                    self.transport_down.value_namespace = name_space
                                    self.transport_down.value_namespace_prefix = name_space_prefix
                                if(value_path == "transport-unavailable"):
                                    self.transport_unavailable = value
                                    self.transport_unavailable.value_namespace = name_space
                                    self.transport_unavailable.value_namespace_prefix = name_space_prefix
                                if(value_path == "transport-up"):
                                    self.transport_up = value
                                    self.transport_up.value_namespace = name_space
                                    self.transport_up.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.last_time_cleared.is_set or
                                self.last_unexpected_event.is_set or
                                self.time_since_cleared.is_set or
                                (self.connection is not None and self.connection.has_data()) or
                                (self.iccp_events is not None and self.iccp_events.has_data()) or
                                (self.iccp_messages is not None and self.iccp_messages.has_data()) or
                                (self.invalid_tl_vs is not None and self.invalid_tl_vs.has_data()) or
                                (self.tl_vs is not None and self.tl_vs.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.last_time_cleared.yfilter != YFilter.not_set or
                                self.last_unexpected_event.yfilter != YFilter.not_set or
                                self.time_since_cleared.yfilter != YFilter.not_set or
                                (self.connection is not None and self.connection.has_operation()) or
                                (self.iccp_events is not None and self.iccp_events.has_operation()) or
                                (self.iccp_messages is not None and self.iccp_messages.has_operation()) or
                                (self.invalid_tl_vs is not None and self.invalid_tl_vs.has_operation()) or
                                (self.tl_vs is not None and self.tl_vs.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "iccp-group-counters" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.last_time_cleared.is_set or self.last_time_cleared.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.last_time_cleared.get_name_leafdata())
                            if (self.last_unexpected_event.is_set or self.last_unexpected_event.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.last_unexpected_event.get_name_leafdata())
                            if (self.time_since_cleared.is_set or self.time_since_cleared.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.time_since_cleared.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "connection"):
                                if (self.connection is None):
                                    self.connection = BundleInformation.MlacpIccpGroupCounters.IccpGroups.IccpGroup.IccpGroupItem.IccpGroupCounters.Connection()
                                    self.connection.parent = self
                                    self._children_name_map["connection"] = "connection"
                                return self.connection

                            if (child_yang_name == "iccp-events"):
                                if (self.iccp_events is None):
                                    self.iccp_events = BundleInformation.MlacpIccpGroupCounters.IccpGroups.IccpGroup.IccpGroupItem.IccpGroupCounters.IccpEvents()
                                    self.iccp_events.parent = self
                                    self._children_name_map["iccp_events"] = "iccp-events"
                                return self.iccp_events

                            if (child_yang_name == "iccp-messages"):
                                if (self.iccp_messages is None):
                                    self.iccp_messages = BundleInformation.MlacpIccpGroupCounters.IccpGroups.IccpGroup.IccpGroupItem.IccpGroupCounters.IccpMessages()
                                    self.iccp_messages.parent = self
                                    self._children_name_map["iccp_messages"] = "iccp-messages"
                                return self.iccp_messages

                            if (child_yang_name == "invalid-tl-vs"):
                                if (self.invalid_tl_vs is None):
                                    self.invalid_tl_vs = BundleInformation.MlacpIccpGroupCounters.IccpGroups.IccpGroup.IccpGroupItem.IccpGroupCounters.InvalidTlVs()
                                    self.invalid_tl_vs.parent = self
                                    self._children_name_map["invalid_tl_vs"] = "invalid-tl-vs"
                                return self.invalid_tl_vs

                            if (child_yang_name == "tl-vs"):
                                if (self.tl_vs is None):
                                    self.tl_vs = BundleInformation.MlacpIccpGroupCounters.IccpGroups.IccpGroup.IccpGroupItem.IccpGroupCounters.TlVs()
                                    self.tl_vs.parent = self
                                    self._children_name_map["tl_vs"] = "tl-vs"
                                return self.tl_vs

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "connection" or name == "iccp-events" or name == "iccp-messages" or name == "invalid-tl-vs" or name == "tl-vs" or name == "last-time-cleared" or name == "last-unexpected-event" or name == "time-since-cleared"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "last-time-cleared"):
                                self.last_time_cleared = value
                                self.last_time_cleared.value_namespace = name_space
                                self.last_time_cleared.value_namespace_prefix = name_space_prefix
                            if(value_path == "last-unexpected-event"):
                                self.last_unexpected_event = value
                                self.last_unexpected_event.value_namespace = name_space
                                self.last_unexpected_event.value_namespace_prefix = name_space_prefix
                            if(value_path == "time-since-cleared"):
                                self.time_since_cleared = value
                                self.time_since_cleared.value_namespace = name_space
                                self.time_since_cleared.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.iccp_group_id.is_set or
                            (self.iccp_group_counters is not None and self.iccp_group_counters.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.iccp_group_id.yfilter != YFilter.not_set or
                            (self.iccp_group_counters is not None and self.iccp_group_counters.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "iccp-group-item" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.iccp_group_id.is_set or self.iccp_group_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.iccp_group_id.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "iccp-group-counters"):
                            if (self.iccp_group_counters is None):
                                self.iccp_group_counters = BundleInformation.MlacpIccpGroupCounters.IccpGroups.IccpGroup.IccpGroupItem.IccpGroupCounters()
                                self.iccp_group_counters.parent = self
                                self._children_name_map["iccp_group_counters"] = "iccp-group-counters"
                            return self.iccp_group_counters

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "iccp-group-counters" or name == "iccp-group-id"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "iccp-group-id"):
                            self.iccp_group_id = value
                            self.iccp_group_id.value_namespace = name_space
                            self.iccp_group_id.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    return (
                        self.iccp_group.is_set or
                        (self.iccp_group_ancestor_bundle is not None and self.iccp_group_ancestor_bundle.has_data()) or
                        (self.iccp_group_ancestor_member is not None and self.iccp_group_ancestor_member.has_data()) or
                        (self.iccp_group_ancestor_node is not None and self.iccp_group_ancestor_node.has_data()) or
                        (self.iccp_group_item is not None and self.iccp_group_item.has_data()))

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.iccp_group.yfilter != YFilter.not_set or
                        (self.iccp_group_ancestor_bundle is not None and self.iccp_group_ancestor_bundle.has_operation()) or
                        (self.iccp_group_ancestor_member is not None and self.iccp_group_ancestor_member.has_operation()) or
                        (self.iccp_group_ancestor_node is not None and self.iccp_group_ancestor_node.has_operation()) or
                        (self.iccp_group_item is not None and self.iccp_group_item.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "iccp-group" + "[iccp-group='" + self.iccp_group.get() + "']" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-bundlemgr-oper:bundle-information/mlacp-iccp-group-counters/iccp-groups/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.iccp_group.is_set or self.iccp_group.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.iccp_group.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "iccp-group-ancestor-bundle"):
                        if (self.iccp_group_ancestor_bundle is None):
                            self.iccp_group_ancestor_bundle = BundleInformation.MlacpIccpGroupCounters.IccpGroups.IccpGroup.IccpGroupAncestorBundle()
                            self.iccp_group_ancestor_bundle.parent = self
                            self._children_name_map["iccp_group_ancestor_bundle"] = "iccp-group-ancestor-bundle"
                        return self.iccp_group_ancestor_bundle

                    if (child_yang_name == "iccp-group-ancestor-member"):
                        if (self.iccp_group_ancestor_member is None):
                            self.iccp_group_ancestor_member = BundleInformation.MlacpIccpGroupCounters.IccpGroups.IccpGroup.IccpGroupAncestorMember()
                            self.iccp_group_ancestor_member.parent = self
                            self._children_name_map["iccp_group_ancestor_member"] = "iccp-group-ancestor-member"
                        return self.iccp_group_ancestor_member

                    if (child_yang_name == "iccp-group-ancestor-node"):
                        if (self.iccp_group_ancestor_node is None):
                            self.iccp_group_ancestor_node = BundleInformation.MlacpIccpGroupCounters.IccpGroups.IccpGroup.IccpGroupAncestorNode()
                            self.iccp_group_ancestor_node.parent = self
                            self._children_name_map["iccp_group_ancestor_node"] = "iccp-group-ancestor-node"
                        return self.iccp_group_ancestor_node

                    if (child_yang_name == "iccp-group-item"):
                        if (self.iccp_group_item is None):
                            self.iccp_group_item = BundleInformation.MlacpIccpGroupCounters.IccpGroups.IccpGroup.IccpGroupItem()
                            self.iccp_group_item.parent = self
                            self._children_name_map["iccp_group_item"] = "iccp-group-item"
                        return self.iccp_group_item

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "iccp-group-ancestor-bundle" or name == "iccp-group-ancestor-member" or name == "iccp-group-ancestor-node" or name == "iccp-group-item" or name == "iccp-group"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "iccp-group"):
                        self.iccp_group = value
                        self.iccp_group.value_namespace = name_space
                        self.iccp_group.value_namespace_prefix = name_space_prefix

            def has_data(self):
                for c in self.iccp_group:
                    if (c.has_data()):
                        return True
                return False

            def has_operation(self):
                for c in self.iccp_group:
                    if (c.has_operation()):
                        return True
                return self.yfilter != YFilter.not_set

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "iccp-groups" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-bundlemgr-oper:bundle-information/mlacp-iccp-group-counters/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "iccp-group"):
                    for c in self.iccp_group:
                        segment = c.get_segment_path()
                        if (segment_path == segment):
                            return c
                    c = BundleInformation.MlacpIccpGroupCounters.IccpGroups.IccpGroup()
                    c.parent = self
                    local_reference_key = "ydk::seg::%s" % segment_path
                    self._local_refs[local_reference_key] = c
                    self.iccp_group.append(c)
                    return c

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "iccp-group"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                pass

        def has_data(self):
            return (self.iccp_groups is not None and self.iccp_groups.has_data())

        def has_operation(self):
            return (
                self.yfilter != YFilter.not_set or
                (self.iccp_groups is not None and self.iccp_groups.has_operation()))

        def get_segment_path(self):
            path_buffer = ""
            path_buffer = "mlacp-iccp-group-counters" + path_buffer

            return path_buffer

        def get_entity_path(self, ancestor):
            path_buffer = ""
            if (ancestor is None):
                path_buffer = "Cisco-IOS-XR-bundlemgr-oper:bundle-information/%s" % self.get_segment_path()
            else:
                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

            leaf_name_data = LeafDataList()

            entity_path = EntityPath(path_buffer, leaf_name_data)
            return entity_path

        def get_child_by_name(self, child_yang_name, segment_path):
            child = self._get_child_by_seg_name([child_yang_name, segment_path])
            if child is not None:
                return child

            if (child_yang_name == "iccp-groups"):
                if (self.iccp_groups is None):
                    self.iccp_groups = BundleInformation.MlacpIccpGroupCounters.IccpGroups()
                    self.iccp_groups.parent = self
                    self._children_name_map["iccp_groups"] = "iccp-groups"
                return self.iccp_groups

            return None

        def has_leaf_or_child_of_name(self, name):
            if(name == "iccp-groups"):
                return True
            return False

        def set_value(self, value_path, value, name_space, name_space_prefix):
            pass


    class SystemId(Entity):
        """
        System Identifiers for the local system and all
        ICCP Groups
        
        .. attribute:: system_id_global
        
        	System Identifier for the local system
        	**type**\:   :py:class:`SystemIdGlobal <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.SystemId.SystemIdGlobal>`
        
        .. attribute:: system_id_iccp_groups
        
        	System Identifiers for all ICCP Groups
        	**type**\:   :py:class:`SystemIdIccpGroups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.SystemId.SystemIdIccpGroups>`
        
        

        """

        _prefix = 'bundlemgr-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(BundleInformation.SystemId, self).__init__()

            self.yang_name = "system-id"
            self.yang_parent_name = "bundle-information"

            self.system_id_global = BundleInformation.SystemId.SystemIdGlobal()
            self.system_id_global.parent = self
            self._children_name_map["system_id_global"] = "system-id-global"
            self._children_yang_names.add("system-id-global")

            self.system_id_iccp_groups = BundleInformation.SystemId.SystemIdIccpGroups()
            self.system_id_iccp_groups.parent = self
            self._children_name_map["system_id_iccp_groups"] = "system-id-iccp-groups"
            self._children_yang_names.add("system-id-iccp-groups")


        class SystemIdGlobal(Entity):
            """
            System Identifier for the local system
            
            .. attribute:: system_id_global_item
            
            	Data for this item
            	**type**\:   :py:class:`SystemIdGlobalItem <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.SystemId.SystemIdGlobal.SystemIdGlobalItem>`
            
            

            """

            _prefix = 'bundlemgr-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(BundleInformation.SystemId.SystemIdGlobal, self).__init__()

                self.yang_name = "system-id-global"
                self.yang_parent_name = "system-id"

                self.system_id_global_item = BundleInformation.SystemId.SystemIdGlobal.SystemIdGlobalItem()
                self.system_id_global_item.parent = self
                self._children_name_map["system_id_global_item"] = "system-id-global-item"
                self._children_yang_names.add("system-id-global-item")


            class SystemIdGlobalItem(Entity):
                """
                Data for this item
                
                .. attribute:: iccp_group_id
                
                	ICCP Group that the system ID is for
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: system_id
                
                	System ID
                	**type**\:   :py:class:`SystemId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.SystemId.SystemIdGlobal.SystemIdGlobalItem.SystemId>`
                
                .. attribute:: system_mac_address
                
                	MAC Address used to identify the system (deprecated)
                	**type**\:  str
                
                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                
                .. attribute:: system_priority
                
                	Priority of the system (deprecated)
                	**type**\:  int
                
                	**range:** 0..65535
                
                

                """

                _prefix = 'bundlemgr-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(BundleInformation.SystemId.SystemIdGlobal.SystemIdGlobalItem, self).__init__()

                    self.yang_name = "system-id-global-item"
                    self.yang_parent_name = "system-id-global"

                    self.iccp_group_id = YLeaf(YType.uint32, "iccp-group-id")

                    self.system_mac_address = YLeaf(YType.str, "system-mac-address")

                    self.system_priority = YLeaf(YType.uint16, "system-priority")

                    self.system_id = BundleInformation.SystemId.SystemIdGlobal.SystemIdGlobalItem.SystemId()
                    self.system_id.parent = self
                    self._children_name_map["system_id"] = "system-id"
                    self._children_yang_names.add("system-id")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("iccp_group_id",
                                    "system_mac_address",
                                    "system_priority") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(BundleInformation.SystemId.SystemIdGlobal.SystemIdGlobalItem, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(BundleInformation.SystemId.SystemIdGlobal.SystemIdGlobalItem, self).__setattr__(name, value)


                class SystemId(Entity):
                    """
                    System ID
                    
                    .. attribute:: system_mac_addr
                    
                    	MAC Address used to identify the system
                    	**type**\:   :py:class:`SystemMacAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.SystemId.SystemIdGlobal.SystemIdGlobalItem.SystemId.SystemMacAddr>`
                    
                    .. attribute:: system_prio
                    
                    	Priority of the system
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'bundlemgr-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(BundleInformation.SystemId.SystemIdGlobal.SystemIdGlobalItem.SystemId, self).__init__()

                        self.yang_name = "system-id"
                        self.yang_parent_name = "system-id-global-item"

                        self.system_prio = YLeaf(YType.uint16, "system-prio")

                        self.system_mac_addr = BundleInformation.SystemId.SystemIdGlobal.SystemIdGlobalItem.SystemId.SystemMacAddr()
                        self.system_mac_addr.parent = self
                        self._children_name_map["system_mac_addr"] = "system-mac-addr"
                        self._children_yang_names.add("system-mac-addr")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("system_prio") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(BundleInformation.SystemId.SystemIdGlobal.SystemIdGlobalItem.SystemId, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(BundleInformation.SystemId.SystemIdGlobal.SystemIdGlobalItem.SystemId, self).__setattr__(name, value)


                    class SystemMacAddr(Entity):
                        """
                        MAC Address used to identify the system
                        
                        .. attribute:: macaddr
                        
                        	macaddr
                        	**type**\:  str
                        
                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                        
                        

                        """

                        _prefix = 'bundlemgr-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(BundleInformation.SystemId.SystemIdGlobal.SystemIdGlobalItem.SystemId.SystemMacAddr, self).__init__()

                            self.yang_name = "system-mac-addr"
                            self.yang_parent_name = "system-id"

                            self.macaddr = YLeaf(YType.str, "macaddr")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("macaddr") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(BundleInformation.SystemId.SystemIdGlobal.SystemIdGlobalItem.SystemId.SystemMacAddr, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(BundleInformation.SystemId.SystemIdGlobal.SystemIdGlobalItem.SystemId.SystemMacAddr, self).__setattr__(name, value)

                        def has_data(self):
                            return self.macaddr.is_set

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.macaddr.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "system-mac-addr" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-bundlemgr-oper:bundle-information/system-id/system-id-global/system-id-global-item/system-id/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.macaddr.is_set or self.macaddr.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.macaddr.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "macaddr"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "macaddr"):
                                self.macaddr = value
                                self.macaddr.value_namespace = name_space
                                self.macaddr.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.system_prio.is_set or
                            (self.system_mac_addr is not None and self.system_mac_addr.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.system_prio.yfilter != YFilter.not_set or
                            (self.system_mac_addr is not None and self.system_mac_addr.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "system-id" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-bundlemgr-oper:bundle-information/system-id/system-id-global/system-id-global-item/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.system_prio.is_set or self.system_prio.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.system_prio.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "system-mac-addr"):
                            if (self.system_mac_addr is None):
                                self.system_mac_addr = BundleInformation.SystemId.SystemIdGlobal.SystemIdGlobalItem.SystemId.SystemMacAddr()
                                self.system_mac_addr.parent = self
                                self._children_name_map["system_mac_addr"] = "system-mac-addr"
                            return self.system_mac_addr

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "system-mac-addr" or name == "system-prio"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "system-prio"):
                            self.system_prio = value
                            self.system_prio.value_namespace = name_space
                            self.system_prio.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    return (
                        self.iccp_group_id.is_set or
                        self.system_mac_address.is_set or
                        self.system_priority.is_set or
                        (self.system_id is not None and self.system_id.has_data()))

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.iccp_group_id.yfilter != YFilter.not_set or
                        self.system_mac_address.yfilter != YFilter.not_set or
                        self.system_priority.yfilter != YFilter.not_set or
                        (self.system_id is not None and self.system_id.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "system-id-global-item" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-bundlemgr-oper:bundle-information/system-id/system-id-global/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.iccp_group_id.is_set or self.iccp_group_id.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.iccp_group_id.get_name_leafdata())
                    if (self.system_mac_address.is_set or self.system_mac_address.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.system_mac_address.get_name_leafdata())
                    if (self.system_priority.is_set or self.system_priority.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.system_priority.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "system-id"):
                        if (self.system_id is None):
                            self.system_id = BundleInformation.SystemId.SystemIdGlobal.SystemIdGlobalItem.SystemId()
                            self.system_id.parent = self
                            self._children_name_map["system_id"] = "system-id"
                        return self.system_id

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "system-id" or name == "iccp-group-id" or name == "system-mac-address" or name == "system-priority"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "iccp-group-id"):
                        self.iccp_group_id = value
                        self.iccp_group_id.value_namespace = name_space
                        self.iccp_group_id.value_namespace_prefix = name_space_prefix
                    if(value_path == "system-mac-address"):
                        self.system_mac_address = value
                        self.system_mac_address.value_namespace = name_space
                        self.system_mac_address.value_namespace_prefix = name_space_prefix
                    if(value_path == "system-priority"):
                        self.system_priority = value
                        self.system_priority.value_namespace = name_space
                        self.system_priority.value_namespace_prefix = name_space_prefix

            def has_data(self):
                return (self.system_id_global_item is not None and self.system_id_global_item.has_data())

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    (self.system_id_global_item is not None and self.system_id_global_item.has_operation()))

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "system-id-global" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-bundlemgr-oper:bundle-information/system-id/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "system-id-global-item"):
                    if (self.system_id_global_item is None):
                        self.system_id_global_item = BundleInformation.SystemId.SystemIdGlobal.SystemIdGlobalItem()
                        self.system_id_global_item.parent = self
                        self._children_name_map["system_id_global_item"] = "system-id-global-item"
                    return self.system_id_global_item

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "system-id-global-item"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                pass


        class SystemIdIccpGroups(Entity):
            """
            System Identifiers for all ICCP Groups
            
            .. attribute:: system_id_iccp_group
            
            	ICCP Group ID
            	**type**\: list of    :py:class:`SystemIdIccpGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.SystemId.SystemIdIccpGroups.SystemIdIccpGroup>`
            
            

            """

            _prefix = 'bundlemgr-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(BundleInformation.SystemId.SystemIdIccpGroups, self).__init__()

                self.yang_name = "system-id-iccp-groups"
                self.yang_parent_name = "system-id"

                self.system_id_iccp_group = YList(self)

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in () and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(BundleInformation.SystemId.SystemIdIccpGroups, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(BundleInformation.SystemId.SystemIdIccpGroups, self).__setattr__(name, value)


            class SystemIdIccpGroup(Entity):
                """
                ICCP Group ID
                
                .. attribute:: iccp_group  <key>
                
                	ICCP Group ID
                	**type**\:  int
                
                	**range:** 1..4294967295
                
                .. attribute:: system_id_iccp_group_item
                
                	Data for this item
                	**type**\:   :py:class:`SystemIdIccpGroupItem <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.SystemId.SystemIdIccpGroups.SystemIdIccpGroup.SystemIdIccpGroupItem>`
                
                

                """

                _prefix = 'bundlemgr-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(BundleInformation.SystemId.SystemIdIccpGroups.SystemIdIccpGroup, self).__init__()

                    self.yang_name = "system-id-iccp-group"
                    self.yang_parent_name = "system-id-iccp-groups"

                    self.iccp_group = YLeaf(YType.uint32, "iccp-group")

                    self.system_id_iccp_group_item = BundleInformation.SystemId.SystemIdIccpGroups.SystemIdIccpGroup.SystemIdIccpGroupItem()
                    self.system_id_iccp_group_item.parent = self
                    self._children_name_map["system_id_iccp_group_item"] = "system-id-iccp-group-item"
                    self._children_yang_names.add("system-id-iccp-group-item")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("iccp_group") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(BundleInformation.SystemId.SystemIdIccpGroups.SystemIdIccpGroup, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(BundleInformation.SystemId.SystemIdIccpGroups.SystemIdIccpGroup, self).__setattr__(name, value)


                class SystemIdIccpGroupItem(Entity):
                    """
                    Data for this item
                    
                    .. attribute:: iccp_group_id
                    
                    	ICCP Group that the system ID is for
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: system_id
                    
                    	System ID
                    	**type**\:   :py:class:`SystemId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.SystemId.SystemIdIccpGroups.SystemIdIccpGroup.SystemIdIccpGroupItem.SystemId>`
                    
                    .. attribute:: system_mac_address
                    
                    	MAC Address used to identify the system (deprecated)
                    	**type**\:  str
                    
                    	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                    
                    .. attribute:: system_priority
                    
                    	Priority of the system (deprecated)
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'bundlemgr-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(BundleInformation.SystemId.SystemIdIccpGroups.SystemIdIccpGroup.SystemIdIccpGroupItem, self).__init__()

                        self.yang_name = "system-id-iccp-group-item"
                        self.yang_parent_name = "system-id-iccp-group"

                        self.iccp_group_id = YLeaf(YType.uint32, "iccp-group-id")

                        self.system_mac_address = YLeaf(YType.str, "system-mac-address")

                        self.system_priority = YLeaf(YType.uint16, "system-priority")

                        self.system_id = BundleInformation.SystemId.SystemIdIccpGroups.SystemIdIccpGroup.SystemIdIccpGroupItem.SystemId()
                        self.system_id.parent = self
                        self._children_name_map["system_id"] = "system-id"
                        self._children_yang_names.add("system-id")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("iccp_group_id",
                                        "system_mac_address",
                                        "system_priority") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(BundleInformation.SystemId.SystemIdIccpGroups.SystemIdIccpGroup.SystemIdIccpGroupItem, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(BundleInformation.SystemId.SystemIdIccpGroups.SystemIdIccpGroup.SystemIdIccpGroupItem, self).__setattr__(name, value)


                    class SystemId(Entity):
                        """
                        System ID
                        
                        .. attribute:: system_mac_addr
                        
                        	MAC Address used to identify the system
                        	**type**\:   :py:class:`SystemMacAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.SystemId.SystemIdIccpGroups.SystemIdIccpGroup.SystemIdIccpGroupItem.SystemId.SystemMacAddr>`
                        
                        .. attribute:: system_prio
                        
                        	Priority of the system
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'bundlemgr-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(BundleInformation.SystemId.SystemIdIccpGroups.SystemIdIccpGroup.SystemIdIccpGroupItem.SystemId, self).__init__()

                            self.yang_name = "system-id"
                            self.yang_parent_name = "system-id-iccp-group-item"

                            self.system_prio = YLeaf(YType.uint16, "system-prio")

                            self.system_mac_addr = BundleInformation.SystemId.SystemIdIccpGroups.SystemIdIccpGroup.SystemIdIccpGroupItem.SystemId.SystemMacAddr()
                            self.system_mac_addr.parent = self
                            self._children_name_map["system_mac_addr"] = "system-mac-addr"
                            self._children_yang_names.add("system-mac-addr")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("system_prio") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(BundleInformation.SystemId.SystemIdIccpGroups.SystemIdIccpGroup.SystemIdIccpGroupItem.SystemId, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(BundleInformation.SystemId.SystemIdIccpGroups.SystemIdIccpGroup.SystemIdIccpGroupItem.SystemId, self).__setattr__(name, value)


                        class SystemMacAddr(Entity):
                            """
                            MAC Address used to identify the system
                            
                            .. attribute:: macaddr
                            
                            	macaddr
                            	**type**\:  str
                            
                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                            
                            

                            """

                            _prefix = 'bundlemgr-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(BundleInformation.SystemId.SystemIdIccpGroups.SystemIdIccpGroup.SystemIdIccpGroupItem.SystemId.SystemMacAddr, self).__init__()

                                self.yang_name = "system-mac-addr"
                                self.yang_parent_name = "system-id"

                                self.macaddr = YLeaf(YType.str, "macaddr")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("macaddr") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(BundleInformation.SystemId.SystemIdIccpGroups.SystemIdIccpGroup.SystemIdIccpGroupItem.SystemId.SystemMacAddr, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(BundleInformation.SystemId.SystemIdIccpGroups.SystemIdIccpGroup.SystemIdIccpGroupItem.SystemId.SystemMacAddr, self).__setattr__(name, value)

                            def has_data(self):
                                return self.macaddr.is_set

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.macaddr.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "system-mac-addr" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.macaddr.is_set or self.macaddr.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.macaddr.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "macaddr"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "macaddr"):
                                    self.macaddr = value
                                    self.macaddr.value_namespace = name_space
                                    self.macaddr.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.system_prio.is_set or
                                (self.system_mac_addr is not None and self.system_mac_addr.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.system_prio.yfilter != YFilter.not_set or
                                (self.system_mac_addr is not None and self.system_mac_addr.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "system-id" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.system_prio.is_set or self.system_prio.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.system_prio.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "system-mac-addr"):
                                if (self.system_mac_addr is None):
                                    self.system_mac_addr = BundleInformation.SystemId.SystemIdIccpGroups.SystemIdIccpGroup.SystemIdIccpGroupItem.SystemId.SystemMacAddr()
                                    self.system_mac_addr.parent = self
                                    self._children_name_map["system_mac_addr"] = "system-mac-addr"
                                return self.system_mac_addr

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "system-mac-addr" or name == "system-prio"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "system-prio"):
                                self.system_prio = value
                                self.system_prio.value_namespace = name_space
                                self.system_prio.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.iccp_group_id.is_set or
                            self.system_mac_address.is_set or
                            self.system_priority.is_set or
                            (self.system_id is not None and self.system_id.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.iccp_group_id.yfilter != YFilter.not_set or
                            self.system_mac_address.yfilter != YFilter.not_set or
                            self.system_priority.yfilter != YFilter.not_set or
                            (self.system_id is not None and self.system_id.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "system-id-iccp-group-item" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.iccp_group_id.is_set or self.iccp_group_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.iccp_group_id.get_name_leafdata())
                        if (self.system_mac_address.is_set or self.system_mac_address.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.system_mac_address.get_name_leafdata())
                        if (self.system_priority.is_set or self.system_priority.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.system_priority.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "system-id"):
                            if (self.system_id is None):
                                self.system_id = BundleInformation.SystemId.SystemIdIccpGroups.SystemIdIccpGroup.SystemIdIccpGroupItem.SystemId()
                                self.system_id.parent = self
                                self._children_name_map["system_id"] = "system-id"
                            return self.system_id

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "system-id" or name == "iccp-group-id" or name == "system-mac-address" or name == "system-priority"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "iccp-group-id"):
                            self.iccp_group_id = value
                            self.iccp_group_id.value_namespace = name_space
                            self.iccp_group_id.value_namespace_prefix = name_space_prefix
                        if(value_path == "system-mac-address"):
                            self.system_mac_address = value
                            self.system_mac_address.value_namespace = name_space
                            self.system_mac_address.value_namespace_prefix = name_space_prefix
                        if(value_path == "system-priority"):
                            self.system_priority = value
                            self.system_priority.value_namespace = name_space
                            self.system_priority.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    return (
                        self.iccp_group.is_set or
                        (self.system_id_iccp_group_item is not None and self.system_id_iccp_group_item.has_data()))

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.iccp_group.yfilter != YFilter.not_set or
                        (self.system_id_iccp_group_item is not None and self.system_id_iccp_group_item.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "system-id-iccp-group" + "[iccp-group='" + self.iccp_group.get() + "']" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-bundlemgr-oper:bundle-information/system-id/system-id-iccp-groups/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.iccp_group.is_set or self.iccp_group.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.iccp_group.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "system-id-iccp-group-item"):
                        if (self.system_id_iccp_group_item is None):
                            self.system_id_iccp_group_item = BundleInformation.SystemId.SystemIdIccpGroups.SystemIdIccpGroup.SystemIdIccpGroupItem()
                            self.system_id_iccp_group_item.parent = self
                            self._children_name_map["system_id_iccp_group_item"] = "system-id-iccp-group-item"
                        return self.system_id_iccp_group_item

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "system-id-iccp-group-item" or name == "iccp-group"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "iccp-group"):
                        self.iccp_group = value
                        self.iccp_group.value_namespace = name_space
                        self.iccp_group.value_namespace_prefix = name_space_prefix

            def has_data(self):
                for c in self.system_id_iccp_group:
                    if (c.has_data()):
                        return True
                return False

            def has_operation(self):
                for c in self.system_id_iccp_group:
                    if (c.has_operation()):
                        return True
                return self.yfilter != YFilter.not_set

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "system-id-iccp-groups" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-bundlemgr-oper:bundle-information/system-id/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "system-id-iccp-group"):
                    for c in self.system_id_iccp_group:
                        segment = c.get_segment_path()
                        if (segment_path == segment):
                            return c
                    c = BundleInformation.SystemId.SystemIdIccpGroups.SystemIdIccpGroup()
                    c.parent = self
                    local_reference_key = "ydk::seg::%s" % segment_path
                    self._local_refs[local_reference_key] = c
                    self.system_id_iccp_group.append(c)
                    return c

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "system-id-iccp-group"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                pass

        def has_data(self):
            return (
                (self.system_id_global is not None and self.system_id_global.has_data()) or
                (self.system_id_iccp_groups is not None and self.system_id_iccp_groups.has_data()))

        def has_operation(self):
            return (
                self.yfilter != YFilter.not_set or
                (self.system_id_global is not None and self.system_id_global.has_operation()) or
                (self.system_id_iccp_groups is not None and self.system_id_iccp_groups.has_operation()))

        def get_segment_path(self):
            path_buffer = ""
            path_buffer = "system-id" + path_buffer

            return path_buffer

        def get_entity_path(self, ancestor):
            path_buffer = ""
            if (ancestor is None):
                path_buffer = "Cisco-IOS-XR-bundlemgr-oper:bundle-information/%s" % self.get_segment_path()
            else:
                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

            leaf_name_data = LeafDataList()

            entity_path = EntityPath(path_buffer, leaf_name_data)
            return entity_path

        def get_child_by_name(self, child_yang_name, segment_path):
            child = self._get_child_by_seg_name([child_yang_name, segment_path])
            if child is not None:
                return child

            if (child_yang_name == "system-id-global"):
                if (self.system_id_global is None):
                    self.system_id_global = BundleInformation.SystemId.SystemIdGlobal()
                    self.system_id_global.parent = self
                    self._children_name_map["system_id_global"] = "system-id-global"
                return self.system_id_global

            if (child_yang_name == "system-id-iccp-groups"):
                if (self.system_id_iccp_groups is None):
                    self.system_id_iccp_groups = BundleInformation.SystemId.SystemIdIccpGroups()
                    self.system_id_iccp_groups.parent = self
                    self._children_name_map["system_id_iccp_groups"] = "system-id-iccp-groups"
                return self.system_id_iccp_groups

            return None

        def has_leaf_or_child_of_name(self, name):
            if(name == "system-id-global" or name == "system-id-iccp-groups"):
                return True
            return False

        def set_value(self, value_path, value, name_space, name_space_prefix):
            pass


    class MlacpMemberCounters(Entity):
        """
        Member specific counters of mLACP events
        
        .. attribute:: bundles
        
        	Bundle interfaces with counters of their member's mLACP events
        	**type**\:   :py:class:`Bundles <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.MlacpMemberCounters.Bundles>`
        
        .. attribute:: iccp_groups
        
        	ICCP Groups with counters of their member's mLACP events
        	**type**\:   :py:class:`IccpGroups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.MlacpMemberCounters.IccpGroups>`
        
        .. attribute:: members
        
        	Member interfaces with counters of mLACP events
        	**type**\:   :py:class:`Members <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.MlacpMemberCounters.Members>`
        
        .. attribute:: nodes
        
        	Devices with counters of their member's mLACP events
        	**type**\:   :py:class:`Nodes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.MlacpMemberCounters.Nodes>`
        
        

        """

        _prefix = 'bundlemgr-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(BundleInformation.MlacpMemberCounters, self).__init__()

            self.yang_name = "mlacp-member-counters"
            self.yang_parent_name = "bundle-information"

            self.bundles = BundleInformation.MlacpMemberCounters.Bundles()
            self.bundles.parent = self
            self._children_name_map["bundles"] = "bundles"
            self._children_yang_names.add("bundles")

            self.iccp_groups = BundleInformation.MlacpMemberCounters.IccpGroups()
            self.iccp_groups.parent = self
            self._children_name_map["iccp_groups"] = "iccp-groups"
            self._children_yang_names.add("iccp-groups")

            self.members = BundleInformation.MlacpMemberCounters.Members()
            self.members.parent = self
            self._children_name_map["members"] = "members"
            self._children_yang_names.add("members")

            self.nodes = BundleInformation.MlacpMemberCounters.Nodes()
            self.nodes.parent = self
            self._children_name_map["nodes"] = "nodes"
            self._children_yang_names.add("nodes")


        class IccpGroups(Entity):
            """
            ICCP Groups with counters of their member's
            mLACP events
            
            .. attribute:: iccp_group
            
            	ICCP Group ID
            	**type**\: list of    :py:class:`IccpGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.MlacpMemberCounters.IccpGroups.IccpGroup>`
            
            

            """

            _prefix = 'bundlemgr-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(BundleInformation.MlacpMemberCounters.IccpGroups, self).__init__()

                self.yang_name = "iccp-groups"
                self.yang_parent_name = "mlacp-member-counters"

                self.iccp_group = YList(self)

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in () and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(BundleInformation.MlacpMemberCounters.IccpGroups, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(BundleInformation.MlacpMemberCounters.IccpGroups, self).__setattr__(name, value)


            class IccpGroup(Entity):
                """
                ICCP Group ID
                
                .. attribute:: iccp_group  <key>
                
                	ICCP Group ID
                	**type**\:  int
                
                	**range:** 1..4294967295
                
                .. attribute:: iccp_group_item
                
                	Data for this item and all its members
                	**type**\:   :py:class:`IccpGroupItem <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.MlacpMemberCounters.IccpGroups.IccpGroup.IccpGroupItem>`
                
                

                """

                _prefix = 'bundlemgr-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(BundleInformation.MlacpMemberCounters.IccpGroups.IccpGroup, self).__init__()

                    self.yang_name = "iccp-group"
                    self.yang_parent_name = "iccp-groups"

                    self.iccp_group = YLeaf(YType.uint32, "iccp-group")

                    self.iccp_group_item = BundleInformation.MlacpMemberCounters.IccpGroups.IccpGroup.IccpGroupItem()
                    self.iccp_group_item.parent = self
                    self._children_name_map["iccp_group_item"] = "iccp-group-item"
                    self._children_yang_names.add("iccp-group-item")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("iccp_group") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(BundleInformation.MlacpMemberCounters.IccpGroups.IccpGroup, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(BundleInformation.MlacpMemberCounters.IccpGroups.IccpGroup, self).__setattr__(name, value)


                class IccpGroupItem(Entity):
                    """
                    Data for this item and all its members
                    
                    .. attribute:: items
                    
                    	mLACP counter information items
                    	**type**\: list of    :py:class:`Items <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.MlacpMemberCounters.IccpGroups.IccpGroup.IccpGroupItem.Items>`
                    
                    

                    """

                    _prefix = 'bundlemgr-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(BundleInformation.MlacpMemberCounters.IccpGroups.IccpGroup.IccpGroupItem, self).__init__()

                        self.yang_name = "iccp-group-item"
                        self.yang_parent_name = "iccp-group"

                        self.items = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(BundleInformation.MlacpMemberCounters.IccpGroups.IccpGroup.IccpGroupItem, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(BundleInformation.MlacpMemberCounters.IccpGroups.IccpGroup.IccpGroupItem, self).__setattr__(name, value)


                    class Items(Entity):
                        """
                        mLACP counter information items
                        
                        .. attribute:: bundle_data
                        
                        	Bundle mLACP TLV counter information
                        	**type**\:   :py:class:`BundleData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.MlacpMemberCounters.IccpGroups.IccpGroup.IccpGroupItem.Items.BundleData>`
                        
                        .. attribute:: member_data
                        
                        	Local member mLACP TLV counter information
                        	**type**\: list of    :py:class:`MemberData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.MlacpMemberCounters.IccpGroups.IccpGroup.IccpGroupItem.Items.MemberData>`
                        
                        .. attribute:: node_data
                        
                        	Peer device mLACP TLV counter information
                        	**type**\: list of    :py:class:`NodeData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.MlacpMemberCounters.IccpGroups.IccpGroup.IccpGroupItem.Items.NodeData>`
                        
                        

                        """

                        _prefix = 'bundlemgr-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(BundleInformation.MlacpMemberCounters.IccpGroups.IccpGroup.IccpGroupItem.Items, self).__init__()

                            self.yang_name = "items"
                            self.yang_parent_name = "iccp-group-item"

                            self.bundle_data = BundleInformation.MlacpMemberCounters.IccpGroups.IccpGroup.IccpGroupItem.Items.BundleData()
                            self.bundle_data.parent = self
                            self._children_name_map["bundle_data"] = "bundle-data"
                            self._children_yang_names.add("bundle-data")

                            self.member_data = YList(self)
                            self.node_data = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(BundleInformation.MlacpMemberCounters.IccpGroups.IccpGroup.IccpGroupItem.Items, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(BundleInformation.MlacpMemberCounters.IccpGroups.IccpGroup.IccpGroupItem.Items, self).__setattr__(name, value)


                        class BundleData(Entity):
                            """
                            Bundle mLACP TLV counter information
                            
                            .. attribute:: bundle_name
                            
                            	Name of the bundle
                            	**type**\:  str
                            
                            .. attribute:: iccp_group_id
                            
                            	ICCP Group ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: mlacp_sync_requests_on_all_local_ports
                            
                            	Counts of mLACP sync request TLVs on all ports
                            	**type**\:   :py:class:`MlacpSyncRequestsOnAllLocalPorts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.MlacpMemberCounters.IccpGroups.IccpGroup.IccpGroupItem.Items.BundleData.MlacpSyncRequestsOnAllLocalPorts>`
                            
                            

                            """

                            _prefix = 'bundlemgr-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(BundleInformation.MlacpMemberCounters.IccpGroups.IccpGroup.IccpGroupItem.Items.BundleData, self).__init__()

                                self.yang_name = "bundle-data"
                                self.yang_parent_name = "items"

                                self.bundle_name = YLeaf(YType.str, "bundle-name")

                                self.iccp_group_id = YLeaf(YType.uint32, "iccp-group-id")

                                self.mlacp_sync_requests_on_all_local_ports = BundleInformation.MlacpMemberCounters.IccpGroups.IccpGroup.IccpGroupItem.Items.BundleData.MlacpSyncRequestsOnAllLocalPorts()
                                self.mlacp_sync_requests_on_all_local_ports.parent = self
                                self._children_name_map["mlacp_sync_requests_on_all_local_ports"] = "mlacp-sync-requests-on-all-local-ports"
                                self._children_yang_names.add("mlacp-sync-requests-on-all-local-ports")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("bundle_name",
                                                "iccp_group_id") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(BundleInformation.MlacpMemberCounters.IccpGroups.IccpGroup.IccpGroupItem.Items.BundleData, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(BundleInformation.MlacpMemberCounters.IccpGroups.IccpGroup.IccpGroupItem.Items.BundleData, self).__setattr__(name, value)


                            class MlacpSyncRequestsOnAllLocalPorts(Entity):
                                """
                                Counts of mLACP sync request TLVs on all ports
                                
                                .. attribute:: last_time_cleared
                                
                                	Time in nsecs from boot when counters were last cleared (deprecated)
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: nanosecond
                                
                                .. attribute:: received_sync_requests
                                
                                	Number of mLACP sync request TLVs received
                                	**type**\:   :py:class:`ReceivedSyncRequests <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.MlacpMemberCounters.IccpGroups.IccpGroup.IccpGroupItem.Items.BundleData.MlacpSyncRequestsOnAllLocalPorts.ReceivedSyncRequests>`
                                
                                .. attribute:: time_since_cleared
                                
                                	Elapsed time in nsecs since counters were last cleared
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: nanosecond
                                
                                

                                """

                                _prefix = 'bundlemgr-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(BundleInformation.MlacpMemberCounters.IccpGroups.IccpGroup.IccpGroupItem.Items.BundleData.MlacpSyncRequestsOnAllLocalPorts, self).__init__()

                                    self.yang_name = "mlacp-sync-requests-on-all-local-ports"
                                    self.yang_parent_name = "bundle-data"

                                    self.last_time_cleared = YLeaf(YType.uint64, "last-time-cleared")

                                    self.time_since_cleared = YLeaf(YType.uint64, "time-since-cleared")

                                    self.received_sync_requests = BundleInformation.MlacpMemberCounters.IccpGroups.IccpGroup.IccpGroupItem.Items.BundleData.MlacpSyncRequestsOnAllLocalPorts.ReceivedSyncRequests()
                                    self.received_sync_requests.parent = self
                                    self._children_name_map["received_sync_requests"] = "received-sync-requests"
                                    self._children_yang_names.add("received-sync-requests")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("last_time_cleared",
                                                    "time_since_cleared") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(BundleInformation.MlacpMemberCounters.IccpGroups.IccpGroup.IccpGroupItem.Items.BundleData.MlacpSyncRequestsOnAllLocalPorts, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(BundleInformation.MlacpMemberCounters.IccpGroups.IccpGroup.IccpGroupItem.Items.BundleData.MlacpSyncRequestsOnAllLocalPorts, self).__setattr__(name, value)


                                class ReceivedSyncRequests(Entity):
                                    """
                                    Number of mLACP sync request TLVs received
                                    
                                    .. attribute:: all_syncs
                                    
                                    	Total number of sync requests received
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: config_syncs
                                    
                                    	Number of config sync requests received
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: state_syncs
                                    
                                    	Number of state sync requests received
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'bundlemgr-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(BundleInformation.MlacpMemberCounters.IccpGroups.IccpGroup.IccpGroupItem.Items.BundleData.MlacpSyncRequestsOnAllLocalPorts.ReceivedSyncRequests, self).__init__()

                                        self.yang_name = "received-sync-requests"
                                        self.yang_parent_name = "mlacp-sync-requests-on-all-local-ports"

                                        self.all_syncs = YLeaf(YType.uint32, "all-syncs")

                                        self.config_syncs = YLeaf(YType.uint32, "config-syncs")

                                        self.state_syncs = YLeaf(YType.uint32, "state-syncs")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("all_syncs",
                                                        "config_syncs",
                                                        "state_syncs") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(BundleInformation.MlacpMemberCounters.IccpGroups.IccpGroup.IccpGroupItem.Items.BundleData.MlacpSyncRequestsOnAllLocalPorts.ReceivedSyncRequests, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(BundleInformation.MlacpMemberCounters.IccpGroups.IccpGroup.IccpGroupItem.Items.BundleData.MlacpSyncRequestsOnAllLocalPorts.ReceivedSyncRequests, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.all_syncs.is_set or
                                            self.config_syncs.is_set or
                                            self.state_syncs.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.all_syncs.yfilter != YFilter.not_set or
                                            self.config_syncs.yfilter != YFilter.not_set or
                                            self.state_syncs.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "received-sync-requests" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.all_syncs.is_set or self.all_syncs.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.all_syncs.get_name_leafdata())
                                        if (self.config_syncs.is_set or self.config_syncs.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.config_syncs.get_name_leafdata())
                                        if (self.state_syncs.is_set or self.state_syncs.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.state_syncs.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "all-syncs" or name == "config-syncs" or name == "state-syncs"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "all-syncs"):
                                            self.all_syncs = value
                                            self.all_syncs.value_namespace = name_space
                                            self.all_syncs.value_namespace_prefix = name_space_prefix
                                        if(value_path == "config-syncs"):
                                            self.config_syncs = value
                                            self.config_syncs.value_namespace = name_space
                                            self.config_syncs.value_namespace_prefix = name_space_prefix
                                        if(value_path == "state-syncs"):
                                            self.state_syncs = value
                                            self.state_syncs.value_namespace = name_space
                                            self.state_syncs.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.last_time_cleared.is_set or
                                        self.time_since_cleared.is_set or
                                        (self.received_sync_requests is not None and self.received_sync_requests.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.last_time_cleared.yfilter != YFilter.not_set or
                                        self.time_since_cleared.yfilter != YFilter.not_set or
                                        (self.received_sync_requests is not None and self.received_sync_requests.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "mlacp-sync-requests-on-all-local-ports" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.last_time_cleared.is_set or self.last_time_cleared.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.last_time_cleared.get_name_leafdata())
                                    if (self.time_since_cleared.is_set or self.time_since_cleared.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.time_since_cleared.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "received-sync-requests"):
                                        if (self.received_sync_requests is None):
                                            self.received_sync_requests = BundleInformation.MlacpMemberCounters.IccpGroups.IccpGroup.IccpGroupItem.Items.BundleData.MlacpSyncRequestsOnAllLocalPorts.ReceivedSyncRequests()
                                            self.received_sync_requests.parent = self
                                            self._children_name_map["received_sync_requests"] = "received-sync-requests"
                                        return self.received_sync_requests

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "received-sync-requests" or name == "last-time-cleared" or name == "time-since-cleared"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "last-time-cleared"):
                                        self.last_time_cleared = value
                                        self.last_time_cleared.value_namespace = name_space
                                        self.last_time_cleared.value_namespace_prefix = name_space_prefix
                                    if(value_path == "time-since-cleared"):
                                        self.time_since_cleared = value
                                        self.time_since_cleared.value_namespace = name_space
                                        self.time_since_cleared.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.bundle_name.is_set or
                                    self.iccp_group_id.is_set or
                                    (self.mlacp_sync_requests_on_all_local_ports is not None and self.mlacp_sync_requests_on_all_local_ports.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.bundle_name.yfilter != YFilter.not_set or
                                    self.iccp_group_id.yfilter != YFilter.not_set or
                                    (self.mlacp_sync_requests_on_all_local_ports is not None and self.mlacp_sync_requests_on_all_local_ports.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "bundle-data" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.bundle_name.is_set or self.bundle_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.bundle_name.get_name_leafdata())
                                if (self.iccp_group_id.is_set or self.iccp_group_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.iccp_group_id.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "mlacp-sync-requests-on-all-local-ports"):
                                    if (self.mlacp_sync_requests_on_all_local_ports is None):
                                        self.mlacp_sync_requests_on_all_local_ports = BundleInformation.MlacpMemberCounters.IccpGroups.IccpGroup.IccpGroupItem.Items.BundleData.MlacpSyncRequestsOnAllLocalPorts()
                                        self.mlacp_sync_requests_on_all_local_ports.parent = self
                                        self._children_name_map["mlacp_sync_requests_on_all_local_ports"] = "mlacp-sync-requests-on-all-local-ports"
                                    return self.mlacp_sync_requests_on_all_local_ports

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "mlacp-sync-requests-on-all-local-ports" or name == "bundle-name" or name == "iccp-group-id"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "bundle-name"):
                                    self.bundle_name = value
                                    self.bundle_name.value_namespace = name_space
                                    self.bundle_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "iccp-group-id"):
                                    self.iccp_group_id = value
                                    self.iccp_group_id.value_namespace = name_space
                                    self.iccp_group_id.value_namespace_prefix = name_space_prefix


                        class NodeData(Entity):
                            """
                            Peer device mLACP TLV counter information
                            
                            .. attribute:: member_data
                            
                            	Member mLACP TLV counter information
                            	**type**\: list of    :py:class:`MemberData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.MlacpMemberCounters.IccpGroups.IccpGroup.IccpGroupItem.Items.NodeData.MemberData>`
                            
                            .. attribute:: mlacp_sync_requests_on_all_foreign_ports
                            
                            	Counts of mLACP sync request TLVs on all ports
                            	**type**\:   :py:class:`MlacpSyncRequestsOnAllForeignPorts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.MlacpMemberCounters.IccpGroups.IccpGroup.IccpGroupItem.Items.NodeData.MlacpSyncRequestsOnAllForeignPorts>`
                            
                            .. attribute:: node_data
                            
                            	Peer device mLACP TLV counter information
                            	**type**\:   :py:class:`NodeData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.MlacpMemberCounters.IccpGroups.IccpGroup.IccpGroupItem.Items.NodeData.NodeData>`
                            
                            

                            """

                            _prefix = 'bundlemgr-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(BundleInformation.MlacpMemberCounters.IccpGroups.IccpGroup.IccpGroupItem.Items.NodeData, self).__init__()

                                self.yang_name = "node-data"
                                self.yang_parent_name = "items"

                                self.mlacp_sync_requests_on_all_foreign_ports = BundleInformation.MlacpMemberCounters.IccpGroups.IccpGroup.IccpGroupItem.Items.NodeData.MlacpSyncRequestsOnAllForeignPorts()
                                self.mlacp_sync_requests_on_all_foreign_ports.parent = self
                                self._children_name_map["mlacp_sync_requests_on_all_foreign_ports"] = "mlacp-sync-requests-on-all-foreign-ports"
                                self._children_yang_names.add("mlacp-sync-requests-on-all-foreign-ports")

                                self.node_data = BundleInformation.MlacpMemberCounters.IccpGroups.IccpGroup.IccpGroupItem.Items.NodeData.NodeData()
                                self.node_data.parent = self
                                self._children_name_map["node_data"] = "node-data"
                                self._children_yang_names.add("node-data")

                                self.member_data = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in () and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(BundleInformation.MlacpMemberCounters.IccpGroups.IccpGroup.IccpGroupItem.Items.NodeData, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(BundleInformation.MlacpMemberCounters.IccpGroups.IccpGroup.IccpGroupItem.Items.NodeData, self).__setattr__(name, value)


                            class NodeData(Entity):
                                """
                                Peer device mLACP TLV counter information
                                
                                .. attribute:: iccp_group_id
                                
                                	ICCP Group ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: node_id
                                
                                	Device ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'bundlemgr-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(BundleInformation.MlacpMemberCounters.IccpGroups.IccpGroup.IccpGroupItem.Items.NodeData.NodeData, self).__init__()

                                    self.yang_name = "node-data"
                                    self.yang_parent_name = "node-data"

                                    self.iccp_group_id = YLeaf(YType.uint32, "iccp-group-id")

                                    self.node_id = YLeaf(YType.uint32, "node-id")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("iccp_group_id",
                                                    "node_id") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(BundleInformation.MlacpMemberCounters.IccpGroups.IccpGroup.IccpGroupItem.Items.NodeData.NodeData, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(BundleInformation.MlacpMemberCounters.IccpGroups.IccpGroup.IccpGroupItem.Items.NodeData.NodeData, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.iccp_group_id.is_set or
                                        self.node_id.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.iccp_group_id.yfilter != YFilter.not_set or
                                        self.node_id.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "node-data" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.iccp_group_id.is_set or self.iccp_group_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.iccp_group_id.get_name_leafdata())
                                    if (self.node_id.is_set or self.node_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.node_id.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "iccp-group-id" or name == "node-id"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "iccp-group-id"):
                                        self.iccp_group_id = value
                                        self.iccp_group_id.value_namespace = name_space
                                        self.iccp_group_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "node-id"):
                                        self.node_id = value
                                        self.node_id.value_namespace = name_space
                                        self.node_id.value_namespace_prefix = name_space_prefix


                            class MlacpSyncRequestsOnAllForeignPorts(Entity):
                                """
                                Counts of mLACP sync request TLVs on all ports
                                
                                .. attribute:: last_time_cleared
                                
                                	Time in nsecs from boot when counters were last cleared (deprecated)
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: nanosecond
                                
                                .. attribute:: received_sync_requests
                                
                                	Number of mLACP sync request TLVs received
                                	**type**\:   :py:class:`ReceivedSyncRequests <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.MlacpMemberCounters.IccpGroups.IccpGroup.IccpGroupItem.Items.NodeData.MlacpSyncRequestsOnAllForeignPorts.ReceivedSyncRequests>`
                                
                                .. attribute:: time_since_cleared
                                
                                	Elapsed time in nsecs since counters were last cleared
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: nanosecond
                                
                                

                                """

                                _prefix = 'bundlemgr-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(BundleInformation.MlacpMemberCounters.IccpGroups.IccpGroup.IccpGroupItem.Items.NodeData.MlacpSyncRequestsOnAllForeignPorts, self).__init__()

                                    self.yang_name = "mlacp-sync-requests-on-all-foreign-ports"
                                    self.yang_parent_name = "node-data"

                                    self.last_time_cleared = YLeaf(YType.uint64, "last-time-cleared")

                                    self.time_since_cleared = YLeaf(YType.uint64, "time-since-cleared")

                                    self.received_sync_requests = BundleInformation.MlacpMemberCounters.IccpGroups.IccpGroup.IccpGroupItem.Items.NodeData.MlacpSyncRequestsOnAllForeignPorts.ReceivedSyncRequests()
                                    self.received_sync_requests.parent = self
                                    self._children_name_map["received_sync_requests"] = "received-sync-requests"
                                    self._children_yang_names.add("received-sync-requests")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("last_time_cleared",
                                                    "time_since_cleared") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(BundleInformation.MlacpMemberCounters.IccpGroups.IccpGroup.IccpGroupItem.Items.NodeData.MlacpSyncRequestsOnAllForeignPorts, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(BundleInformation.MlacpMemberCounters.IccpGroups.IccpGroup.IccpGroupItem.Items.NodeData.MlacpSyncRequestsOnAllForeignPorts, self).__setattr__(name, value)


                                class ReceivedSyncRequests(Entity):
                                    """
                                    Number of mLACP sync request TLVs received
                                    
                                    .. attribute:: all_syncs
                                    
                                    	Total number of sync requests received
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: config_syncs
                                    
                                    	Number of config sync requests received
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: state_syncs
                                    
                                    	Number of state sync requests received
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'bundlemgr-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(BundleInformation.MlacpMemberCounters.IccpGroups.IccpGroup.IccpGroupItem.Items.NodeData.MlacpSyncRequestsOnAllForeignPorts.ReceivedSyncRequests, self).__init__()

                                        self.yang_name = "received-sync-requests"
                                        self.yang_parent_name = "mlacp-sync-requests-on-all-foreign-ports"

                                        self.all_syncs = YLeaf(YType.uint32, "all-syncs")

                                        self.config_syncs = YLeaf(YType.uint32, "config-syncs")

                                        self.state_syncs = YLeaf(YType.uint32, "state-syncs")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("all_syncs",
                                                        "config_syncs",
                                                        "state_syncs") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(BundleInformation.MlacpMemberCounters.IccpGroups.IccpGroup.IccpGroupItem.Items.NodeData.MlacpSyncRequestsOnAllForeignPorts.ReceivedSyncRequests, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(BundleInformation.MlacpMemberCounters.IccpGroups.IccpGroup.IccpGroupItem.Items.NodeData.MlacpSyncRequestsOnAllForeignPorts.ReceivedSyncRequests, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.all_syncs.is_set or
                                            self.config_syncs.is_set or
                                            self.state_syncs.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.all_syncs.yfilter != YFilter.not_set or
                                            self.config_syncs.yfilter != YFilter.not_set or
                                            self.state_syncs.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "received-sync-requests" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.all_syncs.is_set or self.all_syncs.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.all_syncs.get_name_leafdata())
                                        if (self.config_syncs.is_set or self.config_syncs.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.config_syncs.get_name_leafdata())
                                        if (self.state_syncs.is_set or self.state_syncs.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.state_syncs.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "all-syncs" or name == "config-syncs" or name == "state-syncs"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "all-syncs"):
                                            self.all_syncs = value
                                            self.all_syncs.value_namespace = name_space
                                            self.all_syncs.value_namespace_prefix = name_space_prefix
                                        if(value_path == "config-syncs"):
                                            self.config_syncs = value
                                            self.config_syncs.value_namespace = name_space
                                            self.config_syncs.value_namespace_prefix = name_space_prefix
                                        if(value_path == "state-syncs"):
                                            self.state_syncs = value
                                            self.state_syncs.value_namespace = name_space
                                            self.state_syncs.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.last_time_cleared.is_set or
                                        self.time_since_cleared.is_set or
                                        (self.received_sync_requests is not None and self.received_sync_requests.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.last_time_cleared.yfilter != YFilter.not_set or
                                        self.time_since_cleared.yfilter != YFilter.not_set or
                                        (self.received_sync_requests is not None and self.received_sync_requests.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "mlacp-sync-requests-on-all-foreign-ports" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.last_time_cleared.is_set or self.last_time_cleared.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.last_time_cleared.get_name_leafdata())
                                    if (self.time_since_cleared.is_set or self.time_since_cleared.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.time_since_cleared.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "received-sync-requests"):
                                        if (self.received_sync_requests is None):
                                            self.received_sync_requests = BundleInformation.MlacpMemberCounters.IccpGroups.IccpGroup.IccpGroupItem.Items.NodeData.MlacpSyncRequestsOnAllForeignPorts.ReceivedSyncRequests()
                                            self.received_sync_requests.parent = self
                                            self._children_name_map["received_sync_requests"] = "received-sync-requests"
                                        return self.received_sync_requests

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "received-sync-requests" or name == "last-time-cleared" or name == "time-since-cleared"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "last-time-cleared"):
                                        self.last_time_cleared = value
                                        self.last_time_cleared.value_namespace = name_space
                                        self.last_time_cleared.value_namespace_prefix = name_space_prefix
                                    if(value_path == "time-since-cleared"):
                                        self.time_since_cleared = value
                                        self.time_since_cleared.value_namespace = name_space
                                        self.time_since_cleared.value_namespace_prefix = name_space_prefix


                            class MemberData(Entity):
                                """
                                Member mLACP TLV counter information
                                
                                .. attribute:: mlacp_tlv_counters
                                
                                	Counts of mLACP TLVs sent and received
                                	**type**\:   :py:class:`MlacpTlvCounters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.MlacpMemberCounters.IccpGroups.IccpGroup.IccpGroupItem.Items.NodeData.MemberData.MlacpTlvCounters>`
                                
                                .. attribute:: port_name
                                
                                	Port name of member
                                	**type**\:  str
                                
                                

                                """

                                _prefix = 'bundlemgr-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(BundleInformation.MlacpMemberCounters.IccpGroups.IccpGroup.IccpGroupItem.Items.NodeData.MemberData, self).__init__()

                                    self.yang_name = "member-data"
                                    self.yang_parent_name = "node-data"

                                    self.port_name = YLeaf(YType.str, "port-name")

                                    self.mlacp_tlv_counters = BundleInformation.MlacpMemberCounters.IccpGroups.IccpGroup.IccpGroupItem.Items.NodeData.MemberData.MlacpTlvCounters()
                                    self.mlacp_tlv_counters.parent = self
                                    self._children_name_map["mlacp_tlv_counters"] = "mlacp-tlv-counters"
                                    self._children_yang_names.add("mlacp-tlv-counters")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("port_name") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(BundleInformation.MlacpMemberCounters.IccpGroups.IccpGroup.IccpGroupItem.Items.NodeData.MemberData, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(BundleInformation.MlacpMemberCounters.IccpGroups.IccpGroup.IccpGroupItem.Items.NodeData.MemberData, self).__setattr__(name, value)


                                class MlacpTlvCounters(Entity):
                                    """
                                    Counts of mLACP TLVs sent and received
                                    
                                    .. attribute:: last_time_cleared
                                    
                                    	Time in nsecs from boot when counters were last cleared (deprecated)
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: nanosecond
                                    
                                    .. attribute:: last_unexpected_event
                                    
                                    	Elapsed time in nsecs since last unexpected event
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: nanosecond
                                    
                                    .. attribute:: received_nak_tl_vs
                                    
                                    	Number of mLACP NAK TLVs received
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: received_priority_tl_vs
                                    
                                    	Number of mLACP priority TLVs received
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: received_sync_requests
                                    
                                    	Number of mLACP sync request TLVs received
                                    	**type**\:   :py:class:`ReceivedSyncRequests <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.MlacpMemberCounters.IccpGroups.IccpGroup.IccpGroupItem.Items.NodeData.MemberData.MlacpTlvCounters.ReceivedSyncRequests>`
                                    
                                    .. attribute:: sent_config_tl_vs
                                    
                                    	Number of mLACP config TLVs sent
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: sent_priority_tl_vs
                                    
                                    	Number of mLACP priority TLVs sent
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: sent_state_tl_vs
                                    
                                    	Number of mLACP state TLVs sent
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: time_since_cleared
                                    
                                    	Elapsed time in nsecs since counters were last cleared
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: nanosecond
                                    
                                    

                                    """

                                    _prefix = 'bundlemgr-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(BundleInformation.MlacpMemberCounters.IccpGroups.IccpGroup.IccpGroupItem.Items.NodeData.MemberData.MlacpTlvCounters, self).__init__()

                                        self.yang_name = "mlacp-tlv-counters"
                                        self.yang_parent_name = "member-data"

                                        self.last_time_cleared = YLeaf(YType.uint64, "last-time-cleared")

                                        self.last_unexpected_event = YLeaf(YType.uint64, "last-unexpected-event")

                                        self.received_nak_tl_vs = YLeaf(YType.uint32, "received-nak-tl-vs")

                                        self.received_priority_tl_vs = YLeaf(YType.uint32, "received-priority-tl-vs")

                                        self.sent_config_tl_vs = YLeaf(YType.uint32, "sent-config-tl-vs")

                                        self.sent_priority_tl_vs = YLeaf(YType.uint32, "sent-priority-tl-vs")

                                        self.sent_state_tl_vs = YLeaf(YType.uint32, "sent-state-tl-vs")

                                        self.time_since_cleared = YLeaf(YType.uint64, "time-since-cleared")

                                        self.received_sync_requests = BundleInformation.MlacpMemberCounters.IccpGroups.IccpGroup.IccpGroupItem.Items.NodeData.MemberData.MlacpTlvCounters.ReceivedSyncRequests()
                                        self.received_sync_requests.parent = self
                                        self._children_name_map["received_sync_requests"] = "received-sync-requests"
                                        self._children_yang_names.add("received-sync-requests")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("last_time_cleared",
                                                        "last_unexpected_event",
                                                        "received_nak_tl_vs",
                                                        "received_priority_tl_vs",
                                                        "sent_config_tl_vs",
                                                        "sent_priority_tl_vs",
                                                        "sent_state_tl_vs",
                                                        "time_since_cleared") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(BundleInformation.MlacpMemberCounters.IccpGroups.IccpGroup.IccpGroupItem.Items.NodeData.MemberData.MlacpTlvCounters, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(BundleInformation.MlacpMemberCounters.IccpGroups.IccpGroup.IccpGroupItem.Items.NodeData.MemberData.MlacpTlvCounters, self).__setattr__(name, value)


                                    class ReceivedSyncRequests(Entity):
                                        """
                                        Number of mLACP sync request TLVs received
                                        
                                        .. attribute:: all_syncs
                                        
                                        	Total number of sync requests received
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: config_syncs
                                        
                                        	Number of config sync requests received
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: state_syncs
                                        
                                        	Number of state sync requests received
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'bundlemgr-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(BundleInformation.MlacpMemberCounters.IccpGroups.IccpGroup.IccpGroupItem.Items.NodeData.MemberData.MlacpTlvCounters.ReceivedSyncRequests, self).__init__()

                                            self.yang_name = "received-sync-requests"
                                            self.yang_parent_name = "mlacp-tlv-counters"

                                            self.all_syncs = YLeaf(YType.uint32, "all-syncs")

                                            self.config_syncs = YLeaf(YType.uint32, "config-syncs")

                                            self.state_syncs = YLeaf(YType.uint32, "state-syncs")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("all_syncs",
                                                            "config_syncs",
                                                            "state_syncs") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(BundleInformation.MlacpMemberCounters.IccpGroups.IccpGroup.IccpGroupItem.Items.NodeData.MemberData.MlacpTlvCounters.ReceivedSyncRequests, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(BundleInformation.MlacpMemberCounters.IccpGroups.IccpGroup.IccpGroupItem.Items.NodeData.MemberData.MlacpTlvCounters.ReceivedSyncRequests, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.all_syncs.is_set or
                                                self.config_syncs.is_set or
                                                self.state_syncs.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.all_syncs.yfilter != YFilter.not_set or
                                                self.config_syncs.yfilter != YFilter.not_set or
                                                self.state_syncs.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "received-sync-requests" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.all_syncs.is_set or self.all_syncs.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.all_syncs.get_name_leafdata())
                                            if (self.config_syncs.is_set or self.config_syncs.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.config_syncs.get_name_leafdata())
                                            if (self.state_syncs.is_set or self.state_syncs.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.state_syncs.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "all-syncs" or name == "config-syncs" or name == "state-syncs"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "all-syncs"):
                                                self.all_syncs = value
                                                self.all_syncs.value_namespace = name_space
                                                self.all_syncs.value_namespace_prefix = name_space_prefix
                                            if(value_path == "config-syncs"):
                                                self.config_syncs = value
                                                self.config_syncs.value_namespace = name_space
                                                self.config_syncs.value_namespace_prefix = name_space_prefix
                                            if(value_path == "state-syncs"):
                                                self.state_syncs = value
                                                self.state_syncs.value_namespace = name_space
                                                self.state_syncs.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.last_time_cleared.is_set or
                                            self.last_unexpected_event.is_set or
                                            self.received_nak_tl_vs.is_set or
                                            self.received_priority_tl_vs.is_set or
                                            self.sent_config_tl_vs.is_set or
                                            self.sent_priority_tl_vs.is_set or
                                            self.sent_state_tl_vs.is_set or
                                            self.time_since_cleared.is_set or
                                            (self.received_sync_requests is not None and self.received_sync_requests.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.last_time_cleared.yfilter != YFilter.not_set or
                                            self.last_unexpected_event.yfilter != YFilter.not_set or
                                            self.received_nak_tl_vs.yfilter != YFilter.not_set or
                                            self.received_priority_tl_vs.yfilter != YFilter.not_set or
                                            self.sent_config_tl_vs.yfilter != YFilter.not_set or
                                            self.sent_priority_tl_vs.yfilter != YFilter.not_set or
                                            self.sent_state_tl_vs.yfilter != YFilter.not_set or
                                            self.time_since_cleared.yfilter != YFilter.not_set or
                                            (self.received_sync_requests is not None and self.received_sync_requests.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "mlacp-tlv-counters" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.last_time_cleared.is_set or self.last_time_cleared.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.last_time_cleared.get_name_leafdata())
                                        if (self.last_unexpected_event.is_set or self.last_unexpected_event.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.last_unexpected_event.get_name_leafdata())
                                        if (self.received_nak_tl_vs.is_set or self.received_nak_tl_vs.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.received_nak_tl_vs.get_name_leafdata())
                                        if (self.received_priority_tl_vs.is_set or self.received_priority_tl_vs.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.received_priority_tl_vs.get_name_leafdata())
                                        if (self.sent_config_tl_vs.is_set or self.sent_config_tl_vs.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.sent_config_tl_vs.get_name_leafdata())
                                        if (self.sent_priority_tl_vs.is_set or self.sent_priority_tl_vs.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.sent_priority_tl_vs.get_name_leafdata())
                                        if (self.sent_state_tl_vs.is_set or self.sent_state_tl_vs.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.sent_state_tl_vs.get_name_leafdata())
                                        if (self.time_since_cleared.is_set or self.time_since_cleared.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.time_since_cleared.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "received-sync-requests"):
                                            if (self.received_sync_requests is None):
                                                self.received_sync_requests = BundleInformation.MlacpMemberCounters.IccpGroups.IccpGroup.IccpGroupItem.Items.NodeData.MemberData.MlacpTlvCounters.ReceivedSyncRequests()
                                                self.received_sync_requests.parent = self
                                                self._children_name_map["received_sync_requests"] = "received-sync-requests"
                                            return self.received_sync_requests

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "received-sync-requests" or name == "last-time-cleared" or name == "last-unexpected-event" or name == "received-nak-tl-vs" or name == "received-priority-tl-vs" or name == "sent-config-tl-vs" or name == "sent-priority-tl-vs" or name == "sent-state-tl-vs" or name == "time-since-cleared"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "last-time-cleared"):
                                            self.last_time_cleared = value
                                            self.last_time_cleared.value_namespace = name_space
                                            self.last_time_cleared.value_namespace_prefix = name_space_prefix
                                        if(value_path == "last-unexpected-event"):
                                            self.last_unexpected_event = value
                                            self.last_unexpected_event.value_namespace = name_space
                                            self.last_unexpected_event.value_namespace_prefix = name_space_prefix
                                        if(value_path == "received-nak-tl-vs"):
                                            self.received_nak_tl_vs = value
                                            self.received_nak_tl_vs.value_namespace = name_space
                                            self.received_nak_tl_vs.value_namespace_prefix = name_space_prefix
                                        if(value_path == "received-priority-tl-vs"):
                                            self.received_priority_tl_vs = value
                                            self.received_priority_tl_vs.value_namespace = name_space
                                            self.received_priority_tl_vs.value_namespace_prefix = name_space_prefix
                                        if(value_path == "sent-config-tl-vs"):
                                            self.sent_config_tl_vs = value
                                            self.sent_config_tl_vs.value_namespace = name_space
                                            self.sent_config_tl_vs.value_namespace_prefix = name_space_prefix
                                        if(value_path == "sent-priority-tl-vs"):
                                            self.sent_priority_tl_vs = value
                                            self.sent_priority_tl_vs.value_namespace = name_space
                                            self.sent_priority_tl_vs.value_namespace_prefix = name_space_prefix
                                        if(value_path == "sent-state-tl-vs"):
                                            self.sent_state_tl_vs = value
                                            self.sent_state_tl_vs.value_namespace = name_space
                                            self.sent_state_tl_vs.value_namespace_prefix = name_space_prefix
                                        if(value_path == "time-since-cleared"):
                                            self.time_since_cleared = value
                                            self.time_since_cleared.value_namespace = name_space
                                            self.time_since_cleared.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.port_name.is_set or
                                        (self.mlacp_tlv_counters is not None and self.mlacp_tlv_counters.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.port_name.yfilter != YFilter.not_set or
                                        (self.mlacp_tlv_counters is not None and self.mlacp_tlv_counters.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "member-data" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.port_name.is_set or self.port_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.port_name.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "mlacp-tlv-counters"):
                                        if (self.mlacp_tlv_counters is None):
                                            self.mlacp_tlv_counters = BundleInformation.MlacpMemberCounters.IccpGroups.IccpGroup.IccpGroupItem.Items.NodeData.MemberData.MlacpTlvCounters()
                                            self.mlacp_tlv_counters.parent = self
                                            self._children_name_map["mlacp_tlv_counters"] = "mlacp-tlv-counters"
                                        return self.mlacp_tlv_counters

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "mlacp-tlv-counters" or name == "port-name"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "port-name"):
                                        self.port_name = value
                                        self.port_name.value_namespace = name_space
                                        self.port_name.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.member_data:
                                    if (c.has_data()):
                                        return True
                                return (
                                    (self.mlacp_sync_requests_on_all_foreign_ports is not None and self.mlacp_sync_requests_on_all_foreign_ports.has_data()) or
                                    (self.node_data is not None and self.node_data.has_data()))

                            def has_operation(self):
                                for c in self.member_data:
                                    if (c.has_operation()):
                                        return True
                                return (
                                    self.yfilter != YFilter.not_set or
                                    (self.mlacp_sync_requests_on_all_foreign_ports is not None and self.mlacp_sync_requests_on_all_foreign_ports.has_operation()) or
                                    (self.node_data is not None and self.node_data.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "node-data" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "member-data"):
                                    for c in self.member_data:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = BundleInformation.MlacpMemberCounters.IccpGroups.IccpGroup.IccpGroupItem.Items.NodeData.MemberData()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.member_data.append(c)
                                    return c

                                if (child_yang_name == "mlacp-sync-requests-on-all-foreign-ports"):
                                    if (self.mlacp_sync_requests_on_all_foreign_ports is None):
                                        self.mlacp_sync_requests_on_all_foreign_ports = BundleInformation.MlacpMemberCounters.IccpGroups.IccpGroup.IccpGroupItem.Items.NodeData.MlacpSyncRequestsOnAllForeignPorts()
                                        self.mlacp_sync_requests_on_all_foreign_ports.parent = self
                                        self._children_name_map["mlacp_sync_requests_on_all_foreign_ports"] = "mlacp-sync-requests-on-all-foreign-ports"
                                    return self.mlacp_sync_requests_on_all_foreign_ports

                                if (child_yang_name == "node-data"):
                                    if (self.node_data is None):
                                        self.node_data = BundleInformation.MlacpMemberCounters.IccpGroups.IccpGroup.IccpGroupItem.Items.NodeData.NodeData()
                                        self.node_data.parent = self
                                        self._children_name_map["node_data"] = "node-data"
                                    return self.node_data

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "member-data" or name == "mlacp-sync-requests-on-all-foreign-ports" or name == "node-data"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass


                        class MemberData(Entity):
                            """
                            Local member mLACP TLV counter information
                            
                            .. attribute:: mlacp_tlv_counters
                            
                            	Counts of mLACP TLVs sent and received
                            	**type**\:   :py:class:`MlacpTlvCounters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.MlacpMemberCounters.IccpGroups.IccpGroup.IccpGroupItem.Items.MemberData.MlacpTlvCounters>`
                            
                            .. attribute:: port_name
                            
                            	Port name of member
                            	**type**\:  str
                            
                            

                            """

                            _prefix = 'bundlemgr-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(BundleInformation.MlacpMemberCounters.IccpGroups.IccpGroup.IccpGroupItem.Items.MemberData, self).__init__()

                                self.yang_name = "member-data"
                                self.yang_parent_name = "items"

                                self.port_name = YLeaf(YType.str, "port-name")

                                self.mlacp_tlv_counters = BundleInformation.MlacpMemberCounters.IccpGroups.IccpGroup.IccpGroupItem.Items.MemberData.MlacpTlvCounters()
                                self.mlacp_tlv_counters.parent = self
                                self._children_name_map["mlacp_tlv_counters"] = "mlacp-tlv-counters"
                                self._children_yang_names.add("mlacp-tlv-counters")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("port_name") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(BundleInformation.MlacpMemberCounters.IccpGroups.IccpGroup.IccpGroupItem.Items.MemberData, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(BundleInformation.MlacpMemberCounters.IccpGroups.IccpGroup.IccpGroupItem.Items.MemberData, self).__setattr__(name, value)


                            class MlacpTlvCounters(Entity):
                                """
                                Counts of mLACP TLVs sent and received
                                
                                .. attribute:: last_time_cleared
                                
                                	Time in nsecs from boot when counters were last cleared (deprecated)
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: nanosecond
                                
                                .. attribute:: last_unexpected_event
                                
                                	Elapsed time in nsecs since last unexpected event
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: nanosecond
                                
                                .. attribute:: received_nak_tl_vs
                                
                                	Number of mLACP NAK TLVs received
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: received_priority_tl_vs
                                
                                	Number of mLACP priority TLVs received
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: received_sync_requests
                                
                                	Number of mLACP sync request TLVs received
                                	**type**\:   :py:class:`ReceivedSyncRequests <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.MlacpMemberCounters.IccpGroups.IccpGroup.IccpGroupItem.Items.MemberData.MlacpTlvCounters.ReceivedSyncRequests>`
                                
                                .. attribute:: sent_config_tl_vs
                                
                                	Number of mLACP config TLVs sent
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: sent_priority_tl_vs
                                
                                	Number of mLACP priority TLVs sent
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: sent_state_tl_vs
                                
                                	Number of mLACP state TLVs sent
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: time_since_cleared
                                
                                	Elapsed time in nsecs since counters were last cleared
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: nanosecond
                                
                                

                                """

                                _prefix = 'bundlemgr-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(BundleInformation.MlacpMemberCounters.IccpGroups.IccpGroup.IccpGroupItem.Items.MemberData.MlacpTlvCounters, self).__init__()

                                    self.yang_name = "mlacp-tlv-counters"
                                    self.yang_parent_name = "member-data"

                                    self.last_time_cleared = YLeaf(YType.uint64, "last-time-cleared")

                                    self.last_unexpected_event = YLeaf(YType.uint64, "last-unexpected-event")

                                    self.received_nak_tl_vs = YLeaf(YType.uint32, "received-nak-tl-vs")

                                    self.received_priority_tl_vs = YLeaf(YType.uint32, "received-priority-tl-vs")

                                    self.sent_config_tl_vs = YLeaf(YType.uint32, "sent-config-tl-vs")

                                    self.sent_priority_tl_vs = YLeaf(YType.uint32, "sent-priority-tl-vs")

                                    self.sent_state_tl_vs = YLeaf(YType.uint32, "sent-state-tl-vs")

                                    self.time_since_cleared = YLeaf(YType.uint64, "time-since-cleared")

                                    self.received_sync_requests = BundleInformation.MlacpMemberCounters.IccpGroups.IccpGroup.IccpGroupItem.Items.MemberData.MlacpTlvCounters.ReceivedSyncRequests()
                                    self.received_sync_requests.parent = self
                                    self._children_name_map["received_sync_requests"] = "received-sync-requests"
                                    self._children_yang_names.add("received-sync-requests")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("last_time_cleared",
                                                    "last_unexpected_event",
                                                    "received_nak_tl_vs",
                                                    "received_priority_tl_vs",
                                                    "sent_config_tl_vs",
                                                    "sent_priority_tl_vs",
                                                    "sent_state_tl_vs",
                                                    "time_since_cleared") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(BundleInformation.MlacpMemberCounters.IccpGroups.IccpGroup.IccpGroupItem.Items.MemberData.MlacpTlvCounters, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(BundleInformation.MlacpMemberCounters.IccpGroups.IccpGroup.IccpGroupItem.Items.MemberData.MlacpTlvCounters, self).__setattr__(name, value)


                                class ReceivedSyncRequests(Entity):
                                    """
                                    Number of mLACP sync request TLVs received
                                    
                                    .. attribute:: all_syncs
                                    
                                    	Total number of sync requests received
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: config_syncs
                                    
                                    	Number of config sync requests received
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: state_syncs
                                    
                                    	Number of state sync requests received
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'bundlemgr-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(BundleInformation.MlacpMemberCounters.IccpGroups.IccpGroup.IccpGroupItem.Items.MemberData.MlacpTlvCounters.ReceivedSyncRequests, self).__init__()

                                        self.yang_name = "received-sync-requests"
                                        self.yang_parent_name = "mlacp-tlv-counters"

                                        self.all_syncs = YLeaf(YType.uint32, "all-syncs")

                                        self.config_syncs = YLeaf(YType.uint32, "config-syncs")

                                        self.state_syncs = YLeaf(YType.uint32, "state-syncs")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("all_syncs",
                                                        "config_syncs",
                                                        "state_syncs") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(BundleInformation.MlacpMemberCounters.IccpGroups.IccpGroup.IccpGroupItem.Items.MemberData.MlacpTlvCounters.ReceivedSyncRequests, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(BundleInformation.MlacpMemberCounters.IccpGroups.IccpGroup.IccpGroupItem.Items.MemberData.MlacpTlvCounters.ReceivedSyncRequests, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.all_syncs.is_set or
                                            self.config_syncs.is_set or
                                            self.state_syncs.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.all_syncs.yfilter != YFilter.not_set or
                                            self.config_syncs.yfilter != YFilter.not_set or
                                            self.state_syncs.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "received-sync-requests" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.all_syncs.is_set or self.all_syncs.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.all_syncs.get_name_leafdata())
                                        if (self.config_syncs.is_set or self.config_syncs.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.config_syncs.get_name_leafdata())
                                        if (self.state_syncs.is_set or self.state_syncs.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.state_syncs.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "all-syncs" or name == "config-syncs" or name == "state-syncs"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "all-syncs"):
                                            self.all_syncs = value
                                            self.all_syncs.value_namespace = name_space
                                            self.all_syncs.value_namespace_prefix = name_space_prefix
                                        if(value_path == "config-syncs"):
                                            self.config_syncs = value
                                            self.config_syncs.value_namespace = name_space
                                            self.config_syncs.value_namespace_prefix = name_space_prefix
                                        if(value_path == "state-syncs"):
                                            self.state_syncs = value
                                            self.state_syncs.value_namespace = name_space
                                            self.state_syncs.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.last_time_cleared.is_set or
                                        self.last_unexpected_event.is_set or
                                        self.received_nak_tl_vs.is_set or
                                        self.received_priority_tl_vs.is_set or
                                        self.sent_config_tl_vs.is_set or
                                        self.sent_priority_tl_vs.is_set or
                                        self.sent_state_tl_vs.is_set or
                                        self.time_since_cleared.is_set or
                                        (self.received_sync_requests is not None and self.received_sync_requests.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.last_time_cleared.yfilter != YFilter.not_set or
                                        self.last_unexpected_event.yfilter != YFilter.not_set or
                                        self.received_nak_tl_vs.yfilter != YFilter.not_set or
                                        self.received_priority_tl_vs.yfilter != YFilter.not_set or
                                        self.sent_config_tl_vs.yfilter != YFilter.not_set or
                                        self.sent_priority_tl_vs.yfilter != YFilter.not_set or
                                        self.sent_state_tl_vs.yfilter != YFilter.not_set or
                                        self.time_since_cleared.yfilter != YFilter.not_set or
                                        (self.received_sync_requests is not None and self.received_sync_requests.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "mlacp-tlv-counters" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.last_time_cleared.is_set or self.last_time_cleared.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.last_time_cleared.get_name_leafdata())
                                    if (self.last_unexpected_event.is_set or self.last_unexpected_event.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.last_unexpected_event.get_name_leafdata())
                                    if (self.received_nak_tl_vs.is_set or self.received_nak_tl_vs.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.received_nak_tl_vs.get_name_leafdata())
                                    if (self.received_priority_tl_vs.is_set or self.received_priority_tl_vs.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.received_priority_tl_vs.get_name_leafdata())
                                    if (self.sent_config_tl_vs.is_set or self.sent_config_tl_vs.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.sent_config_tl_vs.get_name_leafdata())
                                    if (self.sent_priority_tl_vs.is_set or self.sent_priority_tl_vs.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.sent_priority_tl_vs.get_name_leafdata())
                                    if (self.sent_state_tl_vs.is_set or self.sent_state_tl_vs.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.sent_state_tl_vs.get_name_leafdata())
                                    if (self.time_since_cleared.is_set or self.time_since_cleared.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.time_since_cleared.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "received-sync-requests"):
                                        if (self.received_sync_requests is None):
                                            self.received_sync_requests = BundleInformation.MlacpMemberCounters.IccpGroups.IccpGroup.IccpGroupItem.Items.MemberData.MlacpTlvCounters.ReceivedSyncRequests()
                                            self.received_sync_requests.parent = self
                                            self._children_name_map["received_sync_requests"] = "received-sync-requests"
                                        return self.received_sync_requests

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "received-sync-requests" or name == "last-time-cleared" or name == "last-unexpected-event" or name == "received-nak-tl-vs" or name == "received-priority-tl-vs" or name == "sent-config-tl-vs" or name == "sent-priority-tl-vs" or name == "sent-state-tl-vs" or name == "time-since-cleared"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "last-time-cleared"):
                                        self.last_time_cleared = value
                                        self.last_time_cleared.value_namespace = name_space
                                        self.last_time_cleared.value_namespace_prefix = name_space_prefix
                                    if(value_path == "last-unexpected-event"):
                                        self.last_unexpected_event = value
                                        self.last_unexpected_event.value_namespace = name_space
                                        self.last_unexpected_event.value_namespace_prefix = name_space_prefix
                                    if(value_path == "received-nak-tl-vs"):
                                        self.received_nak_tl_vs = value
                                        self.received_nak_tl_vs.value_namespace = name_space
                                        self.received_nak_tl_vs.value_namespace_prefix = name_space_prefix
                                    if(value_path == "received-priority-tl-vs"):
                                        self.received_priority_tl_vs = value
                                        self.received_priority_tl_vs.value_namespace = name_space
                                        self.received_priority_tl_vs.value_namespace_prefix = name_space_prefix
                                    if(value_path == "sent-config-tl-vs"):
                                        self.sent_config_tl_vs = value
                                        self.sent_config_tl_vs.value_namespace = name_space
                                        self.sent_config_tl_vs.value_namespace_prefix = name_space_prefix
                                    if(value_path == "sent-priority-tl-vs"):
                                        self.sent_priority_tl_vs = value
                                        self.sent_priority_tl_vs.value_namespace = name_space
                                        self.sent_priority_tl_vs.value_namespace_prefix = name_space_prefix
                                    if(value_path == "sent-state-tl-vs"):
                                        self.sent_state_tl_vs = value
                                        self.sent_state_tl_vs.value_namespace = name_space
                                        self.sent_state_tl_vs.value_namespace_prefix = name_space_prefix
                                    if(value_path == "time-since-cleared"):
                                        self.time_since_cleared = value
                                        self.time_since_cleared.value_namespace = name_space
                                        self.time_since_cleared.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.port_name.is_set or
                                    (self.mlacp_tlv_counters is not None and self.mlacp_tlv_counters.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.port_name.yfilter != YFilter.not_set or
                                    (self.mlacp_tlv_counters is not None and self.mlacp_tlv_counters.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "member-data" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.port_name.is_set or self.port_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.port_name.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "mlacp-tlv-counters"):
                                    if (self.mlacp_tlv_counters is None):
                                        self.mlacp_tlv_counters = BundleInformation.MlacpMemberCounters.IccpGroups.IccpGroup.IccpGroupItem.Items.MemberData.MlacpTlvCounters()
                                        self.mlacp_tlv_counters.parent = self
                                        self._children_name_map["mlacp_tlv_counters"] = "mlacp-tlv-counters"
                                    return self.mlacp_tlv_counters

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "mlacp-tlv-counters" or name == "port-name"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "port-name"):
                                    self.port_name = value
                                    self.port_name.value_namespace = name_space
                                    self.port_name.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.member_data:
                                if (c.has_data()):
                                    return True
                            for c in self.node_data:
                                if (c.has_data()):
                                    return True
                            return (self.bundle_data is not None and self.bundle_data.has_data())

                        def has_operation(self):
                            for c in self.member_data:
                                if (c.has_operation()):
                                    return True
                            for c in self.node_data:
                                if (c.has_operation()):
                                    return True
                            return (
                                self.yfilter != YFilter.not_set or
                                (self.bundle_data is not None and self.bundle_data.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "items" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "bundle-data"):
                                if (self.bundle_data is None):
                                    self.bundle_data = BundleInformation.MlacpMemberCounters.IccpGroups.IccpGroup.IccpGroupItem.Items.BundleData()
                                    self.bundle_data.parent = self
                                    self._children_name_map["bundle_data"] = "bundle-data"
                                return self.bundle_data

                            if (child_yang_name == "member-data"):
                                for c in self.member_data:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = BundleInformation.MlacpMemberCounters.IccpGroups.IccpGroup.IccpGroupItem.Items.MemberData()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.member_data.append(c)
                                return c

                            if (child_yang_name == "node-data"):
                                for c in self.node_data:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = BundleInformation.MlacpMemberCounters.IccpGroups.IccpGroup.IccpGroupItem.Items.NodeData()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.node_data.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "bundle-data" or name == "member-data" or name == "node-data"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass

                    def has_data(self):
                        for c in self.items:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.items:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "iccp-group-item" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "items"):
                            for c in self.items:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = BundleInformation.MlacpMemberCounters.IccpGroups.IccpGroup.IccpGroupItem.Items()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.items.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "items"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass

                def has_data(self):
                    return (
                        self.iccp_group.is_set or
                        (self.iccp_group_item is not None and self.iccp_group_item.has_data()))

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.iccp_group.yfilter != YFilter.not_set or
                        (self.iccp_group_item is not None and self.iccp_group_item.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "iccp-group" + "[iccp-group='" + self.iccp_group.get() + "']" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-bundlemgr-oper:bundle-information/mlacp-member-counters/iccp-groups/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.iccp_group.is_set or self.iccp_group.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.iccp_group.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "iccp-group-item"):
                        if (self.iccp_group_item is None):
                            self.iccp_group_item = BundleInformation.MlacpMemberCounters.IccpGroups.IccpGroup.IccpGroupItem()
                            self.iccp_group_item.parent = self
                            self._children_name_map["iccp_group_item"] = "iccp-group-item"
                        return self.iccp_group_item

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "iccp-group-item" or name == "iccp-group"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "iccp-group"):
                        self.iccp_group = value
                        self.iccp_group.value_namespace = name_space
                        self.iccp_group.value_namespace_prefix = name_space_prefix

            def has_data(self):
                for c in self.iccp_group:
                    if (c.has_data()):
                        return True
                return False

            def has_operation(self):
                for c in self.iccp_group:
                    if (c.has_operation()):
                        return True
                return self.yfilter != YFilter.not_set

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "iccp-groups" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-bundlemgr-oper:bundle-information/mlacp-member-counters/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "iccp-group"):
                    for c in self.iccp_group:
                        segment = c.get_segment_path()
                        if (segment_path == segment):
                            return c
                    c = BundleInformation.MlacpMemberCounters.IccpGroups.IccpGroup()
                    c.parent = self
                    local_reference_key = "ydk::seg::%s" % segment_path
                    self._local_refs[local_reference_key] = c
                    self.iccp_group.append(c)
                    return c

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "iccp-group"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                pass


        class Members(Entity):
            """
            Member interfaces with counters of mLACP events
            
            .. attribute:: member
            
            	Member interface
            	**type**\: list of    :py:class:`Member <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.MlacpMemberCounters.Members.Member>`
            
            

            """

            _prefix = 'bundlemgr-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(BundleInformation.MlacpMemberCounters.Members, self).__init__()

                self.yang_name = "members"
                self.yang_parent_name = "mlacp-member-counters"

                self.member = YList(self)

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in () and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(BundleInformation.MlacpMemberCounters.Members, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(BundleInformation.MlacpMemberCounters.Members, self).__setattr__(name, value)


            class Member(Entity):
                """
                Member interface
                
                .. attribute:: member_interface  <key>
                
                	Member interface
                	**type**\:  str
                
                .. attribute:: member_item
                
                	Data for this item
                	**type**\:   :py:class:`MemberItem <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.MlacpMemberCounters.Members.Member.MemberItem>`
                
                

                """

                _prefix = 'bundlemgr-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(BundleInformation.MlacpMemberCounters.Members.Member, self).__init__()

                    self.yang_name = "member"
                    self.yang_parent_name = "members"

                    self.member_interface = YLeaf(YType.str, "member-interface")

                    self.member_item = BundleInformation.MlacpMemberCounters.Members.Member.MemberItem()
                    self.member_item.parent = self
                    self._children_name_map["member_item"] = "member-item"
                    self._children_yang_names.add("member-item")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("member_interface") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(BundleInformation.MlacpMemberCounters.Members.Member, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(BundleInformation.MlacpMemberCounters.Members.Member, self).__setattr__(name, value)


                class MemberItem(Entity):
                    """
                    Data for this item
                    
                    .. attribute:: items
                    
                    	mLACP counter information items
                    	**type**\: list of    :py:class:`Items <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.MlacpMemberCounters.Members.Member.MemberItem.Items>`
                    
                    

                    """

                    _prefix = 'bundlemgr-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(BundleInformation.MlacpMemberCounters.Members.Member.MemberItem, self).__init__()

                        self.yang_name = "member-item"
                        self.yang_parent_name = "member"

                        self.items = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(BundleInformation.MlacpMemberCounters.Members.Member.MemberItem, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(BundleInformation.MlacpMemberCounters.Members.Member.MemberItem, self).__setattr__(name, value)


                    class Items(Entity):
                        """
                        mLACP counter information items
                        
                        .. attribute:: bundle_data
                        
                        	Bundle mLACP TLV counter information
                        	**type**\:   :py:class:`BundleData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.MlacpMemberCounters.Members.Member.MemberItem.Items.BundleData>`
                        
                        .. attribute:: member_data
                        
                        	Local member mLACP TLV counter information
                        	**type**\: list of    :py:class:`MemberData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.MlacpMemberCounters.Members.Member.MemberItem.Items.MemberData>`
                        
                        .. attribute:: node_data
                        
                        	Peer device mLACP TLV counter information
                        	**type**\: list of    :py:class:`NodeData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.MlacpMemberCounters.Members.Member.MemberItem.Items.NodeData>`
                        
                        

                        """

                        _prefix = 'bundlemgr-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(BundleInformation.MlacpMemberCounters.Members.Member.MemberItem.Items, self).__init__()

                            self.yang_name = "items"
                            self.yang_parent_name = "member-item"

                            self.bundle_data = BundleInformation.MlacpMemberCounters.Members.Member.MemberItem.Items.BundleData()
                            self.bundle_data.parent = self
                            self._children_name_map["bundle_data"] = "bundle-data"
                            self._children_yang_names.add("bundle-data")

                            self.member_data = YList(self)
                            self.node_data = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(BundleInformation.MlacpMemberCounters.Members.Member.MemberItem.Items, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(BundleInformation.MlacpMemberCounters.Members.Member.MemberItem.Items, self).__setattr__(name, value)


                        class BundleData(Entity):
                            """
                            Bundle mLACP TLV counter information
                            
                            .. attribute:: bundle_name
                            
                            	Name of the bundle
                            	**type**\:  str
                            
                            .. attribute:: iccp_group_id
                            
                            	ICCP Group ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: mlacp_sync_requests_on_all_local_ports
                            
                            	Counts of mLACP sync request TLVs on all ports
                            	**type**\:   :py:class:`MlacpSyncRequestsOnAllLocalPorts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.MlacpMemberCounters.Members.Member.MemberItem.Items.BundleData.MlacpSyncRequestsOnAllLocalPorts>`
                            
                            

                            """

                            _prefix = 'bundlemgr-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(BundleInformation.MlacpMemberCounters.Members.Member.MemberItem.Items.BundleData, self).__init__()

                                self.yang_name = "bundle-data"
                                self.yang_parent_name = "items"

                                self.bundle_name = YLeaf(YType.str, "bundle-name")

                                self.iccp_group_id = YLeaf(YType.uint32, "iccp-group-id")

                                self.mlacp_sync_requests_on_all_local_ports = BundleInformation.MlacpMemberCounters.Members.Member.MemberItem.Items.BundleData.MlacpSyncRequestsOnAllLocalPorts()
                                self.mlacp_sync_requests_on_all_local_ports.parent = self
                                self._children_name_map["mlacp_sync_requests_on_all_local_ports"] = "mlacp-sync-requests-on-all-local-ports"
                                self._children_yang_names.add("mlacp-sync-requests-on-all-local-ports")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("bundle_name",
                                                "iccp_group_id") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(BundleInformation.MlacpMemberCounters.Members.Member.MemberItem.Items.BundleData, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(BundleInformation.MlacpMemberCounters.Members.Member.MemberItem.Items.BundleData, self).__setattr__(name, value)


                            class MlacpSyncRequestsOnAllLocalPorts(Entity):
                                """
                                Counts of mLACP sync request TLVs on all ports
                                
                                .. attribute:: last_time_cleared
                                
                                	Time in nsecs from boot when counters were last cleared (deprecated)
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: nanosecond
                                
                                .. attribute:: received_sync_requests
                                
                                	Number of mLACP sync request TLVs received
                                	**type**\:   :py:class:`ReceivedSyncRequests <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.MlacpMemberCounters.Members.Member.MemberItem.Items.BundleData.MlacpSyncRequestsOnAllLocalPorts.ReceivedSyncRequests>`
                                
                                .. attribute:: time_since_cleared
                                
                                	Elapsed time in nsecs since counters were last cleared
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: nanosecond
                                
                                

                                """

                                _prefix = 'bundlemgr-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(BundleInformation.MlacpMemberCounters.Members.Member.MemberItem.Items.BundleData.MlacpSyncRequestsOnAllLocalPorts, self).__init__()

                                    self.yang_name = "mlacp-sync-requests-on-all-local-ports"
                                    self.yang_parent_name = "bundle-data"

                                    self.last_time_cleared = YLeaf(YType.uint64, "last-time-cleared")

                                    self.time_since_cleared = YLeaf(YType.uint64, "time-since-cleared")

                                    self.received_sync_requests = BundleInformation.MlacpMemberCounters.Members.Member.MemberItem.Items.BundleData.MlacpSyncRequestsOnAllLocalPorts.ReceivedSyncRequests()
                                    self.received_sync_requests.parent = self
                                    self._children_name_map["received_sync_requests"] = "received-sync-requests"
                                    self._children_yang_names.add("received-sync-requests")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("last_time_cleared",
                                                    "time_since_cleared") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(BundleInformation.MlacpMemberCounters.Members.Member.MemberItem.Items.BundleData.MlacpSyncRequestsOnAllLocalPorts, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(BundleInformation.MlacpMemberCounters.Members.Member.MemberItem.Items.BundleData.MlacpSyncRequestsOnAllLocalPorts, self).__setattr__(name, value)


                                class ReceivedSyncRequests(Entity):
                                    """
                                    Number of mLACP sync request TLVs received
                                    
                                    .. attribute:: all_syncs
                                    
                                    	Total number of sync requests received
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: config_syncs
                                    
                                    	Number of config sync requests received
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: state_syncs
                                    
                                    	Number of state sync requests received
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'bundlemgr-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(BundleInformation.MlacpMemberCounters.Members.Member.MemberItem.Items.BundleData.MlacpSyncRequestsOnAllLocalPorts.ReceivedSyncRequests, self).__init__()

                                        self.yang_name = "received-sync-requests"
                                        self.yang_parent_name = "mlacp-sync-requests-on-all-local-ports"

                                        self.all_syncs = YLeaf(YType.uint32, "all-syncs")

                                        self.config_syncs = YLeaf(YType.uint32, "config-syncs")

                                        self.state_syncs = YLeaf(YType.uint32, "state-syncs")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("all_syncs",
                                                        "config_syncs",
                                                        "state_syncs") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(BundleInformation.MlacpMemberCounters.Members.Member.MemberItem.Items.BundleData.MlacpSyncRequestsOnAllLocalPorts.ReceivedSyncRequests, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(BundleInformation.MlacpMemberCounters.Members.Member.MemberItem.Items.BundleData.MlacpSyncRequestsOnAllLocalPorts.ReceivedSyncRequests, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.all_syncs.is_set or
                                            self.config_syncs.is_set or
                                            self.state_syncs.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.all_syncs.yfilter != YFilter.not_set or
                                            self.config_syncs.yfilter != YFilter.not_set or
                                            self.state_syncs.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "received-sync-requests" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.all_syncs.is_set or self.all_syncs.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.all_syncs.get_name_leafdata())
                                        if (self.config_syncs.is_set or self.config_syncs.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.config_syncs.get_name_leafdata())
                                        if (self.state_syncs.is_set or self.state_syncs.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.state_syncs.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "all-syncs" or name == "config-syncs" or name == "state-syncs"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "all-syncs"):
                                            self.all_syncs = value
                                            self.all_syncs.value_namespace = name_space
                                            self.all_syncs.value_namespace_prefix = name_space_prefix
                                        if(value_path == "config-syncs"):
                                            self.config_syncs = value
                                            self.config_syncs.value_namespace = name_space
                                            self.config_syncs.value_namespace_prefix = name_space_prefix
                                        if(value_path == "state-syncs"):
                                            self.state_syncs = value
                                            self.state_syncs.value_namespace = name_space
                                            self.state_syncs.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.last_time_cleared.is_set or
                                        self.time_since_cleared.is_set or
                                        (self.received_sync_requests is not None and self.received_sync_requests.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.last_time_cleared.yfilter != YFilter.not_set or
                                        self.time_since_cleared.yfilter != YFilter.not_set or
                                        (self.received_sync_requests is not None and self.received_sync_requests.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "mlacp-sync-requests-on-all-local-ports" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.last_time_cleared.is_set or self.last_time_cleared.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.last_time_cleared.get_name_leafdata())
                                    if (self.time_since_cleared.is_set or self.time_since_cleared.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.time_since_cleared.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "received-sync-requests"):
                                        if (self.received_sync_requests is None):
                                            self.received_sync_requests = BundleInformation.MlacpMemberCounters.Members.Member.MemberItem.Items.BundleData.MlacpSyncRequestsOnAllLocalPorts.ReceivedSyncRequests()
                                            self.received_sync_requests.parent = self
                                            self._children_name_map["received_sync_requests"] = "received-sync-requests"
                                        return self.received_sync_requests

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "received-sync-requests" or name == "last-time-cleared" or name == "time-since-cleared"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "last-time-cleared"):
                                        self.last_time_cleared = value
                                        self.last_time_cleared.value_namespace = name_space
                                        self.last_time_cleared.value_namespace_prefix = name_space_prefix
                                    if(value_path == "time-since-cleared"):
                                        self.time_since_cleared = value
                                        self.time_since_cleared.value_namespace = name_space
                                        self.time_since_cleared.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.bundle_name.is_set or
                                    self.iccp_group_id.is_set or
                                    (self.mlacp_sync_requests_on_all_local_ports is not None and self.mlacp_sync_requests_on_all_local_ports.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.bundle_name.yfilter != YFilter.not_set or
                                    self.iccp_group_id.yfilter != YFilter.not_set or
                                    (self.mlacp_sync_requests_on_all_local_ports is not None and self.mlacp_sync_requests_on_all_local_ports.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "bundle-data" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.bundle_name.is_set or self.bundle_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.bundle_name.get_name_leafdata())
                                if (self.iccp_group_id.is_set or self.iccp_group_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.iccp_group_id.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "mlacp-sync-requests-on-all-local-ports"):
                                    if (self.mlacp_sync_requests_on_all_local_ports is None):
                                        self.mlacp_sync_requests_on_all_local_ports = BundleInformation.MlacpMemberCounters.Members.Member.MemberItem.Items.BundleData.MlacpSyncRequestsOnAllLocalPorts()
                                        self.mlacp_sync_requests_on_all_local_ports.parent = self
                                        self._children_name_map["mlacp_sync_requests_on_all_local_ports"] = "mlacp-sync-requests-on-all-local-ports"
                                    return self.mlacp_sync_requests_on_all_local_ports

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "mlacp-sync-requests-on-all-local-ports" or name == "bundle-name" or name == "iccp-group-id"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "bundle-name"):
                                    self.bundle_name = value
                                    self.bundle_name.value_namespace = name_space
                                    self.bundle_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "iccp-group-id"):
                                    self.iccp_group_id = value
                                    self.iccp_group_id.value_namespace = name_space
                                    self.iccp_group_id.value_namespace_prefix = name_space_prefix


                        class NodeData(Entity):
                            """
                            Peer device mLACP TLV counter information
                            
                            .. attribute:: member_data
                            
                            	Member mLACP TLV counter information
                            	**type**\: list of    :py:class:`MemberData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.MlacpMemberCounters.Members.Member.MemberItem.Items.NodeData.MemberData>`
                            
                            .. attribute:: mlacp_sync_requests_on_all_foreign_ports
                            
                            	Counts of mLACP sync request TLVs on all ports
                            	**type**\:   :py:class:`MlacpSyncRequestsOnAllForeignPorts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.MlacpMemberCounters.Members.Member.MemberItem.Items.NodeData.MlacpSyncRequestsOnAllForeignPorts>`
                            
                            .. attribute:: node_data
                            
                            	Peer device mLACP TLV counter information
                            	**type**\:   :py:class:`NodeData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.MlacpMemberCounters.Members.Member.MemberItem.Items.NodeData.NodeData>`
                            
                            

                            """

                            _prefix = 'bundlemgr-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(BundleInformation.MlacpMemberCounters.Members.Member.MemberItem.Items.NodeData, self).__init__()

                                self.yang_name = "node-data"
                                self.yang_parent_name = "items"

                                self.mlacp_sync_requests_on_all_foreign_ports = BundleInformation.MlacpMemberCounters.Members.Member.MemberItem.Items.NodeData.MlacpSyncRequestsOnAllForeignPorts()
                                self.mlacp_sync_requests_on_all_foreign_ports.parent = self
                                self._children_name_map["mlacp_sync_requests_on_all_foreign_ports"] = "mlacp-sync-requests-on-all-foreign-ports"
                                self._children_yang_names.add("mlacp-sync-requests-on-all-foreign-ports")

                                self.node_data = BundleInformation.MlacpMemberCounters.Members.Member.MemberItem.Items.NodeData.NodeData()
                                self.node_data.parent = self
                                self._children_name_map["node_data"] = "node-data"
                                self._children_yang_names.add("node-data")

                                self.member_data = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in () and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(BundleInformation.MlacpMemberCounters.Members.Member.MemberItem.Items.NodeData, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(BundleInformation.MlacpMemberCounters.Members.Member.MemberItem.Items.NodeData, self).__setattr__(name, value)


                            class NodeData(Entity):
                                """
                                Peer device mLACP TLV counter information
                                
                                .. attribute:: iccp_group_id
                                
                                	ICCP Group ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: node_id
                                
                                	Device ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'bundlemgr-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(BundleInformation.MlacpMemberCounters.Members.Member.MemberItem.Items.NodeData.NodeData, self).__init__()

                                    self.yang_name = "node-data"
                                    self.yang_parent_name = "node-data"

                                    self.iccp_group_id = YLeaf(YType.uint32, "iccp-group-id")

                                    self.node_id = YLeaf(YType.uint32, "node-id")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("iccp_group_id",
                                                    "node_id") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(BundleInformation.MlacpMemberCounters.Members.Member.MemberItem.Items.NodeData.NodeData, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(BundleInformation.MlacpMemberCounters.Members.Member.MemberItem.Items.NodeData.NodeData, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.iccp_group_id.is_set or
                                        self.node_id.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.iccp_group_id.yfilter != YFilter.not_set or
                                        self.node_id.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "node-data" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.iccp_group_id.is_set or self.iccp_group_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.iccp_group_id.get_name_leafdata())
                                    if (self.node_id.is_set or self.node_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.node_id.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "iccp-group-id" or name == "node-id"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "iccp-group-id"):
                                        self.iccp_group_id = value
                                        self.iccp_group_id.value_namespace = name_space
                                        self.iccp_group_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "node-id"):
                                        self.node_id = value
                                        self.node_id.value_namespace = name_space
                                        self.node_id.value_namespace_prefix = name_space_prefix


                            class MlacpSyncRequestsOnAllForeignPorts(Entity):
                                """
                                Counts of mLACP sync request TLVs on all ports
                                
                                .. attribute:: last_time_cleared
                                
                                	Time in nsecs from boot when counters were last cleared (deprecated)
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: nanosecond
                                
                                .. attribute:: received_sync_requests
                                
                                	Number of mLACP sync request TLVs received
                                	**type**\:   :py:class:`ReceivedSyncRequests <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.MlacpMemberCounters.Members.Member.MemberItem.Items.NodeData.MlacpSyncRequestsOnAllForeignPorts.ReceivedSyncRequests>`
                                
                                .. attribute:: time_since_cleared
                                
                                	Elapsed time in nsecs since counters were last cleared
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: nanosecond
                                
                                

                                """

                                _prefix = 'bundlemgr-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(BundleInformation.MlacpMemberCounters.Members.Member.MemberItem.Items.NodeData.MlacpSyncRequestsOnAllForeignPorts, self).__init__()

                                    self.yang_name = "mlacp-sync-requests-on-all-foreign-ports"
                                    self.yang_parent_name = "node-data"

                                    self.last_time_cleared = YLeaf(YType.uint64, "last-time-cleared")

                                    self.time_since_cleared = YLeaf(YType.uint64, "time-since-cleared")

                                    self.received_sync_requests = BundleInformation.MlacpMemberCounters.Members.Member.MemberItem.Items.NodeData.MlacpSyncRequestsOnAllForeignPorts.ReceivedSyncRequests()
                                    self.received_sync_requests.parent = self
                                    self._children_name_map["received_sync_requests"] = "received-sync-requests"
                                    self._children_yang_names.add("received-sync-requests")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("last_time_cleared",
                                                    "time_since_cleared") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(BundleInformation.MlacpMemberCounters.Members.Member.MemberItem.Items.NodeData.MlacpSyncRequestsOnAllForeignPorts, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(BundleInformation.MlacpMemberCounters.Members.Member.MemberItem.Items.NodeData.MlacpSyncRequestsOnAllForeignPorts, self).__setattr__(name, value)


                                class ReceivedSyncRequests(Entity):
                                    """
                                    Number of mLACP sync request TLVs received
                                    
                                    .. attribute:: all_syncs
                                    
                                    	Total number of sync requests received
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: config_syncs
                                    
                                    	Number of config sync requests received
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: state_syncs
                                    
                                    	Number of state sync requests received
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'bundlemgr-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(BundleInformation.MlacpMemberCounters.Members.Member.MemberItem.Items.NodeData.MlacpSyncRequestsOnAllForeignPorts.ReceivedSyncRequests, self).__init__()

                                        self.yang_name = "received-sync-requests"
                                        self.yang_parent_name = "mlacp-sync-requests-on-all-foreign-ports"

                                        self.all_syncs = YLeaf(YType.uint32, "all-syncs")

                                        self.config_syncs = YLeaf(YType.uint32, "config-syncs")

                                        self.state_syncs = YLeaf(YType.uint32, "state-syncs")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("all_syncs",
                                                        "config_syncs",
                                                        "state_syncs") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(BundleInformation.MlacpMemberCounters.Members.Member.MemberItem.Items.NodeData.MlacpSyncRequestsOnAllForeignPorts.ReceivedSyncRequests, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(BundleInformation.MlacpMemberCounters.Members.Member.MemberItem.Items.NodeData.MlacpSyncRequestsOnAllForeignPorts.ReceivedSyncRequests, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.all_syncs.is_set or
                                            self.config_syncs.is_set or
                                            self.state_syncs.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.all_syncs.yfilter != YFilter.not_set or
                                            self.config_syncs.yfilter != YFilter.not_set or
                                            self.state_syncs.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "received-sync-requests" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.all_syncs.is_set or self.all_syncs.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.all_syncs.get_name_leafdata())
                                        if (self.config_syncs.is_set or self.config_syncs.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.config_syncs.get_name_leafdata())
                                        if (self.state_syncs.is_set or self.state_syncs.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.state_syncs.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "all-syncs" or name == "config-syncs" or name == "state-syncs"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "all-syncs"):
                                            self.all_syncs = value
                                            self.all_syncs.value_namespace = name_space
                                            self.all_syncs.value_namespace_prefix = name_space_prefix
                                        if(value_path == "config-syncs"):
                                            self.config_syncs = value
                                            self.config_syncs.value_namespace = name_space
                                            self.config_syncs.value_namespace_prefix = name_space_prefix
                                        if(value_path == "state-syncs"):
                                            self.state_syncs = value
                                            self.state_syncs.value_namespace = name_space
                                            self.state_syncs.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.last_time_cleared.is_set or
                                        self.time_since_cleared.is_set or
                                        (self.received_sync_requests is not None and self.received_sync_requests.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.last_time_cleared.yfilter != YFilter.not_set or
                                        self.time_since_cleared.yfilter != YFilter.not_set or
                                        (self.received_sync_requests is not None and self.received_sync_requests.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "mlacp-sync-requests-on-all-foreign-ports" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.last_time_cleared.is_set or self.last_time_cleared.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.last_time_cleared.get_name_leafdata())
                                    if (self.time_since_cleared.is_set or self.time_since_cleared.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.time_since_cleared.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "received-sync-requests"):
                                        if (self.received_sync_requests is None):
                                            self.received_sync_requests = BundleInformation.MlacpMemberCounters.Members.Member.MemberItem.Items.NodeData.MlacpSyncRequestsOnAllForeignPorts.ReceivedSyncRequests()
                                            self.received_sync_requests.parent = self
                                            self._children_name_map["received_sync_requests"] = "received-sync-requests"
                                        return self.received_sync_requests

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "received-sync-requests" or name == "last-time-cleared" or name == "time-since-cleared"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "last-time-cleared"):
                                        self.last_time_cleared = value
                                        self.last_time_cleared.value_namespace = name_space
                                        self.last_time_cleared.value_namespace_prefix = name_space_prefix
                                    if(value_path == "time-since-cleared"):
                                        self.time_since_cleared = value
                                        self.time_since_cleared.value_namespace = name_space
                                        self.time_since_cleared.value_namespace_prefix = name_space_prefix


                            class MemberData(Entity):
                                """
                                Member mLACP TLV counter information
                                
                                .. attribute:: mlacp_tlv_counters
                                
                                	Counts of mLACP TLVs sent and received
                                	**type**\:   :py:class:`MlacpTlvCounters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.MlacpMemberCounters.Members.Member.MemberItem.Items.NodeData.MemberData.MlacpTlvCounters>`
                                
                                .. attribute:: port_name
                                
                                	Port name of member
                                	**type**\:  str
                                
                                

                                """

                                _prefix = 'bundlemgr-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(BundleInformation.MlacpMemberCounters.Members.Member.MemberItem.Items.NodeData.MemberData, self).__init__()

                                    self.yang_name = "member-data"
                                    self.yang_parent_name = "node-data"

                                    self.port_name = YLeaf(YType.str, "port-name")

                                    self.mlacp_tlv_counters = BundleInformation.MlacpMemberCounters.Members.Member.MemberItem.Items.NodeData.MemberData.MlacpTlvCounters()
                                    self.mlacp_tlv_counters.parent = self
                                    self._children_name_map["mlacp_tlv_counters"] = "mlacp-tlv-counters"
                                    self._children_yang_names.add("mlacp-tlv-counters")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("port_name") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(BundleInformation.MlacpMemberCounters.Members.Member.MemberItem.Items.NodeData.MemberData, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(BundleInformation.MlacpMemberCounters.Members.Member.MemberItem.Items.NodeData.MemberData, self).__setattr__(name, value)


                                class MlacpTlvCounters(Entity):
                                    """
                                    Counts of mLACP TLVs sent and received
                                    
                                    .. attribute:: last_time_cleared
                                    
                                    	Time in nsecs from boot when counters were last cleared (deprecated)
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: nanosecond
                                    
                                    .. attribute:: last_unexpected_event
                                    
                                    	Elapsed time in nsecs since last unexpected event
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: nanosecond
                                    
                                    .. attribute:: received_nak_tl_vs
                                    
                                    	Number of mLACP NAK TLVs received
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: received_priority_tl_vs
                                    
                                    	Number of mLACP priority TLVs received
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: received_sync_requests
                                    
                                    	Number of mLACP sync request TLVs received
                                    	**type**\:   :py:class:`ReceivedSyncRequests <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.MlacpMemberCounters.Members.Member.MemberItem.Items.NodeData.MemberData.MlacpTlvCounters.ReceivedSyncRequests>`
                                    
                                    .. attribute:: sent_config_tl_vs
                                    
                                    	Number of mLACP config TLVs sent
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: sent_priority_tl_vs
                                    
                                    	Number of mLACP priority TLVs sent
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: sent_state_tl_vs
                                    
                                    	Number of mLACP state TLVs sent
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: time_since_cleared
                                    
                                    	Elapsed time in nsecs since counters were last cleared
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: nanosecond
                                    
                                    

                                    """

                                    _prefix = 'bundlemgr-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(BundleInformation.MlacpMemberCounters.Members.Member.MemberItem.Items.NodeData.MemberData.MlacpTlvCounters, self).__init__()

                                        self.yang_name = "mlacp-tlv-counters"
                                        self.yang_parent_name = "member-data"

                                        self.last_time_cleared = YLeaf(YType.uint64, "last-time-cleared")

                                        self.last_unexpected_event = YLeaf(YType.uint64, "last-unexpected-event")

                                        self.received_nak_tl_vs = YLeaf(YType.uint32, "received-nak-tl-vs")

                                        self.received_priority_tl_vs = YLeaf(YType.uint32, "received-priority-tl-vs")

                                        self.sent_config_tl_vs = YLeaf(YType.uint32, "sent-config-tl-vs")

                                        self.sent_priority_tl_vs = YLeaf(YType.uint32, "sent-priority-tl-vs")

                                        self.sent_state_tl_vs = YLeaf(YType.uint32, "sent-state-tl-vs")

                                        self.time_since_cleared = YLeaf(YType.uint64, "time-since-cleared")

                                        self.received_sync_requests = BundleInformation.MlacpMemberCounters.Members.Member.MemberItem.Items.NodeData.MemberData.MlacpTlvCounters.ReceivedSyncRequests()
                                        self.received_sync_requests.parent = self
                                        self._children_name_map["received_sync_requests"] = "received-sync-requests"
                                        self._children_yang_names.add("received-sync-requests")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("last_time_cleared",
                                                        "last_unexpected_event",
                                                        "received_nak_tl_vs",
                                                        "received_priority_tl_vs",
                                                        "sent_config_tl_vs",
                                                        "sent_priority_tl_vs",
                                                        "sent_state_tl_vs",
                                                        "time_since_cleared") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(BundleInformation.MlacpMemberCounters.Members.Member.MemberItem.Items.NodeData.MemberData.MlacpTlvCounters, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(BundleInformation.MlacpMemberCounters.Members.Member.MemberItem.Items.NodeData.MemberData.MlacpTlvCounters, self).__setattr__(name, value)


                                    class ReceivedSyncRequests(Entity):
                                        """
                                        Number of mLACP sync request TLVs received
                                        
                                        .. attribute:: all_syncs
                                        
                                        	Total number of sync requests received
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: config_syncs
                                        
                                        	Number of config sync requests received
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: state_syncs
                                        
                                        	Number of state sync requests received
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'bundlemgr-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(BundleInformation.MlacpMemberCounters.Members.Member.MemberItem.Items.NodeData.MemberData.MlacpTlvCounters.ReceivedSyncRequests, self).__init__()

                                            self.yang_name = "received-sync-requests"
                                            self.yang_parent_name = "mlacp-tlv-counters"

                                            self.all_syncs = YLeaf(YType.uint32, "all-syncs")

                                            self.config_syncs = YLeaf(YType.uint32, "config-syncs")

                                            self.state_syncs = YLeaf(YType.uint32, "state-syncs")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("all_syncs",
                                                            "config_syncs",
                                                            "state_syncs") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(BundleInformation.MlacpMemberCounters.Members.Member.MemberItem.Items.NodeData.MemberData.MlacpTlvCounters.ReceivedSyncRequests, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(BundleInformation.MlacpMemberCounters.Members.Member.MemberItem.Items.NodeData.MemberData.MlacpTlvCounters.ReceivedSyncRequests, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.all_syncs.is_set or
                                                self.config_syncs.is_set or
                                                self.state_syncs.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.all_syncs.yfilter != YFilter.not_set or
                                                self.config_syncs.yfilter != YFilter.not_set or
                                                self.state_syncs.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "received-sync-requests" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.all_syncs.is_set or self.all_syncs.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.all_syncs.get_name_leafdata())
                                            if (self.config_syncs.is_set or self.config_syncs.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.config_syncs.get_name_leafdata())
                                            if (self.state_syncs.is_set or self.state_syncs.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.state_syncs.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "all-syncs" or name == "config-syncs" or name == "state-syncs"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "all-syncs"):
                                                self.all_syncs = value
                                                self.all_syncs.value_namespace = name_space
                                                self.all_syncs.value_namespace_prefix = name_space_prefix
                                            if(value_path == "config-syncs"):
                                                self.config_syncs = value
                                                self.config_syncs.value_namespace = name_space
                                                self.config_syncs.value_namespace_prefix = name_space_prefix
                                            if(value_path == "state-syncs"):
                                                self.state_syncs = value
                                                self.state_syncs.value_namespace = name_space
                                                self.state_syncs.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.last_time_cleared.is_set or
                                            self.last_unexpected_event.is_set or
                                            self.received_nak_tl_vs.is_set or
                                            self.received_priority_tl_vs.is_set or
                                            self.sent_config_tl_vs.is_set or
                                            self.sent_priority_tl_vs.is_set or
                                            self.sent_state_tl_vs.is_set or
                                            self.time_since_cleared.is_set or
                                            (self.received_sync_requests is not None and self.received_sync_requests.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.last_time_cleared.yfilter != YFilter.not_set or
                                            self.last_unexpected_event.yfilter != YFilter.not_set or
                                            self.received_nak_tl_vs.yfilter != YFilter.not_set or
                                            self.received_priority_tl_vs.yfilter != YFilter.not_set or
                                            self.sent_config_tl_vs.yfilter != YFilter.not_set or
                                            self.sent_priority_tl_vs.yfilter != YFilter.not_set or
                                            self.sent_state_tl_vs.yfilter != YFilter.not_set or
                                            self.time_since_cleared.yfilter != YFilter.not_set or
                                            (self.received_sync_requests is not None and self.received_sync_requests.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "mlacp-tlv-counters" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.last_time_cleared.is_set or self.last_time_cleared.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.last_time_cleared.get_name_leafdata())
                                        if (self.last_unexpected_event.is_set or self.last_unexpected_event.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.last_unexpected_event.get_name_leafdata())
                                        if (self.received_nak_tl_vs.is_set or self.received_nak_tl_vs.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.received_nak_tl_vs.get_name_leafdata())
                                        if (self.received_priority_tl_vs.is_set or self.received_priority_tl_vs.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.received_priority_tl_vs.get_name_leafdata())
                                        if (self.sent_config_tl_vs.is_set or self.sent_config_tl_vs.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.sent_config_tl_vs.get_name_leafdata())
                                        if (self.sent_priority_tl_vs.is_set or self.sent_priority_tl_vs.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.sent_priority_tl_vs.get_name_leafdata())
                                        if (self.sent_state_tl_vs.is_set or self.sent_state_tl_vs.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.sent_state_tl_vs.get_name_leafdata())
                                        if (self.time_since_cleared.is_set or self.time_since_cleared.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.time_since_cleared.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "received-sync-requests"):
                                            if (self.received_sync_requests is None):
                                                self.received_sync_requests = BundleInformation.MlacpMemberCounters.Members.Member.MemberItem.Items.NodeData.MemberData.MlacpTlvCounters.ReceivedSyncRequests()
                                                self.received_sync_requests.parent = self
                                                self._children_name_map["received_sync_requests"] = "received-sync-requests"
                                            return self.received_sync_requests

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "received-sync-requests" or name == "last-time-cleared" or name == "last-unexpected-event" or name == "received-nak-tl-vs" or name == "received-priority-tl-vs" or name == "sent-config-tl-vs" or name == "sent-priority-tl-vs" or name == "sent-state-tl-vs" or name == "time-since-cleared"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "last-time-cleared"):
                                            self.last_time_cleared = value
                                            self.last_time_cleared.value_namespace = name_space
                                            self.last_time_cleared.value_namespace_prefix = name_space_prefix
                                        if(value_path == "last-unexpected-event"):
                                            self.last_unexpected_event = value
                                            self.last_unexpected_event.value_namespace = name_space
                                            self.last_unexpected_event.value_namespace_prefix = name_space_prefix
                                        if(value_path == "received-nak-tl-vs"):
                                            self.received_nak_tl_vs = value
                                            self.received_nak_tl_vs.value_namespace = name_space
                                            self.received_nak_tl_vs.value_namespace_prefix = name_space_prefix
                                        if(value_path == "received-priority-tl-vs"):
                                            self.received_priority_tl_vs = value
                                            self.received_priority_tl_vs.value_namespace = name_space
                                            self.received_priority_tl_vs.value_namespace_prefix = name_space_prefix
                                        if(value_path == "sent-config-tl-vs"):
                                            self.sent_config_tl_vs = value
                                            self.sent_config_tl_vs.value_namespace = name_space
                                            self.sent_config_tl_vs.value_namespace_prefix = name_space_prefix
                                        if(value_path == "sent-priority-tl-vs"):
                                            self.sent_priority_tl_vs = value
                                            self.sent_priority_tl_vs.value_namespace = name_space
                                            self.sent_priority_tl_vs.value_namespace_prefix = name_space_prefix
                                        if(value_path == "sent-state-tl-vs"):
                                            self.sent_state_tl_vs = value
                                            self.sent_state_tl_vs.value_namespace = name_space
                                            self.sent_state_tl_vs.value_namespace_prefix = name_space_prefix
                                        if(value_path == "time-since-cleared"):
                                            self.time_since_cleared = value
                                            self.time_since_cleared.value_namespace = name_space
                                            self.time_since_cleared.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.port_name.is_set or
                                        (self.mlacp_tlv_counters is not None and self.mlacp_tlv_counters.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.port_name.yfilter != YFilter.not_set or
                                        (self.mlacp_tlv_counters is not None and self.mlacp_tlv_counters.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "member-data" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.port_name.is_set or self.port_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.port_name.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "mlacp-tlv-counters"):
                                        if (self.mlacp_tlv_counters is None):
                                            self.mlacp_tlv_counters = BundleInformation.MlacpMemberCounters.Members.Member.MemberItem.Items.NodeData.MemberData.MlacpTlvCounters()
                                            self.mlacp_tlv_counters.parent = self
                                            self._children_name_map["mlacp_tlv_counters"] = "mlacp-tlv-counters"
                                        return self.mlacp_tlv_counters

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "mlacp-tlv-counters" or name == "port-name"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "port-name"):
                                        self.port_name = value
                                        self.port_name.value_namespace = name_space
                                        self.port_name.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.member_data:
                                    if (c.has_data()):
                                        return True
                                return (
                                    (self.mlacp_sync_requests_on_all_foreign_ports is not None and self.mlacp_sync_requests_on_all_foreign_ports.has_data()) or
                                    (self.node_data is not None and self.node_data.has_data()))

                            def has_operation(self):
                                for c in self.member_data:
                                    if (c.has_operation()):
                                        return True
                                return (
                                    self.yfilter != YFilter.not_set or
                                    (self.mlacp_sync_requests_on_all_foreign_ports is not None and self.mlacp_sync_requests_on_all_foreign_ports.has_operation()) or
                                    (self.node_data is not None and self.node_data.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "node-data" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "member-data"):
                                    for c in self.member_data:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = BundleInformation.MlacpMemberCounters.Members.Member.MemberItem.Items.NodeData.MemberData()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.member_data.append(c)
                                    return c

                                if (child_yang_name == "mlacp-sync-requests-on-all-foreign-ports"):
                                    if (self.mlacp_sync_requests_on_all_foreign_ports is None):
                                        self.mlacp_sync_requests_on_all_foreign_ports = BundleInformation.MlacpMemberCounters.Members.Member.MemberItem.Items.NodeData.MlacpSyncRequestsOnAllForeignPorts()
                                        self.mlacp_sync_requests_on_all_foreign_ports.parent = self
                                        self._children_name_map["mlacp_sync_requests_on_all_foreign_ports"] = "mlacp-sync-requests-on-all-foreign-ports"
                                    return self.mlacp_sync_requests_on_all_foreign_ports

                                if (child_yang_name == "node-data"):
                                    if (self.node_data is None):
                                        self.node_data = BundleInformation.MlacpMemberCounters.Members.Member.MemberItem.Items.NodeData.NodeData()
                                        self.node_data.parent = self
                                        self._children_name_map["node_data"] = "node-data"
                                    return self.node_data

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "member-data" or name == "mlacp-sync-requests-on-all-foreign-ports" or name == "node-data"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass


                        class MemberData(Entity):
                            """
                            Local member mLACP TLV counter information
                            
                            .. attribute:: mlacp_tlv_counters
                            
                            	Counts of mLACP TLVs sent and received
                            	**type**\:   :py:class:`MlacpTlvCounters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.MlacpMemberCounters.Members.Member.MemberItem.Items.MemberData.MlacpTlvCounters>`
                            
                            .. attribute:: port_name
                            
                            	Port name of member
                            	**type**\:  str
                            
                            

                            """

                            _prefix = 'bundlemgr-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(BundleInformation.MlacpMemberCounters.Members.Member.MemberItem.Items.MemberData, self).__init__()

                                self.yang_name = "member-data"
                                self.yang_parent_name = "items"

                                self.port_name = YLeaf(YType.str, "port-name")

                                self.mlacp_tlv_counters = BundleInformation.MlacpMemberCounters.Members.Member.MemberItem.Items.MemberData.MlacpTlvCounters()
                                self.mlacp_tlv_counters.parent = self
                                self._children_name_map["mlacp_tlv_counters"] = "mlacp-tlv-counters"
                                self._children_yang_names.add("mlacp-tlv-counters")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("port_name") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(BundleInformation.MlacpMemberCounters.Members.Member.MemberItem.Items.MemberData, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(BundleInformation.MlacpMemberCounters.Members.Member.MemberItem.Items.MemberData, self).__setattr__(name, value)


                            class MlacpTlvCounters(Entity):
                                """
                                Counts of mLACP TLVs sent and received
                                
                                .. attribute:: last_time_cleared
                                
                                	Time in nsecs from boot when counters were last cleared (deprecated)
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: nanosecond
                                
                                .. attribute:: last_unexpected_event
                                
                                	Elapsed time in nsecs since last unexpected event
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: nanosecond
                                
                                .. attribute:: received_nak_tl_vs
                                
                                	Number of mLACP NAK TLVs received
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: received_priority_tl_vs
                                
                                	Number of mLACP priority TLVs received
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: received_sync_requests
                                
                                	Number of mLACP sync request TLVs received
                                	**type**\:   :py:class:`ReceivedSyncRequests <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.MlacpMemberCounters.Members.Member.MemberItem.Items.MemberData.MlacpTlvCounters.ReceivedSyncRequests>`
                                
                                .. attribute:: sent_config_tl_vs
                                
                                	Number of mLACP config TLVs sent
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: sent_priority_tl_vs
                                
                                	Number of mLACP priority TLVs sent
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: sent_state_tl_vs
                                
                                	Number of mLACP state TLVs sent
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: time_since_cleared
                                
                                	Elapsed time in nsecs since counters were last cleared
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: nanosecond
                                
                                

                                """

                                _prefix = 'bundlemgr-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(BundleInformation.MlacpMemberCounters.Members.Member.MemberItem.Items.MemberData.MlacpTlvCounters, self).__init__()

                                    self.yang_name = "mlacp-tlv-counters"
                                    self.yang_parent_name = "member-data"

                                    self.last_time_cleared = YLeaf(YType.uint64, "last-time-cleared")

                                    self.last_unexpected_event = YLeaf(YType.uint64, "last-unexpected-event")

                                    self.received_nak_tl_vs = YLeaf(YType.uint32, "received-nak-tl-vs")

                                    self.received_priority_tl_vs = YLeaf(YType.uint32, "received-priority-tl-vs")

                                    self.sent_config_tl_vs = YLeaf(YType.uint32, "sent-config-tl-vs")

                                    self.sent_priority_tl_vs = YLeaf(YType.uint32, "sent-priority-tl-vs")

                                    self.sent_state_tl_vs = YLeaf(YType.uint32, "sent-state-tl-vs")

                                    self.time_since_cleared = YLeaf(YType.uint64, "time-since-cleared")

                                    self.received_sync_requests = BundleInformation.MlacpMemberCounters.Members.Member.MemberItem.Items.MemberData.MlacpTlvCounters.ReceivedSyncRequests()
                                    self.received_sync_requests.parent = self
                                    self._children_name_map["received_sync_requests"] = "received-sync-requests"
                                    self._children_yang_names.add("received-sync-requests")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("last_time_cleared",
                                                    "last_unexpected_event",
                                                    "received_nak_tl_vs",
                                                    "received_priority_tl_vs",
                                                    "sent_config_tl_vs",
                                                    "sent_priority_tl_vs",
                                                    "sent_state_tl_vs",
                                                    "time_since_cleared") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(BundleInformation.MlacpMemberCounters.Members.Member.MemberItem.Items.MemberData.MlacpTlvCounters, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(BundleInformation.MlacpMemberCounters.Members.Member.MemberItem.Items.MemberData.MlacpTlvCounters, self).__setattr__(name, value)


                                class ReceivedSyncRequests(Entity):
                                    """
                                    Number of mLACP sync request TLVs received
                                    
                                    .. attribute:: all_syncs
                                    
                                    	Total number of sync requests received
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: config_syncs
                                    
                                    	Number of config sync requests received
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: state_syncs
                                    
                                    	Number of state sync requests received
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'bundlemgr-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(BundleInformation.MlacpMemberCounters.Members.Member.MemberItem.Items.MemberData.MlacpTlvCounters.ReceivedSyncRequests, self).__init__()

                                        self.yang_name = "received-sync-requests"
                                        self.yang_parent_name = "mlacp-tlv-counters"

                                        self.all_syncs = YLeaf(YType.uint32, "all-syncs")

                                        self.config_syncs = YLeaf(YType.uint32, "config-syncs")

                                        self.state_syncs = YLeaf(YType.uint32, "state-syncs")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("all_syncs",
                                                        "config_syncs",
                                                        "state_syncs") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(BundleInformation.MlacpMemberCounters.Members.Member.MemberItem.Items.MemberData.MlacpTlvCounters.ReceivedSyncRequests, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(BundleInformation.MlacpMemberCounters.Members.Member.MemberItem.Items.MemberData.MlacpTlvCounters.ReceivedSyncRequests, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.all_syncs.is_set or
                                            self.config_syncs.is_set or
                                            self.state_syncs.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.all_syncs.yfilter != YFilter.not_set or
                                            self.config_syncs.yfilter != YFilter.not_set or
                                            self.state_syncs.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "received-sync-requests" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.all_syncs.is_set or self.all_syncs.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.all_syncs.get_name_leafdata())
                                        if (self.config_syncs.is_set or self.config_syncs.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.config_syncs.get_name_leafdata())
                                        if (self.state_syncs.is_set or self.state_syncs.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.state_syncs.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "all-syncs" or name == "config-syncs" or name == "state-syncs"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "all-syncs"):
                                            self.all_syncs = value
                                            self.all_syncs.value_namespace = name_space
                                            self.all_syncs.value_namespace_prefix = name_space_prefix
                                        if(value_path == "config-syncs"):
                                            self.config_syncs = value
                                            self.config_syncs.value_namespace = name_space
                                            self.config_syncs.value_namespace_prefix = name_space_prefix
                                        if(value_path == "state-syncs"):
                                            self.state_syncs = value
                                            self.state_syncs.value_namespace = name_space
                                            self.state_syncs.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.last_time_cleared.is_set or
                                        self.last_unexpected_event.is_set or
                                        self.received_nak_tl_vs.is_set or
                                        self.received_priority_tl_vs.is_set or
                                        self.sent_config_tl_vs.is_set or
                                        self.sent_priority_tl_vs.is_set or
                                        self.sent_state_tl_vs.is_set or
                                        self.time_since_cleared.is_set or
                                        (self.received_sync_requests is not None and self.received_sync_requests.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.last_time_cleared.yfilter != YFilter.not_set or
                                        self.last_unexpected_event.yfilter != YFilter.not_set or
                                        self.received_nak_tl_vs.yfilter != YFilter.not_set or
                                        self.received_priority_tl_vs.yfilter != YFilter.not_set or
                                        self.sent_config_tl_vs.yfilter != YFilter.not_set or
                                        self.sent_priority_tl_vs.yfilter != YFilter.not_set or
                                        self.sent_state_tl_vs.yfilter != YFilter.not_set or
                                        self.time_since_cleared.yfilter != YFilter.not_set or
                                        (self.received_sync_requests is not None and self.received_sync_requests.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "mlacp-tlv-counters" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.last_time_cleared.is_set or self.last_time_cleared.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.last_time_cleared.get_name_leafdata())
                                    if (self.last_unexpected_event.is_set or self.last_unexpected_event.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.last_unexpected_event.get_name_leafdata())
                                    if (self.received_nak_tl_vs.is_set or self.received_nak_tl_vs.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.received_nak_tl_vs.get_name_leafdata())
                                    if (self.received_priority_tl_vs.is_set or self.received_priority_tl_vs.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.received_priority_tl_vs.get_name_leafdata())
                                    if (self.sent_config_tl_vs.is_set or self.sent_config_tl_vs.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.sent_config_tl_vs.get_name_leafdata())
                                    if (self.sent_priority_tl_vs.is_set or self.sent_priority_tl_vs.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.sent_priority_tl_vs.get_name_leafdata())
                                    if (self.sent_state_tl_vs.is_set or self.sent_state_tl_vs.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.sent_state_tl_vs.get_name_leafdata())
                                    if (self.time_since_cleared.is_set or self.time_since_cleared.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.time_since_cleared.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "received-sync-requests"):
                                        if (self.received_sync_requests is None):
                                            self.received_sync_requests = BundleInformation.MlacpMemberCounters.Members.Member.MemberItem.Items.MemberData.MlacpTlvCounters.ReceivedSyncRequests()
                                            self.received_sync_requests.parent = self
                                            self._children_name_map["received_sync_requests"] = "received-sync-requests"
                                        return self.received_sync_requests

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "received-sync-requests" or name == "last-time-cleared" or name == "last-unexpected-event" or name == "received-nak-tl-vs" or name == "received-priority-tl-vs" or name == "sent-config-tl-vs" or name == "sent-priority-tl-vs" or name == "sent-state-tl-vs" or name == "time-since-cleared"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "last-time-cleared"):
                                        self.last_time_cleared = value
                                        self.last_time_cleared.value_namespace = name_space
                                        self.last_time_cleared.value_namespace_prefix = name_space_prefix
                                    if(value_path == "last-unexpected-event"):
                                        self.last_unexpected_event = value
                                        self.last_unexpected_event.value_namespace = name_space
                                        self.last_unexpected_event.value_namespace_prefix = name_space_prefix
                                    if(value_path == "received-nak-tl-vs"):
                                        self.received_nak_tl_vs = value
                                        self.received_nak_tl_vs.value_namespace = name_space
                                        self.received_nak_tl_vs.value_namespace_prefix = name_space_prefix
                                    if(value_path == "received-priority-tl-vs"):
                                        self.received_priority_tl_vs = value
                                        self.received_priority_tl_vs.value_namespace = name_space
                                        self.received_priority_tl_vs.value_namespace_prefix = name_space_prefix
                                    if(value_path == "sent-config-tl-vs"):
                                        self.sent_config_tl_vs = value
                                        self.sent_config_tl_vs.value_namespace = name_space
                                        self.sent_config_tl_vs.value_namespace_prefix = name_space_prefix
                                    if(value_path == "sent-priority-tl-vs"):
                                        self.sent_priority_tl_vs = value
                                        self.sent_priority_tl_vs.value_namespace = name_space
                                        self.sent_priority_tl_vs.value_namespace_prefix = name_space_prefix
                                    if(value_path == "sent-state-tl-vs"):
                                        self.sent_state_tl_vs = value
                                        self.sent_state_tl_vs.value_namespace = name_space
                                        self.sent_state_tl_vs.value_namespace_prefix = name_space_prefix
                                    if(value_path == "time-since-cleared"):
                                        self.time_since_cleared = value
                                        self.time_since_cleared.value_namespace = name_space
                                        self.time_since_cleared.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.port_name.is_set or
                                    (self.mlacp_tlv_counters is not None and self.mlacp_tlv_counters.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.port_name.yfilter != YFilter.not_set or
                                    (self.mlacp_tlv_counters is not None and self.mlacp_tlv_counters.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "member-data" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.port_name.is_set or self.port_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.port_name.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "mlacp-tlv-counters"):
                                    if (self.mlacp_tlv_counters is None):
                                        self.mlacp_tlv_counters = BundleInformation.MlacpMemberCounters.Members.Member.MemberItem.Items.MemberData.MlacpTlvCounters()
                                        self.mlacp_tlv_counters.parent = self
                                        self._children_name_map["mlacp_tlv_counters"] = "mlacp-tlv-counters"
                                    return self.mlacp_tlv_counters

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "mlacp-tlv-counters" or name == "port-name"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "port-name"):
                                    self.port_name = value
                                    self.port_name.value_namespace = name_space
                                    self.port_name.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.member_data:
                                if (c.has_data()):
                                    return True
                            for c in self.node_data:
                                if (c.has_data()):
                                    return True
                            return (self.bundle_data is not None and self.bundle_data.has_data())

                        def has_operation(self):
                            for c in self.member_data:
                                if (c.has_operation()):
                                    return True
                            for c in self.node_data:
                                if (c.has_operation()):
                                    return True
                            return (
                                self.yfilter != YFilter.not_set or
                                (self.bundle_data is not None and self.bundle_data.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "items" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "bundle-data"):
                                if (self.bundle_data is None):
                                    self.bundle_data = BundleInformation.MlacpMemberCounters.Members.Member.MemberItem.Items.BundleData()
                                    self.bundle_data.parent = self
                                    self._children_name_map["bundle_data"] = "bundle-data"
                                return self.bundle_data

                            if (child_yang_name == "member-data"):
                                for c in self.member_data:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = BundleInformation.MlacpMemberCounters.Members.Member.MemberItem.Items.MemberData()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.member_data.append(c)
                                return c

                            if (child_yang_name == "node-data"):
                                for c in self.node_data:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = BundleInformation.MlacpMemberCounters.Members.Member.MemberItem.Items.NodeData()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.node_data.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "bundle-data" or name == "member-data" or name == "node-data"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass

                    def has_data(self):
                        for c in self.items:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.items:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "member-item" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "items"):
                            for c in self.items:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = BundleInformation.MlacpMemberCounters.Members.Member.MemberItem.Items()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.items.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "items"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass

                def has_data(self):
                    return (
                        self.member_interface.is_set or
                        (self.member_item is not None and self.member_item.has_data()))

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.member_interface.yfilter != YFilter.not_set or
                        (self.member_item is not None and self.member_item.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "member" + "[member-interface='" + self.member_interface.get() + "']" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-bundlemgr-oper:bundle-information/mlacp-member-counters/members/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.member_interface.is_set or self.member_interface.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.member_interface.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "member-item"):
                        if (self.member_item is None):
                            self.member_item = BundleInformation.MlacpMemberCounters.Members.Member.MemberItem()
                            self.member_item.parent = self
                            self._children_name_map["member_item"] = "member-item"
                        return self.member_item

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "member-item" or name == "member-interface"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "member-interface"):
                        self.member_interface = value
                        self.member_interface.value_namespace = name_space
                        self.member_interface.value_namespace_prefix = name_space_prefix

            def has_data(self):
                for c in self.member:
                    if (c.has_data()):
                        return True
                return False

            def has_operation(self):
                for c in self.member:
                    if (c.has_operation()):
                        return True
                return self.yfilter != YFilter.not_set

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "members" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-bundlemgr-oper:bundle-information/mlacp-member-counters/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "member"):
                    for c in self.member:
                        segment = c.get_segment_path()
                        if (segment_path == segment):
                            return c
                    c = BundleInformation.MlacpMemberCounters.Members.Member()
                    c.parent = self
                    local_reference_key = "ydk::seg::%s" % segment_path
                    self._local_refs[local_reference_key] = c
                    self.member.append(c)
                    return c

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "member"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                pass


        class Bundles(Entity):
            """
            Bundle interfaces with counters of their
            member's mLACP events
            
            .. attribute:: bundle
            
            	Bundle interface
            	**type**\: list of    :py:class:`Bundle <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.MlacpMemberCounters.Bundles.Bundle>`
            
            

            """

            _prefix = 'bundlemgr-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(BundleInformation.MlacpMemberCounters.Bundles, self).__init__()

                self.yang_name = "bundles"
                self.yang_parent_name = "mlacp-member-counters"

                self.bundle = YList(self)

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in () and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(BundleInformation.MlacpMemberCounters.Bundles, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(BundleInformation.MlacpMemberCounters.Bundles, self).__setattr__(name, value)


            class Bundle(Entity):
                """
                Bundle interface
                
                .. attribute:: bundle_interface  <key>
                
                	Bundle interface
                	**type**\:  str
                
                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                
                .. attribute:: bundle_item
                
                	Data for this item
                	**type**\:   :py:class:`BundleItem <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.MlacpMemberCounters.Bundles.Bundle.BundleItem>`
                
                

                """

                _prefix = 'bundlemgr-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(BundleInformation.MlacpMemberCounters.Bundles.Bundle, self).__init__()

                    self.yang_name = "bundle"
                    self.yang_parent_name = "bundles"

                    self.bundle_interface = YLeaf(YType.str, "bundle-interface")

                    self.bundle_item = BundleInformation.MlacpMemberCounters.Bundles.Bundle.BundleItem()
                    self.bundle_item.parent = self
                    self._children_name_map["bundle_item"] = "bundle-item"
                    self._children_yang_names.add("bundle-item")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("bundle_interface") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(BundleInformation.MlacpMemberCounters.Bundles.Bundle, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(BundleInformation.MlacpMemberCounters.Bundles.Bundle, self).__setattr__(name, value)


                class BundleItem(Entity):
                    """
                    Data for this item
                    
                    .. attribute:: bundle_data
                    
                    	Bundle mLACP TLV counter information
                    	**type**\:   :py:class:`BundleData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.MlacpMemberCounters.Bundles.Bundle.BundleItem.BundleData>`
                    
                    .. attribute:: member_data
                    
                    	Local member mLACP TLV counter information
                    	**type**\: list of    :py:class:`MemberData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.MlacpMemberCounters.Bundles.Bundle.BundleItem.MemberData>`
                    
                    .. attribute:: node_data
                    
                    	Peer device mLACP TLV counter information
                    	**type**\: list of    :py:class:`NodeData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.MlacpMemberCounters.Bundles.Bundle.BundleItem.NodeData>`
                    
                    

                    """

                    _prefix = 'bundlemgr-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(BundleInformation.MlacpMemberCounters.Bundles.Bundle.BundleItem, self).__init__()

                        self.yang_name = "bundle-item"
                        self.yang_parent_name = "bundle"

                        self.bundle_data = BundleInformation.MlacpMemberCounters.Bundles.Bundle.BundleItem.BundleData()
                        self.bundle_data.parent = self
                        self._children_name_map["bundle_data"] = "bundle-data"
                        self._children_yang_names.add("bundle-data")

                        self.member_data = YList(self)
                        self.node_data = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(BundleInformation.MlacpMemberCounters.Bundles.Bundle.BundleItem, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(BundleInformation.MlacpMemberCounters.Bundles.Bundle.BundleItem, self).__setattr__(name, value)


                    class BundleData(Entity):
                        """
                        Bundle mLACP TLV counter information
                        
                        .. attribute:: bundle_name
                        
                        	Name of the bundle
                        	**type**\:  str
                        
                        .. attribute:: iccp_group_id
                        
                        	ICCP Group ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: mlacp_sync_requests_on_all_local_ports
                        
                        	Counts of mLACP sync request TLVs on all ports
                        	**type**\:   :py:class:`MlacpSyncRequestsOnAllLocalPorts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.MlacpMemberCounters.Bundles.Bundle.BundleItem.BundleData.MlacpSyncRequestsOnAllLocalPorts>`
                        
                        

                        """

                        _prefix = 'bundlemgr-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(BundleInformation.MlacpMemberCounters.Bundles.Bundle.BundleItem.BundleData, self).__init__()

                            self.yang_name = "bundle-data"
                            self.yang_parent_name = "bundle-item"

                            self.bundle_name = YLeaf(YType.str, "bundle-name")

                            self.iccp_group_id = YLeaf(YType.uint32, "iccp-group-id")

                            self.mlacp_sync_requests_on_all_local_ports = BundleInformation.MlacpMemberCounters.Bundles.Bundle.BundleItem.BundleData.MlacpSyncRequestsOnAllLocalPorts()
                            self.mlacp_sync_requests_on_all_local_ports.parent = self
                            self._children_name_map["mlacp_sync_requests_on_all_local_ports"] = "mlacp-sync-requests-on-all-local-ports"
                            self._children_yang_names.add("mlacp-sync-requests-on-all-local-ports")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("bundle_name",
                                            "iccp_group_id") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(BundleInformation.MlacpMemberCounters.Bundles.Bundle.BundleItem.BundleData, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(BundleInformation.MlacpMemberCounters.Bundles.Bundle.BundleItem.BundleData, self).__setattr__(name, value)


                        class MlacpSyncRequestsOnAllLocalPorts(Entity):
                            """
                            Counts of mLACP sync request TLVs on all ports
                            
                            .. attribute:: last_time_cleared
                            
                            	Time in nsecs from boot when counters were last cleared (deprecated)
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: nanosecond
                            
                            .. attribute:: received_sync_requests
                            
                            	Number of mLACP sync request TLVs received
                            	**type**\:   :py:class:`ReceivedSyncRequests <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.MlacpMemberCounters.Bundles.Bundle.BundleItem.BundleData.MlacpSyncRequestsOnAllLocalPorts.ReceivedSyncRequests>`
                            
                            .. attribute:: time_since_cleared
                            
                            	Elapsed time in nsecs since counters were last cleared
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: nanosecond
                            
                            

                            """

                            _prefix = 'bundlemgr-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(BundleInformation.MlacpMemberCounters.Bundles.Bundle.BundleItem.BundleData.MlacpSyncRequestsOnAllLocalPorts, self).__init__()

                                self.yang_name = "mlacp-sync-requests-on-all-local-ports"
                                self.yang_parent_name = "bundle-data"

                                self.last_time_cleared = YLeaf(YType.uint64, "last-time-cleared")

                                self.time_since_cleared = YLeaf(YType.uint64, "time-since-cleared")

                                self.received_sync_requests = BundleInformation.MlacpMemberCounters.Bundles.Bundle.BundleItem.BundleData.MlacpSyncRequestsOnAllLocalPorts.ReceivedSyncRequests()
                                self.received_sync_requests.parent = self
                                self._children_name_map["received_sync_requests"] = "received-sync-requests"
                                self._children_yang_names.add("received-sync-requests")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("last_time_cleared",
                                                "time_since_cleared") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(BundleInformation.MlacpMemberCounters.Bundles.Bundle.BundleItem.BundleData.MlacpSyncRequestsOnAllLocalPorts, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(BundleInformation.MlacpMemberCounters.Bundles.Bundle.BundleItem.BundleData.MlacpSyncRequestsOnAllLocalPorts, self).__setattr__(name, value)


                            class ReceivedSyncRequests(Entity):
                                """
                                Number of mLACP sync request TLVs received
                                
                                .. attribute:: all_syncs
                                
                                	Total number of sync requests received
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: config_syncs
                                
                                	Number of config sync requests received
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: state_syncs
                                
                                	Number of state sync requests received
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'bundlemgr-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(BundleInformation.MlacpMemberCounters.Bundles.Bundle.BundleItem.BundleData.MlacpSyncRequestsOnAllLocalPorts.ReceivedSyncRequests, self).__init__()

                                    self.yang_name = "received-sync-requests"
                                    self.yang_parent_name = "mlacp-sync-requests-on-all-local-ports"

                                    self.all_syncs = YLeaf(YType.uint32, "all-syncs")

                                    self.config_syncs = YLeaf(YType.uint32, "config-syncs")

                                    self.state_syncs = YLeaf(YType.uint32, "state-syncs")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("all_syncs",
                                                    "config_syncs",
                                                    "state_syncs") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(BundleInformation.MlacpMemberCounters.Bundles.Bundle.BundleItem.BundleData.MlacpSyncRequestsOnAllLocalPorts.ReceivedSyncRequests, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(BundleInformation.MlacpMemberCounters.Bundles.Bundle.BundleItem.BundleData.MlacpSyncRequestsOnAllLocalPorts.ReceivedSyncRequests, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.all_syncs.is_set or
                                        self.config_syncs.is_set or
                                        self.state_syncs.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.all_syncs.yfilter != YFilter.not_set or
                                        self.config_syncs.yfilter != YFilter.not_set or
                                        self.state_syncs.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "received-sync-requests" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.all_syncs.is_set or self.all_syncs.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.all_syncs.get_name_leafdata())
                                    if (self.config_syncs.is_set or self.config_syncs.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.config_syncs.get_name_leafdata())
                                    if (self.state_syncs.is_set or self.state_syncs.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.state_syncs.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "all-syncs" or name == "config-syncs" or name == "state-syncs"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "all-syncs"):
                                        self.all_syncs = value
                                        self.all_syncs.value_namespace = name_space
                                        self.all_syncs.value_namespace_prefix = name_space_prefix
                                    if(value_path == "config-syncs"):
                                        self.config_syncs = value
                                        self.config_syncs.value_namespace = name_space
                                        self.config_syncs.value_namespace_prefix = name_space_prefix
                                    if(value_path == "state-syncs"):
                                        self.state_syncs = value
                                        self.state_syncs.value_namespace = name_space
                                        self.state_syncs.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.last_time_cleared.is_set or
                                    self.time_since_cleared.is_set or
                                    (self.received_sync_requests is not None and self.received_sync_requests.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.last_time_cleared.yfilter != YFilter.not_set or
                                    self.time_since_cleared.yfilter != YFilter.not_set or
                                    (self.received_sync_requests is not None and self.received_sync_requests.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "mlacp-sync-requests-on-all-local-ports" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.last_time_cleared.is_set or self.last_time_cleared.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.last_time_cleared.get_name_leafdata())
                                if (self.time_since_cleared.is_set or self.time_since_cleared.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.time_since_cleared.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "received-sync-requests"):
                                    if (self.received_sync_requests is None):
                                        self.received_sync_requests = BundleInformation.MlacpMemberCounters.Bundles.Bundle.BundleItem.BundleData.MlacpSyncRequestsOnAllLocalPorts.ReceivedSyncRequests()
                                        self.received_sync_requests.parent = self
                                        self._children_name_map["received_sync_requests"] = "received-sync-requests"
                                    return self.received_sync_requests

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "received-sync-requests" or name == "last-time-cleared" or name == "time-since-cleared"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "last-time-cleared"):
                                    self.last_time_cleared = value
                                    self.last_time_cleared.value_namespace = name_space
                                    self.last_time_cleared.value_namespace_prefix = name_space_prefix
                                if(value_path == "time-since-cleared"):
                                    self.time_since_cleared = value
                                    self.time_since_cleared.value_namespace = name_space
                                    self.time_since_cleared.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.bundle_name.is_set or
                                self.iccp_group_id.is_set or
                                (self.mlacp_sync_requests_on_all_local_ports is not None and self.mlacp_sync_requests_on_all_local_ports.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.bundle_name.yfilter != YFilter.not_set or
                                self.iccp_group_id.yfilter != YFilter.not_set or
                                (self.mlacp_sync_requests_on_all_local_ports is not None and self.mlacp_sync_requests_on_all_local_ports.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "bundle-data" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.bundle_name.is_set or self.bundle_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.bundle_name.get_name_leafdata())
                            if (self.iccp_group_id.is_set or self.iccp_group_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.iccp_group_id.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "mlacp-sync-requests-on-all-local-ports"):
                                if (self.mlacp_sync_requests_on_all_local_ports is None):
                                    self.mlacp_sync_requests_on_all_local_ports = BundleInformation.MlacpMemberCounters.Bundles.Bundle.BundleItem.BundleData.MlacpSyncRequestsOnAllLocalPorts()
                                    self.mlacp_sync_requests_on_all_local_ports.parent = self
                                    self._children_name_map["mlacp_sync_requests_on_all_local_ports"] = "mlacp-sync-requests-on-all-local-ports"
                                return self.mlacp_sync_requests_on_all_local_ports

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "mlacp-sync-requests-on-all-local-ports" or name == "bundle-name" or name == "iccp-group-id"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "bundle-name"):
                                self.bundle_name = value
                                self.bundle_name.value_namespace = name_space
                                self.bundle_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "iccp-group-id"):
                                self.iccp_group_id = value
                                self.iccp_group_id.value_namespace = name_space
                                self.iccp_group_id.value_namespace_prefix = name_space_prefix


                    class NodeData(Entity):
                        """
                        Peer device mLACP TLV counter information
                        
                        .. attribute:: member_data
                        
                        	Member mLACP TLV counter information
                        	**type**\: list of    :py:class:`MemberData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.MlacpMemberCounters.Bundles.Bundle.BundleItem.NodeData.MemberData>`
                        
                        .. attribute:: mlacp_sync_requests_on_all_foreign_ports
                        
                        	Counts of mLACP sync request TLVs on all ports
                        	**type**\:   :py:class:`MlacpSyncRequestsOnAllForeignPorts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.MlacpMemberCounters.Bundles.Bundle.BundleItem.NodeData.MlacpSyncRequestsOnAllForeignPorts>`
                        
                        .. attribute:: node_data
                        
                        	Peer device mLACP TLV counter information
                        	**type**\:   :py:class:`NodeData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.MlacpMemberCounters.Bundles.Bundle.BundleItem.NodeData.NodeData>`
                        
                        

                        """

                        _prefix = 'bundlemgr-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(BundleInformation.MlacpMemberCounters.Bundles.Bundle.BundleItem.NodeData, self).__init__()

                            self.yang_name = "node-data"
                            self.yang_parent_name = "bundle-item"

                            self.mlacp_sync_requests_on_all_foreign_ports = BundleInformation.MlacpMemberCounters.Bundles.Bundle.BundleItem.NodeData.MlacpSyncRequestsOnAllForeignPorts()
                            self.mlacp_sync_requests_on_all_foreign_ports.parent = self
                            self._children_name_map["mlacp_sync_requests_on_all_foreign_ports"] = "mlacp-sync-requests-on-all-foreign-ports"
                            self._children_yang_names.add("mlacp-sync-requests-on-all-foreign-ports")

                            self.node_data = BundleInformation.MlacpMemberCounters.Bundles.Bundle.BundleItem.NodeData.NodeData()
                            self.node_data.parent = self
                            self._children_name_map["node_data"] = "node-data"
                            self._children_yang_names.add("node-data")

                            self.member_data = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(BundleInformation.MlacpMemberCounters.Bundles.Bundle.BundleItem.NodeData, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(BundleInformation.MlacpMemberCounters.Bundles.Bundle.BundleItem.NodeData, self).__setattr__(name, value)


                        class NodeData(Entity):
                            """
                            Peer device mLACP TLV counter information
                            
                            .. attribute:: iccp_group_id
                            
                            	ICCP Group ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: node_id
                            
                            	Device ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'bundlemgr-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(BundleInformation.MlacpMemberCounters.Bundles.Bundle.BundleItem.NodeData.NodeData, self).__init__()

                                self.yang_name = "node-data"
                                self.yang_parent_name = "node-data"

                                self.iccp_group_id = YLeaf(YType.uint32, "iccp-group-id")

                                self.node_id = YLeaf(YType.uint32, "node-id")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("iccp_group_id",
                                                "node_id") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(BundleInformation.MlacpMemberCounters.Bundles.Bundle.BundleItem.NodeData.NodeData, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(BundleInformation.MlacpMemberCounters.Bundles.Bundle.BundleItem.NodeData.NodeData, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.iccp_group_id.is_set or
                                    self.node_id.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.iccp_group_id.yfilter != YFilter.not_set or
                                    self.node_id.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "node-data" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.iccp_group_id.is_set or self.iccp_group_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.iccp_group_id.get_name_leafdata())
                                if (self.node_id.is_set or self.node_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.node_id.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "iccp-group-id" or name == "node-id"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "iccp-group-id"):
                                    self.iccp_group_id = value
                                    self.iccp_group_id.value_namespace = name_space
                                    self.iccp_group_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "node-id"):
                                    self.node_id = value
                                    self.node_id.value_namespace = name_space
                                    self.node_id.value_namespace_prefix = name_space_prefix


                        class MlacpSyncRequestsOnAllForeignPorts(Entity):
                            """
                            Counts of mLACP sync request TLVs on all ports
                            
                            .. attribute:: last_time_cleared
                            
                            	Time in nsecs from boot when counters were last cleared (deprecated)
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: nanosecond
                            
                            .. attribute:: received_sync_requests
                            
                            	Number of mLACP sync request TLVs received
                            	**type**\:   :py:class:`ReceivedSyncRequests <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.MlacpMemberCounters.Bundles.Bundle.BundleItem.NodeData.MlacpSyncRequestsOnAllForeignPorts.ReceivedSyncRequests>`
                            
                            .. attribute:: time_since_cleared
                            
                            	Elapsed time in nsecs since counters were last cleared
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: nanosecond
                            
                            

                            """

                            _prefix = 'bundlemgr-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(BundleInformation.MlacpMemberCounters.Bundles.Bundle.BundleItem.NodeData.MlacpSyncRequestsOnAllForeignPorts, self).__init__()

                                self.yang_name = "mlacp-sync-requests-on-all-foreign-ports"
                                self.yang_parent_name = "node-data"

                                self.last_time_cleared = YLeaf(YType.uint64, "last-time-cleared")

                                self.time_since_cleared = YLeaf(YType.uint64, "time-since-cleared")

                                self.received_sync_requests = BundleInformation.MlacpMemberCounters.Bundles.Bundle.BundleItem.NodeData.MlacpSyncRequestsOnAllForeignPorts.ReceivedSyncRequests()
                                self.received_sync_requests.parent = self
                                self._children_name_map["received_sync_requests"] = "received-sync-requests"
                                self._children_yang_names.add("received-sync-requests")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("last_time_cleared",
                                                "time_since_cleared") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(BundleInformation.MlacpMemberCounters.Bundles.Bundle.BundleItem.NodeData.MlacpSyncRequestsOnAllForeignPorts, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(BundleInformation.MlacpMemberCounters.Bundles.Bundle.BundleItem.NodeData.MlacpSyncRequestsOnAllForeignPorts, self).__setattr__(name, value)


                            class ReceivedSyncRequests(Entity):
                                """
                                Number of mLACP sync request TLVs received
                                
                                .. attribute:: all_syncs
                                
                                	Total number of sync requests received
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: config_syncs
                                
                                	Number of config sync requests received
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: state_syncs
                                
                                	Number of state sync requests received
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'bundlemgr-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(BundleInformation.MlacpMemberCounters.Bundles.Bundle.BundleItem.NodeData.MlacpSyncRequestsOnAllForeignPorts.ReceivedSyncRequests, self).__init__()

                                    self.yang_name = "received-sync-requests"
                                    self.yang_parent_name = "mlacp-sync-requests-on-all-foreign-ports"

                                    self.all_syncs = YLeaf(YType.uint32, "all-syncs")

                                    self.config_syncs = YLeaf(YType.uint32, "config-syncs")

                                    self.state_syncs = YLeaf(YType.uint32, "state-syncs")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("all_syncs",
                                                    "config_syncs",
                                                    "state_syncs") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(BundleInformation.MlacpMemberCounters.Bundles.Bundle.BundleItem.NodeData.MlacpSyncRequestsOnAllForeignPorts.ReceivedSyncRequests, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(BundleInformation.MlacpMemberCounters.Bundles.Bundle.BundleItem.NodeData.MlacpSyncRequestsOnAllForeignPorts.ReceivedSyncRequests, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.all_syncs.is_set or
                                        self.config_syncs.is_set or
                                        self.state_syncs.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.all_syncs.yfilter != YFilter.not_set or
                                        self.config_syncs.yfilter != YFilter.not_set or
                                        self.state_syncs.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "received-sync-requests" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.all_syncs.is_set or self.all_syncs.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.all_syncs.get_name_leafdata())
                                    if (self.config_syncs.is_set or self.config_syncs.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.config_syncs.get_name_leafdata())
                                    if (self.state_syncs.is_set or self.state_syncs.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.state_syncs.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "all-syncs" or name == "config-syncs" or name == "state-syncs"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "all-syncs"):
                                        self.all_syncs = value
                                        self.all_syncs.value_namespace = name_space
                                        self.all_syncs.value_namespace_prefix = name_space_prefix
                                    if(value_path == "config-syncs"):
                                        self.config_syncs = value
                                        self.config_syncs.value_namespace = name_space
                                        self.config_syncs.value_namespace_prefix = name_space_prefix
                                    if(value_path == "state-syncs"):
                                        self.state_syncs = value
                                        self.state_syncs.value_namespace = name_space
                                        self.state_syncs.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.last_time_cleared.is_set or
                                    self.time_since_cleared.is_set or
                                    (self.received_sync_requests is not None and self.received_sync_requests.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.last_time_cleared.yfilter != YFilter.not_set or
                                    self.time_since_cleared.yfilter != YFilter.not_set or
                                    (self.received_sync_requests is not None and self.received_sync_requests.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "mlacp-sync-requests-on-all-foreign-ports" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.last_time_cleared.is_set or self.last_time_cleared.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.last_time_cleared.get_name_leafdata())
                                if (self.time_since_cleared.is_set or self.time_since_cleared.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.time_since_cleared.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "received-sync-requests"):
                                    if (self.received_sync_requests is None):
                                        self.received_sync_requests = BundleInformation.MlacpMemberCounters.Bundles.Bundle.BundleItem.NodeData.MlacpSyncRequestsOnAllForeignPorts.ReceivedSyncRequests()
                                        self.received_sync_requests.parent = self
                                        self._children_name_map["received_sync_requests"] = "received-sync-requests"
                                    return self.received_sync_requests

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "received-sync-requests" or name == "last-time-cleared" or name == "time-since-cleared"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "last-time-cleared"):
                                    self.last_time_cleared = value
                                    self.last_time_cleared.value_namespace = name_space
                                    self.last_time_cleared.value_namespace_prefix = name_space_prefix
                                if(value_path == "time-since-cleared"):
                                    self.time_since_cleared = value
                                    self.time_since_cleared.value_namespace = name_space
                                    self.time_since_cleared.value_namespace_prefix = name_space_prefix


                        class MemberData(Entity):
                            """
                            Member mLACP TLV counter information
                            
                            .. attribute:: mlacp_tlv_counters
                            
                            	Counts of mLACP TLVs sent and received
                            	**type**\:   :py:class:`MlacpTlvCounters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.MlacpMemberCounters.Bundles.Bundle.BundleItem.NodeData.MemberData.MlacpTlvCounters>`
                            
                            .. attribute:: port_name
                            
                            	Port name of member
                            	**type**\:  str
                            
                            

                            """

                            _prefix = 'bundlemgr-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(BundleInformation.MlacpMemberCounters.Bundles.Bundle.BundleItem.NodeData.MemberData, self).__init__()

                                self.yang_name = "member-data"
                                self.yang_parent_name = "node-data"

                                self.port_name = YLeaf(YType.str, "port-name")

                                self.mlacp_tlv_counters = BundleInformation.MlacpMemberCounters.Bundles.Bundle.BundleItem.NodeData.MemberData.MlacpTlvCounters()
                                self.mlacp_tlv_counters.parent = self
                                self._children_name_map["mlacp_tlv_counters"] = "mlacp-tlv-counters"
                                self._children_yang_names.add("mlacp-tlv-counters")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("port_name") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(BundleInformation.MlacpMemberCounters.Bundles.Bundle.BundleItem.NodeData.MemberData, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(BundleInformation.MlacpMemberCounters.Bundles.Bundle.BundleItem.NodeData.MemberData, self).__setattr__(name, value)


                            class MlacpTlvCounters(Entity):
                                """
                                Counts of mLACP TLVs sent and received
                                
                                .. attribute:: last_time_cleared
                                
                                	Time in nsecs from boot when counters were last cleared (deprecated)
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: nanosecond
                                
                                .. attribute:: last_unexpected_event
                                
                                	Elapsed time in nsecs since last unexpected event
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: nanosecond
                                
                                .. attribute:: received_nak_tl_vs
                                
                                	Number of mLACP NAK TLVs received
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: received_priority_tl_vs
                                
                                	Number of mLACP priority TLVs received
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: received_sync_requests
                                
                                	Number of mLACP sync request TLVs received
                                	**type**\:   :py:class:`ReceivedSyncRequests <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.MlacpMemberCounters.Bundles.Bundle.BundleItem.NodeData.MemberData.MlacpTlvCounters.ReceivedSyncRequests>`
                                
                                .. attribute:: sent_config_tl_vs
                                
                                	Number of mLACP config TLVs sent
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: sent_priority_tl_vs
                                
                                	Number of mLACP priority TLVs sent
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: sent_state_tl_vs
                                
                                	Number of mLACP state TLVs sent
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: time_since_cleared
                                
                                	Elapsed time in nsecs since counters were last cleared
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: nanosecond
                                
                                

                                """

                                _prefix = 'bundlemgr-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(BundleInformation.MlacpMemberCounters.Bundles.Bundle.BundleItem.NodeData.MemberData.MlacpTlvCounters, self).__init__()

                                    self.yang_name = "mlacp-tlv-counters"
                                    self.yang_parent_name = "member-data"

                                    self.last_time_cleared = YLeaf(YType.uint64, "last-time-cleared")

                                    self.last_unexpected_event = YLeaf(YType.uint64, "last-unexpected-event")

                                    self.received_nak_tl_vs = YLeaf(YType.uint32, "received-nak-tl-vs")

                                    self.received_priority_tl_vs = YLeaf(YType.uint32, "received-priority-tl-vs")

                                    self.sent_config_tl_vs = YLeaf(YType.uint32, "sent-config-tl-vs")

                                    self.sent_priority_tl_vs = YLeaf(YType.uint32, "sent-priority-tl-vs")

                                    self.sent_state_tl_vs = YLeaf(YType.uint32, "sent-state-tl-vs")

                                    self.time_since_cleared = YLeaf(YType.uint64, "time-since-cleared")

                                    self.received_sync_requests = BundleInformation.MlacpMemberCounters.Bundles.Bundle.BundleItem.NodeData.MemberData.MlacpTlvCounters.ReceivedSyncRequests()
                                    self.received_sync_requests.parent = self
                                    self._children_name_map["received_sync_requests"] = "received-sync-requests"
                                    self._children_yang_names.add("received-sync-requests")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("last_time_cleared",
                                                    "last_unexpected_event",
                                                    "received_nak_tl_vs",
                                                    "received_priority_tl_vs",
                                                    "sent_config_tl_vs",
                                                    "sent_priority_tl_vs",
                                                    "sent_state_tl_vs",
                                                    "time_since_cleared") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(BundleInformation.MlacpMemberCounters.Bundles.Bundle.BundleItem.NodeData.MemberData.MlacpTlvCounters, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(BundleInformation.MlacpMemberCounters.Bundles.Bundle.BundleItem.NodeData.MemberData.MlacpTlvCounters, self).__setattr__(name, value)


                                class ReceivedSyncRequests(Entity):
                                    """
                                    Number of mLACP sync request TLVs received
                                    
                                    .. attribute:: all_syncs
                                    
                                    	Total number of sync requests received
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: config_syncs
                                    
                                    	Number of config sync requests received
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: state_syncs
                                    
                                    	Number of state sync requests received
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'bundlemgr-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(BundleInformation.MlacpMemberCounters.Bundles.Bundle.BundleItem.NodeData.MemberData.MlacpTlvCounters.ReceivedSyncRequests, self).__init__()

                                        self.yang_name = "received-sync-requests"
                                        self.yang_parent_name = "mlacp-tlv-counters"

                                        self.all_syncs = YLeaf(YType.uint32, "all-syncs")

                                        self.config_syncs = YLeaf(YType.uint32, "config-syncs")

                                        self.state_syncs = YLeaf(YType.uint32, "state-syncs")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("all_syncs",
                                                        "config_syncs",
                                                        "state_syncs") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(BundleInformation.MlacpMemberCounters.Bundles.Bundle.BundleItem.NodeData.MemberData.MlacpTlvCounters.ReceivedSyncRequests, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(BundleInformation.MlacpMemberCounters.Bundles.Bundle.BundleItem.NodeData.MemberData.MlacpTlvCounters.ReceivedSyncRequests, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.all_syncs.is_set or
                                            self.config_syncs.is_set or
                                            self.state_syncs.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.all_syncs.yfilter != YFilter.not_set or
                                            self.config_syncs.yfilter != YFilter.not_set or
                                            self.state_syncs.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "received-sync-requests" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.all_syncs.is_set or self.all_syncs.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.all_syncs.get_name_leafdata())
                                        if (self.config_syncs.is_set or self.config_syncs.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.config_syncs.get_name_leafdata())
                                        if (self.state_syncs.is_set or self.state_syncs.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.state_syncs.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "all-syncs" or name == "config-syncs" or name == "state-syncs"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "all-syncs"):
                                            self.all_syncs = value
                                            self.all_syncs.value_namespace = name_space
                                            self.all_syncs.value_namespace_prefix = name_space_prefix
                                        if(value_path == "config-syncs"):
                                            self.config_syncs = value
                                            self.config_syncs.value_namespace = name_space
                                            self.config_syncs.value_namespace_prefix = name_space_prefix
                                        if(value_path == "state-syncs"):
                                            self.state_syncs = value
                                            self.state_syncs.value_namespace = name_space
                                            self.state_syncs.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.last_time_cleared.is_set or
                                        self.last_unexpected_event.is_set or
                                        self.received_nak_tl_vs.is_set or
                                        self.received_priority_tl_vs.is_set or
                                        self.sent_config_tl_vs.is_set or
                                        self.sent_priority_tl_vs.is_set or
                                        self.sent_state_tl_vs.is_set or
                                        self.time_since_cleared.is_set or
                                        (self.received_sync_requests is not None and self.received_sync_requests.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.last_time_cleared.yfilter != YFilter.not_set or
                                        self.last_unexpected_event.yfilter != YFilter.not_set or
                                        self.received_nak_tl_vs.yfilter != YFilter.not_set or
                                        self.received_priority_tl_vs.yfilter != YFilter.not_set or
                                        self.sent_config_tl_vs.yfilter != YFilter.not_set or
                                        self.sent_priority_tl_vs.yfilter != YFilter.not_set or
                                        self.sent_state_tl_vs.yfilter != YFilter.not_set or
                                        self.time_since_cleared.yfilter != YFilter.not_set or
                                        (self.received_sync_requests is not None and self.received_sync_requests.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "mlacp-tlv-counters" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.last_time_cleared.is_set or self.last_time_cleared.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.last_time_cleared.get_name_leafdata())
                                    if (self.last_unexpected_event.is_set or self.last_unexpected_event.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.last_unexpected_event.get_name_leafdata())
                                    if (self.received_nak_tl_vs.is_set or self.received_nak_tl_vs.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.received_nak_tl_vs.get_name_leafdata())
                                    if (self.received_priority_tl_vs.is_set or self.received_priority_tl_vs.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.received_priority_tl_vs.get_name_leafdata())
                                    if (self.sent_config_tl_vs.is_set or self.sent_config_tl_vs.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.sent_config_tl_vs.get_name_leafdata())
                                    if (self.sent_priority_tl_vs.is_set or self.sent_priority_tl_vs.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.sent_priority_tl_vs.get_name_leafdata())
                                    if (self.sent_state_tl_vs.is_set or self.sent_state_tl_vs.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.sent_state_tl_vs.get_name_leafdata())
                                    if (self.time_since_cleared.is_set or self.time_since_cleared.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.time_since_cleared.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "received-sync-requests"):
                                        if (self.received_sync_requests is None):
                                            self.received_sync_requests = BundleInformation.MlacpMemberCounters.Bundles.Bundle.BundleItem.NodeData.MemberData.MlacpTlvCounters.ReceivedSyncRequests()
                                            self.received_sync_requests.parent = self
                                            self._children_name_map["received_sync_requests"] = "received-sync-requests"
                                        return self.received_sync_requests

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "received-sync-requests" or name == "last-time-cleared" or name == "last-unexpected-event" or name == "received-nak-tl-vs" or name == "received-priority-tl-vs" or name == "sent-config-tl-vs" or name == "sent-priority-tl-vs" or name == "sent-state-tl-vs" or name == "time-since-cleared"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "last-time-cleared"):
                                        self.last_time_cleared = value
                                        self.last_time_cleared.value_namespace = name_space
                                        self.last_time_cleared.value_namespace_prefix = name_space_prefix
                                    if(value_path == "last-unexpected-event"):
                                        self.last_unexpected_event = value
                                        self.last_unexpected_event.value_namespace = name_space
                                        self.last_unexpected_event.value_namespace_prefix = name_space_prefix
                                    if(value_path == "received-nak-tl-vs"):
                                        self.received_nak_tl_vs = value
                                        self.received_nak_tl_vs.value_namespace = name_space
                                        self.received_nak_tl_vs.value_namespace_prefix = name_space_prefix
                                    if(value_path == "received-priority-tl-vs"):
                                        self.received_priority_tl_vs = value
                                        self.received_priority_tl_vs.value_namespace = name_space
                                        self.received_priority_tl_vs.value_namespace_prefix = name_space_prefix
                                    if(value_path == "sent-config-tl-vs"):
                                        self.sent_config_tl_vs = value
                                        self.sent_config_tl_vs.value_namespace = name_space
                                        self.sent_config_tl_vs.value_namespace_prefix = name_space_prefix
                                    if(value_path == "sent-priority-tl-vs"):
                                        self.sent_priority_tl_vs = value
                                        self.sent_priority_tl_vs.value_namespace = name_space
                                        self.sent_priority_tl_vs.value_namespace_prefix = name_space_prefix
                                    if(value_path == "sent-state-tl-vs"):
                                        self.sent_state_tl_vs = value
                                        self.sent_state_tl_vs.value_namespace = name_space
                                        self.sent_state_tl_vs.value_namespace_prefix = name_space_prefix
                                    if(value_path == "time-since-cleared"):
                                        self.time_since_cleared = value
                                        self.time_since_cleared.value_namespace = name_space
                                        self.time_since_cleared.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.port_name.is_set or
                                    (self.mlacp_tlv_counters is not None and self.mlacp_tlv_counters.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.port_name.yfilter != YFilter.not_set or
                                    (self.mlacp_tlv_counters is not None and self.mlacp_tlv_counters.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "member-data" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.port_name.is_set or self.port_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.port_name.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "mlacp-tlv-counters"):
                                    if (self.mlacp_tlv_counters is None):
                                        self.mlacp_tlv_counters = BundleInformation.MlacpMemberCounters.Bundles.Bundle.BundleItem.NodeData.MemberData.MlacpTlvCounters()
                                        self.mlacp_tlv_counters.parent = self
                                        self._children_name_map["mlacp_tlv_counters"] = "mlacp-tlv-counters"
                                    return self.mlacp_tlv_counters

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "mlacp-tlv-counters" or name == "port-name"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "port-name"):
                                    self.port_name = value
                                    self.port_name.value_namespace = name_space
                                    self.port_name.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.member_data:
                                if (c.has_data()):
                                    return True
                            return (
                                (self.mlacp_sync_requests_on_all_foreign_ports is not None and self.mlacp_sync_requests_on_all_foreign_ports.has_data()) or
                                (self.node_data is not None and self.node_data.has_data()))

                        def has_operation(self):
                            for c in self.member_data:
                                if (c.has_operation()):
                                    return True
                            return (
                                self.yfilter != YFilter.not_set or
                                (self.mlacp_sync_requests_on_all_foreign_ports is not None and self.mlacp_sync_requests_on_all_foreign_ports.has_operation()) or
                                (self.node_data is not None and self.node_data.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "node-data" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "member-data"):
                                for c in self.member_data:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = BundleInformation.MlacpMemberCounters.Bundles.Bundle.BundleItem.NodeData.MemberData()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.member_data.append(c)
                                return c

                            if (child_yang_name == "mlacp-sync-requests-on-all-foreign-ports"):
                                if (self.mlacp_sync_requests_on_all_foreign_ports is None):
                                    self.mlacp_sync_requests_on_all_foreign_ports = BundleInformation.MlacpMemberCounters.Bundles.Bundle.BundleItem.NodeData.MlacpSyncRequestsOnAllForeignPorts()
                                    self.mlacp_sync_requests_on_all_foreign_ports.parent = self
                                    self._children_name_map["mlacp_sync_requests_on_all_foreign_ports"] = "mlacp-sync-requests-on-all-foreign-ports"
                                return self.mlacp_sync_requests_on_all_foreign_ports

                            if (child_yang_name == "node-data"):
                                if (self.node_data is None):
                                    self.node_data = BundleInformation.MlacpMemberCounters.Bundles.Bundle.BundleItem.NodeData.NodeData()
                                    self.node_data.parent = self
                                    self._children_name_map["node_data"] = "node-data"
                                return self.node_data

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "member-data" or name == "mlacp-sync-requests-on-all-foreign-ports" or name == "node-data"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass


                    class MemberData(Entity):
                        """
                        Local member mLACP TLV counter information
                        
                        .. attribute:: mlacp_tlv_counters
                        
                        	Counts of mLACP TLVs sent and received
                        	**type**\:   :py:class:`MlacpTlvCounters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.MlacpMemberCounters.Bundles.Bundle.BundleItem.MemberData.MlacpTlvCounters>`
                        
                        .. attribute:: port_name
                        
                        	Port name of member
                        	**type**\:  str
                        
                        

                        """

                        _prefix = 'bundlemgr-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(BundleInformation.MlacpMemberCounters.Bundles.Bundle.BundleItem.MemberData, self).__init__()

                            self.yang_name = "member-data"
                            self.yang_parent_name = "bundle-item"

                            self.port_name = YLeaf(YType.str, "port-name")

                            self.mlacp_tlv_counters = BundleInformation.MlacpMemberCounters.Bundles.Bundle.BundleItem.MemberData.MlacpTlvCounters()
                            self.mlacp_tlv_counters.parent = self
                            self._children_name_map["mlacp_tlv_counters"] = "mlacp-tlv-counters"
                            self._children_yang_names.add("mlacp-tlv-counters")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("port_name") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(BundleInformation.MlacpMemberCounters.Bundles.Bundle.BundleItem.MemberData, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(BundleInformation.MlacpMemberCounters.Bundles.Bundle.BundleItem.MemberData, self).__setattr__(name, value)


                        class MlacpTlvCounters(Entity):
                            """
                            Counts of mLACP TLVs sent and received
                            
                            .. attribute:: last_time_cleared
                            
                            	Time in nsecs from boot when counters were last cleared (deprecated)
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: nanosecond
                            
                            .. attribute:: last_unexpected_event
                            
                            	Elapsed time in nsecs since last unexpected event
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: nanosecond
                            
                            .. attribute:: received_nak_tl_vs
                            
                            	Number of mLACP NAK TLVs received
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: received_priority_tl_vs
                            
                            	Number of mLACP priority TLVs received
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: received_sync_requests
                            
                            	Number of mLACP sync request TLVs received
                            	**type**\:   :py:class:`ReceivedSyncRequests <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.MlacpMemberCounters.Bundles.Bundle.BundleItem.MemberData.MlacpTlvCounters.ReceivedSyncRequests>`
                            
                            .. attribute:: sent_config_tl_vs
                            
                            	Number of mLACP config TLVs sent
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: sent_priority_tl_vs
                            
                            	Number of mLACP priority TLVs sent
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: sent_state_tl_vs
                            
                            	Number of mLACP state TLVs sent
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: time_since_cleared
                            
                            	Elapsed time in nsecs since counters were last cleared
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: nanosecond
                            
                            

                            """

                            _prefix = 'bundlemgr-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(BundleInformation.MlacpMemberCounters.Bundles.Bundle.BundleItem.MemberData.MlacpTlvCounters, self).__init__()

                                self.yang_name = "mlacp-tlv-counters"
                                self.yang_parent_name = "member-data"

                                self.last_time_cleared = YLeaf(YType.uint64, "last-time-cleared")

                                self.last_unexpected_event = YLeaf(YType.uint64, "last-unexpected-event")

                                self.received_nak_tl_vs = YLeaf(YType.uint32, "received-nak-tl-vs")

                                self.received_priority_tl_vs = YLeaf(YType.uint32, "received-priority-tl-vs")

                                self.sent_config_tl_vs = YLeaf(YType.uint32, "sent-config-tl-vs")

                                self.sent_priority_tl_vs = YLeaf(YType.uint32, "sent-priority-tl-vs")

                                self.sent_state_tl_vs = YLeaf(YType.uint32, "sent-state-tl-vs")

                                self.time_since_cleared = YLeaf(YType.uint64, "time-since-cleared")

                                self.received_sync_requests = BundleInformation.MlacpMemberCounters.Bundles.Bundle.BundleItem.MemberData.MlacpTlvCounters.ReceivedSyncRequests()
                                self.received_sync_requests.parent = self
                                self._children_name_map["received_sync_requests"] = "received-sync-requests"
                                self._children_yang_names.add("received-sync-requests")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("last_time_cleared",
                                                "last_unexpected_event",
                                                "received_nak_tl_vs",
                                                "received_priority_tl_vs",
                                                "sent_config_tl_vs",
                                                "sent_priority_tl_vs",
                                                "sent_state_tl_vs",
                                                "time_since_cleared") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(BundleInformation.MlacpMemberCounters.Bundles.Bundle.BundleItem.MemberData.MlacpTlvCounters, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(BundleInformation.MlacpMemberCounters.Bundles.Bundle.BundleItem.MemberData.MlacpTlvCounters, self).__setattr__(name, value)


                            class ReceivedSyncRequests(Entity):
                                """
                                Number of mLACP sync request TLVs received
                                
                                .. attribute:: all_syncs
                                
                                	Total number of sync requests received
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: config_syncs
                                
                                	Number of config sync requests received
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: state_syncs
                                
                                	Number of state sync requests received
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'bundlemgr-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(BundleInformation.MlacpMemberCounters.Bundles.Bundle.BundleItem.MemberData.MlacpTlvCounters.ReceivedSyncRequests, self).__init__()

                                    self.yang_name = "received-sync-requests"
                                    self.yang_parent_name = "mlacp-tlv-counters"

                                    self.all_syncs = YLeaf(YType.uint32, "all-syncs")

                                    self.config_syncs = YLeaf(YType.uint32, "config-syncs")

                                    self.state_syncs = YLeaf(YType.uint32, "state-syncs")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("all_syncs",
                                                    "config_syncs",
                                                    "state_syncs") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(BundleInformation.MlacpMemberCounters.Bundles.Bundle.BundleItem.MemberData.MlacpTlvCounters.ReceivedSyncRequests, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(BundleInformation.MlacpMemberCounters.Bundles.Bundle.BundleItem.MemberData.MlacpTlvCounters.ReceivedSyncRequests, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.all_syncs.is_set or
                                        self.config_syncs.is_set or
                                        self.state_syncs.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.all_syncs.yfilter != YFilter.not_set or
                                        self.config_syncs.yfilter != YFilter.not_set or
                                        self.state_syncs.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "received-sync-requests" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.all_syncs.is_set or self.all_syncs.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.all_syncs.get_name_leafdata())
                                    if (self.config_syncs.is_set or self.config_syncs.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.config_syncs.get_name_leafdata())
                                    if (self.state_syncs.is_set or self.state_syncs.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.state_syncs.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "all-syncs" or name == "config-syncs" or name == "state-syncs"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "all-syncs"):
                                        self.all_syncs = value
                                        self.all_syncs.value_namespace = name_space
                                        self.all_syncs.value_namespace_prefix = name_space_prefix
                                    if(value_path == "config-syncs"):
                                        self.config_syncs = value
                                        self.config_syncs.value_namespace = name_space
                                        self.config_syncs.value_namespace_prefix = name_space_prefix
                                    if(value_path == "state-syncs"):
                                        self.state_syncs = value
                                        self.state_syncs.value_namespace = name_space
                                        self.state_syncs.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.last_time_cleared.is_set or
                                    self.last_unexpected_event.is_set or
                                    self.received_nak_tl_vs.is_set or
                                    self.received_priority_tl_vs.is_set or
                                    self.sent_config_tl_vs.is_set or
                                    self.sent_priority_tl_vs.is_set or
                                    self.sent_state_tl_vs.is_set or
                                    self.time_since_cleared.is_set or
                                    (self.received_sync_requests is not None and self.received_sync_requests.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.last_time_cleared.yfilter != YFilter.not_set or
                                    self.last_unexpected_event.yfilter != YFilter.not_set or
                                    self.received_nak_tl_vs.yfilter != YFilter.not_set or
                                    self.received_priority_tl_vs.yfilter != YFilter.not_set or
                                    self.sent_config_tl_vs.yfilter != YFilter.not_set or
                                    self.sent_priority_tl_vs.yfilter != YFilter.not_set or
                                    self.sent_state_tl_vs.yfilter != YFilter.not_set or
                                    self.time_since_cleared.yfilter != YFilter.not_set or
                                    (self.received_sync_requests is not None and self.received_sync_requests.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "mlacp-tlv-counters" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.last_time_cleared.is_set or self.last_time_cleared.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.last_time_cleared.get_name_leafdata())
                                if (self.last_unexpected_event.is_set or self.last_unexpected_event.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.last_unexpected_event.get_name_leafdata())
                                if (self.received_nak_tl_vs.is_set or self.received_nak_tl_vs.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.received_nak_tl_vs.get_name_leafdata())
                                if (self.received_priority_tl_vs.is_set or self.received_priority_tl_vs.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.received_priority_tl_vs.get_name_leafdata())
                                if (self.sent_config_tl_vs.is_set or self.sent_config_tl_vs.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.sent_config_tl_vs.get_name_leafdata())
                                if (self.sent_priority_tl_vs.is_set or self.sent_priority_tl_vs.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.sent_priority_tl_vs.get_name_leafdata())
                                if (self.sent_state_tl_vs.is_set or self.sent_state_tl_vs.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.sent_state_tl_vs.get_name_leafdata())
                                if (self.time_since_cleared.is_set or self.time_since_cleared.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.time_since_cleared.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "received-sync-requests"):
                                    if (self.received_sync_requests is None):
                                        self.received_sync_requests = BundleInformation.MlacpMemberCounters.Bundles.Bundle.BundleItem.MemberData.MlacpTlvCounters.ReceivedSyncRequests()
                                        self.received_sync_requests.parent = self
                                        self._children_name_map["received_sync_requests"] = "received-sync-requests"
                                    return self.received_sync_requests

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "received-sync-requests" or name == "last-time-cleared" or name == "last-unexpected-event" or name == "received-nak-tl-vs" or name == "received-priority-tl-vs" or name == "sent-config-tl-vs" or name == "sent-priority-tl-vs" or name == "sent-state-tl-vs" or name == "time-since-cleared"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "last-time-cleared"):
                                    self.last_time_cleared = value
                                    self.last_time_cleared.value_namespace = name_space
                                    self.last_time_cleared.value_namespace_prefix = name_space_prefix
                                if(value_path == "last-unexpected-event"):
                                    self.last_unexpected_event = value
                                    self.last_unexpected_event.value_namespace = name_space
                                    self.last_unexpected_event.value_namespace_prefix = name_space_prefix
                                if(value_path == "received-nak-tl-vs"):
                                    self.received_nak_tl_vs = value
                                    self.received_nak_tl_vs.value_namespace = name_space
                                    self.received_nak_tl_vs.value_namespace_prefix = name_space_prefix
                                if(value_path == "received-priority-tl-vs"):
                                    self.received_priority_tl_vs = value
                                    self.received_priority_tl_vs.value_namespace = name_space
                                    self.received_priority_tl_vs.value_namespace_prefix = name_space_prefix
                                if(value_path == "sent-config-tl-vs"):
                                    self.sent_config_tl_vs = value
                                    self.sent_config_tl_vs.value_namespace = name_space
                                    self.sent_config_tl_vs.value_namespace_prefix = name_space_prefix
                                if(value_path == "sent-priority-tl-vs"):
                                    self.sent_priority_tl_vs = value
                                    self.sent_priority_tl_vs.value_namespace = name_space
                                    self.sent_priority_tl_vs.value_namespace_prefix = name_space_prefix
                                if(value_path == "sent-state-tl-vs"):
                                    self.sent_state_tl_vs = value
                                    self.sent_state_tl_vs.value_namespace = name_space
                                    self.sent_state_tl_vs.value_namespace_prefix = name_space_prefix
                                if(value_path == "time-since-cleared"):
                                    self.time_since_cleared = value
                                    self.time_since_cleared.value_namespace = name_space
                                    self.time_since_cleared.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.port_name.is_set or
                                (self.mlacp_tlv_counters is not None and self.mlacp_tlv_counters.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.port_name.yfilter != YFilter.not_set or
                                (self.mlacp_tlv_counters is not None and self.mlacp_tlv_counters.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "member-data" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.port_name.is_set or self.port_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.port_name.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "mlacp-tlv-counters"):
                                if (self.mlacp_tlv_counters is None):
                                    self.mlacp_tlv_counters = BundleInformation.MlacpMemberCounters.Bundles.Bundle.BundleItem.MemberData.MlacpTlvCounters()
                                    self.mlacp_tlv_counters.parent = self
                                    self._children_name_map["mlacp_tlv_counters"] = "mlacp-tlv-counters"
                                return self.mlacp_tlv_counters

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "mlacp-tlv-counters" or name == "port-name"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "port-name"):
                                self.port_name = value
                                self.port_name.value_namespace = name_space
                                self.port_name.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.member_data:
                            if (c.has_data()):
                                return True
                        for c in self.node_data:
                            if (c.has_data()):
                                return True
                        return (self.bundle_data is not None and self.bundle_data.has_data())

                    def has_operation(self):
                        for c in self.member_data:
                            if (c.has_operation()):
                                return True
                        for c in self.node_data:
                            if (c.has_operation()):
                                return True
                        return (
                            self.yfilter != YFilter.not_set or
                            (self.bundle_data is not None and self.bundle_data.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "bundle-item" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "bundle-data"):
                            if (self.bundle_data is None):
                                self.bundle_data = BundleInformation.MlacpMemberCounters.Bundles.Bundle.BundleItem.BundleData()
                                self.bundle_data.parent = self
                                self._children_name_map["bundle_data"] = "bundle-data"
                            return self.bundle_data

                        if (child_yang_name == "member-data"):
                            for c in self.member_data:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = BundleInformation.MlacpMemberCounters.Bundles.Bundle.BundleItem.MemberData()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.member_data.append(c)
                            return c

                        if (child_yang_name == "node-data"):
                            for c in self.node_data:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = BundleInformation.MlacpMemberCounters.Bundles.Bundle.BundleItem.NodeData()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.node_data.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "bundle-data" or name == "member-data" or name == "node-data"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass

                def has_data(self):
                    return (
                        self.bundle_interface.is_set or
                        (self.bundle_item is not None and self.bundle_item.has_data()))

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.bundle_interface.yfilter != YFilter.not_set or
                        (self.bundle_item is not None and self.bundle_item.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "bundle" + "[bundle-interface='" + self.bundle_interface.get() + "']" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-bundlemgr-oper:bundle-information/mlacp-member-counters/bundles/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.bundle_interface.is_set or self.bundle_interface.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.bundle_interface.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "bundle-item"):
                        if (self.bundle_item is None):
                            self.bundle_item = BundleInformation.MlacpMemberCounters.Bundles.Bundle.BundleItem()
                            self.bundle_item.parent = self
                            self._children_name_map["bundle_item"] = "bundle-item"
                        return self.bundle_item

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "bundle-item" or name == "bundle-interface"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "bundle-interface"):
                        self.bundle_interface = value
                        self.bundle_interface.value_namespace = name_space
                        self.bundle_interface.value_namespace_prefix = name_space_prefix

            def has_data(self):
                for c in self.bundle:
                    if (c.has_data()):
                        return True
                return False

            def has_operation(self):
                for c in self.bundle:
                    if (c.has_operation()):
                        return True
                return self.yfilter != YFilter.not_set

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "bundles" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-bundlemgr-oper:bundle-information/mlacp-member-counters/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "bundle"):
                    for c in self.bundle:
                        segment = c.get_segment_path()
                        if (segment_path == segment):
                            return c
                    c = BundleInformation.MlacpMemberCounters.Bundles.Bundle()
                    c.parent = self
                    local_reference_key = "ydk::seg::%s" % segment_path
                    self._local_refs[local_reference_key] = c
                    self.bundle.append(c)
                    return c

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "bundle"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                pass


        class Nodes(Entity):
            """
            Devices with counters of their member's mLACP
            events
            
            .. attribute:: node
            
            	Node ID
            	**type**\: list of    :py:class:`Node <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.MlacpMemberCounters.Nodes.Node>`
            
            

            """

            _prefix = 'bundlemgr-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(BundleInformation.MlacpMemberCounters.Nodes, self).__init__()

                self.yang_name = "nodes"
                self.yang_parent_name = "mlacp-member-counters"

                self.node = YList(self)

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in () and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(BundleInformation.MlacpMemberCounters.Nodes, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(BundleInformation.MlacpMemberCounters.Nodes, self).__setattr__(name, value)


            class Node(Entity):
                """
                Node ID
                
                .. attribute:: node  <key>
                
                	For a local device the Node ID e.g. '0\_0\_CPU0', for a peer device the LDP ID followed by the ICCP Group ID e.g. '5.4.3.2 ,4'
                	**type**\:  str
                
                .. attribute:: node_item
                
                	Data for this item
                	**type**\:   :py:class:`NodeItem <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.MlacpMemberCounters.Nodes.Node.NodeItem>`
                
                

                """

                _prefix = 'bundlemgr-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(BundleInformation.MlacpMemberCounters.Nodes.Node, self).__init__()

                    self.yang_name = "node"
                    self.yang_parent_name = "nodes"

                    self.node = YLeaf(YType.str, "node")

                    self.node_item = BundleInformation.MlacpMemberCounters.Nodes.Node.NodeItem()
                    self.node_item.parent = self
                    self._children_name_map["node_item"] = "node-item"
                    self._children_yang_names.add("node-item")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("node") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(BundleInformation.MlacpMemberCounters.Nodes.Node, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(BundleInformation.MlacpMemberCounters.Nodes.Node, self).__setattr__(name, value)


                class NodeItem(Entity):
                    """
                    Data for this item
                    
                    .. attribute:: items
                    
                    	mLACP counter information items
                    	**type**\: list of    :py:class:`Items <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.MlacpMemberCounters.Nodes.Node.NodeItem.Items>`
                    
                    

                    """

                    _prefix = 'bundlemgr-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(BundleInformation.MlacpMemberCounters.Nodes.Node.NodeItem, self).__init__()

                        self.yang_name = "node-item"
                        self.yang_parent_name = "node"

                        self.items = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(BundleInformation.MlacpMemberCounters.Nodes.Node.NodeItem, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(BundleInformation.MlacpMemberCounters.Nodes.Node.NodeItem, self).__setattr__(name, value)


                    class Items(Entity):
                        """
                        mLACP counter information items
                        
                        .. attribute:: bundle_data
                        
                        	Bundle mLACP TLV counter information
                        	**type**\:   :py:class:`BundleData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.MlacpMemberCounters.Nodes.Node.NodeItem.Items.BundleData>`
                        
                        .. attribute:: member_data
                        
                        	Local member mLACP TLV counter information
                        	**type**\: list of    :py:class:`MemberData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.MlacpMemberCounters.Nodes.Node.NodeItem.Items.MemberData>`
                        
                        .. attribute:: node_data
                        
                        	Peer device mLACP TLV counter information
                        	**type**\: list of    :py:class:`NodeData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.MlacpMemberCounters.Nodes.Node.NodeItem.Items.NodeData>`
                        
                        

                        """

                        _prefix = 'bundlemgr-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(BundleInformation.MlacpMemberCounters.Nodes.Node.NodeItem.Items, self).__init__()

                            self.yang_name = "items"
                            self.yang_parent_name = "node-item"

                            self.bundle_data = BundleInformation.MlacpMemberCounters.Nodes.Node.NodeItem.Items.BundleData()
                            self.bundle_data.parent = self
                            self._children_name_map["bundle_data"] = "bundle-data"
                            self._children_yang_names.add("bundle-data")

                            self.member_data = YList(self)
                            self.node_data = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(BundleInformation.MlacpMemberCounters.Nodes.Node.NodeItem.Items, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(BundleInformation.MlacpMemberCounters.Nodes.Node.NodeItem.Items, self).__setattr__(name, value)


                        class BundleData(Entity):
                            """
                            Bundle mLACP TLV counter information
                            
                            .. attribute:: bundle_name
                            
                            	Name of the bundle
                            	**type**\:  str
                            
                            .. attribute:: iccp_group_id
                            
                            	ICCP Group ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: mlacp_sync_requests_on_all_local_ports
                            
                            	Counts of mLACP sync request TLVs on all ports
                            	**type**\:   :py:class:`MlacpSyncRequestsOnAllLocalPorts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.MlacpMemberCounters.Nodes.Node.NodeItem.Items.BundleData.MlacpSyncRequestsOnAllLocalPorts>`
                            
                            

                            """

                            _prefix = 'bundlemgr-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(BundleInformation.MlacpMemberCounters.Nodes.Node.NodeItem.Items.BundleData, self).__init__()

                                self.yang_name = "bundle-data"
                                self.yang_parent_name = "items"

                                self.bundle_name = YLeaf(YType.str, "bundle-name")

                                self.iccp_group_id = YLeaf(YType.uint32, "iccp-group-id")

                                self.mlacp_sync_requests_on_all_local_ports = BundleInformation.MlacpMemberCounters.Nodes.Node.NodeItem.Items.BundleData.MlacpSyncRequestsOnAllLocalPorts()
                                self.mlacp_sync_requests_on_all_local_ports.parent = self
                                self._children_name_map["mlacp_sync_requests_on_all_local_ports"] = "mlacp-sync-requests-on-all-local-ports"
                                self._children_yang_names.add("mlacp-sync-requests-on-all-local-ports")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("bundle_name",
                                                "iccp_group_id") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(BundleInformation.MlacpMemberCounters.Nodes.Node.NodeItem.Items.BundleData, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(BundleInformation.MlacpMemberCounters.Nodes.Node.NodeItem.Items.BundleData, self).__setattr__(name, value)


                            class MlacpSyncRequestsOnAllLocalPorts(Entity):
                                """
                                Counts of mLACP sync request TLVs on all ports
                                
                                .. attribute:: last_time_cleared
                                
                                	Time in nsecs from boot when counters were last cleared (deprecated)
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: nanosecond
                                
                                .. attribute:: received_sync_requests
                                
                                	Number of mLACP sync request TLVs received
                                	**type**\:   :py:class:`ReceivedSyncRequests <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.MlacpMemberCounters.Nodes.Node.NodeItem.Items.BundleData.MlacpSyncRequestsOnAllLocalPorts.ReceivedSyncRequests>`
                                
                                .. attribute:: time_since_cleared
                                
                                	Elapsed time in nsecs since counters were last cleared
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: nanosecond
                                
                                

                                """

                                _prefix = 'bundlemgr-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(BundleInformation.MlacpMemberCounters.Nodes.Node.NodeItem.Items.BundleData.MlacpSyncRequestsOnAllLocalPorts, self).__init__()

                                    self.yang_name = "mlacp-sync-requests-on-all-local-ports"
                                    self.yang_parent_name = "bundle-data"

                                    self.last_time_cleared = YLeaf(YType.uint64, "last-time-cleared")

                                    self.time_since_cleared = YLeaf(YType.uint64, "time-since-cleared")

                                    self.received_sync_requests = BundleInformation.MlacpMemberCounters.Nodes.Node.NodeItem.Items.BundleData.MlacpSyncRequestsOnAllLocalPorts.ReceivedSyncRequests()
                                    self.received_sync_requests.parent = self
                                    self._children_name_map["received_sync_requests"] = "received-sync-requests"
                                    self._children_yang_names.add("received-sync-requests")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("last_time_cleared",
                                                    "time_since_cleared") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(BundleInformation.MlacpMemberCounters.Nodes.Node.NodeItem.Items.BundleData.MlacpSyncRequestsOnAllLocalPorts, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(BundleInformation.MlacpMemberCounters.Nodes.Node.NodeItem.Items.BundleData.MlacpSyncRequestsOnAllLocalPorts, self).__setattr__(name, value)


                                class ReceivedSyncRequests(Entity):
                                    """
                                    Number of mLACP sync request TLVs received
                                    
                                    .. attribute:: all_syncs
                                    
                                    	Total number of sync requests received
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: config_syncs
                                    
                                    	Number of config sync requests received
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: state_syncs
                                    
                                    	Number of state sync requests received
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'bundlemgr-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(BundleInformation.MlacpMemberCounters.Nodes.Node.NodeItem.Items.BundleData.MlacpSyncRequestsOnAllLocalPorts.ReceivedSyncRequests, self).__init__()

                                        self.yang_name = "received-sync-requests"
                                        self.yang_parent_name = "mlacp-sync-requests-on-all-local-ports"

                                        self.all_syncs = YLeaf(YType.uint32, "all-syncs")

                                        self.config_syncs = YLeaf(YType.uint32, "config-syncs")

                                        self.state_syncs = YLeaf(YType.uint32, "state-syncs")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("all_syncs",
                                                        "config_syncs",
                                                        "state_syncs") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(BundleInformation.MlacpMemberCounters.Nodes.Node.NodeItem.Items.BundleData.MlacpSyncRequestsOnAllLocalPorts.ReceivedSyncRequests, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(BundleInformation.MlacpMemberCounters.Nodes.Node.NodeItem.Items.BundleData.MlacpSyncRequestsOnAllLocalPorts.ReceivedSyncRequests, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.all_syncs.is_set or
                                            self.config_syncs.is_set or
                                            self.state_syncs.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.all_syncs.yfilter != YFilter.not_set or
                                            self.config_syncs.yfilter != YFilter.not_set or
                                            self.state_syncs.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "received-sync-requests" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.all_syncs.is_set or self.all_syncs.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.all_syncs.get_name_leafdata())
                                        if (self.config_syncs.is_set or self.config_syncs.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.config_syncs.get_name_leafdata())
                                        if (self.state_syncs.is_set or self.state_syncs.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.state_syncs.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "all-syncs" or name == "config-syncs" or name == "state-syncs"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "all-syncs"):
                                            self.all_syncs = value
                                            self.all_syncs.value_namespace = name_space
                                            self.all_syncs.value_namespace_prefix = name_space_prefix
                                        if(value_path == "config-syncs"):
                                            self.config_syncs = value
                                            self.config_syncs.value_namespace = name_space
                                            self.config_syncs.value_namespace_prefix = name_space_prefix
                                        if(value_path == "state-syncs"):
                                            self.state_syncs = value
                                            self.state_syncs.value_namespace = name_space
                                            self.state_syncs.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.last_time_cleared.is_set or
                                        self.time_since_cleared.is_set or
                                        (self.received_sync_requests is not None and self.received_sync_requests.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.last_time_cleared.yfilter != YFilter.not_set or
                                        self.time_since_cleared.yfilter != YFilter.not_set or
                                        (self.received_sync_requests is not None and self.received_sync_requests.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "mlacp-sync-requests-on-all-local-ports" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.last_time_cleared.is_set or self.last_time_cleared.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.last_time_cleared.get_name_leafdata())
                                    if (self.time_since_cleared.is_set or self.time_since_cleared.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.time_since_cleared.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "received-sync-requests"):
                                        if (self.received_sync_requests is None):
                                            self.received_sync_requests = BundleInformation.MlacpMemberCounters.Nodes.Node.NodeItem.Items.BundleData.MlacpSyncRequestsOnAllLocalPorts.ReceivedSyncRequests()
                                            self.received_sync_requests.parent = self
                                            self._children_name_map["received_sync_requests"] = "received-sync-requests"
                                        return self.received_sync_requests

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "received-sync-requests" or name == "last-time-cleared" or name == "time-since-cleared"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "last-time-cleared"):
                                        self.last_time_cleared = value
                                        self.last_time_cleared.value_namespace = name_space
                                        self.last_time_cleared.value_namespace_prefix = name_space_prefix
                                    if(value_path == "time-since-cleared"):
                                        self.time_since_cleared = value
                                        self.time_since_cleared.value_namespace = name_space
                                        self.time_since_cleared.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.bundle_name.is_set or
                                    self.iccp_group_id.is_set or
                                    (self.mlacp_sync_requests_on_all_local_ports is not None and self.mlacp_sync_requests_on_all_local_ports.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.bundle_name.yfilter != YFilter.not_set or
                                    self.iccp_group_id.yfilter != YFilter.not_set or
                                    (self.mlacp_sync_requests_on_all_local_ports is not None and self.mlacp_sync_requests_on_all_local_ports.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "bundle-data" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.bundle_name.is_set or self.bundle_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.bundle_name.get_name_leafdata())
                                if (self.iccp_group_id.is_set or self.iccp_group_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.iccp_group_id.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "mlacp-sync-requests-on-all-local-ports"):
                                    if (self.mlacp_sync_requests_on_all_local_ports is None):
                                        self.mlacp_sync_requests_on_all_local_ports = BundleInformation.MlacpMemberCounters.Nodes.Node.NodeItem.Items.BundleData.MlacpSyncRequestsOnAllLocalPorts()
                                        self.mlacp_sync_requests_on_all_local_ports.parent = self
                                        self._children_name_map["mlacp_sync_requests_on_all_local_ports"] = "mlacp-sync-requests-on-all-local-ports"
                                    return self.mlacp_sync_requests_on_all_local_ports

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "mlacp-sync-requests-on-all-local-ports" or name == "bundle-name" or name == "iccp-group-id"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "bundle-name"):
                                    self.bundle_name = value
                                    self.bundle_name.value_namespace = name_space
                                    self.bundle_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "iccp-group-id"):
                                    self.iccp_group_id = value
                                    self.iccp_group_id.value_namespace = name_space
                                    self.iccp_group_id.value_namespace_prefix = name_space_prefix


                        class NodeData(Entity):
                            """
                            Peer device mLACP TLV counter information
                            
                            .. attribute:: member_data
                            
                            	Member mLACP TLV counter information
                            	**type**\: list of    :py:class:`MemberData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.MlacpMemberCounters.Nodes.Node.NodeItem.Items.NodeData.MemberData>`
                            
                            .. attribute:: mlacp_sync_requests_on_all_foreign_ports
                            
                            	Counts of mLACP sync request TLVs on all ports
                            	**type**\:   :py:class:`MlacpSyncRequestsOnAllForeignPorts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.MlacpMemberCounters.Nodes.Node.NodeItem.Items.NodeData.MlacpSyncRequestsOnAllForeignPorts>`
                            
                            .. attribute:: node_data
                            
                            	Peer device mLACP TLV counter information
                            	**type**\:   :py:class:`NodeData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.MlacpMemberCounters.Nodes.Node.NodeItem.Items.NodeData.NodeData>`
                            
                            

                            """

                            _prefix = 'bundlemgr-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(BundleInformation.MlacpMemberCounters.Nodes.Node.NodeItem.Items.NodeData, self).__init__()

                                self.yang_name = "node-data"
                                self.yang_parent_name = "items"

                                self.mlacp_sync_requests_on_all_foreign_ports = BundleInformation.MlacpMemberCounters.Nodes.Node.NodeItem.Items.NodeData.MlacpSyncRequestsOnAllForeignPorts()
                                self.mlacp_sync_requests_on_all_foreign_ports.parent = self
                                self._children_name_map["mlacp_sync_requests_on_all_foreign_ports"] = "mlacp-sync-requests-on-all-foreign-ports"
                                self._children_yang_names.add("mlacp-sync-requests-on-all-foreign-ports")

                                self.node_data = BundleInformation.MlacpMemberCounters.Nodes.Node.NodeItem.Items.NodeData.NodeData()
                                self.node_data.parent = self
                                self._children_name_map["node_data"] = "node-data"
                                self._children_yang_names.add("node-data")

                                self.member_data = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in () and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(BundleInformation.MlacpMemberCounters.Nodes.Node.NodeItem.Items.NodeData, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(BundleInformation.MlacpMemberCounters.Nodes.Node.NodeItem.Items.NodeData, self).__setattr__(name, value)


                            class NodeData(Entity):
                                """
                                Peer device mLACP TLV counter information
                                
                                .. attribute:: iccp_group_id
                                
                                	ICCP Group ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: node_id
                                
                                	Device ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'bundlemgr-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(BundleInformation.MlacpMemberCounters.Nodes.Node.NodeItem.Items.NodeData.NodeData, self).__init__()

                                    self.yang_name = "node-data"
                                    self.yang_parent_name = "node-data"

                                    self.iccp_group_id = YLeaf(YType.uint32, "iccp-group-id")

                                    self.node_id = YLeaf(YType.uint32, "node-id")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("iccp_group_id",
                                                    "node_id") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(BundleInformation.MlacpMemberCounters.Nodes.Node.NodeItem.Items.NodeData.NodeData, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(BundleInformation.MlacpMemberCounters.Nodes.Node.NodeItem.Items.NodeData.NodeData, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.iccp_group_id.is_set or
                                        self.node_id.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.iccp_group_id.yfilter != YFilter.not_set or
                                        self.node_id.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "node-data" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.iccp_group_id.is_set or self.iccp_group_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.iccp_group_id.get_name_leafdata())
                                    if (self.node_id.is_set or self.node_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.node_id.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "iccp-group-id" or name == "node-id"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "iccp-group-id"):
                                        self.iccp_group_id = value
                                        self.iccp_group_id.value_namespace = name_space
                                        self.iccp_group_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "node-id"):
                                        self.node_id = value
                                        self.node_id.value_namespace = name_space
                                        self.node_id.value_namespace_prefix = name_space_prefix


                            class MlacpSyncRequestsOnAllForeignPorts(Entity):
                                """
                                Counts of mLACP sync request TLVs on all ports
                                
                                .. attribute:: last_time_cleared
                                
                                	Time in nsecs from boot when counters were last cleared (deprecated)
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: nanosecond
                                
                                .. attribute:: received_sync_requests
                                
                                	Number of mLACP sync request TLVs received
                                	**type**\:   :py:class:`ReceivedSyncRequests <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.MlacpMemberCounters.Nodes.Node.NodeItem.Items.NodeData.MlacpSyncRequestsOnAllForeignPorts.ReceivedSyncRequests>`
                                
                                .. attribute:: time_since_cleared
                                
                                	Elapsed time in nsecs since counters were last cleared
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: nanosecond
                                
                                

                                """

                                _prefix = 'bundlemgr-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(BundleInformation.MlacpMemberCounters.Nodes.Node.NodeItem.Items.NodeData.MlacpSyncRequestsOnAllForeignPorts, self).__init__()

                                    self.yang_name = "mlacp-sync-requests-on-all-foreign-ports"
                                    self.yang_parent_name = "node-data"

                                    self.last_time_cleared = YLeaf(YType.uint64, "last-time-cleared")

                                    self.time_since_cleared = YLeaf(YType.uint64, "time-since-cleared")

                                    self.received_sync_requests = BundleInformation.MlacpMemberCounters.Nodes.Node.NodeItem.Items.NodeData.MlacpSyncRequestsOnAllForeignPorts.ReceivedSyncRequests()
                                    self.received_sync_requests.parent = self
                                    self._children_name_map["received_sync_requests"] = "received-sync-requests"
                                    self._children_yang_names.add("received-sync-requests")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("last_time_cleared",
                                                    "time_since_cleared") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(BundleInformation.MlacpMemberCounters.Nodes.Node.NodeItem.Items.NodeData.MlacpSyncRequestsOnAllForeignPorts, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(BundleInformation.MlacpMemberCounters.Nodes.Node.NodeItem.Items.NodeData.MlacpSyncRequestsOnAllForeignPorts, self).__setattr__(name, value)


                                class ReceivedSyncRequests(Entity):
                                    """
                                    Number of mLACP sync request TLVs received
                                    
                                    .. attribute:: all_syncs
                                    
                                    	Total number of sync requests received
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: config_syncs
                                    
                                    	Number of config sync requests received
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: state_syncs
                                    
                                    	Number of state sync requests received
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'bundlemgr-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(BundleInformation.MlacpMemberCounters.Nodes.Node.NodeItem.Items.NodeData.MlacpSyncRequestsOnAllForeignPorts.ReceivedSyncRequests, self).__init__()

                                        self.yang_name = "received-sync-requests"
                                        self.yang_parent_name = "mlacp-sync-requests-on-all-foreign-ports"

                                        self.all_syncs = YLeaf(YType.uint32, "all-syncs")

                                        self.config_syncs = YLeaf(YType.uint32, "config-syncs")

                                        self.state_syncs = YLeaf(YType.uint32, "state-syncs")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("all_syncs",
                                                        "config_syncs",
                                                        "state_syncs") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(BundleInformation.MlacpMemberCounters.Nodes.Node.NodeItem.Items.NodeData.MlacpSyncRequestsOnAllForeignPorts.ReceivedSyncRequests, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(BundleInformation.MlacpMemberCounters.Nodes.Node.NodeItem.Items.NodeData.MlacpSyncRequestsOnAllForeignPorts.ReceivedSyncRequests, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.all_syncs.is_set or
                                            self.config_syncs.is_set or
                                            self.state_syncs.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.all_syncs.yfilter != YFilter.not_set or
                                            self.config_syncs.yfilter != YFilter.not_set or
                                            self.state_syncs.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "received-sync-requests" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.all_syncs.is_set or self.all_syncs.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.all_syncs.get_name_leafdata())
                                        if (self.config_syncs.is_set or self.config_syncs.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.config_syncs.get_name_leafdata())
                                        if (self.state_syncs.is_set or self.state_syncs.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.state_syncs.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "all-syncs" or name == "config-syncs" or name == "state-syncs"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "all-syncs"):
                                            self.all_syncs = value
                                            self.all_syncs.value_namespace = name_space
                                            self.all_syncs.value_namespace_prefix = name_space_prefix
                                        if(value_path == "config-syncs"):
                                            self.config_syncs = value
                                            self.config_syncs.value_namespace = name_space
                                            self.config_syncs.value_namespace_prefix = name_space_prefix
                                        if(value_path == "state-syncs"):
                                            self.state_syncs = value
                                            self.state_syncs.value_namespace = name_space
                                            self.state_syncs.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.last_time_cleared.is_set or
                                        self.time_since_cleared.is_set or
                                        (self.received_sync_requests is not None and self.received_sync_requests.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.last_time_cleared.yfilter != YFilter.not_set or
                                        self.time_since_cleared.yfilter != YFilter.not_set or
                                        (self.received_sync_requests is not None and self.received_sync_requests.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "mlacp-sync-requests-on-all-foreign-ports" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.last_time_cleared.is_set or self.last_time_cleared.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.last_time_cleared.get_name_leafdata())
                                    if (self.time_since_cleared.is_set or self.time_since_cleared.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.time_since_cleared.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "received-sync-requests"):
                                        if (self.received_sync_requests is None):
                                            self.received_sync_requests = BundleInformation.MlacpMemberCounters.Nodes.Node.NodeItem.Items.NodeData.MlacpSyncRequestsOnAllForeignPorts.ReceivedSyncRequests()
                                            self.received_sync_requests.parent = self
                                            self._children_name_map["received_sync_requests"] = "received-sync-requests"
                                        return self.received_sync_requests

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "received-sync-requests" or name == "last-time-cleared" or name == "time-since-cleared"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "last-time-cleared"):
                                        self.last_time_cleared = value
                                        self.last_time_cleared.value_namespace = name_space
                                        self.last_time_cleared.value_namespace_prefix = name_space_prefix
                                    if(value_path == "time-since-cleared"):
                                        self.time_since_cleared = value
                                        self.time_since_cleared.value_namespace = name_space
                                        self.time_since_cleared.value_namespace_prefix = name_space_prefix


                            class MemberData(Entity):
                                """
                                Member mLACP TLV counter information
                                
                                .. attribute:: mlacp_tlv_counters
                                
                                	Counts of mLACP TLVs sent and received
                                	**type**\:   :py:class:`MlacpTlvCounters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.MlacpMemberCounters.Nodes.Node.NodeItem.Items.NodeData.MemberData.MlacpTlvCounters>`
                                
                                .. attribute:: port_name
                                
                                	Port name of member
                                	**type**\:  str
                                
                                

                                """

                                _prefix = 'bundlemgr-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(BundleInformation.MlacpMemberCounters.Nodes.Node.NodeItem.Items.NodeData.MemberData, self).__init__()

                                    self.yang_name = "member-data"
                                    self.yang_parent_name = "node-data"

                                    self.port_name = YLeaf(YType.str, "port-name")

                                    self.mlacp_tlv_counters = BundleInformation.MlacpMemberCounters.Nodes.Node.NodeItem.Items.NodeData.MemberData.MlacpTlvCounters()
                                    self.mlacp_tlv_counters.parent = self
                                    self._children_name_map["mlacp_tlv_counters"] = "mlacp-tlv-counters"
                                    self._children_yang_names.add("mlacp-tlv-counters")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("port_name") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(BundleInformation.MlacpMemberCounters.Nodes.Node.NodeItem.Items.NodeData.MemberData, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(BundleInformation.MlacpMemberCounters.Nodes.Node.NodeItem.Items.NodeData.MemberData, self).__setattr__(name, value)


                                class MlacpTlvCounters(Entity):
                                    """
                                    Counts of mLACP TLVs sent and received
                                    
                                    .. attribute:: last_time_cleared
                                    
                                    	Time in nsecs from boot when counters were last cleared (deprecated)
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: nanosecond
                                    
                                    .. attribute:: last_unexpected_event
                                    
                                    	Elapsed time in nsecs since last unexpected event
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: nanosecond
                                    
                                    .. attribute:: received_nak_tl_vs
                                    
                                    	Number of mLACP NAK TLVs received
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: received_priority_tl_vs
                                    
                                    	Number of mLACP priority TLVs received
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: received_sync_requests
                                    
                                    	Number of mLACP sync request TLVs received
                                    	**type**\:   :py:class:`ReceivedSyncRequests <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.MlacpMemberCounters.Nodes.Node.NodeItem.Items.NodeData.MemberData.MlacpTlvCounters.ReceivedSyncRequests>`
                                    
                                    .. attribute:: sent_config_tl_vs
                                    
                                    	Number of mLACP config TLVs sent
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: sent_priority_tl_vs
                                    
                                    	Number of mLACP priority TLVs sent
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: sent_state_tl_vs
                                    
                                    	Number of mLACP state TLVs sent
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: time_since_cleared
                                    
                                    	Elapsed time in nsecs since counters were last cleared
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: nanosecond
                                    
                                    

                                    """

                                    _prefix = 'bundlemgr-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(BundleInformation.MlacpMemberCounters.Nodes.Node.NodeItem.Items.NodeData.MemberData.MlacpTlvCounters, self).__init__()

                                        self.yang_name = "mlacp-tlv-counters"
                                        self.yang_parent_name = "member-data"

                                        self.last_time_cleared = YLeaf(YType.uint64, "last-time-cleared")

                                        self.last_unexpected_event = YLeaf(YType.uint64, "last-unexpected-event")

                                        self.received_nak_tl_vs = YLeaf(YType.uint32, "received-nak-tl-vs")

                                        self.received_priority_tl_vs = YLeaf(YType.uint32, "received-priority-tl-vs")

                                        self.sent_config_tl_vs = YLeaf(YType.uint32, "sent-config-tl-vs")

                                        self.sent_priority_tl_vs = YLeaf(YType.uint32, "sent-priority-tl-vs")

                                        self.sent_state_tl_vs = YLeaf(YType.uint32, "sent-state-tl-vs")

                                        self.time_since_cleared = YLeaf(YType.uint64, "time-since-cleared")

                                        self.received_sync_requests = BundleInformation.MlacpMemberCounters.Nodes.Node.NodeItem.Items.NodeData.MemberData.MlacpTlvCounters.ReceivedSyncRequests()
                                        self.received_sync_requests.parent = self
                                        self._children_name_map["received_sync_requests"] = "received-sync-requests"
                                        self._children_yang_names.add("received-sync-requests")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("last_time_cleared",
                                                        "last_unexpected_event",
                                                        "received_nak_tl_vs",
                                                        "received_priority_tl_vs",
                                                        "sent_config_tl_vs",
                                                        "sent_priority_tl_vs",
                                                        "sent_state_tl_vs",
                                                        "time_since_cleared") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(BundleInformation.MlacpMemberCounters.Nodes.Node.NodeItem.Items.NodeData.MemberData.MlacpTlvCounters, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(BundleInformation.MlacpMemberCounters.Nodes.Node.NodeItem.Items.NodeData.MemberData.MlacpTlvCounters, self).__setattr__(name, value)


                                    class ReceivedSyncRequests(Entity):
                                        """
                                        Number of mLACP sync request TLVs received
                                        
                                        .. attribute:: all_syncs
                                        
                                        	Total number of sync requests received
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: config_syncs
                                        
                                        	Number of config sync requests received
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: state_syncs
                                        
                                        	Number of state sync requests received
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'bundlemgr-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(BundleInformation.MlacpMemberCounters.Nodes.Node.NodeItem.Items.NodeData.MemberData.MlacpTlvCounters.ReceivedSyncRequests, self).__init__()

                                            self.yang_name = "received-sync-requests"
                                            self.yang_parent_name = "mlacp-tlv-counters"

                                            self.all_syncs = YLeaf(YType.uint32, "all-syncs")

                                            self.config_syncs = YLeaf(YType.uint32, "config-syncs")

                                            self.state_syncs = YLeaf(YType.uint32, "state-syncs")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("all_syncs",
                                                            "config_syncs",
                                                            "state_syncs") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(BundleInformation.MlacpMemberCounters.Nodes.Node.NodeItem.Items.NodeData.MemberData.MlacpTlvCounters.ReceivedSyncRequests, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(BundleInformation.MlacpMemberCounters.Nodes.Node.NodeItem.Items.NodeData.MemberData.MlacpTlvCounters.ReceivedSyncRequests, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.all_syncs.is_set or
                                                self.config_syncs.is_set or
                                                self.state_syncs.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.all_syncs.yfilter != YFilter.not_set or
                                                self.config_syncs.yfilter != YFilter.not_set or
                                                self.state_syncs.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "received-sync-requests" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.all_syncs.is_set or self.all_syncs.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.all_syncs.get_name_leafdata())
                                            if (self.config_syncs.is_set or self.config_syncs.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.config_syncs.get_name_leafdata())
                                            if (self.state_syncs.is_set or self.state_syncs.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.state_syncs.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "all-syncs" or name == "config-syncs" or name == "state-syncs"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "all-syncs"):
                                                self.all_syncs = value
                                                self.all_syncs.value_namespace = name_space
                                                self.all_syncs.value_namespace_prefix = name_space_prefix
                                            if(value_path == "config-syncs"):
                                                self.config_syncs = value
                                                self.config_syncs.value_namespace = name_space
                                                self.config_syncs.value_namespace_prefix = name_space_prefix
                                            if(value_path == "state-syncs"):
                                                self.state_syncs = value
                                                self.state_syncs.value_namespace = name_space
                                                self.state_syncs.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.last_time_cleared.is_set or
                                            self.last_unexpected_event.is_set or
                                            self.received_nak_tl_vs.is_set or
                                            self.received_priority_tl_vs.is_set or
                                            self.sent_config_tl_vs.is_set or
                                            self.sent_priority_tl_vs.is_set or
                                            self.sent_state_tl_vs.is_set or
                                            self.time_since_cleared.is_set or
                                            (self.received_sync_requests is not None and self.received_sync_requests.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.last_time_cleared.yfilter != YFilter.not_set or
                                            self.last_unexpected_event.yfilter != YFilter.not_set or
                                            self.received_nak_tl_vs.yfilter != YFilter.not_set or
                                            self.received_priority_tl_vs.yfilter != YFilter.not_set or
                                            self.sent_config_tl_vs.yfilter != YFilter.not_set or
                                            self.sent_priority_tl_vs.yfilter != YFilter.not_set or
                                            self.sent_state_tl_vs.yfilter != YFilter.not_set or
                                            self.time_since_cleared.yfilter != YFilter.not_set or
                                            (self.received_sync_requests is not None and self.received_sync_requests.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "mlacp-tlv-counters" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.last_time_cleared.is_set or self.last_time_cleared.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.last_time_cleared.get_name_leafdata())
                                        if (self.last_unexpected_event.is_set or self.last_unexpected_event.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.last_unexpected_event.get_name_leafdata())
                                        if (self.received_nak_tl_vs.is_set or self.received_nak_tl_vs.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.received_nak_tl_vs.get_name_leafdata())
                                        if (self.received_priority_tl_vs.is_set or self.received_priority_tl_vs.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.received_priority_tl_vs.get_name_leafdata())
                                        if (self.sent_config_tl_vs.is_set or self.sent_config_tl_vs.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.sent_config_tl_vs.get_name_leafdata())
                                        if (self.sent_priority_tl_vs.is_set or self.sent_priority_tl_vs.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.sent_priority_tl_vs.get_name_leafdata())
                                        if (self.sent_state_tl_vs.is_set or self.sent_state_tl_vs.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.sent_state_tl_vs.get_name_leafdata())
                                        if (self.time_since_cleared.is_set or self.time_since_cleared.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.time_since_cleared.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "received-sync-requests"):
                                            if (self.received_sync_requests is None):
                                                self.received_sync_requests = BundleInformation.MlacpMemberCounters.Nodes.Node.NodeItem.Items.NodeData.MemberData.MlacpTlvCounters.ReceivedSyncRequests()
                                                self.received_sync_requests.parent = self
                                                self._children_name_map["received_sync_requests"] = "received-sync-requests"
                                            return self.received_sync_requests

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "received-sync-requests" or name == "last-time-cleared" or name == "last-unexpected-event" or name == "received-nak-tl-vs" or name == "received-priority-tl-vs" or name == "sent-config-tl-vs" or name == "sent-priority-tl-vs" or name == "sent-state-tl-vs" or name == "time-since-cleared"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "last-time-cleared"):
                                            self.last_time_cleared = value
                                            self.last_time_cleared.value_namespace = name_space
                                            self.last_time_cleared.value_namespace_prefix = name_space_prefix
                                        if(value_path == "last-unexpected-event"):
                                            self.last_unexpected_event = value
                                            self.last_unexpected_event.value_namespace = name_space
                                            self.last_unexpected_event.value_namespace_prefix = name_space_prefix
                                        if(value_path == "received-nak-tl-vs"):
                                            self.received_nak_tl_vs = value
                                            self.received_nak_tl_vs.value_namespace = name_space
                                            self.received_nak_tl_vs.value_namespace_prefix = name_space_prefix
                                        if(value_path == "received-priority-tl-vs"):
                                            self.received_priority_tl_vs = value
                                            self.received_priority_tl_vs.value_namespace = name_space
                                            self.received_priority_tl_vs.value_namespace_prefix = name_space_prefix
                                        if(value_path == "sent-config-tl-vs"):
                                            self.sent_config_tl_vs = value
                                            self.sent_config_tl_vs.value_namespace = name_space
                                            self.sent_config_tl_vs.value_namespace_prefix = name_space_prefix
                                        if(value_path == "sent-priority-tl-vs"):
                                            self.sent_priority_tl_vs = value
                                            self.sent_priority_tl_vs.value_namespace = name_space
                                            self.sent_priority_tl_vs.value_namespace_prefix = name_space_prefix
                                        if(value_path == "sent-state-tl-vs"):
                                            self.sent_state_tl_vs = value
                                            self.sent_state_tl_vs.value_namespace = name_space
                                            self.sent_state_tl_vs.value_namespace_prefix = name_space_prefix
                                        if(value_path == "time-since-cleared"):
                                            self.time_since_cleared = value
                                            self.time_since_cleared.value_namespace = name_space
                                            self.time_since_cleared.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.port_name.is_set or
                                        (self.mlacp_tlv_counters is not None and self.mlacp_tlv_counters.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.port_name.yfilter != YFilter.not_set or
                                        (self.mlacp_tlv_counters is not None and self.mlacp_tlv_counters.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "member-data" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.port_name.is_set or self.port_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.port_name.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "mlacp-tlv-counters"):
                                        if (self.mlacp_tlv_counters is None):
                                            self.mlacp_tlv_counters = BundleInformation.MlacpMemberCounters.Nodes.Node.NodeItem.Items.NodeData.MemberData.MlacpTlvCounters()
                                            self.mlacp_tlv_counters.parent = self
                                            self._children_name_map["mlacp_tlv_counters"] = "mlacp-tlv-counters"
                                        return self.mlacp_tlv_counters

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "mlacp-tlv-counters" or name == "port-name"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "port-name"):
                                        self.port_name = value
                                        self.port_name.value_namespace = name_space
                                        self.port_name.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.member_data:
                                    if (c.has_data()):
                                        return True
                                return (
                                    (self.mlacp_sync_requests_on_all_foreign_ports is not None and self.mlacp_sync_requests_on_all_foreign_ports.has_data()) or
                                    (self.node_data is not None and self.node_data.has_data()))

                            def has_operation(self):
                                for c in self.member_data:
                                    if (c.has_operation()):
                                        return True
                                return (
                                    self.yfilter != YFilter.not_set or
                                    (self.mlacp_sync_requests_on_all_foreign_ports is not None and self.mlacp_sync_requests_on_all_foreign_ports.has_operation()) or
                                    (self.node_data is not None and self.node_data.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "node-data" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "member-data"):
                                    for c in self.member_data:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = BundleInformation.MlacpMemberCounters.Nodes.Node.NodeItem.Items.NodeData.MemberData()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.member_data.append(c)
                                    return c

                                if (child_yang_name == "mlacp-sync-requests-on-all-foreign-ports"):
                                    if (self.mlacp_sync_requests_on_all_foreign_ports is None):
                                        self.mlacp_sync_requests_on_all_foreign_ports = BundleInformation.MlacpMemberCounters.Nodes.Node.NodeItem.Items.NodeData.MlacpSyncRequestsOnAllForeignPorts()
                                        self.mlacp_sync_requests_on_all_foreign_ports.parent = self
                                        self._children_name_map["mlacp_sync_requests_on_all_foreign_ports"] = "mlacp-sync-requests-on-all-foreign-ports"
                                    return self.mlacp_sync_requests_on_all_foreign_ports

                                if (child_yang_name == "node-data"):
                                    if (self.node_data is None):
                                        self.node_data = BundleInformation.MlacpMemberCounters.Nodes.Node.NodeItem.Items.NodeData.NodeData()
                                        self.node_data.parent = self
                                        self._children_name_map["node_data"] = "node-data"
                                    return self.node_data

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "member-data" or name == "mlacp-sync-requests-on-all-foreign-ports" or name == "node-data"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass


                        class MemberData(Entity):
                            """
                            Local member mLACP TLV counter information
                            
                            .. attribute:: mlacp_tlv_counters
                            
                            	Counts of mLACP TLVs sent and received
                            	**type**\:   :py:class:`MlacpTlvCounters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.MlacpMemberCounters.Nodes.Node.NodeItem.Items.MemberData.MlacpTlvCounters>`
                            
                            .. attribute:: port_name
                            
                            	Port name of member
                            	**type**\:  str
                            
                            

                            """

                            _prefix = 'bundlemgr-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(BundleInformation.MlacpMemberCounters.Nodes.Node.NodeItem.Items.MemberData, self).__init__()

                                self.yang_name = "member-data"
                                self.yang_parent_name = "items"

                                self.port_name = YLeaf(YType.str, "port-name")

                                self.mlacp_tlv_counters = BundleInformation.MlacpMemberCounters.Nodes.Node.NodeItem.Items.MemberData.MlacpTlvCounters()
                                self.mlacp_tlv_counters.parent = self
                                self._children_name_map["mlacp_tlv_counters"] = "mlacp-tlv-counters"
                                self._children_yang_names.add("mlacp-tlv-counters")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("port_name") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(BundleInformation.MlacpMemberCounters.Nodes.Node.NodeItem.Items.MemberData, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(BundleInformation.MlacpMemberCounters.Nodes.Node.NodeItem.Items.MemberData, self).__setattr__(name, value)


                            class MlacpTlvCounters(Entity):
                                """
                                Counts of mLACP TLVs sent and received
                                
                                .. attribute:: last_time_cleared
                                
                                	Time in nsecs from boot when counters were last cleared (deprecated)
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: nanosecond
                                
                                .. attribute:: last_unexpected_event
                                
                                	Elapsed time in nsecs since last unexpected event
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: nanosecond
                                
                                .. attribute:: received_nak_tl_vs
                                
                                	Number of mLACP NAK TLVs received
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: received_priority_tl_vs
                                
                                	Number of mLACP priority TLVs received
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: received_sync_requests
                                
                                	Number of mLACP sync request TLVs received
                                	**type**\:   :py:class:`ReceivedSyncRequests <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleInformation.MlacpMemberCounters.Nodes.Node.NodeItem.Items.MemberData.MlacpTlvCounters.ReceivedSyncRequests>`
                                
                                .. attribute:: sent_config_tl_vs
                                
                                	Number of mLACP config TLVs sent
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: sent_priority_tl_vs
                                
                                	Number of mLACP priority TLVs sent
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: sent_state_tl_vs
                                
                                	Number of mLACP state TLVs sent
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: time_since_cleared
                                
                                	Elapsed time in nsecs since counters were last cleared
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: nanosecond
                                
                                

                                """

                                _prefix = 'bundlemgr-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(BundleInformation.MlacpMemberCounters.Nodes.Node.NodeItem.Items.MemberData.MlacpTlvCounters, self).__init__()

                                    self.yang_name = "mlacp-tlv-counters"
                                    self.yang_parent_name = "member-data"

                                    self.last_time_cleared = YLeaf(YType.uint64, "last-time-cleared")

                                    self.last_unexpected_event = YLeaf(YType.uint64, "last-unexpected-event")

                                    self.received_nak_tl_vs = YLeaf(YType.uint32, "received-nak-tl-vs")

                                    self.received_priority_tl_vs = YLeaf(YType.uint32, "received-priority-tl-vs")

                                    self.sent_config_tl_vs = YLeaf(YType.uint32, "sent-config-tl-vs")

                                    self.sent_priority_tl_vs = YLeaf(YType.uint32, "sent-priority-tl-vs")

                                    self.sent_state_tl_vs = YLeaf(YType.uint32, "sent-state-tl-vs")

                                    self.time_since_cleared = YLeaf(YType.uint64, "time-since-cleared")

                                    self.received_sync_requests = BundleInformation.MlacpMemberCounters.Nodes.Node.NodeItem.Items.MemberData.MlacpTlvCounters.ReceivedSyncRequests()
                                    self.received_sync_requests.parent = self
                                    self._children_name_map["received_sync_requests"] = "received-sync-requests"
                                    self._children_yang_names.add("received-sync-requests")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("last_time_cleared",
                                                    "last_unexpected_event",
                                                    "received_nak_tl_vs",
                                                    "received_priority_tl_vs",
                                                    "sent_config_tl_vs",
                                                    "sent_priority_tl_vs",
                                                    "sent_state_tl_vs",
                                                    "time_since_cleared") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(BundleInformation.MlacpMemberCounters.Nodes.Node.NodeItem.Items.MemberData.MlacpTlvCounters, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(BundleInformation.MlacpMemberCounters.Nodes.Node.NodeItem.Items.MemberData.MlacpTlvCounters, self).__setattr__(name, value)


                                class ReceivedSyncRequests(Entity):
                                    """
                                    Number of mLACP sync request TLVs received
                                    
                                    .. attribute:: all_syncs
                                    
                                    	Total number of sync requests received
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: config_syncs
                                    
                                    	Number of config sync requests received
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: state_syncs
                                    
                                    	Number of state sync requests received
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'bundlemgr-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(BundleInformation.MlacpMemberCounters.Nodes.Node.NodeItem.Items.MemberData.MlacpTlvCounters.ReceivedSyncRequests, self).__init__()

                                        self.yang_name = "received-sync-requests"
                                        self.yang_parent_name = "mlacp-tlv-counters"

                                        self.all_syncs = YLeaf(YType.uint32, "all-syncs")

                                        self.config_syncs = YLeaf(YType.uint32, "config-syncs")

                                        self.state_syncs = YLeaf(YType.uint32, "state-syncs")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("all_syncs",
                                                        "config_syncs",
                                                        "state_syncs") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(BundleInformation.MlacpMemberCounters.Nodes.Node.NodeItem.Items.MemberData.MlacpTlvCounters.ReceivedSyncRequests, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(BundleInformation.MlacpMemberCounters.Nodes.Node.NodeItem.Items.MemberData.MlacpTlvCounters.ReceivedSyncRequests, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.all_syncs.is_set or
                                            self.config_syncs.is_set or
                                            self.state_syncs.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.all_syncs.yfilter != YFilter.not_set or
                                            self.config_syncs.yfilter != YFilter.not_set or
                                            self.state_syncs.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "received-sync-requests" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.all_syncs.is_set or self.all_syncs.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.all_syncs.get_name_leafdata())
                                        if (self.config_syncs.is_set or self.config_syncs.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.config_syncs.get_name_leafdata())
                                        if (self.state_syncs.is_set or self.state_syncs.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.state_syncs.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "all-syncs" or name == "config-syncs" or name == "state-syncs"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "all-syncs"):
                                            self.all_syncs = value
                                            self.all_syncs.value_namespace = name_space
                                            self.all_syncs.value_namespace_prefix = name_space_prefix
                                        if(value_path == "config-syncs"):
                                            self.config_syncs = value
                                            self.config_syncs.value_namespace = name_space
                                            self.config_syncs.value_namespace_prefix = name_space_prefix
                                        if(value_path == "state-syncs"):
                                            self.state_syncs = value
                                            self.state_syncs.value_namespace = name_space
                                            self.state_syncs.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.last_time_cleared.is_set or
                                        self.last_unexpected_event.is_set or
                                        self.received_nak_tl_vs.is_set or
                                        self.received_priority_tl_vs.is_set or
                                        self.sent_config_tl_vs.is_set or
                                        self.sent_priority_tl_vs.is_set or
                                        self.sent_state_tl_vs.is_set or
                                        self.time_since_cleared.is_set or
                                        (self.received_sync_requests is not None and self.received_sync_requests.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.last_time_cleared.yfilter != YFilter.not_set or
                                        self.last_unexpected_event.yfilter != YFilter.not_set or
                                        self.received_nak_tl_vs.yfilter != YFilter.not_set or
                                        self.received_priority_tl_vs.yfilter != YFilter.not_set or
                                        self.sent_config_tl_vs.yfilter != YFilter.not_set or
                                        self.sent_priority_tl_vs.yfilter != YFilter.not_set or
                                        self.sent_state_tl_vs.yfilter != YFilter.not_set or
                                        self.time_since_cleared.yfilter != YFilter.not_set or
                                        (self.received_sync_requests is not None and self.received_sync_requests.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "mlacp-tlv-counters" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.last_time_cleared.is_set or self.last_time_cleared.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.last_time_cleared.get_name_leafdata())
                                    if (self.last_unexpected_event.is_set or self.last_unexpected_event.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.last_unexpected_event.get_name_leafdata())
                                    if (self.received_nak_tl_vs.is_set or self.received_nak_tl_vs.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.received_nak_tl_vs.get_name_leafdata())
                                    if (self.received_priority_tl_vs.is_set or self.received_priority_tl_vs.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.received_priority_tl_vs.get_name_leafdata())
                                    if (self.sent_config_tl_vs.is_set or self.sent_config_tl_vs.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.sent_config_tl_vs.get_name_leafdata())
                                    if (self.sent_priority_tl_vs.is_set or self.sent_priority_tl_vs.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.sent_priority_tl_vs.get_name_leafdata())
                                    if (self.sent_state_tl_vs.is_set or self.sent_state_tl_vs.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.sent_state_tl_vs.get_name_leafdata())
                                    if (self.time_since_cleared.is_set or self.time_since_cleared.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.time_since_cleared.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "received-sync-requests"):
                                        if (self.received_sync_requests is None):
                                            self.received_sync_requests = BundleInformation.MlacpMemberCounters.Nodes.Node.NodeItem.Items.MemberData.MlacpTlvCounters.ReceivedSyncRequests()
                                            self.received_sync_requests.parent = self
                                            self._children_name_map["received_sync_requests"] = "received-sync-requests"
                                        return self.received_sync_requests

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "received-sync-requests" or name == "last-time-cleared" or name == "last-unexpected-event" or name == "received-nak-tl-vs" or name == "received-priority-tl-vs" or name == "sent-config-tl-vs" or name == "sent-priority-tl-vs" or name == "sent-state-tl-vs" or name == "time-since-cleared"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "last-time-cleared"):
                                        self.last_time_cleared = value
                                        self.last_time_cleared.value_namespace = name_space
                                        self.last_time_cleared.value_namespace_prefix = name_space_prefix
                                    if(value_path == "last-unexpected-event"):
                                        self.last_unexpected_event = value
                                        self.last_unexpected_event.value_namespace = name_space
                                        self.last_unexpected_event.value_namespace_prefix = name_space_prefix
                                    if(value_path == "received-nak-tl-vs"):
                                        self.received_nak_tl_vs = value
                                        self.received_nak_tl_vs.value_namespace = name_space
                                        self.received_nak_tl_vs.value_namespace_prefix = name_space_prefix
                                    if(value_path == "received-priority-tl-vs"):
                                        self.received_priority_tl_vs = value
                                        self.received_priority_tl_vs.value_namespace = name_space
                                        self.received_priority_tl_vs.value_namespace_prefix = name_space_prefix
                                    if(value_path == "sent-config-tl-vs"):
                                        self.sent_config_tl_vs = value
                                        self.sent_config_tl_vs.value_namespace = name_space
                                        self.sent_config_tl_vs.value_namespace_prefix = name_space_prefix
                                    if(value_path == "sent-priority-tl-vs"):
                                        self.sent_priority_tl_vs = value
                                        self.sent_priority_tl_vs.value_namespace = name_space
                                        self.sent_priority_tl_vs.value_namespace_prefix = name_space_prefix
                                    if(value_path == "sent-state-tl-vs"):
                                        self.sent_state_tl_vs = value
                                        self.sent_state_tl_vs.value_namespace = name_space
                                        self.sent_state_tl_vs.value_namespace_prefix = name_space_prefix
                                    if(value_path == "time-since-cleared"):
                                        self.time_since_cleared = value
                                        self.time_since_cleared.value_namespace = name_space
                                        self.time_since_cleared.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.port_name.is_set or
                                    (self.mlacp_tlv_counters is not None and self.mlacp_tlv_counters.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.port_name.yfilter != YFilter.not_set or
                                    (self.mlacp_tlv_counters is not None and self.mlacp_tlv_counters.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "member-data" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.port_name.is_set or self.port_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.port_name.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "mlacp-tlv-counters"):
                                    if (self.mlacp_tlv_counters is None):
                                        self.mlacp_tlv_counters = BundleInformation.MlacpMemberCounters.Nodes.Node.NodeItem.Items.MemberData.MlacpTlvCounters()
                                        self.mlacp_tlv_counters.parent = self
                                        self._children_name_map["mlacp_tlv_counters"] = "mlacp-tlv-counters"
                                    return self.mlacp_tlv_counters

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "mlacp-tlv-counters" or name == "port-name"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "port-name"):
                                    self.port_name = value
                                    self.port_name.value_namespace = name_space
                                    self.port_name.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.member_data:
                                if (c.has_data()):
                                    return True
                            for c in self.node_data:
                                if (c.has_data()):
                                    return True
                            return (self.bundle_data is not None and self.bundle_data.has_data())

                        def has_operation(self):
                            for c in self.member_data:
                                if (c.has_operation()):
                                    return True
                            for c in self.node_data:
                                if (c.has_operation()):
                                    return True
                            return (
                                self.yfilter != YFilter.not_set or
                                (self.bundle_data is not None and self.bundle_data.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "items" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "bundle-data"):
                                if (self.bundle_data is None):
                                    self.bundle_data = BundleInformation.MlacpMemberCounters.Nodes.Node.NodeItem.Items.BundleData()
                                    self.bundle_data.parent = self
                                    self._children_name_map["bundle_data"] = "bundle-data"
                                return self.bundle_data

                            if (child_yang_name == "member-data"):
                                for c in self.member_data:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = BundleInformation.MlacpMemberCounters.Nodes.Node.NodeItem.Items.MemberData()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.member_data.append(c)
                                return c

                            if (child_yang_name == "node-data"):
                                for c in self.node_data:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = BundleInformation.MlacpMemberCounters.Nodes.Node.NodeItem.Items.NodeData()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.node_data.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "bundle-data" or name == "member-data" or name == "node-data"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass

                    def has_data(self):
                        for c in self.items:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.items:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "node-item" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "items"):
                            for c in self.items:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = BundleInformation.MlacpMemberCounters.Nodes.Node.NodeItem.Items()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.items.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "items"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass

                def has_data(self):
                    return (
                        self.node.is_set or
                        (self.node_item is not None and self.node_item.has_data()))

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.node.yfilter != YFilter.not_set or
                        (self.node_item is not None and self.node_item.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "node" + "[node='" + self.node.get() + "']" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-bundlemgr-oper:bundle-information/mlacp-member-counters/nodes/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.node.is_set or self.node.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.node.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "node-item"):
                        if (self.node_item is None):
                            self.node_item = BundleInformation.MlacpMemberCounters.Nodes.Node.NodeItem()
                            self.node_item.parent = self
                            self._children_name_map["node_item"] = "node-item"
                        return self.node_item

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "node-item" or name == "node"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "node"):
                        self.node = value
                        self.node.value_namespace = name_space
                        self.node.value_namespace_prefix = name_space_prefix

            def has_data(self):
                for c in self.node:
                    if (c.has_data()):
                        return True
                return False

            def has_operation(self):
                for c in self.node:
                    if (c.has_operation()):
                        return True
                return self.yfilter != YFilter.not_set

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "nodes" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-bundlemgr-oper:bundle-information/mlacp-member-counters/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "node"):
                    for c in self.node:
                        segment = c.get_segment_path()
                        if (segment_path == segment):
                            return c
                    c = BundleInformation.MlacpMemberCounters.Nodes.Node()
                    c.parent = self
                    local_reference_key = "ydk::seg::%s" % segment_path
                    self._local_refs[local_reference_key] = c
                    self.node.append(c)
                    return c

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "node"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                pass

        def has_data(self):
            return (
                (self.bundles is not None and self.bundles.has_data()) or
                (self.iccp_groups is not None and self.iccp_groups.has_data()) or
                (self.members is not None and self.members.has_data()) or
                (self.nodes is not None and self.nodes.has_data()))

        def has_operation(self):
            return (
                self.yfilter != YFilter.not_set or
                (self.bundles is not None and self.bundles.has_operation()) or
                (self.iccp_groups is not None and self.iccp_groups.has_operation()) or
                (self.members is not None and self.members.has_operation()) or
                (self.nodes is not None and self.nodes.has_operation()))

        def get_segment_path(self):
            path_buffer = ""
            path_buffer = "mlacp-member-counters" + path_buffer

            return path_buffer

        def get_entity_path(self, ancestor):
            path_buffer = ""
            if (ancestor is None):
                path_buffer = "Cisco-IOS-XR-bundlemgr-oper:bundle-information/%s" % self.get_segment_path()
            else:
                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

            leaf_name_data = LeafDataList()

            entity_path = EntityPath(path_buffer, leaf_name_data)
            return entity_path

        def get_child_by_name(self, child_yang_name, segment_path):
            child = self._get_child_by_seg_name([child_yang_name, segment_path])
            if child is not None:
                return child

            if (child_yang_name == "bundles"):
                if (self.bundles is None):
                    self.bundles = BundleInformation.MlacpMemberCounters.Bundles()
                    self.bundles.parent = self
                    self._children_name_map["bundles"] = "bundles"
                return self.bundles

            if (child_yang_name == "iccp-groups"):
                if (self.iccp_groups is None):
                    self.iccp_groups = BundleInformation.MlacpMemberCounters.IccpGroups()
                    self.iccp_groups.parent = self
                    self._children_name_map["iccp_groups"] = "iccp-groups"
                return self.iccp_groups

            if (child_yang_name == "members"):
                if (self.members is None):
                    self.members = BundleInformation.MlacpMemberCounters.Members()
                    self.members.parent = self
                    self._children_name_map["members"] = "members"
                return self.members

            if (child_yang_name == "nodes"):
                if (self.nodes is None):
                    self.nodes = BundleInformation.MlacpMemberCounters.Nodes()
                    self.nodes.parent = self
                    self._children_name_map["nodes"] = "nodes"
                return self.nodes

            return None

        def has_leaf_or_child_of_name(self, name):
            if(name == "bundles" or name == "iccp-groups" or name == "members" or name == "nodes"):
                return True
            return False

        def set_value(self, value_path, value, name_space, name_space_prefix):
            pass

    def has_data(self):
        return (
            (self.bfd_counters is not None and self.bfd_counters.has_data()) or
            (self.bundle is not None and self.bundle.has_data()) or
            (self.bundle_briefs is not None and self.bundle_briefs.has_data()) or
            (self.events is not None and self.events.has_data()) or
            (self.events_bdl is not None and self.events_bdl.has_data()) or
            (self.events_mbr is not None and self.events_mbr.has_data()) or
            (self.events_rg is not None and self.events_rg.has_data()) or
            (self.lacp is not None and self.lacp.has_data()) or
            (self.mac_allocation is not None and self.mac_allocation.has_data()) or
            (self.mlacp is not None and self.mlacp.has_data()) or
            (self.mlacp_brief is not None and self.mlacp_brief.has_data()) or
            (self.mlacp_bundle_counters is not None and self.mlacp_bundle_counters.has_data()) or
            (self.mlacp_iccp_group_counters is not None and self.mlacp_iccp_group_counters.has_data()) or
            (self.mlacp_member_counters is not None and self.mlacp_member_counters.has_data()) or
            (self.protect is not None and self.protect.has_data()) or
            (self.scheduled_actions is not None and self.scheduled_actions.has_data()) or
            (self.system_id is not None and self.system_id.has_data()))

    def has_operation(self):
        return (
            self.yfilter != YFilter.not_set or
            (self.bfd_counters is not None and self.bfd_counters.has_operation()) or
            (self.bundle is not None and self.bundle.has_operation()) or
            (self.bundle_briefs is not None and self.bundle_briefs.has_operation()) or
            (self.events is not None and self.events.has_operation()) or
            (self.events_bdl is not None and self.events_bdl.has_operation()) or
            (self.events_mbr is not None and self.events_mbr.has_operation()) or
            (self.events_rg is not None and self.events_rg.has_operation()) or
            (self.lacp is not None and self.lacp.has_operation()) or
            (self.mac_allocation is not None and self.mac_allocation.has_operation()) or
            (self.mlacp is not None and self.mlacp.has_operation()) or
            (self.mlacp_brief is not None and self.mlacp_brief.has_operation()) or
            (self.mlacp_bundle_counters is not None and self.mlacp_bundle_counters.has_operation()) or
            (self.mlacp_iccp_group_counters is not None and self.mlacp_iccp_group_counters.has_operation()) or
            (self.mlacp_member_counters is not None and self.mlacp_member_counters.has_operation()) or
            (self.protect is not None and self.protect.has_operation()) or
            (self.scheduled_actions is not None and self.scheduled_actions.has_operation()) or
            (self.system_id is not None and self.system_id.has_operation()))

    def get_segment_path(self):
        path_buffer = ""
        path_buffer = "Cisco-IOS-XR-bundlemgr-oper:bundle-information" + path_buffer

        return path_buffer

    def get_entity_path(self, ancestor):
        path_buffer = ""
        if (not ancestor is None):
            raise YPYModelError("ancestor has to be None for top-level node")

        path_buffer = self.get_segment_path()
        leaf_name_data = LeafDataList()

        entity_path = EntityPath(path_buffer, leaf_name_data)
        return entity_path

    def get_child_by_name(self, child_yang_name, segment_path):
        child = self._get_child_by_seg_name([child_yang_name, segment_path])
        if child is not None:
            return child

        if (child_yang_name == "bfd-counters"):
            if (self.bfd_counters is None):
                self.bfd_counters = BundleInformation.BfdCounters()
                self.bfd_counters.parent = self
                self._children_name_map["bfd_counters"] = "bfd-counters"
            return self.bfd_counters

        if (child_yang_name == "bundle"):
            if (self.bundle is None):
                self.bundle = BundleInformation.Bundle()
                self.bundle.parent = self
                self._children_name_map["bundle"] = "bundle"
            return self.bundle

        if (child_yang_name == "bundle-briefs"):
            if (self.bundle_briefs is None):
                self.bundle_briefs = BundleInformation.BundleBriefs()
                self.bundle_briefs.parent = self
                self._children_name_map["bundle_briefs"] = "bundle-briefs"
            return self.bundle_briefs

        if (child_yang_name == "events"):
            if (self.events is None):
                self.events = BundleInformation.Events()
                self.events.parent = self
                self._children_name_map["events"] = "events"
            return self.events

        if (child_yang_name == "events-bdl"):
            if (self.events_bdl is None):
                self.events_bdl = BundleInformation.EventsBdl()
                self.events_bdl.parent = self
                self._children_name_map["events_bdl"] = "events-bdl"
            return self.events_bdl

        if (child_yang_name == "events-mbr"):
            if (self.events_mbr is None):
                self.events_mbr = BundleInformation.EventsMbr()
                self.events_mbr.parent = self
                self._children_name_map["events_mbr"] = "events-mbr"
            return self.events_mbr

        if (child_yang_name == "events-rg"):
            if (self.events_rg is None):
                self.events_rg = BundleInformation.EventsRg()
                self.events_rg.parent = self
                self._children_name_map["events_rg"] = "events-rg"
            return self.events_rg

        if (child_yang_name == "lacp"):
            if (self.lacp is None):
                self.lacp = BundleInformation.Lacp()
                self.lacp.parent = self
                self._children_name_map["lacp"] = "lacp"
            return self.lacp

        if (child_yang_name == "mac-allocation"):
            if (self.mac_allocation is None):
                self.mac_allocation = BundleInformation.MacAllocation()
                self.mac_allocation.parent = self
                self._children_name_map["mac_allocation"] = "mac-allocation"
            return self.mac_allocation

        if (child_yang_name == "mlacp"):
            if (self.mlacp is None):
                self.mlacp = BundleInformation.Mlacp()
                self.mlacp.parent = self
                self._children_name_map["mlacp"] = "mlacp"
            return self.mlacp

        if (child_yang_name == "mlacp-brief"):
            if (self.mlacp_brief is None):
                self.mlacp_brief = BundleInformation.MlacpBrief()
                self.mlacp_brief.parent = self
                self._children_name_map["mlacp_brief"] = "mlacp-brief"
            return self.mlacp_brief

        if (child_yang_name == "mlacp-bundle-counters"):
            if (self.mlacp_bundle_counters is None):
                self.mlacp_bundle_counters = BundleInformation.MlacpBundleCounters()
                self.mlacp_bundle_counters.parent = self
                self._children_name_map["mlacp_bundle_counters"] = "mlacp-bundle-counters"
            return self.mlacp_bundle_counters

        if (child_yang_name == "mlacp-iccp-group-counters"):
            if (self.mlacp_iccp_group_counters is None):
                self.mlacp_iccp_group_counters = BundleInformation.MlacpIccpGroupCounters()
                self.mlacp_iccp_group_counters.parent = self
                self._children_name_map["mlacp_iccp_group_counters"] = "mlacp-iccp-group-counters"
            return self.mlacp_iccp_group_counters

        if (child_yang_name == "mlacp-member-counters"):
            if (self.mlacp_member_counters is None):
                self.mlacp_member_counters = BundleInformation.MlacpMemberCounters()
                self.mlacp_member_counters.parent = self
                self._children_name_map["mlacp_member_counters"] = "mlacp-member-counters"
            return self.mlacp_member_counters

        if (child_yang_name == "protect"):
            if (self.protect is None):
                self.protect = BundleInformation.Protect()
                self.protect.parent = self
                self._children_name_map["protect"] = "protect"
            return self.protect

        if (child_yang_name == "scheduled-actions"):
            if (self.scheduled_actions is None):
                self.scheduled_actions = BundleInformation.ScheduledActions()
                self.scheduled_actions.parent = self
                self._children_name_map["scheduled_actions"] = "scheduled-actions"
            return self.scheduled_actions

        if (child_yang_name == "system-id"):
            if (self.system_id is None):
                self.system_id = BundleInformation.SystemId()
                self.system_id.parent = self
                self._children_name_map["system_id"] = "system-id"
            return self.system_id

        return None

    def has_leaf_or_child_of_name(self, name):
        if(name == "bfd-counters" or name == "bundle" or name == "bundle-briefs" or name == "events" or name == "events-bdl" or name == "events-mbr" or name == "events-rg" or name == "lacp" or name == "mac-allocation" or name == "mlacp" or name == "mlacp-brief" or name == "mlacp-bundle-counters" or name == "mlacp-iccp-group-counters" or name == "mlacp-member-counters" or name == "protect" or name == "scheduled-actions" or name == "system-id"):
            return True
        return False

    def set_value(self, value_path, value, name_space, name_space_prefix):
        pass

    def clone_ptr(self):
        self._top_entity = BundleInformation()
        return self._top_entity

class LacpData(Entity):
    """
    lacp data
    
    .. attribute:: global_
    
    	Global LACP data
    	**type**\:   :py:class:`Global_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.LacpData.Global_>`
    
    

    """

    _prefix = 'bundlemgr-oper'
    _revision = '2015-11-09'

    def __init__(self):
        super(LacpData, self).__init__()
        self._top_entity = None

        self.yang_name = "lacp-data"
        self.yang_parent_name = "Cisco-IOS-XR-bundlemgr-oper"

        self.global_ = LacpData.Global_()
        self.global_.parent = self
        self._children_name_map["global_"] = "global"
        self._children_yang_names.add("global")


    class Global_(Entity):
        """
        Global LACP data
        
        .. attribute:: system_id
        
        	LACP System ID
        	**type**\:   :py:class:`SystemId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.LacpData.Global_.SystemId>`
        
        

        """

        _prefix = 'bundlemgr-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(LacpData.Global_, self).__init__()

            self.yang_name = "global"
            self.yang_parent_name = "lacp-data"

            self.system_id = LacpData.Global_.SystemId()
            self.system_id.parent = self
            self._children_name_map["system_id"] = "system-id"
            self._children_yang_names.add("system-id")


        class SystemId(Entity):
            """
            LACP System ID
            
            .. attribute:: iccp_group_id
            
            	ICCP Group that the system ID is for
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: system_id
            
            	System ID
            	**type**\:   :py:class:`SystemId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.LacpData.Global_.SystemId.SystemId>`
            
            .. attribute:: system_mac_address
            
            	MAC Address used to identify the system (deprecated)
            	**type**\:  str
            
            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
            
            .. attribute:: system_priority
            
            	Priority of the system (deprecated)
            	**type**\:  int
            
            	**range:** 0..65535
            
            

            """

            _prefix = 'bundlemgr-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(LacpData.Global_.SystemId, self).__init__()

                self.yang_name = "system-id"
                self.yang_parent_name = "global"

                self.iccp_group_id = YLeaf(YType.uint32, "iccp-group-id")

                self.system_mac_address = YLeaf(YType.str, "system-mac-address")

                self.system_priority = YLeaf(YType.uint16, "system-priority")

                self.system_id = LacpData.Global_.SystemId.SystemId()
                self.system_id.parent = self
                self._children_name_map["system_id"] = "system-id"
                self._children_yang_names.add("system-id")

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in ("iccp_group_id",
                                "system_mac_address",
                                "system_priority") and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(LacpData.Global_.SystemId, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(LacpData.Global_.SystemId, self).__setattr__(name, value)


            class SystemId(Entity):
                """
                System ID
                
                .. attribute:: system_mac_addr
                
                	MAC Address used to identify the system
                	**type**\:   :py:class:`SystemMacAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.LacpData.Global_.SystemId.SystemId.SystemMacAddr>`
                
                .. attribute:: system_prio
                
                	Priority of the system
                	**type**\:  int
                
                	**range:** 0..65535
                
                

                """

                _prefix = 'bundlemgr-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(LacpData.Global_.SystemId.SystemId, self).__init__()

                    self.yang_name = "system-id"
                    self.yang_parent_name = "system-id"

                    self.system_prio = YLeaf(YType.uint16, "system-prio")

                    self.system_mac_addr = LacpData.Global_.SystemId.SystemId.SystemMacAddr()
                    self.system_mac_addr.parent = self
                    self._children_name_map["system_mac_addr"] = "system-mac-addr"
                    self._children_yang_names.add("system-mac-addr")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("system_prio") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(LacpData.Global_.SystemId.SystemId, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(LacpData.Global_.SystemId.SystemId, self).__setattr__(name, value)


                class SystemMacAddr(Entity):
                    """
                    MAC Address used to identify the system
                    
                    .. attribute:: macaddr
                    
                    	macaddr
                    	**type**\:  str
                    
                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                    
                    

                    """

                    _prefix = 'bundlemgr-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(LacpData.Global_.SystemId.SystemId.SystemMacAddr, self).__init__()

                        self.yang_name = "system-mac-addr"
                        self.yang_parent_name = "system-id"

                        self.macaddr = YLeaf(YType.str, "macaddr")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("macaddr") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(LacpData.Global_.SystemId.SystemId.SystemMacAddr, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(LacpData.Global_.SystemId.SystemId.SystemMacAddr, self).__setattr__(name, value)

                    def has_data(self):
                        return self.macaddr.is_set

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.macaddr.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "system-mac-addr" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-bundlemgr-oper:lacp-data/global/system-id/system-id/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.macaddr.is_set or self.macaddr.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.macaddr.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "macaddr"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "macaddr"):
                            self.macaddr = value
                            self.macaddr.value_namespace = name_space
                            self.macaddr.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    return (
                        self.system_prio.is_set or
                        (self.system_mac_addr is not None and self.system_mac_addr.has_data()))

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.system_prio.yfilter != YFilter.not_set or
                        (self.system_mac_addr is not None and self.system_mac_addr.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "system-id" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-bundlemgr-oper:lacp-data/global/system-id/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.system_prio.is_set or self.system_prio.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.system_prio.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "system-mac-addr"):
                        if (self.system_mac_addr is None):
                            self.system_mac_addr = LacpData.Global_.SystemId.SystemId.SystemMacAddr()
                            self.system_mac_addr.parent = self
                            self._children_name_map["system_mac_addr"] = "system-mac-addr"
                        return self.system_mac_addr

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "system-mac-addr" or name == "system-prio"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "system-prio"):
                        self.system_prio = value
                        self.system_prio.value_namespace = name_space
                        self.system_prio.value_namespace_prefix = name_space_prefix

            def has_data(self):
                return (
                    self.iccp_group_id.is_set or
                    self.system_mac_address.is_set or
                    self.system_priority.is_set or
                    (self.system_id is not None and self.system_id.has_data()))

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    self.iccp_group_id.yfilter != YFilter.not_set or
                    self.system_mac_address.yfilter != YFilter.not_set or
                    self.system_priority.yfilter != YFilter.not_set or
                    (self.system_id is not None and self.system_id.has_operation()))

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "system-id" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-bundlemgr-oper:lacp-data/global/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()
                if (self.iccp_group_id.is_set or self.iccp_group_id.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.iccp_group_id.get_name_leafdata())
                if (self.system_mac_address.is_set or self.system_mac_address.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.system_mac_address.get_name_leafdata())
                if (self.system_priority.is_set or self.system_priority.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.system_priority.get_name_leafdata())

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "system-id"):
                    if (self.system_id is None):
                        self.system_id = LacpData.Global_.SystemId.SystemId()
                        self.system_id.parent = self
                        self._children_name_map["system_id"] = "system-id"
                    return self.system_id

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "system-id" or name == "iccp-group-id" or name == "system-mac-address" or name == "system-priority"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                if(value_path == "iccp-group-id"):
                    self.iccp_group_id = value
                    self.iccp_group_id.value_namespace = name_space
                    self.iccp_group_id.value_namespace_prefix = name_space_prefix
                if(value_path == "system-mac-address"):
                    self.system_mac_address = value
                    self.system_mac_address.value_namespace = name_space
                    self.system_mac_address.value_namespace_prefix = name_space_prefix
                if(value_path == "system-priority"):
                    self.system_priority = value
                    self.system_priority.value_namespace = name_space
                    self.system_priority.value_namespace_prefix = name_space_prefix

        def has_data(self):
            return (self.system_id is not None and self.system_id.has_data())

        def has_operation(self):
            return (
                self.yfilter != YFilter.not_set or
                (self.system_id is not None and self.system_id.has_operation()))

        def get_segment_path(self):
            path_buffer = ""
            path_buffer = "global" + path_buffer

            return path_buffer

        def get_entity_path(self, ancestor):
            path_buffer = ""
            if (ancestor is None):
                path_buffer = "Cisco-IOS-XR-bundlemgr-oper:lacp-data/%s" % self.get_segment_path()
            else:
                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

            leaf_name_data = LeafDataList()

            entity_path = EntityPath(path_buffer, leaf_name_data)
            return entity_path

        def get_child_by_name(self, child_yang_name, segment_path):
            child = self._get_child_by_seg_name([child_yang_name, segment_path])
            if child is not None:
                return child

            if (child_yang_name == "system-id"):
                if (self.system_id is None):
                    self.system_id = LacpData.Global_.SystemId()
                    self.system_id.parent = self
                    self._children_name_map["system_id"] = "system-id"
                return self.system_id

            return None

        def has_leaf_or_child_of_name(self, name):
            if(name == "system-id"):
                return True
            return False

        def set_value(self, value_path, value, name_space, name_space_prefix):
            pass

    def has_data(self):
        return (self.global_ is not None and self.global_.has_data())

    def has_operation(self):
        return (
            self.yfilter != YFilter.not_set or
            (self.global_ is not None and self.global_.has_operation()))

    def get_segment_path(self):
        path_buffer = ""
        path_buffer = "Cisco-IOS-XR-bundlemgr-oper:lacp-data" + path_buffer

        return path_buffer

    def get_entity_path(self, ancestor):
        path_buffer = ""
        if (not ancestor is None):
            raise YPYModelError("ancestor has to be None for top-level node")

        path_buffer = self.get_segment_path()
        leaf_name_data = LeafDataList()

        entity_path = EntityPath(path_buffer, leaf_name_data)
        return entity_path

    def get_child_by_name(self, child_yang_name, segment_path):
        child = self._get_child_by_seg_name([child_yang_name, segment_path])
        if child is not None:
            return child

        if (child_yang_name == "global"):
            if (self.global_ is None):
                self.global_ = LacpData.Global_()
                self.global_.parent = self
                self._children_name_map["global_"] = "global"
            return self.global_

        return None

    def has_leaf_or_child_of_name(self, name):
        if(name == "global"):
            return True
        return False

    def set_value(self, value_path, value, name_space, name_space_prefix):
        pass

    def clone_ptr(self):
        self._top_entity = LacpData()
        return self._top_entity

class Bundles(Entity):
    """
    bundles
    
    .. attribute:: bundles
    
    	Per bundle operational data
    	**type**\:   :py:class:`Bundles <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.Bundles.Bundles>`
    
    

    """

    _prefix = 'bundlemgr-oper'
    _revision = '2015-11-09'

    def __init__(self):
        super(Bundles, self).__init__()
        self._top_entity = None

        self.yang_name = "bundles"
        self.yang_parent_name = "Cisco-IOS-XR-bundlemgr-oper"

        self.bundles = Bundles.Bundles()
        self.bundles.parent = self
        self._children_name_map["bundles"] = "bundles"
        self._children_yang_names.add("bundles")


    class Bundles(Entity):
        """
        Per bundle operational data
        
        .. attribute:: bundle
        
        	Bundle interface
        	**type**\: list of    :py:class:`Bundle <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.Bundles.Bundles.Bundle>`
        
        

        """

        _prefix = 'bundlemgr-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(Bundles.Bundles, self).__init__()

            self.yang_name = "bundles"
            self.yang_parent_name = "bundles"

            self.bundle = YList(self)

        def __setattr__(self, name, value):
            self._check_monkey_patching_error(name, value)
            with _handle_type_error():
                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                        "Please use list append or extend method."
                                        .format(value))
                if isinstance(value, Enum.YLeaf):
                    value = value.name
                if name in () and name in self.__dict__:
                    if isinstance(value, YLeaf):
                        self.__dict__[name].set(value.get())
                    elif isinstance(value, YLeafList):
                        super(Bundles.Bundles, self).__setattr__(name, value)
                    else:
                        self.__dict__[name].set(value)
                else:
                    if hasattr(value, "parent") and name != "parent":
                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                            value.parent = self
                        elif value.parent is None and value.yang_name in self._children_yang_names:
                            value.parent = self
                    super(Bundles.Bundles, self).__setattr__(name, value)


        class Bundle(Entity):
            """
            Bundle interface
            
            .. attribute:: bundle_interface  <key>
            
            	Bundle interface
            	**type**\:  str
            
            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
            
            .. attribute:: data
            
            	Data for each Bundle
            	**type**\:   :py:class:`Data <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.Bundles.Bundles.Bundle.Data>`
            
            .. attribute:: members
            
            	Member interface
            	**type**\:   :py:class:`Members <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.Bundles.Bundles.Bundle.Members>`
            
            

            """

            _prefix = 'bundlemgr-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(Bundles.Bundles.Bundle, self).__init__()

                self.yang_name = "bundle"
                self.yang_parent_name = "bundles"

                self.bundle_interface = YLeaf(YType.str, "bundle-interface")

                self.data = Bundles.Bundles.Bundle.Data()
                self.data.parent = self
                self._children_name_map["data"] = "data"
                self._children_yang_names.add("data")

                self.members = Bundles.Bundles.Bundle.Members()
                self.members.parent = self
                self._children_name_map["members"] = "members"
                self._children_yang_names.add("members")

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in ("bundle_interface") and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(Bundles.Bundles.Bundle, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(Bundles.Bundles.Bundle, self).__setattr__(name, value)


            class Data(Entity):
                """
                Data for each Bundle
                
                .. attribute:: active_foreign_member_count
                
                	The number of active foreign members on the bundle
                	**type**\:  int
                
                	**range:** 0..65535
                
                .. attribute:: active_member_count
                
                	The number of active local members on the bundle
                	**type**\:  int
                
                	**range:** 0..65535
                
                .. attribute:: available_bandwidth
                
                	Bandwidth available to the bundle interface (kbps)
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: kbit/s
                
                .. attribute:: bfd_config
                
                	Configuration values for BFD on bundle members
                	**type**\: list of    :py:class:`BfdConfig <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.Bundles.Bundles.Bundle.Data.BfdConfig>`
                
                .. attribute:: bundle_interface_name
                
                	Bundle interface name
                	**type**\:  str
                
                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                
                .. attribute:: bundle_status
                
                	The state of the bundle
                	**type**\:   :py:class:`BmBdlState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmBdlState>`
                
                .. attribute:: cisco_extensions
                
                	The status of the Cisco Extensions feature (1 = enabled, 0 = not enabled)
                	**type**\:  bool
                
                .. attribute:: collector_max_delay
                
                	Collector Max Delay
                	**type**\:  int
                
                	**range:** 0..65535
                
                .. attribute:: configured_bandwidth
                
                	Bandwidth configured on the bundle interface (kbps)
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: kbit/s
                
                .. attribute:: configured_foreign_member_count
                
                	The number of configured local members on the bundle
                	**type**\:  int
                
                	**range:** 0..65535
                
                .. attribute:: configured_member_count
                
                	The number of configured local members on the bundle
                	**type**\:  int
                
                	**range:** 0..65535
                
                .. attribute:: effective_bandwidth
                
                	Effective bandwidth on the bundle interface (kbps)
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: kbit/s
                
                .. attribute:: iccp_group_id
                
                	ICCP Group that the bundle is configured to
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: inter_chassis
                
                	Indicates if this bundle is operating as an inter\-chassis link (1 = I\-C link, 0 = normal)
                	**type**\:  bool
                
                .. attribute:: ipv4bfd_status
                
                	The status of the BFD (IPv4) feature on the bundle
                	**type**\:   :py:class:`BmFeatureStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmFeatureStatus>`
                
                .. attribute:: ipv6bfd_status
                
                	The status of the BFD (IPv6) feature on the bundle
                	**type**\:   :py:class:`BmFeatureStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmFeatureStatus>`
                
                .. attribute:: is_active
                
                	Indicates the active/standby redundancy state of the device for the bundle
                	**type**\:  bool
                
                .. attribute:: lacp_nonrevertive
                
                	The status of the LACP nonrevertive feature (1 = enable, 0 = not enabled)
                	**type**\:  bool
                
                .. attribute:: lacp_status
                
                	The status of the LACP feature on the bundle
                	**type**\:   :py:class:`BmFeatureStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmFeatureStatus>`
                
                .. attribute:: link_order_status
                
                	The status of the link order signaling feature on the bundle
                	**type**\:   :py:class:`BmFeatureStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmFeatureStatus>`
                
                .. attribute:: load_balance_hash_type
                
                	The type of hash to use for load balancing
                	**type**\:  str
                
                .. attribute:: load_balance_locality_threshold
                
                	The number of links required per rack for localized load balancing
                	**type**\:  int
                
                	**range:** 0..65535
                
                .. attribute:: mac_address
                
                	MAC address of this member
                	**type**\:   :py:class:`MacAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.Bundles.Bundles.Bundle.Data.MacAddress>`
                
                .. attribute:: mac_source
                
                	The source of the MAC Address
                	**type**\:   :py:class:`BmBdlMacSource <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmBdlMacSource>`
                
                .. attribute:: mac_source_member
                
                	The name of the member that supplied the MAC address
                	**type**\:  str
                
                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                
                .. attribute:: maximize_threshold_value_band_width
                
                	Attempt to maximize the bundle if bandwidth is below this value
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: maximize_threshold_value_links
                
                	Attempt to maximize the bundle if links are below this value
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: maximum_active_links
                
                	Maximum number of active links in the bundle
                	**type**\:  int
                
                	**range:** 0..255
                
                .. attribute:: maximum_active_links_source
                
                	Source of maximum active links value
                	**type**\:   :py:class:`BmWhichSystem <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmWhichSystem>`
                
                .. attribute:: minimum_active_links
                
                	Minimum number of active links for bundle to go up
                	**type**\:  int
                
                	**range:** 0..255
                
                .. attribute:: minimum_bandwidth
                
                	Minimum bundle bandwidth for bundle to go up (kbps)
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: kbit/s
                
                .. attribute:: mlacp_mode
                
                	Indicates the mode of the device for the bundle
                	**type**\:   :py:class:`BundleMlacpMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleMlacpMode>`
                
                .. attribute:: mlacp_status
                
                	The status of the mLACP feature on the bundle
                	**type**\:   :py:class:`BmFeatureStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmFeatureStatus>`
                
                .. attribute:: primary_member
                
                	Primary bundle member (no longer applicable)
                	**type**\:  str
                
                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                
                .. attribute:: recovery_delay
                
                	Number of seconds to wait before becoming active after recovering from a failure
                	**type**\:  int
                
                	**range:** 0..65535
                
                	**units**\: second
                
                .. attribute:: singleton
                
                	Is the ICCP group of the bundle in singleton mode (1 = singleton; 0 = not singleton)
                	**type**\:  bool
                
                .. attribute:: standby_member_count
                
                	The number of standby local members on the bundle
                	**type**\:  int
                
                	**range:** 0..65535
                
                .. attribute:: suppression_timer
                
                	Timer for suppressing bundle state flaps
                	**type**\:  int
                
                	**range:** 0..65535
                
                .. attribute:: switchover_type
                
                	How a switchover of the bundle from this device will occur
                	**type**\:   :py:class:`BmdMlacpSwitchover <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmdMlacpSwitchover>`
                
                .. attribute:: wait_while_timer
                
                	The wait while time used for member ports
                	**type**\:  int
                
                	**range:** 0..65535
                
                

                """

                _prefix = 'bundlemgr-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Bundles.Bundles.Bundle.Data, self).__init__()

                    self.yang_name = "data"
                    self.yang_parent_name = "bundle"

                    self.active_foreign_member_count = YLeaf(YType.uint16, "active-foreign-member-count")

                    self.active_member_count = YLeaf(YType.uint16, "active-member-count")

                    self.available_bandwidth = YLeaf(YType.uint32, "available-bandwidth")

                    self.bundle_interface_name = YLeaf(YType.str, "bundle-interface-name")

                    self.bundle_status = YLeaf(YType.enumeration, "bundle-status")

                    self.cisco_extensions = YLeaf(YType.boolean, "cisco-extensions")

                    self.collector_max_delay = YLeaf(YType.uint16, "collector-max-delay")

                    self.configured_bandwidth = YLeaf(YType.uint32, "configured-bandwidth")

                    self.configured_foreign_member_count = YLeaf(YType.uint16, "configured-foreign-member-count")

                    self.configured_member_count = YLeaf(YType.uint16, "configured-member-count")

                    self.effective_bandwidth = YLeaf(YType.uint32, "effective-bandwidth")

                    self.iccp_group_id = YLeaf(YType.uint32, "iccp-group-id")

                    self.inter_chassis = YLeaf(YType.boolean, "inter-chassis")

                    self.ipv4bfd_status = YLeaf(YType.enumeration, "ipv4bfd-status")

                    self.ipv6bfd_status = YLeaf(YType.enumeration, "ipv6bfd-status")

                    self.is_active = YLeaf(YType.boolean, "is-active")

                    self.lacp_nonrevertive = YLeaf(YType.boolean, "lacp-nonrevertive")

                    self.lacp_status = YLeaf(YType.enumeration, "lacp-status")

                    self.link_order_status = YLeaf(YType.enumeration, "link-order-status")

                    self.load_balance_hash_type = YLeaf(YType.str, "load-balance-hash-type")

                    self.load_balance_locality_threshold = YLeaf(YType.uint16, "load-balance-locality-threshold")

                    self.mac_source = YLeaf(YType.enumeration, "mac-source")

                    self.mac_source_member = YLeaf(YType.str, "mac-source-member")

                    self.maximize_threshold_value_band_width = YLeaf(YType.uint32, "maximize-threshold-value-band-width")

                    self.maximize_threshold_value_links = YLeaf(YType.uint32, "maximize-threshold-value-links")

                    self.maximum_active_links = YLeaf(YType.uint8, "maximum-active-links")

                    self.maximum_active_links_source = YLeaf(YType.enumeration, "maximum-active-links-source")

                    self.minimum_active_links = YLeaf(YType.uint8, "minimum-active-links")

                    self.minimum_bandwidth = YLeaf(YType.uint32, "minimum-bandwidth")

                    self.mlacp_mode = YLeaf(YType.enumeration, "mlacp-mode")

                    self.mlacp_status = YLeaf(YType.enumeration, "mlacp-status")

                    self.primary_member = YLeaf(YType.str, "primary-member")

                    self.recovery_delay = YLeaf(YType.uint16, "recovery-delay")

                    self.singleton = YLeaf(YType.boolean, "singleton")

                    self.standby_member_count = YLeaf(YType.uint16, "standby-member-count")

                    self.suppression_timer = YLeaf(YType.uint16, "suppression-timer")

                    self.switchover_type = YLeaf(YType.enumeration, "switchover-type")

                    self.wait_while_timer = YLeaf(YType.uint16, "wait-while-timer")

                    self.mac_address = Bundles.Bundles.Bundle.Data.MacAddress()
                    self.mac_address.parent = self
                    self._children_name_map["mac_address"] = "mac-address"
                    self._children_yang_names.add("mac-address")

                    self.bfd_config = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("active_foreign_member_count",
                                    "active_member_count",
                                    "available_bandwidth",
                                    "bundle_interface_name",
                                    "bundle_status",
                                    "cisco_extensions",
                                    "collector_max_delay",
                                    "configured_bandwidth",
                                    "configured_foreign_member_count",
                                    "configured_member_count",
                                    "effective_bandwidth",
                                    "iccp_group_id",
                                    "inter_chassis",
                                    "ipv4bfd_status",
                                    "ipv6bfd_status",
                                    "is_active",
                                    "lacp_nonrevertive",
                                    "lacp_status",
                                    "link_order_status",
                                    "load_balance_hash_type",
                                    "load_balance_locality_threshold",
                                    "mac_source",
                                    "mac_source_member",
                                    "maximize_threshold_value_band_width",
                                    "maximize_threshold_value_links",
                                    "maximum_active_links",
                                    "maximum_active_links_source",
                                    "minimum_active_links",
                                    "minimum_bandwidth",
                                    "mlacp_mode",
                                    "mlacp_status",
                                    "primary_member",
                                    "recovery_delay",
                                    "singleton",
                                    "standby_member_count",
                                    "suppression_timer",
                                    "switchover_type",
                                    "wait_while_timer") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Bundles.Bundles.Bundle.Data, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Bundles.Bundles.Bundle.Data, self).__setattr__(name, value)


                class MacAddress(Entity):
                    """
                    MAC address of this member
                    
                    .. attribute:: address
                    
                    	MAC address
                    	**type**\:  str
                    
                    	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                    
                    

                    """

                    _prefix = 'bundlemgr-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Bundles.Bundles.Bundle.Data.MacAddress, self).__init__()

                        self.yang_name = "mac-address"
                        self.yang_parent_name = "data"

                        self.address = YLeaf(YType.str, "address")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("address") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Bundles.Bundles.Bundle.Data.MacAddress, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Bundles.Bundles.Bundle.Data.MacAddress, self).__setattr__(name, value)

                    def has_data(self):
                        return self.address.is_set

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.address.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "mac-address" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.address.is_set or self.address.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.address.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "address"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "address"):
                            self.address = value
                            self.address.value_namespace = name_space
                            self.address.value_namespace_prefix = name_space_prefix


                class BfdConfig(Entity):
                    """
                    Configuration values for BFD on bundle members
                    
                    .. attribute:: bundle_status
                    
                    	Status of BFD on the bundle
                    	**type**\:   :py:class:`BmdBfdBdlState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmdBfdBdlState>`
                    
                    .. attribute:: destination_address
                    
                    	Configured destination address for BFD session
                    	**type**\:   :py:class:`DestinationAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.Bundles.Bundles.Bundle.Data.BfdConfig.DestinationAddress>`
                    
                    .. attribute:: fast_detect
                    
                    	Flag indicating if BFD is enabled (1 = enabled; 0 = not enabled)
                    	**type**\:  bool
                    
                    .. attribute:: mode_info
                    
                    	Standard used for per\-member BFD
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: nbr_unconfig_timer
                    
                    	Time to wait on session NBR\_UNCONFIG before declaring DOWN
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: pref_echo_min_interval
                    
                    	Preferred echo minimum interval for the BFD session (ms)
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: pref_min_interval
                    
                    	Preferred minimum interval for the BFD session (ms)
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: pref_multiplier
                    
                    	Preferred multiplier for the BFD session
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: start_timer
                    
                    	Time to wait on session start before declaring DOWN
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'bundlemgr-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Bundles.Bundles.Bundle.Data.BfdConfig, self).__init__()

                        self.yang_name = "bfd-config"
                        self.yang_parent_name = "data"

                        self.bundle_status = YLeaf(YType.enumeration, "bundle-status")

                        self.fast_detect = YLeaf(YType.boolean, "fast-detect")

                        self.mode_info = YLeaf(YType.uint32, "mode-info")

                        self.nbr_unconfig_timer = YLeaf(YType.uint32, "nbr-unconfig-timer")

                        self.pref_echo_min_interval = YLeaf(YType.uint32, "pref-echo-min-interval")

                        self.pref_min_interval = YLeaf(YType.uint32, "pref-min-interval")

                        self.pref_multiplier = YLeaf(YType.uint16, "pref-multiplier")

                        self.start_timer = YLeaf(YType.uint32, "start-timer")

                        self.destination_address = Bundles.Bundles.Bundle.Data.BfdConfig.DestinationAddress()
                        self.destination_address.parent = self
                        self._children_name_map["destination_address"] = "destination-address"
                        self._children_yang_names.add("destination-address")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("bundle_status",
                                        "fast_detect",
                                        "mode_info",
                                        "nbr_unconfig_timer",
                                        "pref_echo_min_interval",
                                        "pref_min_interval",
                                        "pref_multiplier",
                                        "start_timer") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Bundles.Bundles.Bundle.Data.BfdConfig, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Bundles.Bundles.Bundle.Data.BfdConfig, self).__setattr__(name, value)


                    class DestinationAddress(Entity):
                        """
                        Configured destination address for BFD session
                        
                        .. attribute:: af
                        
                        	AF
                        	**type**\:   :py:class:`BmAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmAfId>`
                        
                        .. attribute:: ipv4
                        
                        	IPv4 address type
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6
                        
                        	IPv6 address type
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'bundlemgr-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Bundles.Bundles.Bundle.Data.BfdConfig.DestinationAddress, self).__init__()

                            self.yang_name = "destination-address"
                            self.yang_parent_name = "bfd-config"

                            self.af = YLeaf(YType.enumeration, "af")

                            self.ipv4 = YLeaf(YType.str, "ipv4")

                            self.ipv6 = YLeaf(YType.str, "ipv6")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af",
                                            "ipv4",
                                            "ipv6") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Bundles.Bundles.Bundle.Data.BfdConfig.DestinationAddress, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Bundles.Bundles.Bundle.Data.BfdConfig.DestinationAddress, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af.is_set or
                                self.ipv4.is_set or
                                self.ipv6.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af.yfilter != YFilter.not_set or
                                self.ipv4.yfilter != YFilter.not_set or
                                self.ipv6.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "destination-address" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af.is_set or self.af.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af.get_name_leafdata())
                            if (self.ipv4.is_set or self.ipv4.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4.get_name_leafdata())
                            if (self.ipv6.is_set or self.ipv6.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af" or name == "ipv4" or name == "ipv6"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af"):
                                self.af = value
                                self.af.value_namespace = name_space
                                self.af.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4"):
                                self.ipv4 = value
                                self.ipv4.value_namespace = name_space
                                self.ipv4.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6"):
                                self.ipv6 = value
                                self.ipv6.value_namespace = name_space
                                self.ipv6.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.bundle_status.is_set or
                            self.fast_detect.is_set or
                            self.mode_info.is_set or
                            self.nbr_unconfig_timer.is_set or
                            self.pref_echo_min_interval.is_set or
                            self.pref_min_interval.is_set or
                            self.pref_multiplier.is_set or
                            self.start_timer.is_set or
                            (self.destination_address is not None and self.destination_address.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.bundle_status.yfilter != YFilter.not_set or
                            self.fast_detect.yfilter != YFilter.not_set or
                            self.mode_info.yfilter != YFilter.not_set or
                            self.nbr_unconfig_timer.yfilter != YFilter.not_set or
                            self.pref_echo_min_interval.yfilter != YFilter.not_set or
                            self.pref_min_interval.yfilter != YFilter.not_set or
                            self.pref_multiplier.yfilter != YFilter.not_set or
                            self.start_timer.yfilter != YFilter.not_set or
                            (self.destination_address is not None and self.destination_address.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "bfd-config" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.bundle_status.is_set or self.bundle_status.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bundle_status.get_name_leafdata())
                        if (self.fast_detect.is_set or self.fast_detect.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.fast_detect.get_name_leafdata())
                        if (self.mode_info.is_set or self.mode_info.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mode_info.get_name_leafdata())
                        if (self.nbr_unconfig_timer.is_set or self.nbr_unconfig_timer.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.nbr_unconfig_timer.get_name_leafdata())
                        if (self.pref_echo_min_interval.is_set or self.pref_echo_min_interval.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.pref_echo_min_interval.get_name_leafdata())
                        if (self.pref_min_interval.is_set or self.pref_min_interval.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.pref_min_interval.get_name_leafdata())
                        if (self.pref_multiplier.is_set or self.pref_multiplier.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.pref_multiplier.get_name_leafdata())
                        if (self.start_timer.is_set or self.start_timer.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.start_timer.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "destination-address"):
                            if (self.destination_address is None):
                                self.destination_address = Bundles.Bundles.Bundle.Data.BfdConfig.DestinationAddress()
                                self.destination_address.parent = self
                                self._children_name_map["destination_address"] = "destination-address"
                            return self.destination_address

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "destination-address" or name == "bundle-status" or name == "fast-detect" or name == "mode-info" or name == "nbr-unconfig-timer" or name == "pref-echo-min-interval" or name == "pref-min-interval" or name == "pref-multiplier" or name == "start-timer"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "bundle-status"):
                            self.bundle_status = value
                            self.bundle_status.value_namespace = name_space
                            self.bundle_status.value_namespace_prefix = name_space_prefix
                        if(value_path == "fast-detect"):
                            self.fast_detect = value
                            self.fast_detect.value_namespace = name_space
                            self.fast_detect.value_namespace_prefix = name_space_prefix
                        if(value_path == "mode-info"):
                            self.mode_info = value
                            self.mode_info.value_namespace = name_space
                            self.mode_info.value_namespace_prefix = name_space_prefix
                        if(value_path == "nbr-unconfig-timer"):
                            self.nbr_unconfig_timer = value
                            self.nbr_unconfig_timer.value_namespace = name_space
                            self.nbr_unconfig_timer.value_namespace_prefix = name_space_prefix
                        if(value_path == "pref-echo-min-interval"):
                            self.pref_echo_min_interval = value
                            self.pref_echo_min_interval.value_namespace = name_space
                            self.pref_echo_min_interval.value_namespace_prefix = name_space_prefix
                        if(value_path == "pref-min-interval"):
                            self.pref_min_interval = value
                            self.pref_min_interval.value_namespace = name_space
                            self.pref_min_interval.value_namespace_prefix = name_space_prefix
                        if(value_path == "pref-multiplier"):
                            self.pref_multiplier = value
                            self.pref_multiplier.value_namespace = name_space
                            self.pref_multiplier.value_namespace_prefix = name_space_prefix
                        if(value_path == "start-timer"):
                            self.start_timer = value
                            self.start_timer.value_namespace = name_space
                            self.start_timer.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.bfd_config:
                        if (c.has_data()):
                            return True
                    return (
                        self.active_foreign_member_count.is_set or
                        self.active_member_count.is_set or
                        self.available_bandwidth.is_set or
                        self.bundle_interface_name.is_set or
                        self.bundle_status.is_set or
                        self.cisco_extensions.is_set or
                        self.collector_max_delay.is_set or
                        self.configured_bandwidth.is_set or
                        self.configured_foreign_member_count.is_set or
                        self.configured_member_count.is_set or
                        self.effective_bandwidth.is_set or
                        self.iccp_group_id.is_set or
                        self.inter_chassis.is_set or
                        self.ipv4bfd_status.is_set or
                        self.ipv6bfd_status.is_set or
                        self.is_active.is_set or
                        self.lacp_nonrevertive.is_set or
                        self.lacp_status.is_set or
                        self.link_order_status.is_set or
                        self.load_balance_hash_type.is_set or
                        self.load_balance_locality_threshold.is_set or
                        self.mac_source.is_set or
                        self.mac_source_member.is_set or
                        self.maximize_threshold_value_band_width.is_set or
                        self.maximize_threshold_value_links.is_set or
                        self.maximum_active_links.is_set or
                        self.maximum_active_links_source.is_set or
                        self.minimum_active_links.is_set or
                        self.minimum_bandwidth.is_set or
                        self.mlacp_mode.is_set or
                        self.mlacp_status.is_set or
                        self.primary_member.is_set or
                        self.recovery_delay.is_set or
                        self.singleton.is_set or
                        self.standby_member_count.is_set or
                        self.suppression_timer.is_set or
                        self.switchover_type.is_set or
                        self.wait_while_timer.is_set or
                        (self.mac_address is not None and self.mac_address.has_data()))

                def has_operation(self):
                    for c in self.bfd_config:
                        if (c.has_operation()):
                            return True
                    return (
                        self.yfilter != YFilter.not_set or
                        self.active_foreign_member_count.yfilter != YFilter.not_set or
                        self.active_member_count.yfilter != YFilter.not_set or
                        self.available_bandwidth.yfilter != YFilter.not_set or
                        self.bundle_interface_name.yfilter != YFilter.not_set or
                        self.bundle_status.yfilter != YFilter.not_set or
                        self.cisco_extensions.yfilter != YFilter.not_set or
                        self.collector_max_delay.yfilter != YFilter.not_set or
                        self.configured_bandwidth.yfilter != YFilter.not_set or
                        self.configured_foreign_member_count.yfilter != YFilter.not_set or
                        self.configured_member_count.yfilter != YFilter.not_set or
                        self.effective_bandwidth.yfilter != YFilter.not_set or
                        self.iccp_group_id.yfilter != YFilter.not_set or
                        self.inter_chassis.yfilter != YFilter.not_set or
                        self.ipv4bfd_status.yfilter != YFilter.not_set or
                        self.ipv6bfd_status.yfilter != YFilter.not_set or
                        self.is_active.yfilter != YFilter.not_set or
                        self.lacp_nonrevertive.yfilter != YFilter.not_set or
                        self.lacp_status.yfilter != YFilter.not_set or
                        self.link_order_status.yfilter != YFilter.not_set or
                        self.load_balance_hash_type.yfilter != YFilter.not_set or
                        self.load_balance_locality_threshold.yfilter != YFilter.not_set or
                        self.mac_source.yfilter != YFilter.not_set or
                        self.mac_source_member.yfilter != YFilter.not_set or
                        self.maximize_threshold_value_band_width.yfilter != YFilter.not_set or
                        self.maximize_threshold_value_links.yfilter != YFilter.not_set or
                        self.maximum_active_links.yfilter != YFilter.not_set or
                        self.maximum_active_links_source.yfilter != YFilter.not_set or
                        self.minimum_active_links.yfilter != YFilter.not_set or
                        self.minimum_bandwidth.yfilter != YFilter.not_set or
                        self.mlacp_mode.yfilter != YFilter.not_set or
                        self.mlacp_status.yfilter != YFilter.not_set or
                        self.primary_member.yfilter != YFilter.not_set or
                        self.recovery_delay.yfilter != YFilter.not_set or
                        self.singleton.yfilter != YFilter.not_set or
                        self.standby_member_count.yfilter != YFilter.not_set or
                        self.suppression_timer.yfilter != YFilter.not_set or
                        self.switchover_type.yfilter != YFilter.not_set or
                        self.wait_while_timer.yfilter != YFilter.not_set or
                        (self.mac_address is not None and self.mac_address.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "data" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.active_foreign_member_count.is_set or self.active_foreign_member_count.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.active_foreign_member_count.get_name_leafdata())
                    if (self.active_member_count.is_set or self.active_member_count.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.active_member_count.get_name_leafdata())
                    if (self.available_bandwidth.is_set or self.available_bandwidth.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.available_bandwidth.get_name_leafdata())
                    if (self.bundle_interface_name.is_set or self.bundle_interface_name.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.bundle_interface_name.get_name_leafdata())
                    if (self.bundle_status.is_set or self.bundle_status.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.bundle_status.get_name_leafdata())
                    if (self.cisco_extensions.is_set or self.cisco_extensions.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.cisco_extensions.get_name_leafdata())
                    if (self.collector_max_delay.is_set or self.collector_max_delay.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.collector_max_delay.get_name_leafdata())
                    if (self.configured_bandwidth.is_set or self.configured_bandwidth.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.configured_bandwidth.get_name_leafdata())
                    if (self.configured_foreign_member_count.is_set or self.configured_foreign_member_count.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.configured_foreign_member_count.get_name_leafdata())
                    if (self.configured_member_count.is_set or self.configured_member_count.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.configured_member_count.get_name_leafdata())
                    if (self.effective_bandwidth.is_set or self.effective_bandwidth.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.effective_bandwidth.get_name_leafdata())
                    if (self.iccp_group_id.is_set or self.iccp_group_id.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.iccp_group_id.get_name_leafdata())
                    if (self.inter_chassis.is_set or self.inter_chassis.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.inter_chassis.get_name_leafdata())
                    if (self.ipv4bfd_status.is_set or self.ipv4bfd_status.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.ipv4bfd_status.get_name_leafdata())
                    if (self.ipv6bfd_status.is_set or self.ipv6bfd_status.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.ipv6bfd_status.get_name_leafdata())
                    if (self.is_active.is_set or self.is_active.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_active.get_name_leafdata())
                    if (self.lacp_nonrevertive.is_set or self.lacp_nonrevertive.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.lacp_nonrevertive.get_name_leafdata())
                    if (self.lacp_status.is_set or self.lacp_status.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.lacp_status.get_name_leafdata())
                    if (self.link_order_status.is_set or self.link_order_status.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.link_order_status.get_name_leafdata())
                    if (self.load_balance_hash_type.is_set or self.load_balance_hash_type.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.load_balance_hash_type.get_name_leafdata())
                    if (self.load_balance_locality_threshold.is_set or self.load_balance_locality_threshold.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.load_balance_locality_threshold.get_name_leafdata())
                    if (self.mac_source.is_set or self.mac_source.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mac_source.get_name_leafdata())
                    if (self.mac_source_member.is_set or self.mac_source_member.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mac_source_member.get_name_leafdata())
                    if (self.maximize_threshold_value_band_width.is_set or self.maximize_threshold_value_band_width.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.maximize_threshold_value_band_width.get_name_leafdata())
                    if (self.maximize_threshold_value_links.is_set or self.maximize_threshold_value_links.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.maximize_threshold_value_links.get_name_leafdata())
                    if (self.maximum_active_links.is_set or self.maximum_active_links.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.maximum_active_links.get_name_leafdata())
                    if (self.maximum_active_links_source.is_set or self.maximum_active_links_source.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.maximum_active_links_source.get_name_leafdata())
                    if (self.minimum_active_links.is_set or self.minimum_active_links.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.minimum_active_links.get_name_leafdata())
                    if (self.minimum_bandwidth.is_set or self.minimum_bandwidth.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.minimum_bandwidth.get_name_leafdata())
                    if (self.mlacp_mode.is_set or self.mlacp_mode.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mlacp_mode.get_name_leafdata())
                    if (self.mlacp_status.is_set or self.mlacp_status.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mlacp_status.get_name_leafdata())
                    if (self.primary_member.is_set or self.primary_member.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.primary_member.get_name_leafdata())
                    if (self.recovery_delay.is_set or self.recovery_delay.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.recovery_delay.get_name_leafdata())
                    if (self.singleton.is_set or self.singleton.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.singleton.get_name_leafdata())
                    if (self.standby_member_count.is_set or self.standby_member_count.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.standby_member_count.get_name_leafdata())
                    if (self.suppression_timer.is_set or self.suppression_timer.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.suppression_timer.get_name_leafdata())
                    if (self.switchover_type.is_set or self.switchover_type.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.switchover_type.get_name_leafdata())
                    if (self.wait_while_timer.is_set or self.wait_while_timer.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.wait_while_timer.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "bfd-config"):
                        for c in self.bfd_config:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Bundles.Bundles.Bundle.Data.BfdConfig()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.bfd_config.append(c)
                        return c

                    if (child_yang_name == "mac-address"):
                        if (self.mac_address is None):
                            self.mac_address = Bundles.Bundles.Bundle.Data.MacAddress()
                            self.mac_address.parent = self
                            self._children_name_map["mac_address"] = "mac-address"
                        return self.mac_address

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "bfd-config" or name == "mac-address" or name == "active-foreign-member-count" or name == "active-member-count" or name == "available-bandwidth" or name == "bundle-interface-name" or name == "bundle-status" or name == "cisco-extensions" or name == "collector-max-delay" or name == "configured-bandwidth" or name == "configured-foreign-member-count" or name == "configured-member-count" or name == "effective-bandwidth" or name == "iccp-group-id" or name == "inter-chassis" or name == "ipv4bfd-status" or name == "ipv6bfd-status" or name == "is-active" or name == "lacp-nonrevertive" or name == "lacp-status" or name == "link-order-status" or name == "load-balance-hash-type" or name == "load-balance-locality-threshold" or name == "mac-source" or name == "mac-source-member" or name == "maximize-threshold-value-band-width" or name == "maximize-threshold-value-links" or name == "maximum-active-links" or name == "maximum-active-links-source" or name == "minimum-active-links" or name == "minimum-bandwidth" or name == "mlacp-mode" or name == "mlacp-status" or name == "primary-member" or name == "recovery-delay" or name == "singleton" or name == "standby-member-count" or name == "suppression-timer" or name == "switchover-type" or name == "wait-while-timer"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "active-foreign-member-count"):
                        self.active_foreign_member_count = value
                        self.active_foreign_member_count.value_namespace = name_space
                        self.active_foreign_member_count.value_namespace_prefix = name_space_prefix
                    if(value_path == "active-member-count"):
                        self.active_member_count = value
                        self.active_member_count.value_namespace = name_space
                        self.active_member_count.value_namespace_prefix = name_space_prefix
                    if(value_path == "available-bandwidth"):
                        self.available_bandwidth = value
                        self.available_bandwidth.value_namespace = name_space
                        self.available_bandwidth.value_namespace_prefix = name_space_prefix
                    if(value_path == "bundle-interface-name"):
                        self.bundle_interface_name = value
                        self.bundle_interface_name.value_namespace = name_space
                        self.bundle_interface_name.value_namespace_prefix = name_space_prefix
                    if(value_path == "bundle-status"):
                        self.bundle_status = value
                        self.bundle_status.value_namespace = name_space
                        self.bundle_status.value_namespace_prefix = name_space_prefix
                    if(value_path == "cisco-extensions"):
                        self.cisco_extensions = value
                        self.cisco_extensions.value_namespace = name_space
                        self.cisco_extensions.value_namespace_prefix = name_space_prefix
                    if(value_path == "collector-max-delay"):
                        self.collector_max_delay = value
                        self.collector_max_delay.value_namespace = name_space
                        self.collector_max_delay.value_namespace_prefix = name_space_prefix
                    if(value_path == "configured-bandwidth"):
                        self.configured_bandwidth = value
                        self.configured_bandwidth.value_namespace = name_space
                        self.configured_bandwidth.value_namespace_prefix = name_space_prefix
                    if(value_path == "configured-foreign-member-count"):
                        self.configured_foreign_member_count = value
                        self.configured_foreign_member_count.value_namespace = name_space
                        self.configured_foreign_member_count.value_namespace_prefix = name_space_prefix
                    if(value_path == "configured-member-count"):
                        self.configured_member_count = value
                        self.configured_member_count.value_namespace = name_space
                        self.configured_member_count.value_namespace_prefix = name_space_prefix
                    if(value_path == "effective-bandwidth"):
                        self.effective_bandwidth = value
                        self.effective_bandwidth.value_namespace = name_space
                        self.effective_bandwidth.value_namespace_prefix = name_space_prefix
                    if(value_path == "iccp-group-id"):
                        self.iccp_group_id = value
                        self.iccp_group_id.value_namespace = name_space
                        self.iccp_group_id.value_namespace_prefix = name_space_prefix
                    if(value_path == "inter-chassis"):
                        self.inter_chassis = value
                        self.inter_chassis.value_namespace = name_space
                        self.inter_chassis.value_namespace_prefix = name_space_prefix
                    if(value_path == "ipv4bfd-status"):
                        self.ipv4bfd_status = value
                        self.ipv4bfd_status.value_namespace = name_space
                        self.ipv4bfd_status.value_namespace_prefix = name_space_prefix
                    if(value_path == "ipv6bfd-status"):
                        self.ipv6bfd_status = value
                        self.ipv6bfd_status.value_namespace = name_space
                        self.ipv6bfd_status.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-active"):
                        self.is_active = value
                        self.is_active.value_namespace = name_space
                        self.is_active.value_namespace_prefix = name_space_prefix
                    if(value_path == "lacp-nonrevertive"):
                        self.lacp_nonrevertive = value
                        self.lacp_nonrevertive.value_namespace = name_space
                        self.lacp_nonrevertive.value_namespace_prefix = name_space_prefix
                    if(value_path == "lacp-status"):
                        self.lacp_status = value
                        self.lacp_status.value_namespace = name_space
                        self.lacp_status.value_namespace_prefix = name_space_prefix
                    if(value_path == "link-order-status"):
                        self.link_order_status = value
                        self.link_order_status.value_namespace = name_space
                        self.link_order_status.value_namespace_prefix = name_space_prefix
                    if(value_path == "load-balance-hash-type"):
                        self.load_balance_hash_type = value
                        self.load_balance_hash_type.value_namespace = name_space
                        self.load_balance_hash_type.value_namespace_prefix = name_space_prefix
                    if(value_path == "load-balance-locality-threshold"):
                        self.load_balance_locality_threshold = value
                        self.load_balance_locality_threshold.value_namespace = name_space
                        self.load_balance_locality_threshold.value_namespace_prefix = name_space_prefix
                    if(value_path == "mac-source"):
                        self.mac_source = value
                        self.mac_source.value_namespace = name_space
                        self.mac_source.value_namespace_prefix = name_space_prefix
                    if(value_path == "mac-source-member"):
                        self.mac_source_member = value
                        self.mac_source_member.value_namespace = name_space
                        self.mac_source_member.value_namespace_prefix = name_space_prefix
                    if(value_path == "maximize-threshold-value-band-width"):
                        self.maximize_threshold_value_band_width = value
                        self.maximize_threshold_value_band_width.value_namespace = name_space
                        self.maximize_threshold_value_band_width.value_namespace_prefix = name_space_prefix
                    if(value_path == "maximize-threshold-value-links"):
                        self.maximize_threshold_value_links = value
                        self.maximize_threshold_value_links.value_namespace = name_space
                        self.maximize_threshold_value_links.value_namespace_prefix = name_space_prefix
                    if(value_path == "maximum-active-links"):
                        self.maximum_active_links = value
                        self.maximum_active_links.value_namespace = name_space
                        self.maximum_active_links.value_namespace_prefix = name_space_prefix
                    if(value_path == "maximum-active-links-source"):
                        self.maximum_active_links_source = value
                        self.maximum_active_links_source.value_namespace = name_space
                        self.maximum_active_links_source.value_namespace_prefix = name_space_prefix
                    if(value_path == "minimum-active-links"):
                        self.minimum_active_links = value
                        self.minimum_active_links.value_namespace = name_space
                        self.minimum_active_links.value_namespace_prefix = name_space_prefix
                    if(value_path == "minimum-bandwidth"):
                        self.minimum_bandwidth = value
                        self.minimum_bandwidth.value_namespace = name_space
                        self.minimum_bandwidth.value_namespace_prefix = name_space_prefix
                    if(value_path == "mlacp-mode"):
                        self.mlacp_mode = value
                        self.mlacp_mode.value_namespace = name_space
                        self.mlacp_mode.value_namespace_prefix = name_space_prefix
                    if(value_path == "mlacp-status"):
                        self.mlacp_status = value
                        self.mlacp_status.value_namespace = name_space
                        self.mlacp_status.value_namespace_prefix = name_space_prefix
                    if(value_path == "primary-member"):
                        self.primary_member = value
                        self.primary_member.value_namespace = name_space
                        self.primary_member.value_namespace_prefix = name_space_prefix
                    if(value_path == "recovery-delay"):
                        self.recovery_delay = value
                        self.recovery_delay.value_namespace = name_space
                        self.recovery_delay.value_namespace_prefix = name_space_prefix
                    if(value_path == "singleton"):
                        self.singleton = value
                        self.singleton.value_namespace = name_space
                        self.singleton.value_namespace_prefix = name_space_prefix
                    if(value_path == "standby-member-count"):
                        self.standby_member_count = value
                        self.standby_member_count.value_namespace = name_space
                        self.standby_member_count.value_namespace_prefix = name_space_prefix
                    if(value_path == "suppression-timer"):
                        self.suppression_timer = value
                        self.suppression_timer.value_namespace = name_space
                        self.suppression_timer.value_namespace_prefix = name_space_prefix
                    if(value_path == "switchover-type"):
                        self.switchover_type = value
                        self.switchover_type.value_namespace = name_space
                        self.switchover_type.value_namespace_prefix = name_space_prefix
                    if(value_path == "wait-while-timer"):
                        self.wait_while_timer = value
                        self.wait_while_timer.value_namespace = name_space
                        self.wait_while_timer.value_namespace_prefix = name_space_prefix


            class Members(Entity):
                """
                Member interface
                
                .. attribute:: member
                
                	Member information
                	**type**\: list of    :py:class:`Member <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.Bundles.Bundles.Bundle.Members.Member>`
                
                

                """

                _prefix = 'bundlemgr-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Bundles.Bundles.Bundle.Members, self).__init__()

                    self.yang_name = "members"
                    self.yang_parent_name = "bundle"

                    self.member = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Bundles.Bundles.Bundle.Members, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Bundles.Bundles.Bundle.Members, self).__setattr__(name, value)


                class Member(Entity):
                    """
                    Member information
                    
                    .. attribute:: member_interface  <key>
                    
                    	Member interface
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: bandwidth
                    
                    	Bandwidth of this member (kbps)
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: kbit/s
                    
                    .. attribute:: counters
                    
                    	Counters data about member link
                    	**type**\:   :py:class:`Counters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.Bundles.Bundles.Bundle.Members.Member.Counters>`
                    
                    .. attribute:: iccp_node
                    
                    	Location of member
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: interface_name
                    
                    	Member's interface name
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: link_data
                    
                    	Lacp data about member link
                    	**type**\:   :py:class:`LinkData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.Bundles.Bundles.Bundle.Members.Member.LinkData>`
                    
                    .. attribute:: link_order_number
                    
                    	Member's link order number
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: mac_address
                    
                    	MAC address of this member (deprecated)
                    	**type**\:   :py:class:`MacAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.Bundles.Bundles.Bundle.Members.Member.MacAddress>`
                    
                    .. attribute:: member_mux_data
                    
                    	Mux state machine data
                    	**type**\:   :py:class:`MemberMuxData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.Bundles.Bundles.Bundle.Members.Member.MemberMuxData>`
                    
                    .. attribute:: member_name
                    
                    	Member's (short form) name
                    	**type**\:  str
                    
                    .. attribute:: member_type
                    
                    	Member's type (local/foreign)
                    	**type**\:   :py:class:`BmdMemberTypeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmdMemberTypeEnum>`
                    
                    .. attribute:: port_number
                    
                    	Member's link number
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: port_priority
                    
                    	The priority of this member
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: underlying_link_id
                    
                    	Member's underlying link ID
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'bundlemgr-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Bundles.Bundles.Bundle.Members.Member, self).__init__()

                        self.yang_name = "member"
                        self.yang_parent_name = "members"

                        self.member_interface = YLeaf(YType.str, "member-interface")

                        self.bandwidth = YLeaf(YType.uint32, "bandwidth")

                        self.iccp_node = YLeaf(YType.uint32, "iccp-node")

                        self.interface_name = YLeaf(YType.str, "interface-name")

                        self.link_order_number = YLeaf(YType.uint16, "link-order-number")

                        self.member_name = YLeaf(YType.str, "member-name")

                        self.member_type = YLeaf(YType.enumeration, "member-type")

                        self.port_number = YLeaf(YType.uint16, "port-number")

                        self.port_priority = YLeaf(YType.uint16, "port-priority")

                        self.underlying_link_id = YLeaf(YType.uint16, "underlying-link-id")

                        self.counters = Bundles.Bundles.Bundle.Members.Member.Counters()
                        self.counters.parent = self
                        self._children_name_map["counters"] = "counters"
                        self._children_yang_names.add("counters")

                        self.link_data = Bundles.Bundles.Bundle.Members.Member.LinkData()
                        self.link_data.parent = self
                        self._children_name_map["link_data"] = "link-data"
                        self._children_yang_names.add("link-data")

                        self.mac_address = Bundles.Bundles.Bundle.Members.Member.MacAddress()
                        self.mac_address.parent = self
                        self._children_name_map["mac_address"] = "mac-address"
                        self._children_yang_names.add("mac-address")

                        self.member_mux_data = Bundles.Bundles.Bundle.Members.Member.MemberMuxData()
                        self.member_mux_data.parent = self
                        self._children_name_map["member_mux_data"] = "member-mux-data"
                        self._children_yang_names.add("member-mux-data")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("member_interface",
                                        "bandwidth",
                                        "iccp_node",
                                        "interface_name",
                                        "link_order_number",
                                        "member_name",
                                        "member_type",
                                        "port_number",
                                        "port_priority",
                                        "underlying_link_id") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Bundles.Bundles.Bundle.Members.Member, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Bundles.Bundles.Bundle.Members.Member, self).__setattr__(name, value)


                    class Counters(Entity):
                        """
                        Counters data about member link
                        
                        .. attribute:: defaulted
                        
                        	State flag set to Defaulted
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: excess_lacpd_us_received
                        
                        	LACPDUs received that exceed the rate limit
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: excess_marker_packets_received
                        
                        	Marker packets received that exceed the rate limit
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: expired
                        
                        	State flag set to Expired
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: illegal_packets_received
                        
                        	Illegal and unknown packets received
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: lacpd_us_received
                        
                        	LACPDUs received
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: lacpd_us_transmitted
                        
                        	LACPDUs transmitted
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: last_cleared_nsec
                        
                        	Last time counters cleared (nsec) (deprecated)
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: last_cleared_sec
                        
                        	Last time counters cleared (s) (deprecated)
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: marker_packets_received
                        
                        	Marker packets received
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: marker_responses_transmitted
                        
                        	Marker response packets transmitted
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'bundlemgr-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Bundles.Bundles.Bundle.Members.Member.Counters, self).__init__()

                            self.yang_name = "counters"
                            self.yang_parent_name = "member"

                            self.defaulted = YLeaf(YType.uint32, "defaulted")

                            self.excess_lacpd_us_received = YLeaf(YType.uint32, "excess-lacpd-us-received")

                            self.excess_marker_packets_received = YLeaf(YType.uint32, "excess-marker-packets-received")

                            self.expired = YLeaf(YType.uint32, "expired")

                            self.illegal_packets_received = YLeaf(YType.uint32, "illegal-packets-received")

                            self.lacpd_us_received = YLeaf(YType.uint32, "lacpd-us-received")

                            self.lacpd_us_transmitted = YLeaf(YType.uint32, "lacpd-us-transmitted")

                            self.last_cleared_nsec = YLeaf(YType.uint32, "last-cleared-nsec")

                            self.last_cleared_sec = YLeaf(YType.uint32, "last-cleared-sec")

                            self.marker_packets_received = YLeaf(YType.uint32, "marker-packets-received")

                            self.marker_responses_transmitted = YLeaf(YType.uint32, "marker-responses-transmitted")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("defaulted",
                                            "excess_lacpd_us_received",
                                            "excess_marker_packets_received",
                                            "expired",
                                            "illegal_packets_received",
                                            "lacpd_us_received",
                                            "lacpd_us_transmitted",
                                            "last_cleared_nsec",
                                            "last_cleared_sec",
                                            "marker_packets_received",
                                            "marker_responses_transmitted") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Bundles.Bundles.Bundle.Members.Member.Counters, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Bundles.Bundles.Bundle.Members.Member.Counters, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.defaulted.is_set or
                                self.excess_lacpd_us_received.is_set or
                                self.excess_marker_packets_received.is_set or
                                self.expired.is_set or
                                self.illegal_packets_received.is_set or
                                self.lacpd_us_received.is_set or
                                self.lacpd_us_transmitted.is_set or
                                self.last_cleared_nsec.is_set or
                                self.last_cleared_sec.is_set or
                                self.marker_packets_received.is_set or
                                self.marker_responses_transmitted.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.defaulted.yfilter != YFilter.not_set or
                                self.excess_lacpd_us_received.yfilter != YFilter.not_set or
                                self.excess_marker_packets_received.yfilter != YFilter.not_set or
                                self.expired.yfilter != YFilter.not_set or
                                self.illegal_packets_received.yfilter != YFilter.not_set or
                                self.lacpd_us_received.yfilter != YFilter.not_set or
                                self.lacpd_us_transmitted.yfilter != YFilter.not_set or
                                self.last_cleared_nsec.yfilter != YFilter.not_set or
                                self.last_cleared_sec.yfilter != YFilter.not_set or
                                self.marker_packets_received.yfilter != YFilter.not_set or
                                self.marker_responses_transmitted.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "counters" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.defaulted.is_set or self.defaulted.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.defaulted.get_name_leafdata())
                            if (self.excess_lacpd_us_received.is_set or self.excess_lacpd_us_received.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.excess_lacpd_us_received.get_name_leafdata())
                            if (self.excess_marker_packets_received.is_set or self.excess_marker_packets_received.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.excess_marker_packets_received.get_name_leafdata())
                            if (self.expired.is_set or self.expired.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.expired.get_name_leafdata())
                            if (self.illegal_packets_received.is_set or self.illegal_packets_received.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.illegal_packets_received.get_name_leafdata())
                            if (self.lacpd_us_received.is_set or self.lacpd_us_received.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.lacpd_us_received.get_name_leafdata())
                            if (self.lacpd_us_transmitted.is_set or self.lacpd_us_transmitted.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.lacpd_us_transmitted.get_name_leafdata())
                            if (self.last_cleared_nsec.is_set or self.last_cleared_nsec.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.last_cleared_nsec.get_name_leafdata())
                            if (self.last_cleared_sec.is_set or self.last_cleared_sec.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.last_cleared_sec.get_name_leafdata())
                            if (self.marker_packets_received.is_set or self.marker_packets_received.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.marker_packets_received.get_name_leafdata())
                            if (self.marker_responses_transmitted.is_set or self.marker_responses_transmitted.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.marker_responses_transmitted.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "defaulted" or name == "excess-lacpd-us-received" or name == "excess-marker-packets-received" or name == "expired" or name == "illegal-packets-received" or name == "lacpd-us-received" or name == "lacpd-us-transmitted" or name == "last-cleared-nsec" or name == "last-cleared-sec" or name == "marker-packets-received" or name == "marker-responses-transmitted"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "defaulted"):
                                self.defaulted = value
                                self.defaulted.value_namespace = name_space
                                self.defaulted.value_namespace_prefix = name_space_prefix
                            if(value_path == "excess-lacpd-us-received"):
                                self.excess_lacpd_us_received = value
                                self.excess_lacpd_us_received.value_namespace = name_space
                                self.excess_lacpd_us_received.value_namespace_prefix = name_space_prefix
                            if(value_path == "excess-marker-packets-received"):
                                self.excess_marker_packets_received = value
                                self.excess_marker_packets_received.value_namespace = name_space
                                self.excess_marker_packets_received.value_namespace_prefix = name_space_prefix
                            if(value_path == "expired"):
                                self.expired = value
                                self.expired.value_namespace = name_space
                                self.expired.value_namespace_prefix = name_space_prefix
                            if(value_path == "illegal-packets-received"):
                                self.illegal_packets_received = value
                                self.illegal_packets_received.value_namespace = name_space
                                self.illegal_packets_received.value_namespace_prefix = name_space_prefix
                            if(value_path == "lacpd-us-received"):
                                self.lacpd_us_received = value
                                self.lacpd_us_received.value_namespace = name_space
                                self.lacpd_us_received.value_namespace_prefix = name_space_prefix
                            if(value_path == "lacpd-us-transmitted"):
                                self.lacpd_us_transmitted = value
                                self.lacpd_us_transmitted.value_namespace = name_space
                                self.lacpd_us_transmitted.value_namespace_prefix = name_space_prefix
                            if(value_path == "last-cleared-nsec"):
                                self.last_cleared_nsec = value
                                self.last_cleared_nsec.value_namespace = name_space
                                self.last_cleared_nsec.value_namespace_prefix = name_space_prefix
                            if(value_path == "last-cleared-sec"):
                                self.last_cleared_sec = value
                                self.last_cleared_sec.value_namespace = name_space
                                self.last_cleared_sec.value_namespace_prefix = name_space_prefix
                            if(value_path == "marker-packets-received"):
                                self.marker_packets_received = value
                                self.marker_packets_received.value_namespace = name_space
                                self.marker_packets_received.value_namespace_prefix = name_space_prefix
                            if(value_path == "marker-responses-transmitted"):
                                self.marker_responses_transmitted = value
                                self.marker_responses_transmitted.value_namespace = name_space
                                self.marker_responses_transmitted.value_namespace_prefix = name_space_prefix


                    class LinkData(Entity):
                        """
                        Lacp data about member link
                        
                        .. attribute:: actor_operational_key
                        
                        	Operational key for this port
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: actor_port_id
                        
                        	Port number of this port
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: actor_port_priority
                        
                        	Priority of this port
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: actor_port_state
                        
                        	LACP state of this port
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: actor_system_mac_address
                        
                        	MAC Address of the actor system
                        	**type**\:  str
                        
                        	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                        
                        .. attribute:: actor_system_priority
                        
                        	System priority of actor system
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: attached_aggregator_id
                        
                        	MIB ifindex of attached bundle
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: interface_handle
                        
                        	Member's interface handle
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: partner_operational_key
                        
                        	Operational key for partner port
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: partner_port_id
                        
                        	Port number of the partner's port
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: partner_port_priority
                        
                        	Priority of the partner's port
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: partner_port_state
                        
                        	LACP state of the partner's port
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: partner_system_mac_address
                        
                        	MAC Address used to identify the partner system
                        	**type**\:  str
                        
                        	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                        
                        .. attribute:: partner_system_priority
                        
                        	System priority of partner system
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: selected_aggregator_id
                        
                        	MIB ifindex of selected bundle
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'bundlemgr-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Bundles.Bundles.Bundle.Members.Member.LinkData, self).__init__()

                            self.yang_name = "link-data"
                            self.yang_parent_name = "member"

                            self.actor_operational_key = YLeaf(YType.uint16, "actor-operational-key")

                            self.actor_port_id = YLeaf(YType.uint16, "actor-port-id")

                            self.actor_port_priority = YLeaf(YType.uint16, "actor-port-priority")

                            self.actor_port_state = YLeaf(YType.uint8, "actor-port-state")

                            self.actor_system_mac_address = YLeaf(YType.str, "actor-system-mac-address")

                            self.actor_system_priority = YLeaf(YType.uint16, "actor-system-priority")

                            self.attached_aggregator_id = YLeaf(YType.uint32, "attached-aggregator-id")

                            self.interface_handle = YLeaf(YType.str, "interface-handle")

                            self.partner_operational_key = YLeaf(YType.uint16, "partner-operational-key")

                            self.partner_port_id = YLeaf(YType.uint16, "partner-port-id")

                            self.partner_port_priority = YLeaf(YType.uint16, "partner-port-priority")

                            self.partner_port_state = YLeaf(YType.uint8, "partner-port-state")

                            self.partner_system_mac_address = YLeaf(YType.str, "partner-system-mac-address")

                            self.partner_system_priority = YLeaf(YType.uint16, "partner-system-priority")

                            self.selected_aggregator_id = YLeaf(YType.uint32, "selected-aggregator-id")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("actor_operational_key",
                                            "actor_port_id",
                                            "actor_port_priority",
                                            "actor_port_state",
                                            "actor_system_mac_address",
                                            "actor_system_priority",
                                            "attached_aggregator_id",
                                            "interface_handle",
                                            "partner_operational_key",
                                            "partner_port_id",
                                            "partner_port_priority",
                                            "partner_port_state",
                                            "partner_system_mac_address",
                                            "partner_system_priority",
                                            "selected_aggregator_id") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Bundles.Bundles.Bundle.Members.Member.LinkData, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Bundles.Bundles.Bundle.Members.Member.LinkData, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.actor_operational_key.is_set or
                                self.actor_port_id.is_set or
                                self.actor_port_priority.is_set or
                                self.actor_port_state.is_set or
                                self.actor_system_mac_address.is_set or
                                self.actor_system_priority.is_set or
                                self.attached_aggregator_id.is_set or
                                self.interface_handle.is_set or
                                self.partner_operational_key.is_set or
                                self.partner_port_id.is_set or
                                self.partner_port_priority.is_set or
                                self.partner_port_state.is_set or
                                self.partner_system_mac_address.is_set or
                                self.partner_system_priority.is_set or
                                self.selected_aggregator_id.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.actor_operational_key.yfilter != YFilter.not_set or
                                self.actor_port_id.yfilter != YFilter.not_set or
                                self.actor_port_priority.yfilter != YFilter.not_set or
                                self.actor_port_state.yfilter != YFilter.not_set or
                                self.actor_system_mac_address.yfilter != YFilter.not_set or
                                self.actor_system_priority.yfilter != YFilter.not_set or
                                self.attached_aggregator_id.yfilter != YFilter.not_set or
                                self.interface_handle.yfilter != YFilter.not_set or
                                self.partner_operational_key.yfilter != YFilter.not_set or
                                self.partner_port_id.yfilter != YFilter.not_set or
                                self.partner_port_priority.yfilter != YFilter.not_set or
                                self.partner_port_state.yfilter != YFilter.not_set or
                                self.partner_system_mac_address.yfilter != YFilter.not_set or
                                self.partner_system_priority.yfilter != YFilter.not_set or
                                self.selected_aggregator_id.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "link-data" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.actor_operational_key.is_set or self.actor_operational_key.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.actor_operational_key.get_name_leafdata())
                            if (self.actor_port_id.is_set or self.actor_port_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.actor_port_id.get_name_leafdata())
                            if (self.actor_port_priority.is_set or self.actor_port_priority.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.actor_port_priority.get_name_leafdata())
                            if (self.actor_port_state.is_set or self.actor_port_state.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.actor_port_state.get_name_leafdata())
                            if (self.actor_system_mac_address.is_set or self.actor_system_mac_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.actor_system_mac_address.get_name_leafdata())
                            if (self.actor_system_priority.is_set or self.actor_system_priority.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.actor_system_priority.get_name_leafdata())
                            if (self.attached_aggregator_id.is_set or self.attached_aggregator_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.attached_aggregator_id.get_name_leafdata())
                            if (self.interface_handle.is_set or self.interface_handle.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface_handle.get_name_leafdata())
                            if (self.partner_operational_key.is_set or self.partner_operational_key.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.partner_operational_key.get_name_leafdata())
                            if (self.partner_port_id.is_set or self.partner_port_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.partner_port_id.get_name_leafdata())
                            if (self.partner_port_priority.is_set or self.partner_port_priority.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.partner_port_priority.get_name_leafdata())
                            if (self.partner_port_state.is_set or self.partner_port_state.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.partner_port_state.get_name_leafdata())
                            if (self.partner_system_mac_address.is_set or self.partner_system_mac_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.partner_system_mac_address.get_name_leafdata())
                            if (self.partner_system_priority.is_set or self.partner_system_priority.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.partner_system_priority.get_name_leafdata())
                            if (self.selected_aggregator_id.is_set or self.selected_aggregator_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.selected_aggregator_id.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "actor-operational-key" or name == "actor-port-id" or name == "actor-port-priority" or name == "actor-port-state" or name == "actor-system-mac-address" or name == "actor-system-priority" or name == "attached-aggregator-id" or name == "interface-handle" or name == "partner-operational-key" or name == "partner-port-id" or name == "partner-port-priority" or name == "partner-port-state" or name == "partner-system-mac-address" or name == "partner-system-priority" or name == "selected-aggregator-id"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "actor-operational-key"):
                                self.actor_operational_key = value
                                self.actor_operational_key.value_namespace = name_space
                                self.actor_operational_key.value_namespace_prefix = name_space_prefix
                            if(value_path == "actor-port-id"):
                                self.actor_port_id = value
                                self.actor_port_id.value_namespace = name_space
                                self.actor_port_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "actor-port-priority"):
                                self.actor_port_priority = value
                                self.actor_port_priority.value_namespace = name_space
                                self.actor_port_priority.value_namespace_prefix = name_space_prefix
                            if(value_path == "actor-port-state"):
                                self.actor_port_state = value
                                self.actor_port_state.value_namespace = name_space
                                self.actor_port_state.value_namespace_prefix = name_space_prefix
                            if(value_path == "actor-system-mac-address"):
                                self.actor_system_mac_address = value
                                self.actor_system_mac_address.value_namespace = name_space
                                self.actor_system_mac_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "actor-system-priority"):
                                self.actor_system_priority = value
                                self.actor_system_priority.value_namespace = name_space
                                self.actor_system_priority.value_namespace_prefix = name_space_prefix
                            if(value_path == "attached-aggregator-id"):
                                self.attached_aggregator_id = value
                                self.attached_aggregator_id.value_namespace = name_space
                                self.attached_aggregator_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "interface-handle"):
                                self.interface_handle = value
                                self.interface_handle.value_namespace = name_space
                                self.interface_handle.value_namespace_prefix = name_space_prefix
                            if(value_path == "partner-operational-key"):
                                self.partner_operational_key = value
                                self.partner_operational_key.value_namespace = name_space
                                self.partner_operational_key.value_namespace_prefix = name_space_prefix
                            if(value_path == "partner-port-id"):
                                self.partner_port_id = value
                                self.partner_port_id.value_namespace = name_space
                                self.partner_port_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "partner-port-priority"):
                                self.partner_port_priority = value
                                self.partner_port_priority.value_namespace = name_space
                                self.partner_port_priority.value_namespace_prefix = name_space_prefix
                            if(value_path == "partner-port-state"):
                                self.partner_port_state = value
                                self.partner_port_state.value_namespace = name_space
                                self.partner_port_state.value_namespace_prefix = name_space_prefix
                            if(value_path == "partner-system-mac-address"):
                                self.partner_system_mac_address = value
                                self.partner_system_mac_address.value_namespace = name_space
                                self.partner_system_mac_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "partner-system-priority"):
                                self.partner_system_priority = value
                                self.partner_system_priority.value_namespace = name_space
                                self.partner_system_priority.value_namespace_prefix = name_space_prefix
                            if(value_path == "selected-aggregator-id"):
                                self.selected_aggregator_id = value
                                self.selected_aggregator_id.value_namespace = name_space
                                self.selected_aggregator_id.value_namespace_prefix = name_space_prefix


                    class MemberMuxData(Entity):
                        """
                        Mux state machine data
                        
                        .. attribute:: error
                        
                        	Internal value indicating if an error occurred trying to put a link into the desired state
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: member_mux_state_reason
                        
                        	Reason for last Mux state change
                        	**type**\:   :py:class:`BmMbrStateReason <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmMbrStateReason>`
                        
                        .. attribute:: member_mux_state_reason_data
                        
                        	Data regarding the reason for last Mux state change
                        	**type**\:   :py:class:`MemberMuxStateReasonData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.Bundles.Bundles.Bundle.Members.Member.MemberMuxData.MemberMuxStateReasonData>`
                        
                        .. attribute:: member_state
                        
                        	Current internal state of this bundle member
                        	**type**\:   :py:class:`BmdMemberState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmdMemberState>`
                        
                        .. attribute:: mux_state
                        
                        	Current state of this bundle member
                        	**type**\:   :py:class:`BmMuxstate <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmMuxstate>`
                        
                        .. attribute:: mux_state_reason
                        
                        	Reason for last Mux state change (Deprecated)
                        	**type**\:   :py:class:`BmMuxreason <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmMuxreason>`
                        
                        

                        """

                        _prefix = 'bundlemgr-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Bundles.Bundles.Bundle.Members.Member.MemberMuxData, self).__init__()

                            self.yang_name = "member-mux-data"
                            self.yang_parent_name = "member"

                            self.error = YLeaf(YType.uint32, "error")

                            self.member_mux_state_reason = YLeaf(YType.enumeration, "member-mux-state-reason")

                            self.member_state = YLeaf(YType.enumeration, "member-state")

                            self.mux_state = YLeaf(YType.enumeration, "mux-state")

                            self.mux_state_reason = YLeaf(YType.enumeration, "mux-state-reason")

                            self.member_mux_state_reason_data = Bundles.Bundles.Bundle.Members.Member.MemberMuxData.MemberMuxStateReasonData()
                            self.member_mux_state_reason_data.parent = self
                            self._children_name_map["member_mux_state_reason_data"] = "member-mux-state-reason-data"
                            self._children_yang_names.add("member-mux-state-reason-data")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("error",
                                            "member_mux_state_reason",
                                            "member_state",
                                            "mux_state",
                                            "mux_state_reason") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Bundles.Bundles.Bundle.Members.Member.MemberMuxData, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Bundles.Bundles.Bundle.Members.Member.MemberMuxData, self).__setattr__(name, value)


                        class MemberMuxStateReasonData(Entity):
                            """
                            Data regarding the reason for last Mux state
                            change
                            
                            .. attribute:: reason_type
                            
                            	The item the reason applies to
                            	**type**\:   :py:class:`BmStateReasonTarget <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmStateReasonTarget>`
                            
                            .. attribute:: severity
                            
                            	The severity of the reason
                            	**type**\:   :py:class:`BmSeverity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BmSeverity>`
                            
                            

                            """

                            _prefix = 'bundlemgr-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Bundles.Bundles.Bundle.Members.Member.MemberMuxData.MemberMuxStateReasonData, self).__init__()

                                self.yang_name = "member-mux-state-reason-data"
                                self.yang_parent_name = "member-mux-data"

                                self.reason_type = YLeaf(YType.enumeration, "reason-type")

                                self.severity = YLeaf(YType.enumeration, "severity")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("reason_type",
                                                "severity") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Bundles.Bundles.Bundle.Members.Member.MemberMuxData.MemberMuxStateReasonData, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Bundles.Bundles.Bundle.Members.Member.MemberMuxData.MemberMuxStateReasonData, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.reason_type.is_set or
                                    self.severity.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.reason_type.yfilter != YFilter.not_set or
                                    self.severity.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "member-mux-state-reason-data" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.reason_type.is_set or self.reason_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.reason_type.get_name_leafdata())
                                if (self.severity.is_set or self.severity.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.severity.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "reason-type" or name == "severity"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "reason-type"):
                                    self.reason_type = value
                                    self.reason_type.value_namespace = name_space
                                    self.reason_type.value_namespace_prefix = name_space_prefix
                                if(value_path == "severity"):
                                    self.severity = value
                                    self.severity.value_namespace = name_space
                                    self.severity.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.error.is_set or
                                self.member_mux_state_reason.is_set or
                                self.member_state.is_set or
                                self.mux_state.is_set or
                                self.mux_state_reason.is_set or
                                (self.member_mux_state_reason_data is not None and self.member_mux_state_reason_data.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.error.yfilter != YFilter.not_set or
                                self.member_mux_state_reason.yfilter != YFilter.not_set or
                                self.member_state.yfilter != YFilter.not_set or
                                self.mux_state.yfilter != YFilter.not_set or
                                self.mux_state_reason.yfilter != YFilter.not_set or
                                (self.member_mux_state_reason_data is not None and self.member_mux_state_reason_data.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "member-mux-data" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.error.is_set or self.error.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.error.get_name_leafdata())
                            if (self.member_mux_state_reason.is_set or self.member_mux_state_reason.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.member_mux_state_reason.get_name_leafdata())
                            if (self.member_state.is_set or self.member_state.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.member_state.get_name_leafdata())
                            if (self.mux_state.is_set or self.mux_state.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mux_state.get_name_leafdata())
                            if (self.mux_state_reason.is_set or self.mux_state_reason.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mux_state_reason.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "member-mux-state-reason-data"):
                                if (self.member_mux_state_reason_data is None):
                                    self.member_mux_state_reason_data = Bundles.Bundles.Bundle.Members.Member.MemberMuxData.MemberMuxStateReasonData()
                                    self.member_mux_state_reason_data.parent = self
                                    self._children_name_map["member_mux_state_reason_data"] = "member-mux-state-reason-data"
                                return self.member_mux_state_reason_data

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "member-mux-state-reason-data" or name == "error" or name == "member-mux-state-reason" or name == "member-state" or name == "mux-state" or name == "mux-state-reason"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "error"):
                                self.error = value
                                self.error.value_namespace = name_space
                                self.error.value_namespace_prefix = name_space_prefix
                            if(value_path == "member-mux-state-reason"):
                                self.member_mux_state_reason = value
                                self.member_mux_state_reason.value_namespace = name_space
                                self.member_mux_state_reason.value_namespace_prefix = name_space_prefix
                            if(value_path == "member-state"):
                                self.member_state = value
                                self.member_state.value_namespace = name_space
                                self.member_state.value_namespace_prefix = name_space_prefix
                            if(value_path == "mux-state"):
                                self.mux_state = value
                                self.mux_state.value_namespace = name_space
                                self.mux_state.value_namespace_prefix = name_space_prefix
                            if(value_path == "mux-state-reason"):
                                self.mux_state_reason = value
                                self.mux_state_reason.value_namespace = name_space
                                self.mux_state_reason.value_namespace_prefix = name_space_prefix


                    class MacAddress(Entity):
                        """
                        MAC address of this member (deprecated)
                        
                        .. attribute:: address
                        
                        	MAC address
                        	**type**\:  str
                        
                        	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                        
                        

                        """

                        _prefix = 'bundlemgr-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Bundles.Bundles.Bundle.Members.Member.MacAddress, self).__init__()

                            self.yang_name = "mac-address"
                            self.yang_parent_name = "member"

                            self.address = YLeaf(YType.str, "address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Bundles.Bundles.Bundle.Members.Member.MacAddress, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Bundles.Bundles.Bundle.Members.Member.MacAddress, self).__setattr__(name, value)

                        def has_data(self):
                            return self.address.is_set

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "mac-address" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.address.is_set or self.address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "address"):
                                self.address = value
                                self.address.value_namespace = name_space
                                self.address.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.member_interface.is_set or
                            self.bandwidth.is_set or
                            self.iccp_node.is_set or
                            self.interface_name.is_set or
                            self.link_order_number.is_set or
                            self.member_name.is_set or
                            self.member_type.is_set or
                            self.port_number.is_set or
                            self.port_priority.is_set or
                            self.underlying_link_id.is_set or
                            (self.counters is not None and self.counters.has_data()) or
                            (self.link_data is not None and self.link_data.has_data()) or
                            (self.mac_address is not None and self.mac_address.has_data()) or
                            (self.member_mux_data is not None and self.member_mux_data.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.member_interface.yfilter != YFilter.not_set or
                            self.bandwidth.yfilter != YFilter.not_set or
                            self.iccp_node.yfilter != YFilter.not_set or
                            self.interface_name.yfilter != YFilter.not_set or
                            self.link_order_number.yfilter != YFilter.not_set or
                            self.member_name.yfilter != YFilter.not_set or
                            self.member_type.yfilter != YFilter.not_set or
                            self.port_number.yfilter != YFilter.not_set or
                            self.port_priority.yfilter != YFilter.not_set or
                            self.underlying_link_id.yfilter != YFilter.not_set or
                            (self.counters is not None and self.counters.has_operation()) or
                            (self.link_data is not None and self.link_data.has_operation()) or
                            (self.mac_address is not None and self.mac_address.has_operation()) or
                            (self.member_mux_data is not None and self.member_mux_data.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "member" + "[member-interface='" + self.member_interface.get() + "']" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.member_interface.is_set or self.member_interface.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.member_interface.get_name_leafdata())
                        if (self.bandwidth.is_set or self.bandwidth.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bandwidth.get_name_leafdata())
                        if (self.iccp_node.is_set or self.iccp_node.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.iccp_node.get_name_leafdata())
                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_name.get_name_leafdata())
                        if (self.link_order_number.is_set or self.link_order_number.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.link_order_number.get_name_leafdata())
                        if (self.member_name.is_set or self.member_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.member_name.get_name_leafdata())
                        if (self.member_type.is_set or self.member_type.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.member_type.get_name_leafdata())
                        if (self.port_number.is_set or self.port_number.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.port_number.get_name_leafdata())
                        if (self.port_priority.is_set or self.port_priority.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.port_priority.get_name_leafdata())
                        if (self.underlying_link_id.is_set or self.underlying_link_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.underlying_link_id.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "counters"):
                            if (self.counters is None):
                                self.counters = Bundles.Bundles.Bundle.Members.Member.Counters()
                                self.counters.parent = self
                                self._children_name_map["counters"] = "counters"
                            return self.counters

                        if (child_yang_name == "link-data"):
                            if (self.link_data is None):
                                self.link_data = Bundles.Bundles.Bundle.Members.Member.LinkData()
                                self.link_data.parent = self
                                self._children_name_map["link_data"] = "link-data"
                            return self.link_data

                        if (child_yang_name == "mac-address"):
                            if (self.mac_address is None):
                                self.mac_address = Bundles.Bundles.Bundle.Members.Member.MacAddress()
                                self.mac_address.parent = self
                                self._children_name_map["mac_address"] = "mac-address"
                            return self.mac_address

                        if (child_yang_name == "member-mux-data"):
                            if (self.member_mux_data is None):
                                self.member_mux_data = Bundles.Bundles.Bundle.Members.Member.MemberMuxData()
                                self.member_mux_data.parent = self
                                self._children_name_map["member_mux_data"] = "member-mux-data"
                            return self.member_mux_data

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "counters" or name == "link-data" or name == "mac-address" or name == "member-mux-data" or name == "member-interface" or name == "bandwidth" or name == "iccp-node" or name == "interface-name" or name == "link-order-number" or name == "member-name" or name == "member-type" or name == "port-number" or name == "port-priority" or name == "underlying-link-id"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "member-interface"):
                            self.member_interface = value
                            self.member_interface.value_namespace = name_space
                            self.member_interface.value_namespace_prefix = name_space_prefix
                        if(value_path == "bandwidth"):
                            self.bandwidth = value
                            self.bandwidth.value_namespace = name_space
                            self.bandwidth.value_namespace_prefix = name_space_prefix
                        if(value_path == "iccp-node"):
                            self.iccp_node = value
                            self.iccp_node.value_namespace = name_space
                            self.iccp_node.value_namespace_prefix = name_space_prefix
                        if(value_path == "interface-name"):
                            self.interface_name = value
                            self.interface_name.value_namespace = name_space
                            self.interface_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "link-order-number"):
                            self.link_order_number = value
                            self.link_order_number.value_namespace = name_space
                            self.link_order_number.value_namespace_prefix = name_space_prefix
                        if(value_path == "member-name"):
                            self.member_name = value
                            self.member_name.value_namespace = name_space
                            self.member_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "member-type"):
                            self.member_type = value
                            self.member_type.value_namespace = name_space
                            self.member_type.value_namespace_prefix = name_space_prefix
                        if(value_path == "port-number"):
                            self.port_number = value
                            self.port_number.value_namespace = name_space
                            self.port_number.value_namespace_prefix = name_space_prefix
                        if(value_path == "port-priority"):
                            self.port_priority = value
                            self.port_priority.value_namespace = name_space
                            self.port_priority.value_namespace_prefix = name_space_prefix
                        if(value_path == "underlying-link-id"):
                            self.underlying_link_id = value
                            self.underlying_link_id.value_namespace = name_space
                            self.underlying_link_id.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.member:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.member:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "members" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "member"):
                        for c in self.member:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Bundles.Bundles.Bundle.Members.Member()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.member.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "member"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass

            def has_data(self):
                return (
                    self.bundle_interface.is_set or
                    (self.data is not None and self.data.has_data()) or
                    (self.members is not None and self.members.has_data()))

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    self.bundle_interface.yfilter != YFilter.not_set or
                    (self.data is not None and self.data.has_operation()) or
                    (self.members is not None and self.members.has_operation()))

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "bundle" + "[bundle-interface='" + self.bundle_interface.get() + "']" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-bundlemgr-oper:bundles/bundles/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()
                if (self.bundle_interface.is_set or self.bundle_interface.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.bundle_interface.get_name_leafdata())

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "data"):
                    if (self.data is None):
                        self.data = Bundles.Bundles.Bundle.Data()
                        self.data.parent = self
                        self._children_name_map["data"] = "data"
                    return self.data

                if (child_yang_name == "members"):
                    if (self.members is None):
                        self.members = Bundles.Bundles.Bundle.Members()
                        self.members.parent = self
                        self._children_name_map["members"] = "members"
                    return self.members

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "data" or name == "members" or name == "bundle-interface"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                if(value_path == "bundle-interface"):
                    self.bundle_interface = value
                    self.bundle_interface.value_namespace = name_space
                    self.bundle_interface.value_namespace_prefix = name_space_prefix

        def has_data(self):
            for c in self.bundle:
                if (c.has_data()):
                    return True
            return False

        def has_operation(self):
            for c in self.bundle:
                if (c.has_operation()):
                    return True
            return self.yfilter != YFilter.not_set

        def get_segment_path(self):
            path_buffer = ""
            path_buffer = "bundles" + path_buffer

            return path_buffer

        def get_entity_path(self, ancestor):
            path_buffer = ""
            if (ancestor is None):
                path_buffer = "Cisco-IOS-XR-bundlemgr-oper:bundles/%s" % self.get_segment_path()
            else:
                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

            leaf_name_data = LeafDataList()

            entity_path = EntityPath(path_buffer, leaf_name_data)
            return entity_path

        def get_child_by_name(self, child_yang_name, segment_path):
            child = self._get_child_by_seg_name([child_yang_name, segment_path])
            if child is not None:
                return child

            if (child_yang_name == "bundle"):
                for c in self.bundle:
                    segment = c.get_segment_path()
                    if (segment_path == segment):
                        return c
                c = Bundles.Bundles.Bundle()
                c.parent = self
                local_reference_key = "ydk::seg::%s" % segment_path
                self._local_refs[local_reference_key] = c
                self.bundle.append(c)
                return c

            return None

        def has_leaf_or_child_of_name(self, name):
            if(name == "bundle"):
                return True
            return False

        def set_value(self, value_path, value, name_space, name_space_prefix):
            pass

    def has_data(self):
        return (self.bundles is not None and self.bundles.has_data())

    def has_operation(self):
        return (
            self.yfilter != YFilter.not_set or
            (self.bundles is not None and self.bundles.has_operation()))

    def get_segment_path(self):
        path_buffer = ""
        path_buffer = "Cisco-IOS-XR-bundlemgr-oper:bundles" + path_buffer

        return path_buffer

    def get_entity_path(self, ancestor):
        path_buffer = ""
        if (not ancestor is None):
            raise YPYModelError("ancestor has to be None for top-level node")

        path_buffer = self.get_segment_path()
        leaf_name_data = LeafDataList()

        entity_path = EntityPath(path_buffer, leaf_name_data)
        return entity_path

    def get_child_by_name(self, child_yang_name, segment_path):
        child = self._get_child_by_seg_name([child_yang_name, segment_path])
        if child is not None:
            return child

        if (child_yang_name == "bundles"):
            if (self.bundles is None):
                self.bundles = Bundles.Bundles()
                self.bundles.parent = self
                self._children_name_map["bundles"] = "bundles"
            return self.bundles

        return None

    def has_leaf_or_child_of_name(self, name):
        if(name == "bundles"):
            return True
        return False

    def set_value(self, value_path, value, name_space, name_space_prefix):
        pass

    def clone_ptr(self):
        self._top_entity = Bundles()
        return self._top_entity

class LacpBundleMembers(Entity):
    """
    lacp bundle members
    
    .. attribute:: members
    
    	Table of LACP bundle member interfaces
    	**type**\:   :py:class:`Members <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.LacpBundleMembers.Members>`
    
    .. attribute:: nodes
    
    	Table of devices with their LACP bundle member interfaces
    	**type**\:   :py:class:`Nodes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.LacpBundleMembers.Nodes>`
    
    

    """

    _prefix = 'bundlemgr-oper'
    _revision = '2015-11-09'

    def __init__(self):
        super(LacpBundleMembers, self).__init__()
        self._top_entity = None

        self.yang_name = "lacp-bundle-members"
        self.yang_parent_name = "Cisco-IOS-XR-bundlemgr-oper"

        self.members = LacpBundleMembers.Members()
        self.members.parent = self
        self._children_name_map["members"] = "members"
        self._children_yang_names.add("members")

        self.nodes = LacpBundleMembers.Nodes()
        self.nodes.parent = self
        self._children_name_map["nodes"] = "nodes"
        self._children_yang_names.add("nodes")


    class Nodes(Entity):
        """
        Table of devices with their LACP bundle member
        interfaces
        
        .. attribute:: node
        
        	Node ID
        	**type**\: list of    :py:class:`Node <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.LacpBundleMembers.Nodes.Node>`
        
        

        """

        _prefix = 'bundlemgr-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(LacpBundleMembers.Nodes, self).__init__()

            self.yang_name = "nodes"
            self.yang_parent_name = "lacp-bundle-members"

            self.node = YList(self)

        def __setattr__(self, name, value):
            self._check_monkey_patching_error(name, value)
            with _handle_type_error():
                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                        "Please use list append or extend method."
                                        .format(value))
                if isinstance(value, Enum.YLeaf):
                    value = value.name
                if name in () and name in self.__dict__:
                    if isinstance(value, YLeaf):
                        self.__dict__[name].set(value.get())
                    elif isinstance(value, YLeafList):
                        super(LacpBundleMembers.Nodes, self).__setattr__(name, value)
                    else:
                        self.__dict__[name].set(value)
                else:
                    if hasattr(value, "parent") and name != "parent":
                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                            value.parent = self
                        elif value.parent is None and value.yang_name in self._children_yang_names:
                            value.parent = self
                    super(LacpBundleMembers.Nodes, self).__setattr__(name, value)


        class Node(Entity):
            """
            Node ID
            
            .. attribute:: node  <key>
            
            	For a local device the Node ID e.g. '0\_0\_CPU0' , for a peer device the LDP ID followed by the ICCP Group ID e.g. '5.4.3.2,4'
            	**type**\:  str
            
            .. attribute:: counters
            
            	Link counters for LACP bundle members per node
            	**type**\:   :py:class:`Counters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.LacpBundleMembers.Nodes.Node.Counters>`
            
            

            """

            _prefix = 'bundlemgr-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(LacpBundleMembers.Nodes.Node, self).__init__()

                self.yang_name = "node"
                self.yang_parent_name = "nodes"

                self.node = YLeaf(YType.str, "node")

                self.counters = LacpBundleMembers.Nodes.Node.Counters()
                self.counters.parent = self
                self._children_name_map["counters"] = "counters"
                self._children_yang_names.add("counters")

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in ("node") and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(LacpBundleMembers.Nodes.Node, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(LacpBundleMembers.Nodes.Node, self).__setattr__(name, value)


            class Counters(Entity):
                """
                Link counters for LACP bundle members per node
                
                .. attribute:: last_wrong_port
                
                	Last unrecognized port on which a packet was received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: time_since_cleared
                
                	Time elapsed since counters were last cleared (in nanoseconds)
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                	**units**\: nanosecond
                
                .. attribute:: time_since_last_updated
                
                	Time elapsed since statistics were last updated (in nanoseconds)
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                	**units**\: nanosecond
                
                .. attribute:: time_since_unexpected_event
                
                	Time elapsed since last unexpected event (in nanoseconds)
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                	**units**\: nanosecond
                
                .. attribute:: undecodable_packets
                
                	Packets received which could not be decoded
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: unknown_port_count
                
                	Packets received for which rx port could not be determined
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: wrong_port_count
                
                	LACP protocol packets received on ports with LACP inactive/off
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'bundlemgr-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(LacpBundleMembers.Nodes.Node.Counters, self).__init__()

                    self.yang_name = "counters"
                    self.yang_parent_name = "node"

                    self.last_wrong_port = YLeaf(YType.uint32, "last-wrong-port")

                    self.time_since_cleared = YLeaf(YType.uint64, "time-since-cleared")

                    self.time_since_last_updated = YLeaf(YType.uint64, "time-since-last-updated")

                    self.time_since_unexpected_event = YLeaf(YType.uint64, "time-since-unexpected-event")

                    self.undecodable_packets = YLeaf(YType.uint32, "undecodable-packets")

                    self.unknown_port_count = YLeaf(YType.uint32, "unknown-port-count")

                    self.wrong_port_count = YLeaf(YType.uint32, "wrong-port-count")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("last_wrong_port",
                                    "time_since_cleared",
                                    "time_since_last_updated",
                                    "time_since_unexpected_event",
                                    "undecodable_packets",
                                    "unknown_port_count",
                                    "wrong_port_count") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(LacpBundleMembers.Nodes.Node.Counters, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(LacpBundleMembers.Nodes.Node.Counters, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.last_wrong_port.is_set or
                        self.time_since_cleared.is_set or
                        self.time_since_last_updated.is_set or
                        self.time_since_unexpected_event.is_set or
                        self.undecodable_packets.is_set or
                        self.unknown_port_count.is_set or
                        self.wrong_port_count.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.last_wrong_port.yfilter != YFilter.not_set or
                        self.time_since_cleared.yfilter != YFilter.not_set or
                        self.time_since_last_updated.yfilter != YFilter.not_set or
                        self.time_since_unexpected_event.yfilter != YFilter.not_set or
                        self.undecodable_packets.yfilter != YFilter.not_set or
                        self.unknown_port_count.yfilter != YFilter.not_set or
                        self.wrong_port_count.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "counters" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.last_wrong_port.is_set or self.last_wrong_port.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.last_wrong_port.get_name_leafdata())
                    if (self.time_since_cleared.is_set or self.time_since_cleared.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.time_since_cleared.get_name_leafdata())
                    if (self.time_since_last_updated.is_set or self.time_since_last_updated.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.time_since_last_updated.get_name_leafdata())
                    if (self.time_since_unexpected_event.is_set or self.time_since_unexpected_event.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.time_since_unexpected_event.get_name_leafdata())
                    if (self.undecodable_packets.is_set or self.undecodable_packets.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.undecodable_packets.get_name_leafdata())
                    if (self.unknown_port_count.is_set or self.unknown_port_count.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.unknown_port_count.get_name_leafdata())
                    if (self.wrong_port_count.is_set or self.wrong_port_count.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.wrong_port_count.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "last-wrong-port" or name == "time-since-cleared" or name == "time-since-last-updated" or name == "time-since-unexpected-event" or name == "undecodable-packets" or name == "unknown-port-count" or name == "wrong-port-count"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "last-wrong-port"):
                        self.last_wrong_port = value
                        self.last_wrong_port.value_namespace = name_space
                        self.last_wrong_port.value_namespace_prefix = name_space_prefix
                    if(value_path == "time-since-cleared"):
                        self.time_since_cleared = value
                        self.time_since_cleared.value_namespace = name_space
                        self.time_since_cleared.value_namespace_prefix = name_space_prefix
                    if(value_path == "time-since-last-updated"):
                        self.time_since_last_updated = value
                        self.time_since_last_updated.value_namespace = name_space
                        self.time_since_last_updated.value_namespace_prefix = name_space_prefix
                    if(value_path == "time-since-unexpected-event"):
                        self.time_since_unexpected_event = value
                        self.time_since_unexpected_event.value_namespace = name_space
                        self.time_since_unexpected_event.value_namespace_prefix = name_space_prefix
                    if(value_path == "undecodable-packets"):
                        self.undecodable_packets = value
                        self.undecodable_packets.value_namespace = name_space
                        self.undecodable_packets.value_namespace_prefix = name_space_prefix
                    if(value_path == "unknown-port-count"):
                        self.unknown_port_count = value
                        self.unknown_port_count.value_namespace = name_space
                        self.unknown_port_count.value_namespace_prefix = name_space_prefix
                    if(value_path == "wrong-port-count"):
                        self.wrong_port_count = value
                        self.wrong_port_count.value_namespace = name_space
                        self.wrong_port_count.value_namespace_prefix = name_space_prefix

            def has_data(self):
                return (
                    self.node.is_set or
                    (self.counters is not None and self.counters.has_data()))

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    self.node.yfilter != YFilter.not_set or
                    (self.counters is not None and self.counters.has_operation()))

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "node" + "[node='" + self.node.get() + "']" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-bundlemgr-oper:lacp-bundle-members/nodes/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()
                if (self.node.is_set or self.node.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.node.get_name_leafdata())

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "counters"):
                    if (self.counters is None):
                        self.counters = LacpBundleMembers.Nodes.Node.Counters()
                        self.counters.parent = self
                        self._children_name_map["counters"] = "counters"
                    return self.counters

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "counters" or name == "node"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                if(value_path == "node"):
                    self.node = value
                    self.node.value_namespace = name_space
                    self.node.value_namespace_prefix = name_space_prefix

        def has_data(self):
            for c in self.node:
                if (c.has_data()):
                    return True
            return False

        def has_operation(self):
            for c in self.node:
                if (c.has_operation()):
                    return True
            return self.yfilter != YFilter.not_set

        def get_segment_path(self):
            path_buffer = ""
            path_buffer = "nodes" + path_buffer

            return path_buffer

        def get_entity_path(self, ancestor):
            path_buffer = ""
            if (ancestor is None):
                path_buffer = "Cisco-IOS-XR-bundlemgr-oper:lacp-bundle-members/%s" % self.get_segment_path()
            else:
                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

            leaf_name_data = LeafDataList()

            entity_path = EntityPath(path_buffer, leaf_name_data)
            return entity_path

        def get_child_by_name(self, child_yang_name, segment_path):
            child = self._get_child_by_seg_name([child_yang_name, segment_path])
            if child is not None:
                return child

            if (child_yang_name == "node"):
                for c in self.node:
                    segment = c.get_segment_path()
                    if (segment_path == segment):
                        return c
                c = LacpBundleMembers.Nodes.Node()
                c.parent = self
                local_reference_key = "ydk::seg::%s" % segment_path
                self._local_refs[local_reference_key] = c
                self.node.append(c)
                return c

            return None

        def has_leaf_or_child_of_name(self, name):
            if(name == "node"):
                return True
            return False

        def set_value(self, value_path, value, name_space, name_space_prefix):
            pass


    class Members(Entity):
        """
        Table of LACP bundle member interfaces
        
        .. attribute:: member
        
        	LACP bundle member interface data
        	**type**\: list of    :py:class:`Member <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.LacpBundleMembers.Members.Member>`
        
        

        """

        _prefix = 'bundlemgr-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(LacpBundleMembers.Members, self).__init__()

            self.yang_name = "members"
            self.yang_parent_name = "lacp-bundle-members"

            self.member = YList(self)

        def __setattr__(self, name, value):
            self._check_monkey_patching_error(name, value)
            with _handle_type_error():
                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                        "Please use list append or extend method."
                                        .format(value))
                if isinstance(value, Enum.YLeaf):
                    value = value.name
                if name in () and name in self.__dict__:
                    if isinstance(value, YLeaf):
                        self.__dict__[name].set(value.get())
                    elif isinstance(value, YLeafList):
                        super(LacpBundleMembers.Members, self).__setattr__(name, value)
                    else:
                        self.__dict__[name].set(value)
                else:
                    if hasattr(value, "parent") and name != "parent":
                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                            value.parent = self
                        elif value.parent is None and value.yang_name in self._children_yang_names:
                            value.parent = self
                    super(LacpBundleMembers.Members, self).__setattr__(name, value)


        class Member(Entity):
            """
            LACP bundle member interface data
            
            .. attribute:: member_interface  <key>
            
            	Member interface
            	**type**\:  str
            
            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
            
            .. attribute:: counters
            
            	Link counters for LACP bundle members
            	**type**\:   :py:class:`Counters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.LacpBundleMembers.Members.Member.Counters>`
            
            .. attribute:: data
            
            	Link data for LACP bundle members
            	**type**\:   :py:class:`Data <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.LacpBundleMembers.Members.Member.Data>`
            
            

            """

            _prefix = 'bundlemgr-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(LacpBundleMembers.Members.Member, self).__init__()

                self.yang_name = "member"
                self.yang_parent_name = "members"

                self.member_interface = YLeaf(YType.str, "member-interface")

                self.counters = LacpBundleMembers.Members.Member.Counters()
                self.counters.parent = self
                self._children_name_map["counters"] = "counters"
                self._children_yang_names.add("counters")

                self.data = LacpBundleMembers.Members.Member.Data()
                self.data.parent = self
                self._children_name_map["data"] = "data"
                self._children_yang_names.add("data")

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in ("member_interface") and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(LacpBundleMembers.Members.Member, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(LacpBundleMembers.Members.Member, self).__setattr__(name, value)


            class Data(Entity):
                """
                Link data for LACP bundle members
                
                .. attribute:: actor_operational_key
                
                	Operational key for this port
                	**type**\:  int
                
                	**range:** 0..65535
                
                .. attribute:: actor_port_id
                
                	Port number of this port
                	**type**\:  int
                
                	**range:** 0..65535
                
                .. attribute:: actor_port_priority
                
                	Priority of this port
                	**type**\:  int
                
                	**range:** 0..65535
                
                .. attribute:: actor_port_state
                
                	LACP state of this port
                	**type**\:  int
                
                	**range:** 0..255
                
                .. attribute:: actor_system_mac_address
                
                	MAC Address of the actor system
                	**type**\:  str
                
                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                
                .. attribute:: actor_system_priority
                
                	System priority of the actor system
                	**type**\:  int
                
                	**range:** 0..65535
                
                .. attribute:: attached_aggregator_id
                
                	MIB ifindex of attached bundle
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: interface_handle
                
                	Member's interface handle
                	**type**\:  str
                
                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                
                .. attribute:: partner_operational_key
                
                	Operational key for partner port
                	**type**\:  int
                
                	**range:** 0..65535
                
                .. attribute:: partner_port_id
                
                	Port number of the partner's port
                	**type**\:  int
                
                	**range:** 0..65535
                
                .. attribute:: partner_port_priority
                
                	Priority of the partner's port
                	**type**\:  int
                
                	**range:** 0..65535
                
                .. attribute:: partner_port_state
                
                	LACP state of the partner's port
                	**type**\:  int
                
                	**range:** 0..255
                
                .. attribute:: partner_system_mac_address
                
                	MAC Address used to identify the partner system
                	**type**\:  str
                
                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                
                .. attribute:: partner_system_priority
                
                	System priority of partner system
                	**type**\:  int
                
                	**range:** 0..65535
                
                .. attribute:: selected_aggregator_id
                
                	MIB ifindex of selected bundle
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'bundlemgr-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(LacpBundleMembers.Members.Member.Data, self).__init__()

                    self.yang_name = "data"
                    self.yang_parent_name = "member"

                    self.actor_operational_key = YLeaf(YType.uint16, "actor-operational-key")

                    self.actor_port_id = YLeaf(YType.uint16, "actor-port-id")

                    self.actor_port_priority = YLeaf(YType.uint16, "actor-port-priority")

                    self.actor_port_state = YLeaf(YType.uint8, "actor-port-state")

                    self.actor_system_mac_address = YLeaf(YType.str, "actor-system-mac-address")

                    self.actor_system_priority = YLeaf(YType.uint16, "actor-system-priority")

                    self.attached_aggregator_id = YLeaf(YType.uint32, "attached-aggregator-id")

                    self.interface_handle = YLeaf(YType.str, "interface-handle")

                    self.partner_operational_key = YLeaf(YType.uint16, "partner-operational-key")

                    self.partner_port_id = YLeaf(YType.uint16, "partner-port-id")

                    self.partner_port_priority = YLeaf(YType.uint16, "partner-port-priority")

                    self.partner_port_state = YLeaf(YType.uint8, "partner-port-state")

                    self.partner_system_mac_address = YLeaf(YType.str, "partner-system-mac-address")

                    self.partner_system_priority = YLeaf(YType.uint16, "partner-system-priority")

                    self.selected_aggregator_id = YLeaf(YType.uint32, "selected-aggregator-id")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("actor_operational_key",
                                    "actor_port_id",
                                    "actor_port_priority",
                                    "actor_port_state",
                                    "actor_system_mac_address",
                                    "actor_system_priority",
                                    "attached_aggregator_id",
                                    "interface_handle",
                                    "partner_operational_key",
                                    "partner_port_id",
                                    "partner_port_priority",
                                    "partner_port_state",
                                    "partner_system_mac_address",
                                    "partner_system_priority",
                                    "selected_aggregator_id") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(LacpBundleMembers.Members.Member.Data, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(LacpBundleMembers.Members.Member.Data, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.actor_operational_key.is_set or
                        self.actor_port_id.is_set or
                        self.actor_port_priority.is_set or
                        self.actor_port_state.is_set or
                        self.actor_system_mac_address.is_set or
                        self.actor_system_priority.is_set or
                        self.attached_aggregator_id.is_set or
                        self.interface_handle.is_set or
                        self.partner_operational_key.is_set or
                        self.partner_port_id.is_set or
                        self.partner_port_priority.is_set or
                        self.partner_port_state.is_set or
                        self.partner_system_mac_address.is_set or
                        self.partner_system_priority.is_set or
                        self.selected_aggregator_id.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.actor_operational_key.yfilter != YFilter.not_set or
                        self.actor_port_id.yfilter != YFilter.not_set or
                        self.actor_port_priority.yfilter != YFilter.not_set or
                        self.actor_port_state.yfilter != YFilter.not_set or
                        self.actor_system_mac_address.yfilter != YFilter.not_set or
                        self.actor_system_priority.yfilter != YFilter.not_set or
                        self.attached_aggregator_id.yfilter != YFilter.not_set or
                        self.interface_handle.yfilter != YFilter.not_set or
                        self.partner_operational_key.yfilter != YFilter.not_set or
                        self.partner_port_id.yfilter != YFilter.not_set or
                        self.partner_port_priority.yfilter != YFilter.not_set or
                        self.partner_port_state.yfilter != YFilter.not_set or
                        self.partner_system_mac_address.yfilter != YFilter.not_set or
                        self.partner_system_priority.yfilter != YFilter.not_set or
                        self.selected_aggregator_id.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "data" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.actor_operational_key.is_set or self.actor_operational_key.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.actor_operational_key.get_name_leafdata())
                    if (self.actor_port_id.is_set or self.actor_port_id.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.actor_port_id.get_name_leafdata())
                    if (self.actor_port_priority.is_set or self.actor_port_priority.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.actor_port_priority.get_name_leafdata())
                    if (self.actor_port_state.is_set or self.actor_port_state.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.actor_port_state.get_name_leafdata())
                    if (self.actor_system_mac_address.is_set or self.actor_system_mac_address.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.actor_system_mac_address.get_name_leafdata())
                    if (self.actor_system_priority.is_set or self.actor_system_priority.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.actor_system_priority.get_name_leafdata())
                    if (self.attached_aggregator_id.is_set or self.attached_aggregator_id.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.attached_aggregator_id.get_name_leafdata())
                    if (self.interface_handle.is_set or self.interface_handle.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.interface_handle.get_name_leafdata())
                    if (self.partner_operational_key.is_set or self.partner_operational_key.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.partner_operational_key.get_name_leafdata())
                    if (self.partner_port_id.is_set or self.partner_port_id.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.partner_port_id.get_name_leafdata())
                    if (self.partner_port_priority.is_set or self.partner_port_priority.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.partner_port_priority.get_name_leafdata())
                    if (self.partner_port_state.is_set or self.partner_port_state.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.partner_port_state.get_name_leafdata())
                    if (self.partner_system_mac_address.is_set or self.partner_system_mac_address.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.partner_system_mac_address.get_name_leafdata())
                    if (self.partner_system_priority.is_set or self.partner_system_priority.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.partner_system_priority.get_name_leafdata())
                    if (self.selected_aggregator_id.is_set or self.selected_aggregator_id.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.selected_aggregator_id.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "actor-operational-key" or name == "actor-port-id" or name == "actor-port-priority" or name == "actor-port-state" or name == "actor-system-mac-address" or name == "actor-system-priority" or name == "attached-aggregator-id" or name == "interface-handle" or name == "partner-operational-key" or name == "partner-port-id" or name == "partner-port-priority" or name == "partner-port-state" or name == "partner-system-mac-address" or name == "partner-system-priority" or name == "selected-aggregator-id"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "actor-operational-key"):
                        self.actor_operational_key = value
                        self.actor_operational_key.value_namespace = name_space
                        self.actor_operational_key.value_namespace_prefix = name_space_prefix
                    if(value_path == "actor-port-id"):
                        self.actor_port_id = value
                        self.actor_port_id.value_namespace = name_space
                        self.actor_port_id.value_namespace_prefix = name_space_prefix
                    if(value_path == "actor-port-priority"):
                        self.actor_port_priority = value
                        self.actor_port_priority.value_namespace = name_space
                        self.actor_port_priority.value_namespace_prefix = name_space_prefix
                    if(value_path == "actor-port-state"):
                        self.actor_port_state = value
                        self.actor_port_state.value_namespace = name_space
                        self.actor_port_state.value_namespace_prefix = name_space_prefix
                    if(value_path == "actor-system-mac-address"):
                        self.actor_system_mac_address = value
                        self.actor_system_mac_address.value_namespace = name_space
                        self.actor_system_mac_address.value_namespace_prefix = name_space_prefix
                    if(value_path == "actor-system-priority"):
                        self.actor_system_priority = value
                        self.actor_system_priority.value_namespace = name_space
                        self.actor_system_priority.value_namespace_prefix = name_space_prefix
                    if(value_path == "attached-aggregator-id"):
                        self.attached_aggregator_id = value
                        self.attached_aggregator_id.value_namespace = name_space
                        self.attached_aggregator_id.value_namespace_prefix = name_space_prefix
                    if(value_path == "interface-handle"):
                        self.interface_handle = value
                        self.interface_handle.value_namespace = name_space
                        self.interface_handle.value_namespace_prefix = name_space_prefix
                    if(value_path == "partner-operational-key"):
                        self.partner_operational_key = value
                        self.partner_operational_key.value_namespace = name_space
                        self.partner_operational_key.value_namespace_prefix = name_space_prefix
                    if(value_path == "partner-port-id"):
                        self.partner_port_id = value
                        self.partner_port_id.value_namespace = name_space
                        self.partner_port_id.value_namespace_prefix = name_space_prefix
                    if(value_path == "partner-port-priority"):
                        self.partner_port_priority = value
                        self.partner_port_priority.value_namespace = name_space
                        self.partner_port_priority.value_namespace_prefix = name_space_prefix
                    if(value_path == "partner-port-state"):
                        self.partner_port_state = value
                        self.partner_port_state.value_namespace = name_space
                        self.partner_port_state.value_namespace_prefix = name_space_prefix
                    if(value_path == "partner-system-mac-address"):
                        self.partner_system_mac_address = value
                        self.partner_system_mac_address.value_namespace = name_space
                        self.partner_system_mac_address.value_namespace_prefix = name_space_prefix
                    if(value_path == "partner-system-priority"):
                        self.partner_system_priority = value
                        self.partner_system_priority.value_namespace = name_space
                        self.partner_system_priority.value_namespace_prefix = name_space_prefix
                    if(value_path == "selected-aggregator-id"):
                        self.selected_aggregator_id = value
                        self.selected_aggregator_id.value_namespace = name_space
                        self.selected_aggregator_id.value_namespace_prefix = name_space_prefix


            class Counters(Entity):
                """
                Link counters for LACP bundle members
                
                .. attribute:: defaulted
                
                	State flag set to Defaulted
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: excess_lacpd_us_received
                
                	LACPDUs received that exceed the rate limit
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: excess_marker_packets_received
                
                	Marker packets received that exceed the rate limit
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: expired
                
                	State flag set to Expired
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: illegal_packets_received
                
                	Illegal and unknown packets received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: lacpd_us_received
                
                	LACPDUs received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: lacpd_us_transmitted
                
                	LACPDUs transmitted
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: last_cleared_nsec
                
                	Last time counters cleared (nsec) (deprecated)
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: last_cleared_sec
                
                	Last time counters cleared (s) (deprecated)
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: marker_packets_received
                
                	Marker packets received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: marker_responses_transmitted
                
                	Marker response packets transmitted
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: time_since_cleared
                
                	Time elapsed since counters last cleared (nsec)
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: time_since_last_lacpdu_received
                
                	Time elapsed since last LACPDU received (nsec)
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: time_since_unexpected_event
                
                	Time elapsed since last unexpected event (nsec)
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                

                """

                _prefix = 'bundlemgr-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(LacpBundleMembers.Members.Member.Counters, self).__init__()

                    self.yang_name = "counters"
                    self.yang_parent_name = "member"

                    self.defaulted = YLeaf(YType.uint32, "defaulted")

                    self.excess_lacpd_us_received = YLeaf(YType.uint32, "excess-lacpd-us-received")

                    self.excess_marker_packets_received = YLeaf(YType.uint32, "excess-marker-packets-received")

                    self.expired = YLeaf(YType.uint32, "expired")

                    self.illegal_packets_received = YLeaf(YType.uint32, "illegal-packets-received")

                    self.lacpd_us_received = YLeaf(YType.uint32, "lacpd-us-received")

                    self.lacpd_us_transmitted = YLeaf(YType.uint32, "lacpd-us-transmitted")

                    self.last_cleared_nsec = YLeaf(YType.uint32, "last-cleared-nsec")

                    self.last_cleared_sec = YLeaf(YType.uint32, "last-cleared-sec")

                    self.marker_packets_received = YLeaf(YType.uint32, "marker-packets-received")

                    self.marker_responses_transmitted = YLeaf(YType.uint32, "marker-responses-transmitted")

                    self.time_since_cleared = YLeaf(YType.uint64, "time-since-cleared")

                    self.time_since_last_lacpdu_received = YLeaf(YType.uint64, "time-since-last-lacpdu-received")

                    self.time_since_unexpected_event = YLeaf(YType.uint64, "time-since-unexpected-event")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("defaulted",
                                    "excess_lacpd_us_received",
                                    "excess_marker_packets_received",
                                    "expired",
                                    "illegal_packets_received",
                                    "lacpd_us_received",
                                    "lacpd_us_transmitted",
                                    "last_cleared_nsec",
                                    "last_cleared_sec",
                                    "marker_packets_received",
                                    "marker_responses_transmitted",
                                    "time_since_cleared",
                                    "time_since_last_lacpdu_received",
                                    "time_since_unexpected_event") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(LacpBundleMembers.Members.Member.Counters, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(LacpBundleMembers.Members.Member.Counters, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.defaulted.is_set or
                        self.excess_lacpd_us_received.is_set or
                        self.excess_marker_packets_received.is_set or
                        self.expired.is_set or
                        self.illegal_packets_received.is_set or
                        self.lacpd_us_received.is_set or
                        self.lacpd_us_transmitted.is_set or
                        self.last_cleared_nsec.is_set or
                        self.last_cleared_sec.is_set or
                        self.marker_packets_received.is_set or
                        self.marker_responses_transmitted.is_set or
                        self.time_since_cleared.is_set or
                        self.time_since_last_lacpdu_received.is_set or
                        self.time_since_unexpected_event.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.defaulted.yfilter != YFilter.not_set or
                        self.excess_lacpd_us_received.yfilter != YFilter.not_set or
                        self.excess_marker_packets_received.yfilter != YFilter.not_set or
                        self.expired.yfilter != YFilter.not_set or
                        self.illegal_packets_received.yfilter != YFilter.not_set or
                        self.lacpd_us_received.yfilter != YFilter.not_set or
                        self.lacpd_us_transmitted.yfilter != YFilter.not_set or
                        self.last_cleared_nsec.yfilter != YFilter.not_set or
                        self.last_cleared_sec.yfilter != YFilter.not_set or
                        self.marker_packets_received.yfilter != YFilter.not_set or
                        self.marker_responses_transmitted.yfilter != YFilter.not_set or
                        self.time_since_cleared.yfilter != YFilter.not_set or
                        self.time_since_last_lacpdu_received.yfilter != YFilter.not_set or
                        self.time_since_unexpected_event.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "counters" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.defaulted.is_set or self.defaulted.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.defaulted.get_name_leafdata())
                    if (self.excess_lacpd_us_received.is_set or self.excess_lacpd_us_received.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.excess_lacpd_us_received.get_name_leafdata())
                    if (self.excess_marker_packets_received.is_set or self.excess_marker_packets_received.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.excess_marker_packets_received.get_name_leafdata())
                    if (self.expired.is_set or self.expired.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.expired.get_name_leafdata())
                    if (self.illegal_packets_received.is_set or self.illegal_packets_received.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.illegal_packets_received.get_name_leafdata())
                    if (self.lacpd_us_received.is_set or self.lacpd_us_received.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.lacpd_us_received.get_name_leafdata())
                    if (self.lacpd_us_transmitted.is_set or self.lacpd_us_transmitted.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.lacpd_us_transmitted.get_name_leafdata())
                    if (self.last_cleared_nsec.is_set or self.last_cleared_nsec.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.last_cleared_nsec.get_name_leafdata())
                    if (self.last_cleared_sec.is_set or self.last_cleared_sec.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.last_cleared_sec.get_name_leafdata())
                    if (self.marker_packets_received.is_set or self.marker_packets_received.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.marker_packets_received.get_name_leafdata())
                    if (self.marker_responses_transmitted.is_set or self.marker_responses_transmitted.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.marker_responses_transmitted.get_name_leafdata())
                    if (self.time_since_cleared.is_set or self.time_since_cleared.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.time_since_cleared.get_name_leafdata())
                    if (self.time_since_last_lacpdu_received.is_set or self.time_since_last_lacpdu_received.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.time_since_last_lacpdu_received.get_name_leafdata())
                    if (self.time_since_unexpected_event.is_set or self.time_since_unexpected_event.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.time_since_unexpected_event.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "defaulted" or name == "excess-lacpd-us-received" or name == "excess-marker-packets-received" or name == "expired" or name == "illegal-packets-received" or name == "lacpd-us-received" or name == "lacpd-us-transmitted" or name == "last-cleared-nsec" or name == "last-cleared-sec" or name == "marker-packets-received" or name == "marker-responses-transmitted" or name == "time-since-cleared" or name == "time-since-last-lacpdu-received" or name == "time-since-unexpected-event"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "defaulted"):
                        self.defaulted = value
                        self.defaulted.value_namespace = name_space
                        self.defaulted.value_namespace_prefix = name_space_prefix
                    if(value_path == "excess-lacpd-us-received"):
                        self.excess_lacpd_us_received = value
                        self.excess_lacpd_us_received.value_namespace = name_space
                        self.excess_lacpd_us_received.value_namespace_prefix = name_space_prefix
                    if(value_path == "excess-marker-packets-received"):
                        self.excess_marker_packets_received = value
                        self.excess_marker_packets_received.value_namespace = name_space
                        self.excess_marker_packets_received.value_namespace_prefix = name_space_prefix
                    if(value_path == "expired"):
                        self.expired = value
                        self.expired.value_namespace = name_space
                        self.expired.value_namespace_prefix = name_space_prefix
                    if(value_path == "illegal-packets-received"):
                        self.illegal_packets_received = value
                        self.illegal_packets_received.value_namespace = name_space
                        self.illegal_packets_received.value_namespace_prefix = name_space_prefix
                    if(value_path == "lacpd-us-received"):
                        self.lacpd_us_received = value
                        self.lacpd_us_received.value_namespace = name_space
                        self.lacpd_us_received.value_namespace_prefix = name_space_prefix
                    if(value_path == "lacpd-us-transmitted"):
                        self.lacpd_us_transmitted = value
                        self.lacpd_us_transmitted.value_namespace = name_space
                        self.lacpd_us_transmitted.value_namespace_prefix = name_space_prefix
                    if(value_path == "last-cleared-nsec"):
                        self.last_cleared_nsec = value
                        self.last_cleared_nsec.value_namespace = name_space
                        self.last_cleared_nsec.value_namespace_prefix = name_space_prefix
                    if(value_path == "last-cleared-sec"):
                        self.last_cleared_sec = value
                        self.last_cleared_sec.value_namespace = name_space
                        self.last_cleared_sec.value_namespace_prefix = name_space_prefix
                    if(value_path == "marker-packets-received"):
                        self.marker_packets_received = value
                        self.marker_packets_received.value_namespace = name_space
                        self.marker_packets_received.value_namespace_prefix = name_space_prefix
                    if(value_path == "marker-responses-transmitted"):
                        self.marker_responses_transmitted = value
                        self.marker_responses_transmitted.value_namespace = name_space
                        self.marker_responses_transmitted.value_namespace_prefix = name_space_prefix
                    if(value_path == "time-since-cleared"):
                        self.time_since_cleared = value
                        self.time_since_cleared.value_namespace = name_space
                        self.time_since_cleared.value_namespace_prefix = name_space_prefix
                    if(value_path == "time-since-last-lacpdu-received"):
                        self.time_since_last_lacpdu_received = value
                        self.time_since_last_lacpdu_received.value_namespace = name_space
                        self.time_since_last_lacpdu_received.value_namespace_prefix = name_space_prefix
                    if(value_path == "time-since-unexpected-event"):
                        self.time_since_unexpected_event = value
                        self.time_since_unexpected_event.value_namespace = name_space
                        self.time_since_unexpected_event.value_namespace_prefix = name_space_prefix

            def has_data(self):
                return (
                    self.member_interface.is_set or
                    (self.counters is not None and self.counters.has_data()) or
                    (self.data is not None and self.data.has_data()))

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    self.member_interface.yfilter != YFilter.not_set or
                    (self.counters is not None and self.counters.has_operation()) or
                    (self.data is not None and self.data.has_operation()))

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "member" + "[member-interface='" + self.member_interface.get() + "']" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-bundlemgr-oper:lacp-bundle-members/members/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()
                if (self.member_interface.is_set or self.member_interface.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.member_interface.get_name_leafdata())

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "counters"):
                    if (self.counters is None):
                        self.counters = LacpBundleMembers.Members.Member.Counters()
                        self.counters.parent = self
                        self._children_name_map["counters"] = "counters"
                    return self.counters

                if (child_yang_name == "data"):
                    if (self.data is None):
                        self.data = LacpBundleMembers.Members.Member.Data()
                        self.data.parent = self
                        self._children_name_map["data"] = "data"
                    return self.data

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "counters" or name == "data" or name == "member-interface"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                if(value_path == "member-interface"):
                    self.member_interface = value
                    self.member_interface.value_namespace = name_space
                    self.member_interface.value_namespace_prefix = name_space_prefix

        def has_data(self):
            for c in self.member:
                if (c.has_data()):
                    return True
            return False

        def has_operation(self):
            for c in self.member:
                if (c.has_operation()):
                    return True
            return self.yfilter != YFilter.not_set

        def get_segment_path(self):
            path_buffer = ""
            path_buffer = "members" + path_buffer

            return path_buffer

        def get_entity_path(self, ancestor):
            path_buffer = ""
            if (ancestor is None):
                path_buffer = "Cisco-IOS-XR-bundlemgr-oper:lacp-bundle-members/%s" % self.get_segment_path()
            else:
                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

            leaf_name_data = LeafDataList()

            entity_path = EntityPath(path_buffer, leaf_name_data)
            return entity_path

        def get_child_by_name(self, child_yang_name, segment_path):
            child = self._get_child_by_seg_name([child_yang_name, segment_path])
            if child is not None:
                return child

            if (child_yang_name == "member"):
                for c in self.member:
                    segment = c.get_segment_path()
                    if (segment_path == segment):
                        return c
                c = LacpBundleMembers.Members.Member()
                c.parent = self
                local_reference_key = "ydk::seg::%s" % segment_path
                self._local_refs[local_reference_key] = c
                self.member.append(c)
                return c

            return None

        def has_leaf_or_child_of_name(self, name):
            if(name == "member"):
                return True
            return False

        def set_value(self, value_path, value, name_space, name_space_prefix):
            pass

    def has_data(self):
        return (
            (self.members is not None and self.members.has_data()) or
            (self.nodes is not None and self.nodes.has_data()))

    def has_operation(self):
        return (
            self.yfilter != YFilter.not_set or
            (self.members is not None and self.members.has_operation()) or
            (self.nodes is not None and self.nodes.has_operation()))

    def get_segment_path(self):
        path_buffer = ""
        path_buffer = "Cisco-IOS-XR-bundlemgr-oper:lacp-bundle-members" + path_buffer

        return path_buffer

    def get_entity_path(self, ancestor):
        path_buffer = ""
        if (not ancestor is None):
            raise YPYModelError("ancestor has to be None for top-level node")

        path_buffer = self.get_segment_path()
        leaf_name_data = LeafDataList()

        entity_path = EntityPath(path_buffer, leaf_name_data)
        return entity_path

    def get_child_by_name(self, child_yang_name, segment_path):
        child = self._get_child_by_seg_name([child_yang_name, segment_path])
        if child is not None:
            return child

        if (child_yang_name == "members"):
            if (self.members is None):
                self.members = LacpBundleMembers.Members()
                self.members.parent = self
                self._children_name_map["members"] = "members"
            return self.members

        if (child_yang_name == "nodes"):
            if (self.nodes is None):
                self.nodes = LacpBundleMembers.Nodes()
                self.nodes.parent = self
                self._children_name_map["nodes"] = "nodes"
            return self.nodes

        return None

    def has_leaf_or_child_of_name(self, name):
        if(name == "members" or name == "nodes"):
            return True
        return False

    def set_value(self, value_path, value, name_space, name_space_prefix):
        pass

    def clone_ptr(self):
        self._top_entity = LacpBundleMembers()
        return self._top_entity

class BundlesAdjacency(Entity):
    """
    bundles adjacency
    
    .. attribute:: nodes
    
    	Per bundle operational data
    	**type**\:   :py:class:`Nodes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundlesAdjacency.Nodes>`
    
    

    """

    _prefix = 'bundlemgr-oper'
    _revision = '2015-11-09'

    def __init__(self):
        super(BundlesAdjacency, self).__init__()
        self._top_entity = None

        self.yang_name = "bundles-adjacency"
        self.yang_parent_name = "Cisco-IOS-XR-bundlemgr-oper"

        self.nodes = BundlesAdjacency.Nodes()
        self.nodes.parent = self
        self._children_name_map["nodes"] = "nodes"
        self._children_yang_names.add("nodes")


    class Nodes(Entity):
        """
        Per bundle operational data
        
        .. attribute:: node
        
        	Location
        	**type**\: list of    :py:class:`Node <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundlesAdjacency.Nodes.Node>`
        
        

        """

        _prefix = 'bundlemgr-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(BundlesAdjacency.Nodes, self).__init__()

            self.yang_name = "nodes"
            self.yang_parent_name = "bundles-adjacency"

            self.node = YList(self)

        def __setattr__(self, name, value):
            self._check_monkey_patching_error(name, value)
            with _handle_type_error():
                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                        "Please use list append or extend method."
                                        .format(value))
                if isinstance(value, Enum.YLeaf):
                    value = value.name
                if name in () and name in self.__dict__:
                    if isinstance(value, YLeaf):
                        self.__dict__[name].set(value.get())
                    elif isinstance(value, YLeafList):
                        super(BundlesAdjacency.Nodes, self).__setattr__(name, value)
                    else:
                        self.__dict__[name].set(value)
                else:
                    if hasattr(value, "parent") and name != "parent":
                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                            value.parent = self
                        elif value.parent is None and value.yang_name in self._children_yang_names:
                            value.parent = self
                    super(BundlesAdjacency.Nodes, self).__setattr__(name, value)


        class Node(Entity):
            """
            Location
            
            .. attribute:: node_name  <key>
            
            	Node ID
            	**type**\:  str
            
            	**pattern:** ([a\-zA\-Z0\-9\_]\*\\d+/){1,2}([a\-zA\-Z0\-9\_]\*\\d+)
            
            .. attribute:: brief
            
            	Brief load\-balance information for the node
            	**type**\:   :py:class:`Brief <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundlesAdjacency.Nodes.Node.Brief>`
            
            .. attribute:: bundles
            
            	Per bundle operational data
            	**type**\:   :py:class:`Bundles <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundlesAdjacency.Nodes.Node.Bundles>`
            
            

            """

            _prefix = 'bundlemgr-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(BundlesAdjacency.Nodes.Node, self).__init__()

                self.yang_name = "node"
                self.yang_parent_name = "nodes"

                self.node_name = YLeaf(YType.str, "node-name")

                self.brief = BundlesAdjacency.Nodes.Node.Brief()
                self.brief.parent = self
                self._children_name_map["brief"] = "brief"
                self._children_yang_names.add("brief")

                self.bundles = BundlesAdjacency.Nodes.Node.Bundles()
                self.bundles.parent = self
                self._children_name_map["bundles"] = "bundles"
                self._children_yang_names.add("bundles")

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in ("node_name") and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(BundlesAdjacency.Nodes.Node, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(BundlesAdjacency.Nodes.Node, self).__setattr__(name, value)


            class Brief(Entity):
                """
                Brief load\-balance information for the node
                
                .. attribute:: bundle_data
                
                	Data for all bundles on node
                	**type**\: list of    :py:class:`BundleData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundlesAdjacency.Nodes.Node.Brief.BundleData>`
                
                

                """

                _prefix = 'bundlemgr-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(BundlesAdjacency.Nodes.Node.Brief, self).__init__()

                    self.yang_name = "brief"
                    self.yang_parent_name = "node"

                    self.bundle_data = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(BundlesAdjacency.Nodes.Node.Brief, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(BundlesAdjacency.Nodes.Node.Brief, self).__setattr__(name, value)


                class BundleData(Entity):
                    """
                    Data for all bundles on node
                    
                    .. attribute:: interface_name
                    
                    	Bundle interface
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: member_count
                    
                    	Number of members configured to the bundle
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: sub_interface
                    
                    	Sub\-interfaces of the bundle
                    	**type**\: list of    :py:class:`SubInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundlesAdjacency.Nodes.Node.Brief.BundleData.SubInterface>`
                    
                    .. attribute:: sub_interface_count
                    
                    	Number of sub\-interfaces on the bundle
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: total_weight
                    
                    	Total weighting (relative bandwidth) of bundle
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'bundlemgr-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(BundlesAdjacency.Nodes.Node.Brief.BundleData, self).__init__()

                        self.yang_name = "bundle-data"
                        self.yang_parent_name = "brief"

                        self.interface_name = YLeaf(YType.str, "interface-name")

                        self.member_count = YLeaf(YType.uint32, "member-count")

                        self.sub_interface_count = YLeaf(YType.uint32, "sub-interface-count")

                        self.total_weight = YLeaf(YType.uint32, "total-weight")

                        self.sub_interface = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("interface_name",
                                        "member_count",
                                        "sub_interface_count",
                                        "total_weight") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(BundlesAdjacency.Nodes.Node.Brief.BundleData, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(BundlesAdjacency.Nodes.Node.Brief.BundleData, self).__setattr__(name, value)


                    class SubInterface(Entity):
                        """
                        Sub\-interfaces of the bundle
                        
                        .. attribute:: interface_name
                        
                        	Sub interface
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: load_balance_data
                        
                        	Load balance data
                        	**type**\:   :py:class:`LoadBalanceData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundlesAdjacency.Nodes.Node.Brief.BundleData.SubInterface.LoadBalanceData>`
                        
                        

                        """

                        _prefix = 'bundlemgr-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(BundlesAdjacency.Nodes.Node.Brief.BundleData.SubInterface, self).__init__()

                            self.yang_name = "sub-interface"
                            self.yang_parent_name = "bundle-data"

                            self.interface_name = YLeaf(YType.str, "interface-name")

                            self.load_balance_data = BundlesAdjacency.Nodes.Node.Brief.BundleData.SubInterface.LoadBalanceData()
                            self.load_balance_data.parent = self
                            self._children_name_map["load_balance_data"] = "load-balance-data"
                            self._children_yang_names.add("load-balance-data")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("interface_name") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(BundlesAdjacency.Nodes.Node.Brief.BundleData.SubInterface, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(BundlesAdjacency.Nodes.Node.Brief.BundleData.SubInterface, self).__setattr__(name, value)


                        class LoadBalanceData(Entity):
                            """
                            Load balance data
                            
                            .. attribute:: local_link_threshold
                            
                            	Threshold below which rack\-local balancing is disabled
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: type
                            
                            	Type of load balancing to use
                            	**type**\:   :py:class:`LoadBalance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.LoadBalance>`
                            
                            .. attribute:: value
                            
                            	Load balance hash value
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'bundlemgr-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(BundlesAdjacency.Nodes.Node.Brief.BundleData.SubInterface.LoadBalanceData, self).__init__()

                                self.yang_name = "load-balance-data"
                                self.yang_parent_name = "sub-interface"

                                self.local_link_threshold = YLeaf(YType.uint32, "local-link-threshold")

                                self.type = YLeaf(YType.enumeration, "type")

                                self.value = YLeaf(YType.uint32, "value")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("local_link_threshold",
                                                "type",
                                                "value") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(BundlesAdjacency.Nodes.Node.Brief.BundleData.SubInterface.LoadBalanceData, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(BundlesAdjacency.Nodes.Node.Brief.BundleData.SubInterface.LoadBalanceData, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.local_link_threshold.is_set or
                                    self.type.is_set or
                                    self.value.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.local_link_threshold.yfilter != YFilter.not_set or
                                    self.type.yfilter != YFilter.not_set or
                                    self.value.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "load-balance-data" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.local_link_threshold.is_set or self.local_link_threshold.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_link_threshold.get_name_leafdata())
                                if (self.type.is_set or self.type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.type.get_name_leafdata())
                                if (self.value.is_set or self.value.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.value.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "local-link-threshold" or name == "type" or name == "value"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "local-link-threshold"):
                                    self.local_link_threshold = value
                                    self.local_link_threshold.value_namespace = name_space
                                    self.local_link_threshold.value_namespace_prefix = name_space_prefix
                                if(value_path == "type"):
                                    self.type = value
                                    self.type.value_namespace = name_space
                                    self.type.value_namespace_prefix = name_space_prefix
                                if(value_path == "value"):
                                    self.value = value
                                    self.value.value_namespace = name_space
                                    self.value.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.interface_name.is_set or
                                (self.load_balance_data is not None and self.load_balance_data.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.interface_name.yfilter != YFilter.not_set or
                                (self.load_balance_data is not None and self.load_balance_data.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "sub-interface" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface_name.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "load-balance-data"):
                                if (self.load_balance_data is None):
                                    self.load_balance_data = BundlesAdjacency.Nodes.Node.Brief.BundleData.SubInterface.LoadBalanceData()
                                    self.load_balance_data.parent = self
                                    self._children_name_map["load_balance_data"] = "load-balance-data"
                                return self.load_balance_data

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "load-balance-data" or name == "interface-name"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "interface-name"):
                                self.interface_name = value
                                self.interface_name.value_namespace = name_space
                                self.interface_name.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.sub_interface:
                            if (c.has_data()):
                                return True
                        return (
                            self.interface_name.is_set or
                            self.member_count.is_set or
                            self.sub_interface_count.is_set or
                            self.total_weight.is_set)

                    def has_operation(self):
                        for c in self.sub_interface:
                            if (c.has_operation()):
                                return True
                        return (
                            self.yfilter != YFilter.not_set or
                            self.interface_name.yfilter != YFilter.not_set or
                            self.member_count.yfilter != YFilter.not_set or
                            self.sub_interface_count.yfilter != YFilter.not_set or
                            self.total_weight.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "bundle-data" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_name.get_name_leafdata())
                        if (self.member_count.is_set or self.member_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.member_count.get_name_leafdata())
                        if (self.sub_interface_count.is_set or self.sub_interface_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.sub_interface_count.get_name_leafdata())
                        if (self.total_weight.is_set or self.total_weight.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.total_weight.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "sub-interface"):
                            for c in self.sub_interface:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = BundlesAdjacency.Nodes.Node.Brief.BundleData.SubInterface()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.sub_interface.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "sub-interface" or name == "interface-name" or name == "member-count" or name == "sub-interface-count" or name == "total-weight"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "interface-name"):
                            self.interface_name = value
                            self.interface_name.value_namespace = name_space
                            self.interface_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "member-count"):
                            self.member_count = value
                            self.member_count.value_namespace = name_space
                            self.member_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "sub-interface-count"):
                            self.sub_interface_count = value
                            self.sub_interface_count.value_namespace = name_space
                            self.sub_interface_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "total-weight"):
                            self.total_weight = value
                            self.total_weight.value_namespace = name_space
                            self.total_weight.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.bundle_data:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.bundle_data:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "brief" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "bundle-data"):
                        for c in self.bundle_data:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = BundlesAdjacency.Nodes.Node.Brief.BundleData()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.bundle_data.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "bundle-data"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class Bundles(Entity):
                """
                Per bundle operational data
                
                .. attribute:: bundle
                
                	Bundle information
                	**type**\: list of    :py:class:`Bundle <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundlesAdjacency.Nodes.Node.Bundles.Bundle>`
                
                

                """

                _prefix = 'bundlemgr-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(BundlesAdjacency.Nodes.Node.Bundles, self).__init__()

                    self.yang_name = "bundles"
                    self.yang_parent_name = "node"

                    self.bundle = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(BundlesAdjacency.Nodes.Node.Bundles, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(BundlesAdjacency.Nodes.Node.Bundles, self).__setattr__(name, value)


                class Bundle(Entity):
                    """
                    Bundle information
                    
                    .. attribute:: bundle_name  <key>
                    
                    	Bundle interface
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: bundle_info
                    
                    	Data for each Bundle
                    	**type**\:   :py:class:`BundleInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundlesAdjacency.Nodes.Node.Bundles.Bundle.BundleInfo>`
                    
                    

                    """

                    _prefix = 'bundlemgr-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(BundlesAdjacency.Nodes.Node.Bundles.Bundle, self).__init__()

                        self.yang_name = "bundle"
                        self.yang_parent_name = "bundles"

                        self.bundle_name = YLeaf(YType.str, "bundle-name")

                        self.bundle_info = BundlesAdjacency.Nodes.Node.Bundles.Bundle.BundleInfo()
                        self.bundle_info.parent = self
                        self._children_name_map["bundle_info"] = "bundle-info"
                        self._children_yang_names.add("bundle-info")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("bundle_name") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(BundlesAdjacency.Nodes.Node.Bundles.Bundle, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(BundlesAdjacency.Nodes.Node.Bundles.Bundle, self).__setattr__(name, value)


                    class BundleInfo(Entity):
                        """
                        Data for each Bundle
                        
                        .. attribute:: avoid_rebalance
                        
                        	Avoid rebalancing traffic flows
                        	**type**\:  bool
                        
                        .. attribute:: brief
                        
                        	Brief bundle data
                        	**type**\:   :py:class:`Brief <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundlesAdjacency.Nodes.Node.Bundles.Bundle.BundleInfo.Brief>`
                        
                        .. attribute:: load_balance_data
                        
                        	Load Balance data
                        	**type**\:   :py:class:`LoadBalanceData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundlesAdjacency.Nodes.Node.Bundles.Bundle.BundleInfo.LoadBalanceData>`
                        
                        .. attribute:: max_member_count
                        
                        	Maximum number of members for the bundle
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: media
                        
                        	Media type of bundle
                        	**type**\:   :py:class:`BundleMedia1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundleMedia1>`
                        
                        .. attribute:: member
                        
                        	Members of the bundle
                        	**type**\: list of    :py:class:`Member <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundlesAdjacency.Nodes.Node.Bundles.Bundle.BundleInfo.Member>`
                        
                        .. attribute:: sub_interface
                        
                        	Sub\-interfaces of the bundle
                        	**type**\: list of    :py:class:`SubInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundlesAdjacency.Nodes.Node.Bundles.Bundle.BundleInfo.SubInterface>`
                        
                        

                        """

                        _prefix = 'bundlemgr-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(BundlesAdjacency.Nodes.Node.Bundles.Bundle.BundleInfo, self).__init__()

                            self.yang_name = "bundle-info"
                            self.yang_parent_name = "bundle"

                            self.avoid_rebalance = YLeaf(YType.boolean, "avoid-rebalance")

                            self.max_member_count = YLeaf(YType.uint32, "max-member-count")

                            self.media = YLeaf(YType.enumeration, "media")

                            self.brief = BundlesAdjacency.Nodes.Node.Bundles.Bundle.BundleInfo.Brief()
                            self.brief.parent = self
                            self._children_name_map["brief"] = "brief"
                            self._children_yang_names.add("brief")

                            self.load_balance_data = BundlesAdjacency.Nodes.Node.Bundles.Bundle.BundleInfo.LoadBalanceData()
                            self.load_balance_data.parent = self
                            self._children_name_map["load_balance_data"] = "load-balance-data"
                            self._children_yang_names.add("load-balance-data")

                            self.member = YList(self)
                            self.sub_interface = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("avoid_rebalance",
                                            "max_member_count",
                                            "media") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(BundlesAdjacency.Nodes.Node.Bundles.Bundle.BundleInfo, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(BundlesAdjacency.Nodes.Node.Bundles.Bundle.BundleInfo, self).__setattr__(name, value)


                        class Brief(Entity):
                            """
                            Brief bundle data
                            
                            .. attribute:: interface_name
                            
                            	Bundle interface
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: member_count
                            
                            	Number of members configured to the bundle
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: sub_interface
                            
                            	Sub\-interfaces of the bundle
                            	**type**\: list of    :py:class:`SubInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundlesAdjacency.Nodes.Node.Bundles.Bundle.BundleInfo.Brief.SubInterface>`
                            
                            .. attribute:: sub_interface_count
                            
                            	Number of sub\-interfaces on the bundle
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: total_weight
                            
                            	Total weighting (relative bandwidth) of bundle
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'bundlemgr-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(BundlesAdjacency.Nodes.Node.Bundles.Bundle.BundleInfo.Brief, self).__init__()

                                self.yang_name = "brief"
                                self.yang_parent_name = "bundle-info"

                                self.interface_name = YLeaf(YType.str, "interface-name")

                                self.member_count = YLeaf(YType.uint32, "member-count")

                                self.sub_interface_count = YLeaf(YType.uint32, "sub-interface-count")

                                self.total_weight = YLeaf(YType.uint32, "total-weight")

                                self.sub_interface = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("interface_name",
                                                "member_count",
                                                "sub_interface_count",
                                                "total_weight") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(BundlesAdjacency.Nodes.Node.Bundles.Bundle.BundleInfo.Brief, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(BundlesAdjacency.Nodes.Node.Bundles.Bundle.BundleInfo.Brief, self).__setattr__(name, value)


                            class SubInterface(Entity):
                                """
                                Sub\-interfaces of the bundle
                                
                                .. attribute:: interface_name
                                
                                	Sub interface
                                	**type**\:  str
                                
                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                
                                .. attribute:: load_balance_data
                                
                                	Load balance data
                                	**type**\:   :py:class:`LoadBalanceData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundlesAdjacency.Nodes.Node.Bundles.Bundle.BundleInfo.Brief.SubInterface.LoadBalanceData>`
                                
                                

                                """

                                _prefix = 'bundlemgr-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(BundlesAdjacency.Nodes.Node.Bundles.Bundle.BundleInfo.Brief.SubInterface, self).__init__()

                                    self.yang_name = "sub-interface"
                                    self.yang_parent_name = "brief"

                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                    self.load_balance_data = BundlesAdjacency.Nodes.Node.Bundles.Bundle.BundleInfo.Brief.SubInterface.LoadBalanceData()
                                    self.load_balance_data.parent = self
                                    self._children_name_map["load_balance_data"] = "load-balance-data"
                                    self._children_yang_names.add("load-balance-data")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("interface_name") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(BundlesAdjacency.Nodes.Node.Bundles.Bundle.BundleInfo.Brief.SubInterface, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(BundlesAdjacency.Nodes.Node.Bundles.Bundle.BundleInfo.Brief.SubInterface, self).__setattr__(name, value)


                                class LoadBalanceData(Entity):
                                    """
                                    Load balance data
                                    
                                    .. attribute:: local_link_threshold
                                    
                                    	Threshold below which rack\-local balancing is disabled
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: type
                                    
                                    	Type of load balancing to use
                                    	**type**\:   :py:class:`LoadBalance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.LoadBalance>`
                                    
                                    .. attribute:: value
                                    
                                    	Load balance hash value
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'bundlemgr-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(BundlesAdjacency.Nodes.Node.Bundles.Bundle.BundleInfo.Brief.SubInterface.LoadBalanceData, self).__init__()

                                        self.yang_name = "load-balance-data"
                                        self.yang_parent_name = "sub-interface"

                                        self.local_link_threshold = YLeaf(YType.uint32, "local-link-threshold")

                                        self.type = YLeaf(YType.enumeration, "type")

                                        self.value = YLeaf(YType.uint32, "value")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("local_link_threshold",
                                                        "type",
                                                        "value") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(BundlesAdjacency.Nodes.Node.Bundles.Bundle.BundleInfo.Brief.SubInterface.LoadBalanceData, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(BundlesAdjacency.Nodes.Node.Bundles.Bundle.BundleInfo.Brief.SubInterface.LoadBalanceData, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.local_link_threshold.is_set or
                                            self.type.is_set or
                                            self.value.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.local_link_threshold.yfilter != YFilter.not_set or
                                            self.type.yfilter != YFilter.not_set or
                                            self.value.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "load-balance-data" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.local_link_threshold.is_set or self.local_link_threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_link_threshold.get_name_leafdata())
                                        if (self.type.is_set or self.type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.type.get_name_leafdata())
                                        if (self.value.is_set or self.value.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.value.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "local-link-threshold" or name == "type" or name == "value"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "local-link-threshold"):
                                            self.local_link_threshold = value
                                            self.local_link_threshold.value_namespace = name_space
                                            self.local_link_threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "type"):
                                            self.type = value
                                            self.type.value_namespace = name_space
                                            self.type.value_namespace_prefix = name_space_prefix
                                        if(value_path == "value"):
                                            self.value = value
                                            self.value.value_namespace = name_space
                                            self.value.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.interface_name.is_set or
                                        (self.load_balance_data is not None and self.load_balance_data.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.interface_name.yfilter != YFilter.not_set or
                                        (self.load_balance_data is not None and self.load_balance_data.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "sub-interface" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.interface_name.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "load-balance-data"):
                                        if (self.load_balance_data is None):
                                            self.load_balance_data = BundlesAdjacency.Nodes.Node.Bundles.Bundle.BundleInfo.Brief.SubInterface.LoadBalanceData()
                                            self.load_balance_data.parent = self
                                            self._children_name_map["load_balance_data"] = "load-balance-data"
                                        return self.load_balance_data

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "load-balance-data" or name == "interface-name"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "interface-name"):
                                        self.interface_name = value
                                        self.interface_name.value_namespace = name_space
                                        self.interface_name.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.sub_interface:
                                    if (c.has_data()):
                                        return True
                                return (
                                    self.interface_name.is_set or
                                    self.member_count.is_set or
                                    self.sub_interface_count.is_set or
                                    self.total_weight.is_set)

                            def has_operation(self):
                                for c in self.sub_interface:
                                    if (c.has_operation()):
                                        return True
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.interface_name.yfilter != YFilter.not_set or
                                    self.member_count.yfilter != YFilter.not_set or
                                    self.sub_interface_count.yfilter != YFilter.not_set or
                                    self.total_weight.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "brief" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.interface_name.get_name_leafdata())
                                if (self.member_count.is_set or self.member_count.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.member_count.get_name_leafdata())
                                if (self.sub_interface_count.is_set or self.sub_interface_count.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.sub_interface_count.get_name_leafdata())
                                if (self.total_weight.is_set or self.total_weight.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.total_weight.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "sub-interface"):
                                    for c in self.sub_interface:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = BundlesAdjacency.Nodes.Node.Bundles.Bundle.BundleInfo.Brief.SubInterface()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.sub_interface.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "sub-interface" or name == "interface-name" or name == "member-count" or name == "sub-interface-count" or name == "total-weight"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "interface-name"):
                                    self.interface_name = value
                                    self.interface_name.value_namespace = name_space
                                    self.interface_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "member-count"):
                                    self.member_count = value
                                    self.member_count.value_namespace = name_space
                                    self.member_count.value_namespace_prefix = name_space_prefix
                                if(value_path == "sub-interface-count"):
                                    self.sub_interface_count = value
                                    self.sub_interface_count.value_namespace = name_space
                                    self.sub_interface_count.value_namespace_prefix = name_space_prefix
                                if(value_path == "total-weight"):
                                    self.total_weight = value
                                    self.total_weight.value_namespace = name_space
                                    self.total_weight.value_namespace_prefix = name_space_prefix


                        class LoadBalanceData(Entity):
                            """
                            Load Balance data
                            
                            .. attribute:: local_link_threshold
                            
                            	Threshold below which rack\-local balancing is disabled
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: type
                            
                            	Type of load balancing to use
                            	**type**\:   :py:class:`LoadBalance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.LoadBalance>`
                            
                            .. attribute:: value
                            
                            	Load balance hash value
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'bundlemgr-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(BundlesAdjacency.Nodes.Node.Bundles.Bundle.BundleInfo.LoadBalanceData, self).__init__()

                                self.yang_name = "load-balance-data"
                                self.yang_parent_name = "bundle-info"

                                self.local_link_threshold = YLeaf(YType.uint32, "local-link-threshold")

                                self.type = YLeaf(YType.enumeration, "type")

                                self.value = YLeaf(YType.uint32, "value")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("local_link_threshold",
                                                "type",
                                                "value") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(BundlesAdjacency.Nodes.Node.Bundles.Bundle.BundleInfo.LoadBalanceData, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(BundlesAdjacency.Nodes.Node.Bundles.Bundle.BundleInfo.LoadBalanceData, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.local_link_threshold.is_set or
                                    self.type.is_set or
                                    self.value.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.local_link_threshold.yfilter != YFilter.not_set or
                                    self.type.yfilter != YFilter.not_set or
                                    self.value.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "load-balance-data" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.local_link_threshold.is_set or self.local_link_threshold.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_link_threshold.get_name_leafdata())
                                if (self.type.is_set or self.type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.type.get_name_leafdata())
                                if (self.value.is_set or self.value.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.value.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "local-link-threshold" or name == "type" or name == "value"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "local-link-threshold"):
                                    self.local_link_threshold = value
                                    self.local_link_threshold.value_namespace = name_space
                                    self.local_link_threshold.value_namespace_prefix = name_space_prefix
                                if(value_path == "type"):
                                    self.type = value
                                    self.type.value_namespace = name_space
                                    self.type.value_namespace_prefix = name_space_prefix
                                if(value_path == "value"):
                                    self.value = value
                                    self.value.value_namespace = name_space
                                    self.value.value_namespace_prefix = name_space_prefix


                        class Member(Entity):
                            """
                            Members of the bundle
                            
                            .. attribute:: bandwidth
                            
                            	Member's relative bandwidth
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: interface_name
                            
                            	Member interface
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: link_id
                            
                            	Member's link ID in database
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: link_order_number
                            
                            	Member's link order number in database
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            

                            """

                            _prefix = 'bundlemgr-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(BundlesAdjacency.Nodes.Node.Bundles.Bundle.BundleInfo.Member, self).__init__()

                                self.yang_name = "member"
                                self.yang_parent_name = "bundle-info"

                                self.bandwidth = YLeaf(YType.uint8, "bandwidth")

                                self.interface_name = YLeaf(YType.str, "interface-name")

                                self.link_id = YLeaf(YType.uint8, "link-id")

                                self.link_order_number = YLeaf(YType.uint8, "link-order-number")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("bandwidth",
                                                "interface_name",
                                                "link_id",
                                                "link_order_number") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(BundlesAdjacency.Nodes.Node.Bundles.Bundle.BundleInfo.Member, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(BundlesAdjacency.Nodes.Node.Bundles.Bundle.BundleInfo.Member, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.bandwidth.is_set or
                                    self.interface_name.is_set or
                                    self.link_id.is_set or
                                    self.link_order_number.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.bandwidth.yfilter != YFilter.not_set or
                                    self.interface_name.yfilter != YFilter.not_set or
                                    self.link_id.yfilter != YFilter.not_set or
                                    self.link_order_number.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "member" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.bandwidth.is_set or self.bandwidth.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.bandwidth.get_name_leafdata())
                                if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.interface_name.get_name_leafdata())
                                if (self.link_id.is_set or self.link_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.link_id.get_name_leafdata())
                                if (self.link_order_number.is_set or self.link_order_number.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.link_order_number.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "bandwidth" or name == "interface-name" or name == "link-id" or name == "link-order-number"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "bandwidth"):
                                    self.bandwidth = value
                                    self.bandwidth.value_namespace = name_space
                                    self.bandwidth.value_namespace_prefix = name_space_prefix
                                if(value_path == "interface-name"):
                                    self.interface_name = value
                                    self.interface_name.value_namespace = name_space
                                    self.interface_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "link-id"):
                                    self.link_id = value
                                    self.link_id.value_namespace = name_space
                                    self.link_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "link-order-number"):
                                    self.link_order_number = value
                                    self.link_order_number.value_namespace = name_space
                                    self.link_order_number.value_namespace_prefix = name_space_prefix


                        class SubInterface(Entity):
                            """
                            Sub\-interfaces of the bundle
                            
                            .. attribute:: interface_name
                            
                            	Sub interface
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: load_balance_data
                            
                            	Load balance data
                            	**type**\:   :py:class:`LoadBalanceData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.BundlesAdjacency.Nodes.Node.Bundles.Bundle.BundleInfo.SubInterface.LoadBalanceData>`
                            
                            

                            """

                            _prefix = 'bundlemgr-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(BundlesAdjacency.Nodes.Node.Bundles.Bundle.BundleInfo.SubInterface, self).__init__()

                                self.yang_name = "sub-interface"
                                self.yang_parent_name = "bundle-info"

                                self.interface_name = YLeaf(YType.str, "interface-name")

                                self.load_balance_data = BundlesAdjacency.Nodes.Node.Bundles.Bundle.BundleInfo.SubInterface.LoadBalanceData()
                                self.load_balance_data.parent = self
                                self._children_name_map["load_balance_data"] = "load-balance-data"
                                self._children_yang_names.add("load-balance-data")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("interface_name") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(BundlesAdjacency.Nodes.Node.Bundles.Bundle.BundleInfo.SubInterface, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(BundlesAdjacency.Nodes.Node.Bundles.Bundle.BundleInfo.SubInterface, self).__setattr__(name, value)


                            class LoadBalanceData(Entity):
                                """
                                Load balance data
                                
                                .. attribute:: local_link_threshold
                                
                                	Threshold below which rack\-local balancing is disabled
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: type
                                
                                	Type of load balancing to use
                                	**type**\:   :py:class:`LoadBalance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_oper.LoadBalance>`
                                
                                .. attribute:: value
                                
                                	Load balance hash value
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'bundlemgr-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(BundlesAdjacency.Nodes.Node.Bundles.Bundle.BundleInfo.SubInterface.LoadBalanceData, self).__init__()

                                    self.yang_name = "load-balance-data"
                                    self.yang_parent_name = "sub-interface"

                                    self.local_link_threshold = YLeaf(YType.uint32, "local-link-threshold")

                                    self.type = YLeaf(YType.enumeration, "type")

                                    self.value = YLeaf(YType.uint32, "value")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("local_link_threshold",
                                                    "type",
                                                    "value") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(BundlesAdjacency.Nodes.Node.Bundles.Bundle.BundleInfo.SubInterface.LoadBalanceData, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(BundlesAdjacency.Nodes.Node.Bundles.Bundle.BundleInfo.SubInterface.LoadBalanceData, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.local_link_threshold.is_set or
                                        self.type.is_set or
                                        self.value.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.local_link_threshold.yfilter != YFilter.not_set or
                                        self.type.yfilter != YFilter.not_set or
                                        self.value.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "load-balance-data" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.local_link_threshold.is_set or self.local_link_threshold.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_link_threshold.get_name_leafdata())
                                    if (self.type.is_set or self.type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.type.get_name_leafdata())
                                    if (self.value.is_set or self.value.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.value.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "local-link-threshold" or name == "type" or name == "value"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "local-link-threshold"):
                                        self.local_link_threshold = value
                                        self.local_link_threshold.value_namespace = name_space
                                        self.local_link_threshold.value_namespace_prefix = name_space_prefix
                                    if(value_path == "type"):
                                        self.type = value
                                        self.type.value_namespace = name_space
                                        self.type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "value"):
                                        self.value = value
                                        self.value.value_namespace = name_space
                                        self.value.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.interface_name.is_set or
                                    (self.load_balance_data is not None and self.load_balance_data.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.interface_name.yfilter != YFilter.not_set or
                                    (self.load_balance_data is not None and self.load_balance_data.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "sub-interface" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.interface_name.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "load-balance-data"):
                                    if (self.load_balance_data is None):
                                        self.load_balance_data = BundlesAdjacency.Nodes.Node.Bundles.Bundle.BundleInfo.SubInterface.LoadBalanceData()
                                        self.load_balance_data.parent = self
                                        self._children_name_map["load_balance_data"] = "load-balance-data"
                                    return self.load_balance_data

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "load-balance-data" or name == "interface-name"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "interface-name"):
                                    self.interface_name = value
                                    self.interface_name.value_namespace = name_space
                                    self.interface_name.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.member:
                                if (c.has_data()):
                                    return True
                            for c in self.sub_interface:
                                if (c.has_data()):
                                    return True
                            return (
                                self.avoid_rebalance.is_set or
                                self.max_member_count.is_set or
                                self.media.is_set or
                                (self.brief is not None and self.brief.has_data()) or
                                (self.load_balance_data is not None and self.load_balance_data.has_data()))

                        def has_operation(self):
                            for c in self.member:
                                if (c.has_operation()):
                                    return True
                            for c in self.sub_interface:
                                if (c.has_operation()):
                                    return True
                            return (
                                self.yfilter != YFilter.not_set or
                                self.avoid_rebalance.yfilter != YFilter.not_set or
                                self.max_member_count.yfilter != YFilter.not_set or
                                self.media.yfilter != YFilter.not_set or
                                (self.brief is not None and self.brief.has_operation()) or
                                (self.load_balance_data is not None and self.load_balance_data.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "bundle-info" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.avoid_rebalance.is_set or self.avoid_rebalance.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.avoid_rebalance.get_name_leafdata())
                            if (self.max_member_count.is_set or self.max_member_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.max_member_count.get_name_leafdata())
                            if (self.media.is_set or self.media.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.media.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "brief"):
                                if (self.brief is None):
                                    self.brief = BundlesAdjacency.Nodes.Node.Bundles.Bundle.BundleInfo.Brief()
                                    self.brief.parent = self
                                    self._children_name_map["brief"] = "brief"
                                return self.brief

                            if (child_yang_name == "load-balance-data"):
                                if (self.load_balance_data is None):
                                    self.load_balance_data = BundlesAdjacency.Nodes.Node.Bundles.Bundle.BundleInfo.LoadBalanceData()
                                    self.load_balance_data.parent = self
                                    self._children_name_map["load_balance_data"] = "load-balance-data"
                                return self.load_balance_data

                            if (child_yang_name == "member"):
                                for c in self.member:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = BundlesAdjacency.Nodes.Node.Bundles.Bundle.BundleInfo.Member()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.member.append(c)
                                return c

                            if (child_yang_name == "sub-interface"):
                                for c in self.sub_interface:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = BundlesAdjacency.Nodes.Node.Bundles.Bundle.BundleInfo.SubInterface()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.sub_interface.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "brief" or name == "load-balance-data" or name == "member" or name == "sub-interface" or name == "avoid-rebalance" or name == "max-member-count" or name == "media"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "avoid-rebalance"):
                                self.avoid_rebalance = value
                                self.avoid_rebalance.value_namespace = name_space
                                self.avoid_rebalance.value_namespace_prefix = name_space_prefix
                            if(value_path == "max-member-count"):
                                self.max_member_count = value
                                self.max_member_count.value_namespace = name_space
                                self.max_member_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "media"):
                                self.media = value
                                self.media.value_namespace = name_space
                                self.media.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.bundle_name.is_set or
                            (self.bundle_info is not None and self.bundle_info.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.bundle_name.yfilter != YFilter.not_set or
                            (self.bundle_info is not None and self.bundle_info.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "bundle" + "[bundle-name='" + self.bundle_name.get() + "']" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.bundle_name.is_set or self.bundle_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bundle_name.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "bundle-info"):
                            if (self.bundle_info is None):
                                self.bundle_info = BundlesAdjacency.Nodes.Node.Bundles.Bundle.BundleInfo()
                                self.bundle_info.parent = self
                                self._children_name_map["bundle_info"] = "bundle-info"
                            return self.bundle_info

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "bundle-info" or name == "bundle-name"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "bundle-name"):
                            self.bundle_name = value
                            self.bundle_name.value_namespace = name_space
                            self.bundle_name.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.bundle:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.bundle:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "bundles" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "bundle"):
                        for c in self.bundle:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = BundlesAdjacency.Nodes.Node.Bundles.Bundle()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.bundle.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "bundle"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass

            def has_data(self):
                return (
                    self.node_name.is_set or
                    (self.brief is not None and self.brief.has_data()) or
                    (self.bundles is not None and self.bundles.has_data()))

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    self.node_name.yfilter != YFilter.not_set or
                    (self.brief is not None and self.brief.has_operation()) or
                    (self.bundles is not None and self.bundles.has_operation()))

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "node" + "[node-name='" + self.node_name.get() + "']" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-bundlemgr-oper:bundles-adjacency/nodes/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()
                if (self.node_name.is_set or self.node_name.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.node_name.get_name_leafdata())

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "brief"):
                    if (self.brief is None):
                        self.brief = BundlesAdjacency.Nodes.Node.Brief()
                        self.brief.parent = self
                        self._children_name_map["brief"] = "brief"
                    return self.brief

                if (child_yang_name == "bundles"):
                    if (self.bundles is None):
                        self.bundles = BundlesAdjacency.Nodes.Node.Bundles()
                        self.bundles.parent = self
                        self._children_name_map["bundles"] = "bundles"
                    return self.bundles

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "brief" or name == "bundles" or name == "node-name"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                if(value_path == "node-name"):
                    self.node_name = value
                    self.node_name.value_namespace = name_space
                    self.node_name.value_namespace_prefix = name_space_prefix

        def has_data(self):
            for c in self.node:
                if (c.has_data()):
                    return True
            return False

        def has_operation(self):
            for c in self.node:
                if (c.has_operation()):
                    return True
            return self.yfilter != YFilter.not_set

        def get_segment_path(self):
            path_buffer = ""
            path_buffer = "nodes" + path_buffer

            return path_buffer

        def get_entity_path(self, ancestor):
            path_buffer = ""
            if (ancestor is None):
                path_buffer = "Cisco-IOS-XR-bundlemgr-oper:bundles-adjacency/%s" % self.get_segment_path()
            else:
                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

            leaf_name_data = LeafDataList()

            entity_path = EntityPath(path_buffer, leaf_name_data)
            return entity_path

        def get_child_by_name(self, child_yang_name, segment_path):
            child = self._get_child_by_seg_name([child_yang_name, segment_path])
            if child is not None:
                return child

            if (child_yang_name == "node"):
                for c in self.node:
                    segment = c.get_segment_path()
                    if (segment_path == segment):
                        return c
                c = BundlesAdjacency.Nodes.Node()
                c.parent = self
                local_reference_key = "ydk::seg::%s" % segment_path
                self._local_refs[local_reference_key] = c
                self.node.append(c)
                return c

            return None

        def has_leaf_or_child_of_name(self, name):
            if(name == "node"):
                return True
            return False

        def set_value(self, value_path, value, name_space, name_space_prefix):
            pass

    def has_data(self):
        return (self.nodes is not None and self.nodes.has_data())

    def has_operation(self):
        return (
            self.yfilter != YFilter.not_set or
            (self.nodes is not None and self.nodes.has_operation()))

    def get_segment_path(self):
        path_buffer = ""
        path_buffer = "Cisco-IOS-XR-bundlemgr-oper:bundles-adjacency" + path_buffer

        return path_buffer

    def get_entity_path(self, ancestor):
        path_buffer = ""
        if (not ancestor is None):
            raise YPYModelError("ancestor has to be None for top-level node")

        path_buffer = self.get_segment_path()
        leaf_name_data = LeafDataList()

        entity_path = EntityPath(path_buffer, leaf_name_data)
        return entity_path

    def get_child_by_name(self, child_yang_name, segment_path):
        child = self._get_child_by_seg_name([child_yang_name, segment_path])
        if child is not None:
            return child

        if (child_yang_name == "nodes"):
            if (self.nodes is None):
                self.nodes = BundlesAdjacency.Nodes()
                self.nodes.parent = self
                self._children_name_map["nodes"] = "nodes"
            return self.nodes

        return None

    def has_leaf_or_child_of_name(self, name):
        if(name == "nodes"):
            return True
        return False

    def set_value(self, value_path, value, name_space, name_space_prefix):
        pass

    def clone_ptr(self):
        self._top_entity = BundlesAdjacency()
        return self._top_entity

